/* SPEEDUP Path Integral Monte Carlo code is developed by A. Balaz,
   D. Stojiljkovic, I. Vidanovic, A. Belic, and A. Bogojevic.
         
   Address: Institute of Physics, Belgrade, Serbia
   Scientific Computing Laboratory, http://www.scl.rs/

   Public use and modification of this code is allowed providing 
   the authors are properly acknowledged. The authors would be   
   grateful for all information and/or comments regarding the use   
   of the code.  
*/

/* Example p.c file for the model-specific approach for the modified
   P\"oschl-Teller potential
                        V(x) = - c / cosh(a * x)^2
   Parameters: c = par[0], a = par[1], as entered on the command line.

   Maximal implemented level of the effective action is p = 10.
*/

/* Function func(q[]) returns exp(- action + norm), where the variable action is
   the action for the given path (q[0], q[step], ..., q[N]) plus the exponent of
   the Gaussian probability density function (*distrexp), and norm is the normalization
   (*norm) of the path integral (which also includes the normalization of Gaussians).
   Array *norm is defined in main(), array *distrexp in distr().
   The effective potential Wp() for every pair of points (q[i], q[i + step])
   is evaluated at the mid-point x.
*/

#include <p.h>

double func(double *q, double T, int s, int n)
{
   double Wp(void); /* The function that, for a given p, returns the effective potential. */

   int i; /* Loop variable for the loop over the time steps. */

   c = par[0]; /* Initialization of parameters of the potential and their powers. */
   c2 = c * c;
   c3 = c * c2;
   c4 = c * c3;
   c5 = c * c4;
   a = par[1];
   a2 = a * a;
   a4 = a2 * a2;
   a6 = a2 * a4;
   a8 = a2 * a6;
   a10 = a2 * a8;
   a12 = a * a10;
   a14 = a2 * a12;
   a16 = a2 * a14;
   a18 = a2 * a16;

   action = 0; /* Initialiation of the action. */
   Nmax = two[s]; /* The maximal number of time steps. */
   Nc = two[n]; /* The current number of time steps. */
   step = two[s - n]; /* Index distance of path nodes at current bisection level. */
   eps = T / Nc; /* Current time step and related variables, introduced for optimization. */
   epsinv = 1. / eps;
   eps2 = eps * eps;
   eps3 = eps * eps2;
   eps4 = eps * eps3;
   eps5 = eps * eps4;
   eps6 = eps * eps5;
   eps7 = eps * eps6;
   eps8 = eps * eps7;
   eps9 = eps * eps8;

   for(i = 0; i < Nmax; i += step) /* Loop over path nodes at current bisection level. */
   {
      x = (q[i + step] + q[i]) * 0.5; /* Mid-point for nearest nodes, tanh(a * x), sech(a * x) and powers. */
      tax = tanh(a * x);
      tax2 = tax * tax;
      tax4 = tax2 * tax2;
      tax6 = tax2 * tax4;
      tax8 = tax2 * tax6;
      tax10 = tax2 * tax8;
      tax12 = tax * tax10;
      tax14 = tax2 * tax12;
      tax16 = tax2 * tax14;
      tax18 = tax2 * tax16;
      scx = 1. / cosh(a * x);
      scx2 = scx * scx;
      scx4 = scx2 * scx2;
      scx6 = scx2 * scx4;
      scx8 = scx2 * scx6;
      scx10 = scx2 * scx8;
      scx12 = scx * scx10;
      scx14 = scx2 * scx12;
      scx16 = scx2 * scx14;
      scx18 = scx2 * scx16;
      scx20 = scx2 * scx18;

      xbar = (q[i + step] - q[i]) * 0.5; /* Half-distance between nearest nodes and its powers. */
      xbar2 = xbar * xbar; /* Square of xbar. */
      xbar4 = xbar2 * xbar2;
      xbar6 = xbar2 * xbar4;
      xbar8 = xbar2 * xbar6;
      xbar10 = xbar2 * xbar8;
      xbar12 = xbar2 * xbar10;
      xbar14 = xbar2 * xbar12;
      xbar16 = xbar2 * xbar14;
      xbar18 = xbar2 * xbar16;

      action += 2 * xbar2 * epsinv + eps * Wp() - distrexp[i]; /* Accumulation of the action minus
                                                                     the exponent of the Gaussian. */
   }

   return exp(- action + norm[n]); /* norm[n] includes the path integral norm for a
                                      given number of time steps 2^n and normalization of Gaussians
                                      used as probability density functions. */
}

/* For a chosen p, the function Vp() returns the value of the effective potential.
   This function uses the values of the potential and all its nonvanishing
   derivatives up to order 2p-2, defined in V0(), supplied by the user.

   V00 is the value of the potential, and Vnm (nm = 01, 02, ..., 34) are the
   derivatives of the potential. Additional variables Vnmk = (Vnm)^k and
   xbarn = xbar^n are introduced for optimization purposes.
*/


#ifdef p1
double Wp(void)
{
   return -1.*c*scx2;
}
#endif

#ifdef p2
double Wp(void)
{
   return -1.*c*scx2 + xbar2*
   (0.333333333333333333*a2*c*scx4 - 
     0.666666666666666667*a2*c*scx2*tax2) + eps*(0.166666666666666667*a2*c*scx4 - 
     0.333333333333333333*a2*c*scx2*tax2);
}
#endif

#ifdef p3
double Wp(void)
{
   return -1.*c*scx2 + xbar2*
   (0.333333333333333333*a2*c*scx4 - 
     0.666666666666666667*a2*c*scx2*tax2) + eps*(0.166666666666666667*a2*c*scx4 - 
     0.333333333333333333*a2*c*scx2*tax2) + eps*xbar2*(-0.133333333333333333*a4*c*
      scx6 + 0.733333333333333333*a4*c*
      scx4*tax2 - 
     0.133333333333333333*a4*c*scx2*tax4) + xbar4*(-0.133333333333333333*a4*c*scx6 + 
     0.733333333333333333*a4*c*scx4*
      tax2 - 0.133333333333333333*a4*c*
      scx2*tax4) + 
  eps2*(-0.0666666666666666667*a4*c*scx6 + 
     (0.366666666666666667*a4*c - 
        0.166666666666666667*a2*c2)*scx4*
      tax2 - 0.0666666666666666667*a4*c*
      scx2*tax4);
}
#endif

#ifdef p4
double Wp(void)
{
   return -1.*c*scx2 + xbar2*
   (0.333333333333333333*a2*c*scx4 - 
     0.666666666666666667*a2*c*scx2*tax2) + eps*(0.166666666666666667*a2*c*scx4 - 
     0.333333333333333333*a2*c*scx2*tax2) + eps*xbar2*(-0.133333333333333333*a4*c*
      scx6 + 0.733333333333333333*a4*c*
      scx4*tax2 - 
     0.133333333333333333*a4*c*scx2*tax4) + xbar4*(-0.133333333333333333*a4*c*scx6 + 
     0.733333333333333333*a4*c*scx4*
      tax2 - 0.133333333333333333*a4*c*
      scx2*tax4) + 
  eps2*(-0.0666666666666666667*a4*c*scx6 + 
     (0.366666666666666667*a4*c - 
        0.166666666666666667*a2*c2)*scx4*
      tax2 - 0.0666666666666666667*a4*c*
      scx2*tax4) + 
  eps*xbar4*(0.0809523809523809524*a6*c*
      scx8 - 0.857142857142857143*a6*c*
      scx6*tax2 + 
     0.542857142857142857*a6*c*scx4*
      tax4 - 0.0190476190476190476*a6*c*
      scx2*tax6) + 
  eps2*xbar2*((0.0809523809523809524*a6*c - 
        0.0111111111111111111*a4*c2)*scx8 + 
     (-0.857142857142857143*a6*c + 
        0.311111111111111111*a4*c2)*scx6*
      tax2 + (0.542857142857142857*a6*c - 
        0.177777777777777778*a4*c2)*scx4*
      tax4 - 0.0190476190476190476*a6*c*
      scx2*tax6) + 
  xbar6*(0.0539682539682539683*a6*c*scx8 - 
     0.571428571428571429*a6*c*scx6*
      tax2 + 0.361904761904761905*a6*c*
      scx4*tax4 - 
     0.0126984126984126984*a6*c*scx2*
      tax6) + eps3*
   ((0.0404761904761904762*a6*c - 
        0.0111111111111111111*a4*c2)*scx8 + 
     (-0.428571428571428571*a6*c + 
        0.311111111111111111*a4*c2)*scx6*
      tax2 + (0.271428571428571429*a6*c - 
        0.177777777777777778*a4*c2)*scx4*
      tax4 - 0.00952380952380952381*a6*c*
      scx2*tax6);
}
#endif

#ifdef p5
double Wp(void)
{
   return -1.*c*scx2 + xbar2*
   (0.333333333333333333*a2*c*scx4 - 
     0.666666666666666667*a2*c*scx2*tax2) + eps*(0.166666666666666667*a2*c*scx4 - 
     0.333333333333333333*a2*c*scx2*tax2) + eps*xbar2*(-0.133333333333333333*a4*c*
      scx6 + 0.733333333333333333*a4*c*
      scx4*tax2 - 
     0.133333333333333333*a4*c*scx2*tax4) + xbar4*(-0.133333333333333333*a4*c*scx6 + 
     0.733333333333333333*a4*c*scx4*
      tax2 - 0.133333333333333333*a4*c*
      scx2*tax4) + 
  eps2*(-0.0666666666666666667*a4*c*scx6 + 
     (0.366666666666666667*a4*c - 
        0.166666666666666667*a2*c2)*scx4*
      tax2 - 0.0666666666666666667*a4*c*
      scx2*tax4) + 
  eps*xbar4*(0.0809523809523809524*a6*c*
      scx8 - 0.857142857142857143*a6*c*
      scx6*tax2 + 
     0.542857142857142857*a6*c*scx4*
      tax4 - 0.0190476190476190476*a6*c*
      scx2*tax6) + 
  eps2*xbar2*((0.0809523809523809524*a6*c - 
        0.0111111111111111111*a4*c2)*scx8 + 
     (-0.857142857142857143*a6*c + 
        0.311111111111111111*a4*c2)*scx6*
      tax2 + (0.542857142857142857*a6*c - 
        0.177777777777777778*a4*c2)*scx4*
      tax4 - 0.0190476190476190476*a6*c*
      scx2*tax6) + 
  xbar6*(0.0539682539682539683*a6*c*scx8 - 
     0.571428571428571429*a6*c*scx6*
      tax2 + 0.361904761904761905*a6*c*
      scx4*tax4 - 
     0.0126984126984126984*a6*c*scx2*
      tax6) + eps3*
   ((0.0404761904761904762*a6*c - 
        0.0111111111111111111*a4*c2)*scx8 + 
     (-0.428571428571428571*a6*c + 
        0.311111111111111111*a4*c2)*scx6*
      tax2 + (0.271428571428571429*a6*c - 
        0.177777777777777778*a4*c2)*scx4*
      tax4 - 0.00952380952380952381*a6*c*
      scx2*tax6) + 
  eps3*xbar2*((-0.0656084656084656085*a8*c + 
        0.0253968253968253968*a6*c2)*scx10 + 
     (1.13439153439153439*a8*c - 
        0.768253968253968254*a6*c2)*scx8*
      tax2 + (-1.53650793650793651*a8*c + 
        1.05396825396825397*a6*c2)*scx6*
      tax4 + (0.261375661375661376*a8*c - 
        0.152380952380952381*a6*c2)*scx4*
      tax6 - 0.0021164021164021164*a8*c*
      scx2*tax8) + 
  eps2*xbar4*((-0.0656084656084656085*a8*c + 
        0.0126984126984126984*a6*c2)*scx10 + 
     (1.13439153439153439*a8*c - 
        0.384126984126984127*a6*c2)*scx8*
      tax2 + (-1.53650793650793651*a8*c + 
        0.526984126984126984*a6*c2)*scx6*
      tax4 + (0.261375661375661376*a8*c - 
        0.0761904761904761905*a6*c2)*scx4*
      tax6 - 0.0021164021164021164*a8*c*
      scx2*tax8) + 
  eps*xbar6*(-0.0437389770723104056*a8*c*
      scx10 + 0.756261022927689594*a8*c*
      scx8*tax2 - 
     1.02433862433862434*a8*c*scx6*
      tax4 + 0.174250440917107584*a8*c*
      scx4*tax6 - 
     0.0014109347442680776*a8*c*scx2*
      tax8) + eps4*
   ((-0.0328042328042328042*a8*c + 
        0.0190476190476190476*a6*c2)*scx10 + 
     (0.567195767195767196*a8*c - 
        0.531746031746031746*a6*c2 + 
        0.0333333333333333333*a4*c3)*scx8*
      tax2 + (-0.768253968253968254*a8*c + 
        0.746031746031746032*a6*c2 - 
        0.0666666666666666667*a4*c3)*scx6*
      tax4 + (0.130687830687830688*a8*c - 
        0.103174603174603175*a6*c2)*scx4*
      tax6 - 0.0010582010582010582*a8*c*
      scx2*tax8) + 
  xbar8*(-0.0218694885361552028*a8*c*scx10 + 
     0.378130511463844797*a8*c*scx8*
      tax2 - 0.512169312169312169*a8*c*
      scx6*tax4 + 
     0.0871252204585537919*a8*c*scx4*
      tax6 - 0.000705467372134038801*a8*c*
      scx2*tax8);
}
#endif

#ifdef p6
double Wp(void)
{
   return -1.*c*scx2 + xbar2*
   (0.333333333333333333*a2*c*scx4 - 
     0.666666666666666667*a2*c*scx2*tax2) + eps*(0.166666666666666667*a2*c*scx4 - 
     0.333333333333333333*a2*c*scx2*tax2) + eps*xbar2*(-0.133333333333333333*a4*c*
      scx6 + 0.733333333333333333*a4*c*
      scx4*tax2 - 
     0.133333333333333333*a4*c*scx2*tax4) + xbar4*(-0.133333333333333333*a4*c*scx6 + 
     0.733333333333333333*a4*c*scx4*
      tax2 - 0.133333333333333333*a4*c*
      scx2*tax4) + 
  eps2*(-0.0666666666666666667*a4*c*scx6 + 
     (0.366666666666666667*a4*c - 
        0.166666666666666667*a2*c2)*scx4*
      tax2 - 0.0666666666666666667*a4*c*
      scx2*tax4) + 
  eps*xbar4*(0.0809523809523809524*a6*c*
      scx8 - 0.857142857142857143*a6*c*
      scx6*tax2 + 
     0.542857142857142857*a6*c*scx4*
      tax4 - 0.0190476190476190476*a6*c*
      scx2*tax6) + 
  eps2*xbar2*((0.0809523809523809524*a6*c - 
        0.0111111111111111111*a4*c2)*scx8 + 
     (-0.857142857142857143*a6*c + 
        0.311111111111111111*a4*c2)*scx6*
      tax2 + (0.542857142857142857*a6*c - 
        0.177777777777777778*a4*c2)*scx4*
      tax4 - 0.0190476190476190476*a6*c*
      scx2*tax6) + 
  xbar6*(0.0539682539682539683*a6*c*scx8 - 
     0.571428571428571429*a6*c*scx6*
      tax2 + 0.361904761904761905*a6*c*
      scx4*tax4 - 
     0.0126984126984126984*a6*c*scx2*
      tax6) + eps3*
   ((0.0404761904761904762*a6*c - 
        0.0111111111111111111*a4*c2)*scx8 + 
     (-0.428571428571428571*a6*c + 
        0.311111111111111111*a4*c2)*scx6*
      tax2 + (0.271428571428571429*a6*c - 
        0.177777777777777778*a4*c2)*scx4*
      tax4 - 0.00952380952380952381*a6*c*
      scx2*tax6) + 
  eps3*xbar2*((-0.0656084656084656085*a8*c + 
        0.0253968253968253968*a6*c2)*scx10 + 
     (1.13439153439153439*a8*c - 
        0.768253968253968254*a6*c2)*scx8*
      tax2 + (-1.53650793650793651*a8*c + 
        1.05396825396825397*a6*c2)*scx6*
      tax4 + (0.261375661375661376*a8*c - 
        0.152380952380952381*a6*c2)*scx4*
      tax6 - 0.0021164021164021164*a8*c*
      scx2*tax8) + 
  eps2*xbar4*((-0.0656084656084656085*a8*c + 
        0.0126984126984126984*a6*c2)*scx10 + 
     (1.13439153439153439*a8*c - 
        0.384126984126984127*a6*c2)*scx8*
      tax2 + (-1.53650793650793651*a8*c + 
        0.526984126984126984*a6*c2)*scx6*
      tax4 + (0.261375661375661376*a8*c - 
        0.0761904761904761905*a6*c2)*scx4*
      tax6 - 0.0021164021164021164*a8*c*
      scx2*tax8) + 
  eps*xbar6*(-0.0437389770723104056*a8*c*
      scx10 + 0.756261022927689594*a8*c*
      scx8*tax2 - 
     1.02433862433862434*a8*c*scx6*
      tax4 + 0.174250440917107584*a8*c*
      scx4*tax6 - 
     0.0014109347442680776*a8*c*scx2*
      tax8) + eps4*
   ((-0.0328042328042328042*a8*c + 
        0.0190476190476190476*a6*c2)*scx10 + 
     (0.567195767195767196*a8*c - 
        0.531746031746031746*a6*c2 + 
        0.0333333333333333333*a4*c3)*scx8*
      tax2 + (-0.768253968253968254*a8*c + 
        0.746031746031746032*a6*c2 - 
        0.0666666666666666667*a4*c3)*scx6*
      tax4 + (0.130687830687830688*a8*c - 
        0.103174603174603175*a6*c2)*scx4*
      tax6 - 0.0010582010582010582*a8*c*
      scx2*tax8) + 
  xbar8*(-0.0218694885361552028*a8*c*scx10 + 
     0.378130511463844797*a8*c*scx8*
      tax2 - 0.512169312169312169*a8*c*
      scx6*tax4 + 
     0.0871252204585537919*a8*c*scx4*
      tax6 - 0.000705467372134038801*a8*c*
      scx2*tax8) + 
  eps4*xbar2*((0.0664742664742664743*a10*c - 
        0.0434920634920634921*a8*c2 + 
        0.000529100529100529101*a6*c3)*scx12
+ (-1.70254930254930255*a10*c + 
        1.56253968253968254*a8*c2 - 
        0.0984126984126984127*a6*c3)*scx10*
      tax2 + (3.99331409331409331*a10*c - 
        3.8180952380952381*a8*c2 + 
        0.301587301587301587*a6*c3)*scx8*
      tax4 + (-1.64001924001924002*a10*c + 
        1.50222222222222222*a8*c2 - 
        0.0994708994708994709*a6*c3)*scx6*
      tax6 + (0.0974506974506974507*a10*c - 
        0.0736507936507936508*a8*c2)*scx4*
      tax8 - 0.0001924001924001924*a10*c*
      scx2*tax10) + 
  eps3*xbar4*((0.0664742664742664743*a10*c - 
        0.0298412698412698413*a8*c2)*scx12 + 
     (-1.70254930254930255*a10*c + 
        1.12296296296296296*a8*c2)*scx10*
      tax2 + (3.99331409331409331*a10*c - 
        2.71873015873015873*a8*c2)*scx8*
      tax4 + (-1.64001924001924002*a10*c + 
        1.07428571428571429*a8*c2)*scx6*
      tax6 + (0.0974506974506974507*a10*c - 
        0.0541798941798941799*a8*c2)*scx4*
      tax8 - 0.0001924001924001924*a10*c*
      scx2*tax10) + 
  eps2*xbar6*((0.0443161776495109828*a10*c - 
        0.00994708994708994709*a8*c2)*scx12 + 
     (-1.1350328683662017*a10*c + 
        0.374320987654320988*a8*c2)*scx10*
      tax2 + (2.66220939554272888*a10*c - 
        0.906243386243386243*a8*c2)*scx8*
      tax4 + (-1.09334616001282668*a10*c + 
        0.358095238095238095*a8*c2)*scx6*
      tax6 + (0.0649671316337983005*a10*c - 
        0.0180599647266313933*a8*c2)*scx4*
      tax8 - 0.0001282667949334616*a10*c*
      scx2*tax10) + 
  eps5*((0.0332371332371332371*a10*c - 
        0.0279365079365079365*a8*c2 + 
        0.0014109347442680776*a6*c3)*scx12 + 
     (-0.851274651274651275*a10*c + 
        0.940105820105820106*a8*c2 - 
        0.129100529100529101*a6*c3)*scx10*
      tax2 + (1.99665704665704666*a10*c - 
        2.32873015873015873*a8*c2 + 
        0.404232804232804233*a6*c3)*scx8*
      tax4 + (-0.82000962000962001*a10*c + 
        0.910476190476190476*a8*c2 - 
        0.131922398589065256*a6*c3)*scx6*
      tax6 + (0.0487253487253487253*a10*c - 
        0.0427513227513227513*a8*c2)*scx4*
      tax8 - 0.0000962000962000962001*a10*c*
      scx2*tax10) + 
  eps*xbar8*(0.0221580888247554914*a10*c*
      scx12 - 0.56751643418310085*a10*c*
      scx10*tax2 + 
     1.33110469777136444*a10*c*scx8*
      tax4 - 0.54667308000641334*a10*c*
      scx6*tax6 + 
     0.0324835658168991502*a10*c*scx4*
      tax8 - 0.0000641333974667308001*a10*c*
      scx2*tax10) + 
  xbar10*(0.00886323552990219657*a10*c*scx12 - 
     0.22700657367324034*a10*c*scx10*
      tax2 + 0.532441879108545775*a10*c*
      scx8*tax4 - 
     0.218669232002565336*a10*c*scx6*
      tax6 + 0.0129934263267596601*a10*c*
      scx4*tax8 - 
     0.00002565335898669232*a10*c*scx2*
      tax10);
}
#endif

#ifdef p7
double Wp(void)
{
   return -1.*c*scx2 + xbar2*
   (0.333333333333333333*a2*c*scx4 - 
     0.666666666666666667*a2*c*scx2*tax2) + eps*(0.166666666666666667*a2*c*scx4 - 
     0.333333333333333333*a2*c*scx2*tax2) + eps*xbar2*(-0.133333333333333333*a4*c*
      scx6 + 0.733333333333333333*a4*c*
      scx4*tax2 - 
     0.133333333333333333*a4*c*scx2*tax4) + xbar4*(-0.133333333333333333*a4*c*scx6 + 
     0.733333333333333333*a4*c*scx4*
      tax2 - 0.133333333333333333*a4*c*
      scx2*tax4) + 
  eps2*(-0.0666666666666666667*a4*c*scx6 + 
     (0.366666666666666667*a4*c - 
        0.166666666666666667*a2*c2)*scx4*
      tax2 - 0.0666666666666666667*a4*c*
      scx2*tax4) + 
  eps*xbar4*(0.0809523809523809524*a6*c*
      scx8 - 0.857142857142857143*a6*c*
      scx6*tax2 + 
     0.542857142857142857*a6*c*scx4*
      tax4 - 0.0190476190476190476*a6*c*
      scx2*tax6) + 
  eps2*xbar2*((0.0809523809523809524*a6*c - 
        0.0111111111111111111*a4*c2)*scx8 + 
     (-0.857142857142857143*a6*c + 
        0.311111111111111111*a4*c2)*scx6*
      tax2 + (0.542857142857142857*a6*c - 
        0.177777777777777778*a4*c2)*scx4*
      tax4 - 0.0190476190476190476*a6*c*
      scx2*tax6) + 
  xbar6*(0.0539682539682539683*a6*c*scx8 - 
     0.571428571428571429*a6*c*scx6*
      tax2 + 0.361904761904761905*a6*c*
      scx4*tax4 - 
     0.0126984126984126984*a6*c*scx2*
      tax6) + eps3*
   ((0.0404761904761904762*a6*c - 
        0.0111111111111111111*a4*c2)*scx8 + 
     (-0.428571428571428571*a6*c + 
        0.311111111111111111*a4*c2)*scx6*
      tax2 + (0.271428571428571429*a6*c - 
        0.177777777777777778*a4*c2)*scx4*
      tax4 - 0.00952380952380952381*a6*c*
      scx2*tax6) + 
  eps3*xbar2*((-0.0656084656084656085*a8*c + 
        0.0253968253968253968*a6*c2)*scx10 + 
     (1.13439153439153439*a8*c - 
        0.768253968253968254*a6*c2)*scx8*
      tax2 + (-1.53650793650793651*a8*c + 
        1.05396825396825397*a6*c2)*scx6*
      tax4 + (0.261375661375661376*a8*c - 
        0.152380952380952381*a6*c2)*scx4*
      tax6 - 0.0021164021164021164*a8*c*
      scx2*tax8) + 
  eps2*xbar4*((-0.0656084656084656085*a8*c + 
        0.0126984126984126984*a6*c2)*scx10 + 
     (1.13439153439153439*a8*c - 
        0.384126984126984127*a6*c2)*scx8*
      tax2 + (-1.53650793650793651*a8*c + 
        0.526984126984126984*a6*c2)*scx6*
      tax4 + (0.261375661375661376*a8*c - 
        0.0761904761904761905*a6*c2)*scx4*
      tax6 - 0.0021164021164021164*a8*c*
      scx2*tax8) + 
  eps*xbar6*(-0.0437389770723104056*a8*c*
      scx10 + 0.756261022927689594*a8*c*
      scx8*tax2 - 
     1.02433862433862434*a8*c*scx6*
      tax4 + 0.174250440917107584*a8*c*
      scx4*tax6 - 
     0.0014109347442680776*a8*c*scx2*
      tax8) + eps4*
   ((-0.0328042328042328042*a8*c + 
        0.0190476190476190476*a6*c2)*scx10 + 
     (0.567195767195767196*a8*c - 
        0.531746031746031746*a6*c2 + 
        0.0333333333333333333*a4*c3)*scx8*
      tax2 + (-0.768253968253968254*a8*c + 
        0.746031746031746032*a6*c2 - 
        0.0666666666666666667*a4*c3)*scx6*
      tax4 + (0.130687830687830688*a8*c - 
        0.103174603174603175*a6*c2)*scx4*
      tax6 - 0.0010582010582010582*a8*c*
      scx2*tax8) + 
  xbar8*(-0.0218694885361552028*a8*c*scx10 + 
     0.378130511463844797*a8*c*scx8*
      tax2 - 0.512169312169312169*a8*c*
      scx6*tax4 + 
     0.0871252204585537919*a8*c*scx4*
      tax6 - 0.000705467372134038801*a8*c*
      scx2*tax8) + 
  eps4*xbar2*((0.0664742664742664743*a10*c - 
        0.0434920634920634921*a8*c2 + 
        0.000529100529100529101*a6*c3)*scx12
+ (-1.70254930254930255*a10*c + 
        1.56253968253968254*a8*c2 - 
        0.0984126984126984127*a6*c3)*scx10*
      tax2 + (3.99331409331409331*a10*c - 
        3.8180952380952381*a8*c2 + 
        0.301587301587301587*a6*c3)*scx8*
      tax4 + (-1.64001924001924002*a10*c + 
        1.50222222222222222*a8*c2 - 
        0.0994708994708994709*a6*c3)*scx6*
      tax6 + (0.0974506974506974507*a10*c - 
        0.0736507936507936508*a8*c2)*scx4*
      tax8 - 0.0001924001924001924*a10*c*
      scx2*tax10) + 
  eps3*xbar4*((0.0664742664742664743*a10*c - 
        0.0298412698412698413*a8*c2)*scx12 + 
     (-1.70254930254930255*a10*c + 
        1.12296296296296296*a8*c2)*scx10*
      tax2 + (3.99331409331409331*a10*c - 
        2.71873015873015873*a8*c2)*scx8*
      tax4 + (-1.64001924001924002*a10*c + 
        1.07428571428571429*a8*c2)*scx6*
      tax6 + (0.0974506974506974507*a10*c - 
        0.0541798941798941799*a8*c2)*scx4*
      tax8 - 0.0001924001924001924*a10*c*
      scx2*tax10) + 
  eps2*xbar6*((0.0443161776495109828*a10*c - 
        0.00994708994708994709*a8*c2)*scx12 + 
     (-1.1350328683662017*a10*c + 
        0.374320987654320988*a8*c2)*scx10*
      tax2 + (2.66220939554272888*a10*c - 
        0.906243386243386243*a8*c2)*scx8*
      tax4 + (-1.09334616001282668*a10*c + 
        0.358095238095238095*a8*c2)*scx6*
      tax6 + (0.0649671316337983005*a10*c - 
        0.0180599647266313933*a8*c2)*scx4*
      tax8 - 0.0001282667949334616*a10*c*
      scx2*tax10) + 
  eps5*((0.0332371332371332371*a10*c - 
        0.0279365079365079365*a8*c2 + 
        0.0014109347442680776*a6*c3)*scx12 + 
     (-0.851274651274651275*a10*c + 
        0.940105820105820106*a8*c2 - 
        0.129100529100529101*a6*c3)*scx10*
      tax2 + (1.99665704665704666*a10*c - 
        2.32873015873015873*a8*c2 + 
        0.404232804232804233*a6*c3)*scx8*
      tax4 + (-0.82000962000962001*a10*c + 
        0.910476190476190476*a8*c2 - 
        0.131922398589065256*a6*c3)*scx6*
      tax6 + (0.0487253487253487253*a10*c - 
        0.0427513227513227513*a8*c2)*scx4*
      tax8 - 0.0000962000962000962001*a10*c*
      scx2*tax10) + 
  eps*xbar8*(0.0221580888247554914*a10*c*
      scx12 - 0.56751643418310085*a10*c*
      scx10*tax2 + 
     1.33110469777136444*a10*c*scx8*
      tax4 - 0.54667308000641334*a10*c*
      scx6*tax6 + 
     0.0324835658168991502*a10*c*scx4*
      tax8 - 0.0000641333974667308001*a10*c*
      scx2*tax10) + 
  xbar10*(0.00886323552990219657*a10*c*
      scx12 - 0.22700657367324034*a10*c*
      scx10*tax2 + 
     0.532441879108545775*a10*c*scx8*
      tax4 - 0.218669232002565336*a10*c*
      scx6*tax6 + 
     0.0129934263267596601*a10*c*scx4*
      tax8 - 0.00002565335898669232*a10*c*
      scx2*tax10) + 
  eps5*xbar2*((-0.0808228808228808229*a12*c + 
        0.0717139650472983806*a10*c2 - 
        0.00465608465608465608*a8*c3)*scx14 + 
     (2.87364857364857365*a12*c - 
        3.15666827000160333*a10*c2 + 
        0.436402116402116402*a8*c3)*scx12*
      tax2 + (-10.3638583638583639*a12*c + 
        11.9069809203142536*a10*c2 - 
        1.95174603174603175*a8*c3)*scx10*
      tax4 + (7.85828985828985829*a12*c - 
        8.95524130190796857*a10*c2 + 
        1.43534391534391534*a8*c3)*scx8*
      tax6 + (-1.29315129315129315*a12*c + 
        1.38333172999839667*a10*c2 - 
        0.171851851851851852*a8*c3)*scx6*
      tax8 + (0.0302142302142302142*a12*c - 
        0.0260638127304793971*a10*c2)*scx4*
      tax10 - 0.0000148000148000148*a12*c*
      scx2*tax12) + 
  eps4*xbar4*((-0.0808228808228808229*a12*c + 
        0.0567837101170434504*a10*c2 - 
        0.00126984126984126984*a8*c3)*scx14 + 
     (2.87364857364857365*a12*c - 
        2.61428250761584095*a10*c2 + 
        0.164761904761904762*a8*c3)*scx12*
      tax2 + (-10.3638583638583639*a12*c + 
        9.79408048741382075*a10*c2 - 
        0.731428571428571429*a8*c3)*scx10*
      tax4 + (7.85828985828985829*a12*c - 
        7.36422639089305756*a10*c2 + 
        0.537777777777777778*a8*c3)*scx8*
      tax6 + (-1.29315129315129315*a12*c + 
        1.14825717492384159*a10*c2 - 
        0.0647619047619047619*a8*c3)*scx6*
      tax8 + (0.0302142302142302142*a12*c - 
        0.0223697290363957031*a10*c2)*scx4*
      tax10 - 0.0000148000148000148*a12*c*
      scx2*tax12) + 
  eps3*xbar6*((-0.0538819205485872153*a12*c + 
        0.0263032440810218588*a10*c2)*scx14 + 
     (1.91576571576571577*a12*c - 
        1.24964780075891187*a10*c2)*scx12*
      tax2 + (-6.90923890923890924*a12*c + 
        4.66006947784725563*a10*c2)*scx10*
      tax4 + (5.23885990552657219*a12*c - 
        3.50331676553898776*a10*c2)*scx8*
      tax6 + (-0.862100862100862101*a12*c + 
        0.549717278606167495*a10*c2)*scx6*
      tax8 + (0.0201428201428201428*a12*c - 
        0.0109454331676553899*a10*c2)*scx4*
      tax10 - 9.86667653334320001e-6*a12*c*
      scx2*tax12) + 
  eps6*((-0.0404114404114404114*a12*c + 
        0.0421228154561487895*a10*c2 - 
        0.00507936507936507937*a8*c3)*scx14 + 
     (1.43682428682428682*a12*c - 
        1.77375100208433542*a10*c2 + 
        0.367248677248677249*a8*c3 - 
        0.00674603174603174603*a6*c4)*scx12*
      tax2 + (-5.18192918192918193*a12*c + 
        6.73456148789482123*a10*c2 - 
        1.6526984126984127*a8*c3 + 
        0.0460317460317460317*a6*c4)*scx10*
      tax4 + (3.92914492914492914*a12*c - 
        5.07305755972422639*a10*c2 + 
        1.2273015873015873*a8*c3 - 
        0.0365079365079365079*a6*c4)*scx8*
      tax6 + (-0.646575646575646576*a12*c + 
        0.773153759820426487*a10*c2 - 
        0.140529100529100529*a8*c3)*scx6*
      tax8 + (0.0151071151071151071*a12*c - 
        0.014067660734327401*a10*c2)*scx4*
      tax10 - 7.40000740000740001e-6*a12*c*
      scx2*tax12) + 
  eps2*xbar8*((-0.0269409602742936076*a12*c + 
        0.0065758110202554647*a10*c2)*scx14 + 
     (0.957882857882857883*a12*c - 
        0.312411950189727968*a10*c2)*scx12*
      tax2 + (-3.45461945461945462*a12*c + 
        1.16501736946181391*a10*c2)*scx10*
      tax4 + (2.6194299527632861*a12*c - 
        0.87582919138474694*a10*c2)*scx8*
      tax6 + (-0.43105043105043105*a12*c + 
        0.137429319651541874*a10*c2)*scx6*
      tax8 + (0.0100714100714100714*a12*c - 
        0.00273635829191384747*a10*c2)*scx4*
      tax10 - 4.9333382666716e-6*a12*c*
      scx2*tax12) + 
  eps*xbar10*(-0.0107763841097174431*a12*c*
      scx14 + 0.383153143153143153*a12*c*
      scx12*tax2 - 
     1.38184778184778185*a12*c*scx10*
      tax4 + 1.04777198110531444*a12*c*
      scx8*tax6 - 
     0.17242017242017242*a12*c*scx6*
      tax8 + 0.00402856402856402856*a12*c*
      scx4*tax10 - 
     1.97333530666864e-6*a12*c*scx2*
      tax12) + xbar12*
   (-0.00359212803657248102*a12*c*scx14 + 
     0.127717714384381051*a12*c*scx12*
      tax2 - 0.460615927282593949*a12*c*
      scx10*tax4 + 
     0.349257327035104813*a12*c*scx8*
      tax6 - 0.0574733908067241401*a12*c*
      scx6*tax8 + 
     0.00134285467618800952*a12*c*scx4*
      tax10 - 6.57778435556213334e-7*a12*c*
      scx2*tax12);
}
#endif

#ifdef p8
double Wp(void)
{
   return -1.*c*scx2 + xbar2*
   (0.333333333333333333*a2*c*scx4 - 
     0.666666666666666667*a2*c*scx2*tax2) + eps*(0.166666666666666667*a2*c*scx4 - 
     0.333333333333333333*a2*c*scx2*tax2) + eps*xbar2*(-0.133333333333333333*a4*c*
      scx6 + 0.733333333333333333*a4*c*
      scx4*tax2 - 
     0.133333333333333333*a4*c*scx2*tax4) + xbar4*(-0.133333333333333333*a4*c*scx6 + 
     0.733333333333333333*a4*c*scx4*
      tax2 - 0.133333333333333333*a4*c*
      scx2*tax4) + 
  eps2*(-0.0666666666666666667*a4*c*scx6 + 
     (0.366666666666666667*a4*c - 
        0.166666666666666667*a2*c2)*scx4*
      tax2 - 0.0666666666666666667*a4*c*
      scx2*tax4) + 
  eps*xbar4*(0.0809523809523809524*a6*c*
      scx8 - 0.857142857142857143*a6*c*
      scx6*tax2 + 
     0.542857142857142857*a6*c*scx4*
      tax4 - 0.0190476190476190476*a6*c*
      scx2*tax6) + 
  eps2*xbar2*((0.0809523809523809524*a6*c - 
        0.0111111111111111111*a4*c2)*scx8 + 
     (-0.857142857142857143*a6*c + 
        0.311111111111111111*a4*c2)*scx6*
      tax2 + (0.542857142857142857*a6*c - 
        0.177777777777777778*a4*c2)*scx4*
      tax4 - 0.0190476190476190476*a6*c*
      scx2*tax6) + 
  xbar6*(0.0539682539682539683*a6*c*scx8 - 
     0.571428571428571429*a6*c*scx6*
      tax2 + 0.361904761904761905*a6*c*
      scx4*tax4 - 
     0.0126984126984126984*a6*c*scx2*
      tax6) + eps3*
   ((0.0404761904761904762*a6*c - 
        0.0111111111111111111*a4*c2)*scx8 + 
     (-0.428571428571428571*a6*c + 
        0.311111111111111111*a4*c2)*scx6*
      tax2 + (0.271428571428571429*a6*c - 
        0.177777777777777778*a4*c2)*scx4*
      tax4 - 0.00952380952380952381*a6*c*
      scx2*tax6) + 
  eps3*xbar2*((-0.0656084656084656085*a8*c + 
        0.0253968253968253968*a6*c2)*scx10 + 
     (1.13439153439153439*a8*c - 
        0.768253968253968254*a6*c2)*scx8*
      tax2 + (-1.53650793650793651*a8*c + 
        1.05396825396825397*a6*c2)*scx6*
      tax4 + (0.261375661375661376*a8*c - 
        0.152380952380952381*a6*c2)*scx4*
      tax6 - 0.0021164021164021164*a8*c*
      scx2*tax8) + 
  eps2*xbar4*((-0.0656084656084656085*a8*c + 
        0.0126984126984126984*a6*c2)*scx10 + 
     (1.13439153439153439*a8*c - 
        0.384126984126984127*a6*c2)*scx8*
      tax2 + (-1.53650793650793651*a8*c + 
        0.526984126984126984*a6*c2)*scx6*
      tax4 + (0.261375661375661376*a8*c - 
        0.0761904761904761905*a6*c2)*scx4*
      tax6 - 0.0021164021164021164*a8*c*
      scx2*tax8) + 
  eps*xbar6*(-0.0437389770723104056*a8*c*
      scx10 + 0.756261022927689594*a8*c*
      scx8*tax2 - 
     1.02433862433862434*a8*c*scx6*
      tax4 + 0.174250440917107584*a8*c*
      scx4*tax6 - 
     0.0014109347442680776*a8*c*scx2*
      tax8) + eps4*
   ((-0.0328042328042328042*a8*c + 
        0.0190476190476190476*a6*c2)*scx10 + 
     (0.567195767195767196*a8*c - 
        0.531746031746031746*a6*c2 + 
        0.0333333333333333333*a4*c3)*scx8*
      tax2 + (-0.768253968253968254*a8*c + 
        0.746031746031746032*a6*c2 - 
        0.0666666666666666667*a4*c3)*scx6*
      tax4 + (0.130687830687830688*a8*c - 
        0.103174603174603175*a6*c2)*scx4*
      tax6 - 0.0010582010582010582*a8*c*
      scx2*tax8) + 
  xbar8*(-0.0218694885361552028*a8*c*scx10 + 
     0.378130511463844797*a8*c*scx8*
      tax2 - 0.512169312169312169*a8*c*
      scx6*tax4 + 
     0.0871252204585537919*a8*c*scx4*
      tax6 - 0.000705467372134038801*a8*c*
      scx2*tax8) + 
  eps4*xbar2*((0.0664742664742664743*a10*c - 
        0.0434920634920634921*a8*c2 + 
        0.000529100529100529101*a6*c3)*scx12
+ (-1.70254930254930255*a10*c + 
        1.56253968253968254*a8*c2 - 
        0.0984126984126984127*a6*c3)*scx10*
      tax2 + (3.99331409331409331*a10*c - 
        3.8180952380952381*a8*c2 + 
        0.301587301587301587*a6*c3)*scx8*
      tax4 + (-1.64001924001924002*a10*c + 
        1.50222222222222222*a8*c2 - 
        0.0994708994708994709*a6*c3)*scx6*
      tax6 + (0.0974506974506974507*a10*c - 
        0.0736507936507936508*a8*c2)*scx4*
      tax8 - 0.0001924001924001924*a10*c*
      scx2*tax10) + 
  eps3*xbar4*((0.0664742664742664743*a10*c - 
        0.0298412698412698413*a8*c2)*scx12 + 
     (-1.70254930254930255*a10*c + 
        1.12296296296296296*a8*c2)*scx10*
      tax2 + (3.99331409331409331*a10*c - 
        2.71873015873015873*a8*c2)*scx8*
      tax4 + (-1.64001924001924002*a10*c + 
        1.07428571428571429*a8*c2)*scx6*
      tax6 + (0.0974506974506974507*a10*c - 
        0.0541798941798941799*a8*c2)*scx4*
      tax8 - 0.0001924001924001924*a10*c*
      scx2*tax10) + 
  eps2*xbar6*((0.0443161776495109828*a10*c - 
        0.00994708994708994709*a8*c2)*scx12 + 
     (-1.1350328683662017*a10*c + 
        0.374320987654320988*a8*c2)*scx10*
      tax2 + (2.66220939554272888*a10*c - 
        0.906243386243386243*a8*c2)*scx8*
      tax4 + (-1.09334616001282668*a10*c + 
        0.358095238095238095*a8*c2)*scx6*
      tax6 + (0.0649671316337983005*a10*c - 
        0.0180599647266313933*a8*c2)*scx4*
      tax8 - 0.0001282667949334616*a10*c*
      scx2*tax10) + 
  eps5*((0.0332371332371332371*a10*c - 
        0.0279365079365079365*a8*c2 + 
        0.0014109347442680776*a6*c3)*scx12 + 
     (-0.851274651274651275*a10*c + 
        0.940105820105820106*a8*c2 - 
        0.129100529100529101*a6*c3)*scx10*
      tax2 + (1.99665704665704666*a10*c - 
        2.32873015873015873*a8*c2 + 
        0.404232804232804233*a6*c3)*scx8*
      tax4 + (-0.82000962000962001*a10*c + 
        0.910476190476190476*a8*c2 - 
        0.131922398589065256*a6*c3)*scx6*
      tax6 + (0.0487253487253487253*a10*c - 
        0.0427513227513227513*a8*c2)*scx4*
      tax8 - 0.0000962000962000962001*a10*c*
      scx2*tax10) + 
  eps*xbar8*(0.0221580888247554914*a10*c*
      scx12 - 0.56751643418310085*a10*c*
      scx10*tax2 + 
     1.33110469777136444*a10*c*scx8*
      tax4 - 0.54667308000641334*a10*c*
      scx6*tax6 + 
     0.0324835658168991502*a10*c*scx4*
      tax8 - 0.0000641333974667308001*a10*c*
      scx2*tax10) + 
  xbar10*(0.00886323552990219657*a10*c*
      scx12 - 0.22700657367324034*a10*c*
      scx10*tax2 + 
     0.532441879108545775*a10*c*scx8*
      tax4 - 0.218669232002565336*a10*c*
      scx6*tax6 + 
     0.0129934263267596601*a10*c*scx4*
      tax8 - 0.00002565335898669232*a10*c*
      scx2*tax10) + 
  eps5*xbar2*((-0.0808228808228808229*a12*c + 
        0.0717139650472983806*a10*c2 - 
        0.00465608465608465608*a8*c3)*scx14 + 
     (2.87364857364857365*a12*c - 
        3.15666827000160333*a10*c2 + 
        0.436402116402116402*a8*c3)*scx12*
      tax2 + (-10.3638583638583639*a12*c + 
        11.9069809203142536*a10*c2 - 
        1.95174603174603175*a8*c3)*scx10*
      tax4 + (7.85828985828985829*a12*c - 
        8.95524130190796857*a10*c2 + 
        1.43534391534391534*a8*c3)*scx8*
      tax6 + (-1.29315129315129315*a12*c + 
        1.38333172999839667*a10*c2 - 
        0.171851851851851852*a8*c3)*scx6*
      tax8 + (0.0302142302142302142*a12*c - 
        0.0260638127304793971*a10*c2)*scx4*
      tax10 - 0.0000148000148000148*a12*c*
      scx2*tax12) + 
  eps4*xbar4*((-0.0808228808228808229*a12*c + 
        0.0567837101170434504*a10*c2 - 
        0.00126984126984126984*a8*c3)*scx14 + 
     (2.87364857364857365*a12*c - 
        2.61428250761584095*a10*c2 + 
        0.164761904761904762*a8*c3)*scx12*
      tax2 + (-10.3638583638583639*a12*c + 
        9.79408048741382075*a10*c2 - 
        0.731428571428571429*a8*c3)*scx10*
      tax4 + (7.85828985828985829*a12*c - 
        7.36422639089305756*a10*c2 + 
        0.537777777777777778*a8*c3)*scx8*
      tax6 + (-1.29315129315129315*a12*c + 
        1.14825717492384159*a10*c2 - 
        0.0647619047619047619*a8*c3)*scx6*
      tax8 + (0.0302142302142302142*a12*c - 
        0.0223697290363957031*a10*c2)*scx4*
      tax10 - 0.0000148000148000148*a12*c*
      scx2*tax12) + 
  eps3*xbar6*((-0.0538819205485872153*a12*c + 
        0.0263032440810218588*a10*c2)*scx14 + 
     (1.91576571576571577*a12*c - 
        1.24964780075891187*a10*c2)*scx12*
      tax2 + (-6.90923890923890924*a12*c + 
        4.66006947784725563*a10*c2)*scx10*
      tax4 + (5.23885990552657219*a12*c - 
        3.50331676553898776*a10*c2)*scx8*
      tax6 + (-0.862100862100862101*a12*c + 
        0.549717278606167495*a10*c2)*scx6*
      tax8 + (0.0201428201428201428*a12*c - 
        0.0109454331676553899*a10*c2)*scx4*
      tax10 - 9.86667653334320001e-6*a12*c*
      scx2*tax12) + 
  eps6*((-0.0404114404114404114*a12*c + 
        0.0421228154561487895*a10*c2 - 
        0.00507936507936507937*a8*c3)*scx14 + 
     (1.43682428682428682*a12*c - 
        1.77375100208433542*a10*c2 + 
        0.367248677248677249*a8*c3 - 
        0.00674603174603174603*a6*c4)*scx12*
      tax2 + (-5.18192918192918193*a12*c + 
        6.73456148789482123*a10*c2 - 
        1.6526984126984127*a8*c3 + 
        0.0460317460317460317*a6*c4)*scx10*
      tax4 + (3.92914492914492914*a12*c - 
        5.07305755972422639*a10*c2 + 
        1.2273015873015873*a8*c3 - 
        0.0365079365079365079*a6*c4)*scx8*
      tax6 + (-0.646575646575646576*a12*c + 
        0.773153759820426487*a10*c2 - 
        0.140529100529100529*a8*c3)*scx6*
      tax8 + (0.0151071151071151071*a12*c - 
        0.014067660734327401*a10*c2)*scx4*
      tax10 - 7.40000740000740001e-6*a12*c*
      scx2*tax12) + 
  eps2*xbar8*((-0.0269409602742936076*a12*c + 
        0.0065758110202554647*a10*c2)*scx14 + 
     (0.957882857882857883*a12*c - 
        0.312411950189727968*a10*c2)*scx12*
      tax2 + (-3.45461945461945462*a12*c + 
        1.16501736946181391*a10*c2)*scx10*
      tax4 + (2.6194299527632861*a12*c - 
        0.87582919138474694*a10*c2)*scx8*
      tax6 + (-0.43105043105043105*a12*c + 
        0.137429319651541874*a10*c2)*scx6*
      tax8 + (0.0100714100714100714*a12*c - 
        0.00273635829191384747*a10*c2)*scx4*
      tax10 - 4.9333382666716e-6*a12*c*
      scx2*tax12) + 
  eps*xbar10*(-0.0107763841097174431*a12*c*
      scx14 + 0.383153143153143153*a12*c*
      scx12*tax2 - 
     1.38184778184778185*a12*c*scx10*
      tax4 + 1.04777198110531444*a12*c*
      scx8*tax6 - 
     0.17242017242017242*a12*c*scx6*
      tax8 + 0.00402856402856402856*a12*c*
      scx4*tax10 - 
     1.97333530666864e-6*a12*c*scx2*
      tax12) + xbar12*
   (-0.00359212803657248102*a12*c*scx14 + 
     0.127717714384381051*a12*c*scx12*
      tax2 - 0.460615927282593949*a12*c*
      scx10*tax4 + 
     0.349257327035104813*a12*c*scx8*
      tax6 - 0.0574733908067241401*a12*c*
      scx6*tax8 + 
     0.00134285467618800952*a12*c*scx4*
      tax10 - 6.57778435556213334e-7*a12*c*
      scx2*tax12) + 
  eps6*xbar2*((0.114646957980291314*a14*c - 
        0.123035808988189941*a12*c2 + 
        0.0164742664742664743*a10*c3 - 
        0.000026455026455026455*a8*c4)*scx16
+ (-5.40201822868489535*a14*c + 
        6.66970722399293828*a12*c2 - 
        1.39242584575917909*a10*c3 + 
        0.0268783068783068783*a8*c4)*scx14*
      tax2 + (27.7535368335368335*a14*c - 
        35.7117733060590203*a12*c2 + 
        8.50629469296135963*a10*c3 - 
        0.224761904761904762*a8*c4)*scx12*
      tax4 + (-33.6727322060655394*a14*c + 
        43.5586104195628005*a12*c2 - 
        10.5729292929292929*a10*c3 + 
        0.303068783068783069*a8*c4)*scx10*
      tax6 + (10.970694737361404*a14*c - 
        13.8359195302052445*a12*c2 + 
        3.09984928651595318*a10*c3 - 
        0.0702645502645502646*a8*c4)*scx8*
      tax8 + (-0.828294668294668295*a14*c + 
        0.968485482771197057*a12*c2 - 
        0.162026615359948693*a10*c3)*scx6*
      tax10 + (0.00807538140871474205*a14*c - 
        0.00746822842060937299*a12*c2)*scx4*
      tax12 - 9.86667653334320001e-7*a14*c*
      scx2*tax14) + 
  eps5*xbar4*((0.114646957980291314*a14*c - 
        0.105648830886926125*a12*c2 + 
        0.00815776815776815777*a10*c3)*scx16
+ (-5.40201822868489535*a14*c + 
        5.92416697940507464*a12*c2 - 
        0.823831970498637165*a10*c3)*scx14*
      tax2 + (27.7535368335368335*a14*c - 
        31.604538459776555*a12*c2 + 
        5.02521083854417188*a10*c3)*scx12*
      tax4 + (-33.6727322060655394*a14*c + 
        38.4779933998981618*a12*c2 - 
        6.21090909090909091*a10*c3)*scx10*
      tax6 + (10.970694737361404*a14*c - 
        12.2623867842915462*a12*c2 + 
        1.83309924643257977*a10*c3)*scx8*
      tax8 + (-0.828294668294668295*a14*c + 
        0.868364510269272174*a12*c2 - 
        0.0987910854577521244*a10*c3)*scx6*
      tax10 + (0.00807538140871474205*a14*c - 
        0.00690103547246404389*a12*c2)*scx4*
      tax12 - 9.86667653334320001e-7*a14*c*
      scx2*tax14) + 
  eps4*xbar6*((0.0764313053201942091*a14*c - 
        0.0563019343971724924*a12*c2 + 
        0.0016835016835016835*a10*c3)*scx16 + 
     (-3.60134548578993023*a14*c + 
        3.26488627187039885*a12*c2 - 
        0.206432579765913099*a10*c3)*scx14*
      tax2 + (18.5023578890245557*a14*c - 
        17.3517450920625524*a12*c2 + 
        1.25690556357223024*a10*c3)*scx12*
      tax4 + (-22.4484881373770263*a14*c + 
        21.0995997065838336*a12*c2 - 
        1.55163059163059163*a10*c3)*scx10*
      tax6 + (7.31379649157426935*a14*c - 
        6.74178303765605353*a12*c2 + 
        0.458540965207631874*a10*c3)*scx8*
      tax8 + (-0.552196445529778863*a14*c + 
        0.481744804284486824*a12*c2 - 
        0.0248067981401314735*a10*c3)*scx6*
      tax10 + (0.00538358760580982803*a14*c - 
        0.00393915314550235185*a12*c2)*scx4*
      tax12 - 6.57778435556213334e-7*a14*c*
      scx2*tax14) + 
  eps7*((0.0573234789901456568*a14*c - 
        0.0684889537270489651*a12*c2 + 
        0.0131024531024531025*a10*c3 - 
        0.00021164021164021164*a8*c4)*scx16 + 
     (-2.70100911434244768*a14*c + 
        3.60800807657950515*a12*c2 - 
        0.964399551066217733*a10*c3 + 
        0.0435978835978835979*a8*c4)*scx14*
      tax2 + (13.8767684167684168*a14*c - 
        19.3695036180750466*a12*c2 + 
        5.88809684143017476*a10*c3 - 
        0.356825396825396825*a8*c4)*scx12*
      tax4 + (-16.8363661030327697*a14*c + 
        23.6879987032367985*a12*c2 - 
        7.38495430495430495*a10*c3 + 
        0.488042328042328042*a8*c4)*scx10*
      tax6 + (5.48534736868070201*a14*c - 
        7.49490044347187204*a12*c2 + 
        2.14269039602372936*a10*c3 - 
        0.111322751322751323*a8*c4)*scx8*
      tax8 + (-0.414147334147334147*a14*c + 
        0.517214425785854357*a12*c2 - 
        0.10675645342312009*a10*c3)*scx6*
      tax10 + (0.00403769070435737102*a14*c - 
        0.00388577912387436197*a12*c2)*scx4*
      tax12 - 4.9333382666716e-7*a14*c*
      scx2*tax14) + 
  eps3*xbar8*((0.0382156526600971045*a14*c - 
        0.0196946498533800121*a12*c2)*scx16 + 
     (-1.80067274289496512*a14*c + 
        1.16904283253489603*a12*c2)*scx14*
      tax2 + (9.25117894451227785*a14*c - 
        6.19710859393399076*a12*c2)*scx12*
      tax4 + (-11.2242440686885131*a14*c + 
        7.52936070396387857*a12*c2)*scx10*
      tax6 + (3.65689824578713468*a14*c - 
        2.41008491802142596*a12*c2)*scx8*
      tax8 + (-0.276098222764889432*a14*c + 
        0.173264947868122471*a12*c2)*scx6*
      tax10 + (0.00269179380290491402*a14*c - 
        0.00144335382430620526*a12*c2)*scx4*
      tax12 - 3.28889217778106667e-7*a14*c*
      scx2*tax14) + 
  eps2*xbar10*((0.0152862610640388418*a14*c - 
        0.00393892997067600242*a12*c2)*scx16
+ (-0.720269097157986047*a14*c + 
        0.233808566506979205*a12*c2)*scx14*
      tax2 + (3.70047157780491114*a14*c - 
        1.23942171878679815*a12*c2)*scx12*
      tax4 + (-4.48969762747540525*a14*c + 
        1.50587214079277571*a12*c2)*scx10*
      tax6 + (1.46275929831485387*a14*c - 
        0.482016983604285192*a12*c2)*scx8*
      tax8 + (-0.110439289105955773*a14*c + 
        0.0346529895736244943*a12*c2)*scx6*
      tax10 + (0.00107671752116196561*a14*c - 
        0.000288670764861241052*a12*c2)*scx4*
      tax12 - 1.31555687111242667e-7*a14*c*
      scx2*tax14) + 
  eps*xbar12*(0.00509542035467961394*a14*c*
      scx16 - 0.240089699052662016*a14*c*
      scx14*tax2 + 
     1.23349052593497038*a14*c*scx12*
      tax4 - 1.49656587582513508*a14*c*
      scx10*tax6 + 
     0.487586432771617957*a14*c*scx8*
      tax8 - 0.0368130963686519242*a14*c*
      scx6*tax10 + 
     0.000358905840387321869*a14*c*scx4*
      tax12 - 4.38518957037475556e-8*a14*c*
      scx2*tax14) + 
  xbar14*(0.00145583438705131827*a14*c*scx16 - 
     0.0685970568721891473*a14*c*scx14*
      tax2 + 0.35242586455284868*a14*c*
      scx12*tax4 - 
     0.427590250235752881*a14*c*scx10*
      tax6 + 0.139310409363319416*a14*c*
      scx8*tax8 - 
     0.0105180275339005498*a14*c*scx6*
      tax10 + 0.000102544525824949105*a14*c*
      scx4*tax12 - 
     1.25291130582135873e-8*a14*c*scx2*
      tax14);
}
#endif

#ifdef p9
double Wp(void)
{
   return -1.*c*scx2 + xbar2*
   (0.333333333333333333*a2*c*scx4 - 
     0.666666666666666667*a2*c*scx2*tax2) + eps*(0.166666666666666667*a2*c*scx4 - 
     0.333333333333333333*a2*c*scx2*tax2) + eps*xbar2*(-0.133333333333333333*a4*c*
      scx6 + 0.733333333333333333*a4*c*
      scx4*tax2 - 
     0.133333333333333333*a4*c*scx2*tax4) + xbar4*(-0.133333333333333333*a4*c*scx6 + 
     0.733333333333333333*a4*c*scx4*
      tax2 - 0.133333333333333333*a4*c*
      scx2*tax4) + 
  eps2*(-0.0666666666666666667*a4*c*scx6 + 
     (0.366666666666666667*a4*c - 
        0.166666666666666667*a2*c2)*scx4*
      tax2 - 0.0666666666666666667*a4*c*
      scx2*tax4) + 
  eps*xbar4*(0.0809523809523809524*a6*c*
      scx8 - 0.857142857142857143*a6*c*
      scx6*tax2 + 
     0.542857142857142857*a6*c*scx4*
      tax4 - 0.0190476190476190476*a6*c*
      scx2*tax6) + 
  eps2*xbar2*((0.0809523809523809524*a6*c - 
        0.0111111111111111111*a4*c2)*scx8 + 
     (-0.857142857142857143*a6*c + 
        0.311111111111111111*a4*c2)*scx6*
      tax2 + (0.542857142857142857*a6*c - 
        0.177777777777777778*a4*c2)*scx4*
      tax4 - 0.0190476190476190476*a6*c*
      scx2*tax6) + 
  xbar6*(0.0539682539682539683*a6*c*scx8 - 
     0.571428571428571429*a6*c*scx6*
      tax2 + 0.361904761904761905*a6*c*
      scx4*tax4 - 
     0.0126984126984126984*a6*c*scx2*
      tax6) + eps3*
   ((0.0404761904761904762*a6*c - 
        0.0111111111111111111*a4*c2)*scx8 + 
     (-0.428571428571428571*a6*c + 
        0.311111111111111111*a4*c2)*scx6*
      tax2 + (0.271428571428571429*a6*c - 
        0.177777777777777778*a4*c2)*scx4*
      tax4 - 0.00952380952380952381*a6*c*
      scx2*tax6) + 
  eps3*xbar2*((-0.0656084656084656085*a8*c + 
        0.0253968253968253968*a6*c2)*scx10 + 
     (1.13439153439153439*a8*c - 
        0.768253968253968254*a6*c2)*scx8*
      tax2 + (-1.53650793650793651*a8*c + 
        1.05396825396825397*a6*c2)*scx6*
      tax4 + (0.261375661375661376*a8*c - 
        0.152380952380952381*a6*c2)*scx4*
      tax6 - 0.0021164021164021164*a8*c*
      scx2*tax8) + 
  eps2*xbar4*((-0.0656084656084656085*a8*c + 
        0.0126984126984126984*a6*c2)*scx10 + 
     (1.13439153439153439*a8*c - 
        0.384126984126984127*a6*c2)*scx8*
      tax2 + (-1.53650793650793651*a8*c + 
        0.526984126984126984*a6*c2)*scx6*
      tax4 + (0.261375661375661376*a8*c - 
        0.0761904761904761905*a6*c2)*scx4*
      tax6 - 0.0021164021164021164*a8*c*
      scx2*tax8) + 
  eps*xbar6*(-0.0437389770723104056*a8*c*
      scx10 + 0.756261022927689594*a8*c*
      scx8*tax2 - 
     1.02433862433862434*a8*c*scx6*
      tax4 + 0.174250440917107584*a8*c*
      scx4*tax6 - 
     0.0014109347442680776*a8*c*scx2*
      tax8) + eps4*
   ((-0.0328042328042328042*a8*c + 
        0.0190476190476190476*a6*c2)*scx10 + 
     (0.567195767195767196*a8*c - 
        0.531746031746031746*a6*c2 + 
        0.0333333333333333333*a4*c3)*scx8*
      tax2 + (-0.768253968253968254*a8*c + 
        0.746031746031746032*a6*c2 - 
        0.0666666666666666667*a4*c3)*scx6*
      tax4 + (0.130687830687830688*a8*c - 
        0.103174603174603175*a6*c2)*scx4*
      tax6 - 0.0010582010582010582*a8*c*
      scx2*tax8) + 
  xbar8*(-0.0218694885361552028*a8*c*scx10 + 
     0.378130511463844797*a8*c*scx8*
      tax2 - 0.512169312169312169*a8*c*
      scx6*tax4 + 
     0.0871252204585537919*a8*c*scx4*
      tax6 - 0.000705467372134038801*a8*c*
      scx2*tax8) + 
  eps4*xbar2*((0.0664742664742664743*a10*c - 
        0.0434920634920634921*a8*c2 + 
        0.000529100529100529101*a6*c3)*scx12 
+ (-1.70254930254930255*a10*c + 
        1.56253968253968254*a8*c2 - 
        0.0984126984126984127*a6*c3)*scx10*
      tax2 + (3.99331409331409331*a10*c - 
        3.8180952380952381*a8*c2 + 
        0.301587301587301587*a6*c3)*scx8*
      tax4 + (-1.64001924001924002*a10*c + 
        1.50222222222222222*a8*c2 - 
        0.0994708994708994709*a6*c3)*scx6*
      tax6 + (0.0974506974506974507*a10*c - 
        0.0736507936507936508*a8*c2)*scx4*
      tax8 - 0.0001924001924001924*a10*c*
      scx2*tax10) + 
  eps3*xbar4*((0.0664742664742664743*a10*c - 
        0.0298412698412698413*a8*c2)*scx12 + 
     (-1.70254930254930255*a10*c + 
        1.12296296296296296*a8*c2)*scx10*
      tax2 + (3.99331409331409331*a10*c - 
        2.71873015873015873*a8*c2)*scx8*
      tax4 + (-1.64001924001924002*a10*c + 
        1.07428571428571429*a8*c2)*scx6*
      tax6 + (0.0974506974506974507*a10*c - 
        0.0541798941798941799*a8*c2)*scx4*
      tax8 - 0.0001924001924001924*a10*c*
      scx2*tax10) + 
  eps2*xbar6*((0.0443161776495109828*a10*c - 
        0.00994708994708994709*a8*c2)*scx12 + 
     (-1.1350328683662017*a10*c + 
        0.374320987654320988*a8*c2)*scx10*
      tax2 + (2.66220939554272888*a10*c - 
        0.906243386243386243*a8*c2)*scx8*
      tax4 + (-1.09334616001282668*a10*c + 
        0.358095238095238095*a8*c2)*scx6*
      tax6 + (0.0649671316337983005*a10*c - 
        0.0180599647266313933*a8*c2)*scx4*
      tax8 - 0.0001282667949334616*a10*c*
      scx2*tax10) + 
  eps5*((0.0332371332371332371*a10*c - 
        0.0279365079365079365*a8*c2 + 
        0.0014109347442680776*a6*c3)*scx12 + 
     (-0.851274651274651275*a10*c + 
        0.940105820105820106*a8*c2 - 
        0.129100529100529101*a6*c3)*scx10*
      tax2 + (1.99665704665704666*a10*c - 
        2.32873015873015873*a8*c2 + 
        0.404232804232804233*a6*c3)*scx8*
      tax4 + (-0.82000962000962001*a10*c + 
        0.910476190476190476*a8*c2 - 
        0.131922398589065256*a6*c3)*scx6*
      tax6 + (0.0487253487253487253*a10*c - 
        0.0427513227513227513*a8*c2)*scx4*
      tax8 - 0.0000962000962000962001*a10*c*
      scx2*tax10) + 
  eps*xbar8*(0.0221580888247554914*a10*c*
      scx12 - 0.56751643418310085*a10*c*
      scx10*tax2 + 
     1.33110469777136444*a10*c*scx8*
      tax4 - 0.54667308000641334*a10*c*
      scx6*tax6 + 
     0.0324835658168991502*a10*c*scx4*
      tax8 - 0.0000641333974667308001*a10*c*
      scx2*tax10) + 
  xbar10*(0.00886323552990219657*a10*c*
      scx12 - 0.22700657367324034*a10*c*
      scx10*tax2 + 
     0.532441879108545775*a10*c*scx8*
      tax4 - 0.218669232002565336*a10*c*
      scx6*tax6 + 
     0.0129934263267596601*a10*c*scx4*
      tax8 - 0.00002565335898669232*a10*c*
      scx2*tax10) + 
  eps5*xbar2*((-0.0808228808228808229*a12*c + 
        0.0717139650472983806*a10*c2 - 
        0.00465608465608465608*a8*c3)*scx14 + 
     (2.87364857364857365*a12*c - 
        3.15666827000160333*a10*c2 + 
        0.436402116402116402*a8*c3)*scx12*
      tax2 + (-10.3638583638583639*a12*c + 
        11.9069809203142536*a10*c2 - 
        1.95174603174603175*a8*c3)*scx10*
      tax4 + (7.85828985828985829*a12*c - 
        8.95524130190796857*a10*c2 + 
        1.43534391534391534*a8*c3)*scx8*
      tax6 + (-1.29315129315129315*a12*c + 
        1.38333172999839667*a10*c2 - 
        0.171851851851851852*a8*c3)*scx6*
      tax8 + (0.0302142302142302142*a12*c - 
        0.0260638127304793971*a10*c2)*scx4*
      tax10 - 0.0000148000148000148*a12*c*
      scx2*tax12) + 
  eps4*xbar4*((-0.0808228808228808229*a12*c + 
        0.0567837101170434504*a10*c2 - 
        0.00126984126984126984*a8*c3)*scx14 + 
     (2.87364857364857365*a12*c - 
        2.61428250761584095*a10*c2 + 
        0.164761904761904762*a8*c3)*scx12*
      tax2 + (-10.3638583638583639*a12*c + 
        9.79408048741382075*a10*c2 - 
        0.731428571428571429*a8*c3)*scx10*
      tax4 + (7.85828985828985829*a12*c - 
        7.36422639089305756*a10*c2 + 
        0.537777777777777778*a8*c3)*scx8*
      tax6 + (-1.29315129315129315*a12*c + 
        1.14825717492384159*a10*c2 - 
        0.0647619047619047619*a8*c3)*scx6*
      tax8 + (0.0302142302142302142*a12*c - 
        0.0223697290363957031*a10*c2)*scx4*
      tax10 - 0.0000148000148000148*a12*c*
      scx2*tax12) + 
  eps3*xbar6*((-0.0538819205485872153*a12*c + 
        0.0263032440810218588*a10*c2)*scx14 + 
     (1.91576571576571577*a12*c - 
        1.24964780075891187*a10*c2)*scx12*
      tax2 + (-6.90923890923890924*a12*c + 
        4.66006947784725563*a10*c2)*scx10*
      tax4 + (5.23885990552657219*a12*c - 
        3.50331676553898776*a10*c2)*scx8*
      tax6 + (-0.862100862100862101*a12*c + 
        0.549717278606167495*a10*c2)*scx6*
      tax8 + (0.0201428201428201428*a12*c - 
        0.0109454331676553899*a10*c2)*scx4*
      tax10 - 9.86667653334320001e-6*a12*c*
      scx2*tax12) + 
  eps6*((-0.0404114404114404114*a12*c + 
        0.0421228154561487895*a10*c2 - 
        0.00507936507936507937*a8*c3)*scx14 + 
     (1.43682428682428682*a12*c - 
        1.77375100208433542*a10*c2 + 
        0.367248677248677249*a8*c3 - 
        0.00674603174603174603*a6*c4)*scx12*
      tax2 + (-5.18192918192918193*a12*c + 
        6.73456148789482123*a10*c2 - 
        1.6526984126984127*a8*c3 + 
        0.0460317460317460317*a6*c4)*scx10*
      tax4 + (3.92914492914492914*a12*c - 
        5.07305755972422639*a10*c2 + 
        1.2273015873015873*a8*c3 - 
        0.0365079365079365079*a6*c4)*scx8*
      tax6 + (-0.646575646575646576*a12*c + 
        0.773153759820426487*a10*c2 - 
        0.140529100529100529*a8*c3)*scx6*
      tax8 + (0.0151071151071151071*a12*c - 
        0.014067660734327401*a10*c2)*scx4*
      tax10 - 7.40000740000740001e-6*a12*c*
      scx2*tax12) + 
  eps2*xbar8*((-0.0269409602742936076*a12*c + 
        0.0065758110202554647*a10*c2)*scx14 + 
     (0.957882857882857883*a12*c - 
        0.312411950189727968*a10*c2)*scx12*
      tax2 + (-3.45461945461945462*a12*c + 
        1.16501736946181391*a10*c2)*scx10*
      tax4 + (2.6194299527632861*a12*c - 
        0.87582919138474694*a10*c2)*scx8*
      tax6 + (-0.43105043105043105*a12*c + 
        0.137429319651541874*a10*c2)*scx6*
      tax8 + (0.0100714100714100714*a12*c - 
        0.00273635829191384747*a10*c2)*scx4*
      tax10 - 4.9333382666716e-6*a12*c*
      scx2*tax12) + 
  eps*xbar10*(-0.0107763841097174431*a12*c*
      scx14 + 0.383153143153143153*a12*c*
      scx12*tax2 - 
     1.38184778184778185*a12*c*scx10*
      tax4 + 1.04777198110531444*a12*c*
      scx8*tax6 - 
     0.17242017242017242*a12*c*scx6*
      tax8 + 0.00402856402856402856*a12*c*
      scx4*tax10 - 
     1.97333530666864e-6*a12*c*scx2*
      tax12) + xbar12*
   (-0.00359212803657248102*a12*c*scx14 + 
     0.127717714384381051*a12*c*scx12*
      tax2 - 0.460615927282593949*a12*c*
      scx10*tax4 + 
     0.349257327035104813*a12*c*scx8*
      tax6 - 0.0574733908067241401*a12*c*
      scx6*tax8 + 
     0.00134285467618800952*a12*c*scx4*
      tax10 - 6.57778435556213334e-7*a12*c*
      scx2*tax12) + 
  eps6*xbar2*((0.114646957980291314*a14*c - 
        0.123035808988189941*a12*c2 + 
        0.0164742664742664743*a10*c3 - 
        0.000026455026455026455*a8*c4)*scx16 
+ (-5.40201822868489535*a14*c + 
        6.66970722399293828*a12*c2 - 
        1.39242584575917909*a10*c3 + 
        0.0268783068783068783*a8*c4)*scx14*
      tax2 + (27.7535368335368335*a14*c - 
        35.7117733060590203*a12*c2 + 
        8.50629469296135963*a10*c3 - 
        0.224761904761904762*a8*c4)*scx12*
      tax4 + (-33.6727322060655394*a14*c + 
        43.5586104195628005*a12*c2 - 
        10.5729292929292929*a10*c3 + 
        0.303068783068783069*a8*c4)*scx10*
      tax6 + (10.970694737361404*a14*c - 
        13.8359195302052445*a12*c2 + 
        3.09984928651595318*a10*c3 - 
        0.0702645502645502646*a8*c4)*scx8*
      tax8 + (-0.828294668294668295*a14*c + 
        0.968485482771197057*a12*c2 - 
        0.162026615359948693*a10*c3)*scx6*
      tax10 + (0.00807538140871474205*a14*c - 
        0.00746822842060937299*a12*c2)*scx4*
      tax12 - 9.86667653334320001e-7*a14*c*
      scx2*tax14) + 
  eps5*xbar4*((0.114646957980291314*a14*c - 
        0.105648830886926125*a12*c2 + 
        0.00815776815776815777*a10*c3)*scx16 
+ (-5.40201822868489535*a14*c + 
        5.92416697940507464*a12*c2 - 
        0.823831970498637165*a10*c3)*scx14*
      tax2 + (27.7535368335368335*a14*c - 
        31.604538459776555*a12*c2 + 
        5.02521083854417188*a10*c3)*scx12*
      tax4 + (-33.6727322060655394*a14*c + 
        38.4779933998981618*a12*c2 - 
        6.21090909090909091*a10*c3)*scx10*
      tax6 + (10.970694737361404*a14*c - 
        12.2623867842915462*a12*c2 + 
        1.83309924643257977*a10*c3)*scx8*
      tax8 + (-0.828294668294668295*a14*c + 
        0.868364510269272174*a12*c2 - 
        0.0987910854577521244*a10*c3)*scx6*
      tax10 + (0.00807538140871474205*a14*c - 
        0.00690103547246404389*a12*c2)*scx4*
      tax12 - 9.86667653334320001e-7*a14*c*
      scx2*tax14) + 
  eps4*xbar6*((0.0764313053201942091*a14*c - 
        0.0563019343971724924*a12*c2 + 
        0.0016835016835016835*a10*c3)*scx16 + 
     (-3.60134548578993023*a14*c + 
        3.26488627187039885*a12*c2 - 
        0.206432579765913099*a10*c3)*scx14*
      tax2 + (18.5023578890245557*a14*c - 
        17.3517450920625524*a12*c2 + 
        1.25690556357223024*a10*c3)*scx12*
      tax4 + (-22.4484881373770263*a14*c + 
        21.0995997065838336*a12*c2 - 
        1.55163059163059163*a10*c3)*scx10*
      tax6 + (7.31379649157426935*a14*c - 
        6.74178303765605353*a12*c2 + 
        0.458540965207631874*a10*c3)*scx8*
      tax8 + (-0.552196445529778863*a14*c + 
        0.481744804284486824*a12*c2 - 
        0.0248067981401314735*a10*c3)*scx6*
      tax10 + (0.00538358760580982803*a14*c - 
        0.00393915314550235185*a12*c2)*scx4*
      tax12 - 6.57778435556213334e-7*a14*c*
      scx2*tax14) + 
  eps7*((0.0573234789901456568*a14*c - 
        0.0684889537270489651*a12*c2 + 
        0.0131024531024531025*a10*c3 - 
        0.00021164021164021164*a8*c4)*scx16 + 
     (-2.70100911434244768*a14*c + 
        3.60800807657950515*a12*c2 - 
        0.964399551066217733*a10*c3 + 
        0.0435978835978835979*a8*c4)*scx14*
      tax2 + (13.8767684167684168*a14*c - 
        19.3695036180750466*a12*c2 + 
        5.88809684143017476*a10*c3 - 
        0.356825396825396825*a8*c4)*scx12*
      tax4 + (-16.8363661030327697*a14*c + 
        23.6879987032367985*a12*c2 - 
        7.38495430495430495*a10*c3 + 
        0.488042328042328042*a8*c4)*scx10*
      tax6 + (5.48534736868070201*a14*c - 
        7.49490044347187204*a12*c2 + 
        2.14269039602372936*a10*c3 - 
        0.111322751322751323*a8*c4)*scx8*
      tax8 + (-0.414147334147334147*a14*c + 
        0.517214425785854357*a12*c2 - 
        0.10675645342312009*a10*c3)*scx6*
      tax10 + (0.00403769070435737102*a14*c - 
        0.00388577912387436197*a12*c2)*scx4*
      tax12 - 4.9333382666716e-7*a14*c*
      scx2*tax14) + 
  eps3*xbar8*((0.0382156526600971045*a14*c - 
        0.0196946498533800121*a12*c2)*scx16 + 
     (-1.80067274289496512*a14*c + 
        1.16904283253489603*a12*c2)*scx14*
      tax2 + (9.25117894451227785*a14*c - 
        6.19710859393399076*a12*c2)*scx12*
      tax4 + (-11.2242440686885131*a14*c + 
        7.52936070396387857*a12*c2)*scx10*
      tax6 + (3.65689824578713468*a14*c - 
        2.41008491802142596*a12*c2)*scx8*
      tax8 + (-0.276098222764889432*a14*c + 
        0.173264947868122471*a12*c2)*scx6*
      tax10 + (0.00269179380290491402*a14*c - 
        0.00144335382430620526*a12*c2)*scx4*
      tax12 - 3.28889217778106667e-7*a14*c*
      scx2*tax14) + 
  eps2*xbar10*((0.0152862610640388418*a14*c - 
        0.00393892997067600242*a12*c2)*scx16 
+ (-0.720269097157986047*a14*c + 
        0.233808566506979205*a12*c2)*scx14*
      tax2 + (3.70047157780491114*a14*c - 
        1.23942171878679815*a12*c2)*scx12*
      tax4 + (-4.48969762747540525*a14*c + 
        1.50587214079277571*a12*c2)*scx10*
      tax6 + (1.46275929831485387*a14*c - 
        0.482016983604285192*a12*c2)*scx8*
      tax8 + (-0.110439289105955773*a14*c + 
        0.0346529895736244943*a12*c2)*scx6*
      tax10 + (0.00107671752116196561*a14*c - 
        0.000288670764861241052*a12*c2)*scx4*
      tax12 - 1.31555687111242667e-7*a14*c*
      scx2*tax14) + 
  eps*xbar12*(0.00509542035467961394*a14*c*
      scx16 - 0.240089699052662016*a14*c*
      scx14*tax2 + 
     1.23349052593497038*a14*c*scx12*
      tax4 - 1.49656587582513508*a14*c*
      scx10*tax6 + 
     0.487586432771617957*a14*c*scx8*
      tax8 - 0.0368130963686519242*a14*c*
      scx6*tax10 + 
     0.000358905840387321869*a14*c*scx4*
      tax12 - 4.38518957037475556e-8*a14*c*
      scx2*tax14) + 
  xbar14*(0.00145583438705131827*a14*c*
      scx16 - 0.0685970568721891473*a14*c*
      scx14*tax2 + 
     0.35242586455284868*a14*c*scx12*
      tax4 - 0.427590250235752881*a14*c*
      scx10*tax6 + 
     0.139310409363319416*a14*c*scx8*
      tax8 - 0.0105180275339005498*a14*c*
      scx6*tax10 + 
     0.000102544525824949105*a14*c*scx4*
      tax12 - 1.25291130582135873e-8*a14*c*
      scx2*tax14) + 
  eps7*xbar2*((-0.185858643897859584*a16*c + 
        0.226050069859593669*a14*c2 - 
        0.0457946568422758899*a12*c3 + 
        0.000885040885040885041*a10*c4)*scx18 
+ (11.2079619436482182*a16*c - 
        15.0010988658607706*a14*c2 + 
        4.04373775078536983*a12*c3 - 
        0.188590668590668591*a10*c4)*scx16*
      tax2 + (-77.7704089955070347*a16*c + 
        107.894628546057117*a14*c2 - 
        32.2687829278305469*a12*c3 + 
        1.90133718133718134*a10*c4)*scx14*
      tax4 + (138.123473273277195*a16*c - 
        193.684971043066281*a14*c2 + 
        59.7631320355129879*a12*c3 - 
        3.82226070226070226*a10*c4)*scx12*
      tax6 + (-75.1377256004706985*a16*c + 
        104.373751398513303*a14*c2 - 
        31.3736089659899184*a12*c3 + 
        1.89267917267917268*a10*c4)*scx10*
      tax8 + (12.1194328692367908*a16*c - 
        16.259099630528202*a14*c2 + 
        4.39479755517850756*a12*c3 - 
        0.194247234247234247*a10*c4)*scx8*
      tax10 + (-0.453237278335317551*a16*c + 
        0.558575956671194766*a14*c2 - 
        0.110146107860393575*a12*c3)*scx6*
      tax12 + (0.00190133758761209742*a16*c - 
        0.00182448944353706258*a14*c2)*scx4*
      tax14 - 5.80392737255482354e-8*a16*c*
      scx2*tax16) + 
  eps6*xbar4*((-0.185858643897859584*a16*c + 
        0.203924611543659163*a14*c2 - 
        0.0296020405226754433*a12*c3 + 
        0.00011544011544011544*a10*c4)*scx18 
+ (11.2079619436482182*a16*c - 
        13.8531909360480789*a14*c2 + 
        2.9138804616899855*a12*c3 - 
        0.058152958152958153*a10*c4)*scx16*
      tax2 + (-77.7704089955070347*a16*c + 
        99.4877112305683734*a14*c2 - 
        23.2957734329162901*a12*c3 + 
        0.596921596921596922*a10*c4)*scx14*
      tax4 + (138.123473273277195*a16*c - 
        178.250027926218402*a14*c2 + 
        42.9167486716693066*a12*c3 - 
        1.1924963924963925*a10*c4)*scx12*
      tax6 + (-75.1377256004706985*a16*c + 
        96.1311196739768168*a14*c2 - 
        22.5589448294210199*a12*c3 + 
        0.591053391053391053*a10*c4)*scx10*
      tax8 + (12.1194328692367908*a16*c - 
        15.0490802319373748*a14*c2 + 
        3.20175604289890004*a12*c3 - 
        0.0612602212602212602*a10*c4)*scx8*
      tax10 + (-0.453237278335317551*a16*c + 
        0.523194759385235576*a14*c2 - 
        0.0832945208818224691*a12*c3)*scx6*
      tax12 + (0.00190133758761209742*a16*c - 
        0.00175063032205889349*a14*c2)*scx4*
      tax14 - 5.80392737255482354e-8*a16*c*
      scx2*tax16) + 
  eps5*xbar6*((-0.123905762598573056*a16*c + 
        0.117400483114768829*a14*c2 - 
        0.0102164768408154652*a12*c3)*scx18 + 
     (7.47197462909881211*a16*c - 
        8.19425898029072632*a14*c2 + 
        1.14659809796317733*a12*c3)*scx16*
      tax2 + (-51.8469393303380231*a16*c + 
        58.7218594456689695*a14*c2 - 
        9.17379763094048808*a12*c3)*scx14*
      tax4 + (92.0823155155181299*a16*c - 
        105.045261475737666*a14*c2 + 
        16.8408481661391714*a12*c3)*scx12*
      tax6 + (-50.0918170669804657*a16*c + 
        56.6950520144170938*a14*c2 - 
        8.85988602813999639*a12*c3)*scx10*
      tax8 + (8.0796219128245272*a16*c - 
        8.912052462528653*a14*c2 + 
        1.26820357067976116*a12*c3)*scx8*
      tax10 + (-0.302158185556878367*a16*c + 
        0.313038636848160658*a14*c2 - 
        0.0337833626299234765*a12*c3)*scx6*
      tax12 + (0.00126755839174139828*a16*c - 
        0.00107650139396171142*a14*c2)*scx4*
      tax14 - 3.86928491503654902e-8*a16*c*
      scx2*tax16) + 
  eps8*((-0.0929293219489297921*a16*c + 
        0.121721382673763626*a14*c2 - 
        0.0309726064646699567*a12*c3 + 
        0.001282667949334616*a10*c4)*scx18 + 
     (5.60398097182410908*a16*c - 
        7.93101200386914673*a14*c2 + 
        2.51969506507601746*a12*c3 - 
        0.18594997594997595*a10*c4 + 
        0.00136684303350970018*a8*c5)*scx16*
      tax2 + (-38.8852044977535174*a16*c + 
        57.0846957275528704*a14*c2 - 
        20.0409831966974824*a12*c3 + 
        1.83578964245630912*a10*c4 - 
        0.0208994708994708995*a8*c5)*scx14*
      tax4 + (69.0617366366385974*a16*c - 
        102.699346878870688*a14*c2 + 
        37.3511459146379781*a12*c3 - 
        3.72521564854898188*a10*c4 + 
        0.0513227513227513228*a8*c5)*scx12*
      tax6 + (-37.5688628002353493*a16*c + 
        55.3069127697699126*a14*c2 - 
        19.5891233281709472*a12*c3 + 
        1.84754208754208754*a10*c4 - 
        0.0236331569664902998*a8*c5)*scx10*
      tax8 + (6.0597164346183954*a16*c - 
        8.56489404775119061*a14*c2 + 
        2.6950718487861345*a12*c3 - 
        0.181997755331088664*a10*c4)*scx8*
      tax10 + (-0.226618639167658776*a16*c + 
        0.290485740009549533*a14*c2 - 
        0.0646747068334369922*a12*c3)*scx6*
      tax12 + (0.000950668793806048708*a16*c - 
        0.000931449502878074307*a14*c2)*scx4*
      tax14 - 2.90196368627741177e-8*a16*c*
      scx2*tax16) + 
  eps4*xbar8*((-0.061952881299286528*a16*c + 
        0.0472042478391684741*a14*c2 - 
        0.00167763570938174113*a12*c3)*scx18 
+ (3.73598731454940605*a16*c - 
        3.3833464947750662*a14*c2 + 
        0.21498789746408794*a12*c3)*scx16*
      tax2 + (-25.9234696651690116*a16*c + 
        24.1913574961194009*a14*c2 - 
        1.72116581830867545*a12*c3)*scx14*
      tax4 + (46.0411577577590649*a16*c - 
        43.2220304445701271*a14*c2 + 
        3.15677276280450884*a12*c3)*scx12*
      tax6 + (-25.0459085334902328*a16*c + 
        23.3437749552035266*a14*c2 - 
        1.6609766247861486*a12*c3)*scx10*
      tax8 + (4.0398109564122636*a16*c - 
        3.68143087952611762*a14*c2 + 
        0.238059887202744346*a12*c3)*scx8*
      tax10 + (-0.151079092778439184*a16*c + 
        0.130395412935095475*a14*c2 - 
        0.00635937372445308953*a12*c3)*scx6*
      tax12 + (0.000633779195870699139*a16*c - 
        0.000460069031497602926*a14*c2)*scx4*
      tax14 - 1.93464245751827451e-8*a16*c*
      scx2*tax16) + 
  eps3*xbar10*((-0.0247811525197146112*a16*c + 
        0.0132660003136193612*a14*c2)*scx18 + 
     (1.49439492581976242*a16*c - 
        0.968465599068773672*a14*c2)*scx16*
      tax2 + (-10.3693878660676046*a16*c + 
        6.91410284248379486*a14*c2)*scx14*
      tax4 + (18.416463103103626*a16*c - 
        12.3429536953346477*a14*c2)*scx12*
      tax6 + (-10.0183634133960931*a16*c + 
        6.66940781734432528*a14*c2)*scx10*
      tax8 + (1.61592438256490544*a16*c - 
        1.05412262517024422*a14*c2)*scx8*
      tax10 + (-0.0604316371113756735*a16*c + 
        0.0375467072609929753*a14*c2)*scx6*
      tax12 + (0.000253511678348279655*a16*c - 
        0.000134713023601912491*a14*c2)*scx4*
      tax14 - 7.73856983007309805e-9*a16*c*
      scx2*tax16) + 
  eps2*xbar12*((-0.00826038417323820374*a16*c + 
        0.00221100005226989354*a14*c2)*scx18 
+ (0.498131641939920807*a16*c - 
        0.161410933178128945*a14*c2)*scx16*
      tax2 + (-3.45646262202253488*a16*c + 
        1.15235047374729914*a14*c2)*scx14*
      tax4 + (6.13882103436787533*a16*c - 
        2.05715894922244129*a14*c2)*scx12*
      tax6 + (-3.33945447113203104*a16*c + 
        1.11156796955738755*a14*c2)*scx10*
      tax8 + (0.53864146085496848*a16*c - 
        0.175687104195040703*a14*c2)*scx8*
      tax10 + (-0.0201438790371252245*a16*c + 
        0.00625778454349882921*a14*c2)*scx6*
      tax12 + (0.0000845038927827598852*a16*c - 
        0.0000224521706003187485*a14*c2)*
      scx4*tax14 - 
     2.57952327669103268e-9*a16*c*scx2*
      tax16) + eps*xbar14*
   (-0.00236010976378234393*a16*c*scx18 + 
     0.142323326268548802*a16*c*scx16*
      tax2 - 0.987560749149295679*a16*c*
      scx14*tax4 + 
     1.75394886696225009*a16*c*scx12*
      tax6 - 0.954129848894866013*a16*c*
      scx10*tax8 + 
     0.153897560244276709*a16*c*scx8*
      tax10 - 0.005755394010607207*a16*c*
      scx6*tax12 + 
     0.0000241439693665028243*a16*c*scx4*
      tax14 - 7.37006650483152195e-10*a16*c*
      scx2*tax16) + 
  xbar16*(-0.000590027440945585981*a16*c*
      scx18 + 0.0355808315671372005*a16*c*
      scx16*tax2 - 
     0.24689018728732392*a16*c*scx14*
      tax4 + 0.438487216740562523*a16*c*
      scx12*tax6 - 
     0.238532462223716503*a16*c*scx10*
      tax8 + 0.0384743900610691772*a16*c*
      scx8*tax10 - 
     0.00143884850265180175*a16*c*scx6*
      tax12 + 6.03599234162570608e-6*a16*c*
      scx4*tax14 - 
     1.84251662620788049e-10*a16*c*scx2*
      tax16);
}
#endif

#ifdef p10
double Wp(void)
{
   return -1.*c*scx2 + xbar2*
   (0.333333333333333333*a2*c*scx4 - 
     0.666666666666666667*a2*c*scx2*tax2) + eps*(0.166666666666666667*a2*c*scx4 - 
     0.333333333333333333*a2*c*scx2*tax2) + eps*xbar2*(-0.133333333333333333*a4*c*
      scx6 + 0.733333333333333333*a4*c*
      scx4*tax2 - 
     0.133333333333333333*a4*c*scx2*tax4) + xbar4*(-0.133333333333333333*a4*c*scx6 + 
     0.733333333333333333*a4*c*scx4*
      tax2 - 0.133333333333333333*a4*c*
      scx2*tax4) + 
  eps2*(-0.0666666666666666667*a4*c*scx6 + 
     (0.366666666666666667*a4*c - 
        0.166666666666666667*a2*c2)*scx4*
      tax2 - 0.0666666666666666667*a4*c*
      scx2*tax4) + 
  eps*xbar4*(0.0809523809523809524*a6*c*
      scx8 - 0.857142857142857143*a6*c*
      scx6*tax2 + 
     0.542857142857142857*a6*c*scx4*
      tax4 - 0.0190476190476190476*a6*c*
      scx2*tax6) + 
  eps2*xbar2*((0.0809523809523809524*a6*c - 
        0.0111111111111111111*a4*c2)*scx8 + 
     (-0.857142857142857143*a6*c + 
        0.311111111111111111*a4*c2)*scx6*
      tax2 + (0.542857142857142857*a6*c - 
        0.177777777777777778*a4*c2)*scx4*
      tax4 - 0.0190476190476190476*a6*c*
      scx2*tax6) + 
  xbar6*(0.0539682539682539683*a6*c*scx8 - 
     0.571428571428571429*a6*c*scx6*
      tax2 + 0.361904761904761905*a6*c*
      scx4*tax4 - 
     0.0126984126984126984*a6*c*scx2*
      tax6) + eps3*
   ((0.0404761904761904762*a6*c - 
        0.0111111111111111111*a4*c2)*scx8 + 
     (-0.428571428571428571*a6*c + 
        0.311111111111111111*a4*c2)*scx6*
      tax2 + (0.271428571428571429*a6*c - 
        0.177777777777777778*a4*c2)*scx4*
      tax4 - 0.00952380952380952381*a6*c*
      scx2*tax6) + 
  eps3*xbar2*((-0.0656084656084656085*a8*c + 
        0.0253968253968253968*a6*c2)*scx10 + 
     (1.13439153439153439*a8*c - 
        0.768253968253968254*a6*c2)*scx8*
      tax2 + (-1.53650793650793651*a8*c + 
        1.05396825396825397*a6*c2)*scx6*
      tax4 + (0.261375661375661376*a8*c - 
        0.152380952380952381*a6*c2)*scx4*
      tax6 - 0.0021164021164021164*a8*c*
      scx2*tax8) + 
  eps2*xbar4*((-0.0656084656084656085*a8*c + 
        0.0126984126984126984*a6*c2)*scx10 + 
     (1.13439153439153439*a8*c - 
        0.384126984126984127*a6*c2)*scx8*
      tax2 + (-1.53650793650793651*a8*c + 
        0.526984126984126984*a6*c2)*scx6*
      tax4 + (0.261375661375661376*a8*c - 
        0.0761904761904761905*a6*c2)*scx4*
      tax6 - 0.0021164021164021164*a8*c*
      scx2*tax8) + 
  eps*xbar6*(-0.0437389770723104056*a8*c*
      scx10 + 0.756261022927689594*a8*c*
      scx8*tax2 - 
     1.02433862433862434*a8*c*scx6*
      tax4 + 0.174250440917107584*a8*c*
      scx4*tax6 - 
     0.0014109347442680776*a8*c*scx2*
      tax8) + eps4*
   ((-0.0328042328042328042*a8*c + 
        0.0190476190476190476*a6*c2)*scx10 + 
     (0.567195767195767196*a8*c - 
        0.531746031746031746*a6*c2 + 
        0.0333333333333333333*a4*c3)*scx8*
      tax2 + (-0.768253968253968254*a8*c + 
        0.746031746031746032*a6*c2 - 
        0.0666666666666666667*a4*c3)*scx6*
      tax4 + (0.130687830687830688*a8*c - 
        0.103174603174603175*a6*c2)*scx4*
      tax6 - 0.0010582010582010582*a8*c*
      scx2*tax8) + 
  xbar8*(-0.0218694885361552028*a8*c*scx10 + 
     0.378130511463844797*a8*c*scx8*
      tax2 - 0.512169312169312169*a8*c*
      scx6*tax4 + 
     0.0871252204585537919*a8*c*scx4*
      tax6 - 0.000705467372134038801*a8*c*
      scx2*tax8) + 
  eps4*xbar2*((0.0664742664742664743*a10*c - 
        0.0434920634920634921*a8*c2 + 
        0.000529100529100529101*a6*c3)*scx12 
+ (-1.70254930254930255*a10*c + 
        1.56253968253968254*a8*c2 - 
        0.0984126984126984127*a6*c3)*scx10*
      tax2 + (3.99331409331409331*a10*c - 
        3.8180952380952381*a8*c2 + 
        0.301587301587301587*a6*c3)*scx8*
      tax4 + (-1.64001924001924002*a10*c + 
        1.50222222222222222*a8*c2 - 
        0.0994708994708994709*a6*c3)*scx6*
      tax6 + (0.0974506974506974507*a10*c - 
        0.0736507936507936508*a8*c2)*scx4*
      tax8 - 0.0001924001924001924*a10*c*
      scx2*tax10) + 
  eps3*xbar4*((0.0664742664742664743*a10*c - 
        0.0298412698412698413*a8*c2)*scx12 + 
     (-1.70254930254930255*a10*c + 
        1.12296296296296296*a8*c2)*scx10*
      tax2 + (3.99331409331409331*a10*c - 
        2.71873015873015873*a8*c2)*scx8*
      tax4 + (-1.64001924001924002*a10*c + 
        1.07428571428571429*a8*c2)*scx6*
      tax6 + (0.0974506974506974507*a10*c - 
        0.0541798941798941799*a8*c2)*scx4*
      tax8 - 0.0001924001924001924*a10*c*
      scx2*tax10) + 
  eps2*xbar6*((0.0443161776495109828*a10*c - 
        0.00994708994708994709*a8*c2)*scx12 + 
     (-1.1350328683662017*a10*c + 
        0.374320987654320988*a8*c2)*scx10*
      tax2 + (2.66220939554272888*a10*c - 
        0.906243386243386243*a8*c2)*scx8*
      tax4 + (-1.09334616001282668*a10*c + 
        0.358095238095238095*a8*c2)*scx6*
      tax6 + (0.0649671316337983005*a10*c - 
        0.0180599647266313933*a8*c2)*scx4*
      tax8 - 0.0001282667949334616*a10*c*
      scx2*tax10) + 
  eps5*((0.0332371332371332371*a10*c - 
        0.0279365079365079365*a8*c2 + 
        0.0014109347442680776*a6*c3)*scx12 + 
     (-0.851274651274651275*a10*c + 
        0.940105820105820106*a8*c2 - 
        0.129100529100529101*a6*c3)*scx10*
      tax2 + (1.99665704665704666*a10*c - 
        2.32873015873015873*a8*c2 + 
        0.404232804232804233*a6*c3)*scx8*
      tax4 + (-0.82000962000962001*a10*c + 
        0.910476190476190476*a8*c2 - 
        0.131922398589065256*a6*c3)*scx6*
      tax6 + (0.0487253487253487253*a10*c - 
        0.0427513227513227513*a8*c2)*scx4*
      tax8 - 0.0000962000962000962001*a10*c*
      scx2*tax10) + 
  eps*xbar8*(0.0221580888247554914*a10*c*
      scx12 - 0.56751643418310085*a10*c*
      scx10*tax2 + 
     1.33110469777136444*a10*c*scx8*
      tax4 - 0.54667308000641334*a10*c*
      scx6*tax6 + 
     0.0324835658168991502*a10*c*scx4*
      tax8 - 0.0000641333974667308001*a10*c*
      scx2*tax10) + 
  xbar10*(0.00886323552990219657*a10*c*
      scx12 - 0.22700657367324034*a10*c*
      scx10*tax2 + 
     0.532441879108545775*a10*c*scx8*
      tax4 - 0.218669232002565336*a10*c*
      scx6*tax6 + 
     0.0129934263267596601*a10*c*scx4*
      tax8 - 0.00002565335898669232*a10*c*
      scx2*tax10) + 
  eps5*xbar2*((-0.0808228808228808229*a12*c + 
        0.0717139650472983806*a10*c2 - 
        0.00465608465608465608*a8*c3)*scx14 + 
     (2.87364857364857365*a12*c - 
        3.15666827000160333*a10*c2 + 
        0.436402116402116402*a8*c3)*scx12*
      tax2 + (-10.3638583638583639*a12*c + 
        11.9069809203142536*a10*c2 - 
        1.95174603174603175*a8*c3)*scx10*
      tax4 + (7.85828985828985829*a12*c - 
        8.95524130190796857*a10*c2 + 
        1.43534391534391534*a8*c3)*scx8*
      tax6 + (-1.29315129315129315*a12*c + 
        1.38333172999839667*a10*c2 - 
        0.171851851851851852*a8*c3)*scx6*
      tax8 + (0.0302142302142302142*a12*c - 
        0.0260638127304793971*a10*c2)*scx4*
      tax10 - 0.0000148000148000148*a12*c*
      scx2*tax12) + 
  eps4*xbar4*((-0.0808228808228808229*a12*c + 
        0.0567837101170434504*a10*c2 - 
        0.00126984126984126984*a8*c3)*scx14 + 
     (2.87364857364857365*a12*c - 
        2.61428250761584095*a10*c2 + 
        0.164761904761904762*a8*c3)*scx12*
      tax2 + (-10.3638583638583639*a12*c + 
        9.79408048741382075*a10*c2 - 
        0.731428571428571429*a8*c3)*scx10*
      tax4 + (7.85828985828985829*a12*c - 
        7.36422639089305756*a10*c2 + 
        0.537777777777777778*a8*c3)*scx8*
      tax6 + (-1.29315129315129315*a12*c + 
        1.14825717492384159*a10*c2 - 
        0.0647619047619047619*a8*c3)*scx6*
      tax8 + (0.0302142302142302142*a12*c - 
        0.0223697290363957031*a10*c2)*scx4*
      tax10 - 0.0000148000148000148*a12*c*
      scx2*tax12) + 
  eps3*xbar6*((-0.0538819205485872153*a12*c + 
        0.0263032440810218588*a10*c2)*scx14 + 
     (1.91576571576571577*a12*c - 
        1.24964780075891187*a10*c2)*scx12*
      tax2 + (-6.90923890923890924*a12*c + 
        4.66006947784725563*a10*c2)*scx10*
      tax4 + (5.23885990552657219*a12*c - 
        3.50331676553898776*a10*c2)*scx8*
      tax6 + (-0.862100862100862101*a12*c + 
        0.549717278606167495*a10*c2)*scx6*
      tax8 + (0.0201428201428201428*a12*c - 
        0.0109454331676553899*a10*c2)*scx4*
      tax10 - 9.86667653334320001e-6*a12*c*
      scx2*tax12) + 
  eps6*((-0.0404114404114404114*a12*c + 
        0.0421228154561487895*a10*c2 - 
        0.00507936507936507937*a8*c3)*scx14 + 
     (1.43682428682428682*a12*c - 
        1.77375100208433542*a10*c2 + 
        0.367248677248677249*a8*c3 - 
        0.00674603174603174603*a6*c4)*scx12*
      tax2 + (-5.18192918192918193*a12*c + 
        6.73456148789482123*a10*c2 - 
        1.6526984126984127*a8*c3 + 
        0.0460317460317460317*a6*c4)*scx10*
      tax4 + (3.92914492914492914*a12*c - 
        5.07305755972422639*a10*c2 + 
        1.2273015873015873*a8*c3 - 
        0.0365079365079365079*a6*c4)*scx8*
      tax6 + (-0.646575646575646576*a12*c + 
        0.773153759820426487*a10*c2 - 
        0.140529100529100529*a8*c3)*scx6*
      tax8 + (0.0151071151071151071*a12*c - 
        0.014067660734327401*a10*c2)*scx4*
      tax10 - 7.40000740000740001e-6*a12*c*
      scx2*tax12) + 
  eps2*xbar8*((-0.0269409602742936076*a12*c + 
        0.0065758110202554647*a10*c2)*scx14 + 
     (0.957882857882857883*a12*c - 
        0.312411950189727968*a10*c2)*scx12*
      tax2 + (-3.45461945461945462*a12*c + 
        1.16501736946181391*a10*c2)*scx10*
      tax4 + (2.6194299527632861*a12*c - 
        0.87582919138474694*a10*c2)*scx8*
      tax6 + (-0.43105043105043105*a12*c + 
        0.137429319651541874*a10*c2)*scx6*
      tax8 + (0.0100714100714100714*a12*c - 
        0.00273635829191384747*a10*c2)*scx4*
      tax10 - 4.9333382666716e-6*a12*c*
      scx2*tax12) + 
  eps*xbar10*(-0.0107763841097174431*a12*c*
      scx14 + 0.383153143153143153*a12*c*
      scx12*tax2 - 
     1.38184778184778185*a12*c*scx10*
      tax4 + 1.04777198110531444*a12*c*
      scx8*tax6 - 
     0.17242017242017242*a12*c*scx6*
      tax8 + 0.00402856402856402856*a12*c*
      scx4*tax10 - 
     1.97333530666864e-6*a12*c*scx2*
      tax12) + xbar12*
   (-0.00359212803657248102*a12*c*scx14 + 
     0.127717714384381051*a12*c*scx12*
      tax2 - 0.460615927282593949*a12*c*
      scx10*tax4 + 
     0.349257327035104813*a12*c*scx8*
      tax6 - 0.0574733908067241401*a12*c*
      scx6*tax8 + 
     0.00134285467618800952*a12*c*scx4*
      tax10 - 6.57778435556213334e-7*a12*c*
      scx2*tax12) + 
  eps6*xbar2*((0.114646957980291314*a14*c - 
        0.123035808988189941*a12*c2 + 
        0.0164742664742664743*a10*c3 - 
        0.000026455026455026455*a8*c4)*scx16 
+ (-5.40201822868489535*a14*c + 
        6.66970722399293828*a12*c2 - 
        1.39242584575917909*a10*c3 + 
        0.0268783068783068783*a8*c4)*scx14*
      tax2 + (27.7535368335368335*a14*c - 
        35.7117733060590203*a12*c2 + 
        8.50629469296135963*a10*c3 - 
        0.224761904761904762*a8*c4)*scx12*
      tax4 + (-33.6727322060655394*a14*c + 
        43.5586104195628005*a12*c2 - 
        10.5729292929292929*a10*c3 + 
        0.303068783068783069*a8*c4)*scx10*
      tax6 + (10.970694737361404*a14*c - 
        13.8359195302052445*a12*c2 + 
        3.09984928651595318*a10*c3 - 
        0.0702645502645502646*a8*c4)*scx8*
      tax8 + (-0.828294668294668295*a14*c + 
        0.968485482771197057*a12*c2 - 
        0.162026615359948693*a10*c3)*scx6*
      tax10 + (0.00807538140871474205*a14*c - 
        0.00746822842060937299*a12*c2)*scx4*
      tax12 - 9.86667653334320001e-7*a14*c*
      scx2*tax14) + 
  eps5*xbar4*((0.114646957980291314*a14*c - 
        0.105648830886926125*a12*c2 + 
        0.00815776815776815777*a10*c3)*scx16 
+ (-5.40201822868489535*a14*c + 
        5.92416697940507464*a12*c2 - 
        0.823831970498637165*a10*c3)*scx14*
      tax2 + (27.7535368335368335*a14*c - 
        31.604538459776555*a12*c2 + 
        5.02521083854417188*a10*c3)*scx12*
      tax4 + (-33.6727322060655394*a14*c + 
        38.4779933998981618*a12*c2 - 
        6.21090909090909091*a10*c3)*scx10*
      tax6 + (10.970694737361404*a14*c - 
        12.2623867842915462*a12*c2 + 
        1.83309924643257977*a10*c3)*scx8*
      tax8 + (-0.828294668294668295*a14*c + 
        0.868364510269272174*a12*c2 - 
        0.0987910854577521244*a10*c3)*scx6*
      tax10 + (0.00807538140871474205*a14*c - 
        0.00690103547246404389*a12*c2)*scx4*
      tax12 - 9.86667653334320001e-7*a14*c*
      scx2*tax14) + 
  eps4*xbar6*((0.0764313053201942091*a14*c - 
        0.0563019343971724924*a12*c2 + 
        0.0016835016835016835*a10*c3)*scx16 + 
     (-3.60134548578993023*a14*c + 
        3.26488627187039885*a12*c2 - 
        0.206432579765913099*a10*c3)*scx14*
      tax2 + (18.5023578890245557*a14*c - 
        17.3517450920625524*a12*c2 + 
        1.25690556357223024*a10*c3)*scx12*
      tax4 + (-22.4484881373770263*a14*c + 
        21.0995997065838336*a12*c2 - 
        1.55163059163059163*a10*c3)*scx10*
      tax6 + (7.31379649157426935*a14*c - 
        6.74178303765605353*a12*c2 + 
        0.458540965207631874*a10*c3)*scx8*
      tax8 + (-0.552196445529778863*a14*c + 
        0.481744804284486824*a12*c2 - 
        0.0248067981401314735*a10*c3)*scx6*
      tax10 + (0.00538358760580982803*a14*c - 
        0.00393915314550235185*a12*c2)*scx4*
      tax12 - 6.57778435556213334e-7*a14*c*
      scx2*tax14) + 
  eps7*((0.0573234789901456568*a14*c - 
        0.0684889537270489651*a12*c2 + 
        0.0131024531024531025*a10*c3 - 
        0.00021164021164021164*a8*c4)*scx16 + 
     (-2.70100911434244768*a14*c + 
        3.60800807657950515*a12*c2 - 
        0.964399551066217733*a10*c3 + 
        0.0435978835978835979*a8*c4)*scx14*
      tax2 + (13.8767684167684168*a14*c - 
        19.3695036180750466*a12*c2 + 
        5.88809684143017476*a10*c3 - 
        0.356825396825396825*a8*c4)*scx12*
      tax4 + (-16.8363661030327697*a14*c + 
        23.6879987032367985*a12*c2 - 
        7.38495430495430495*a10*c3 + 
        0.488042328042328042*a8*c4)*scx10*
      tax6 + (5.48534736868070201*a14*c - 
        7.49490044347187204*a12*c2 + 
        2.14269039602372936*a10*c3 - 
        0.111322751322751323*a8*c4)*scx8*
      tax8 + (-0.414147334147334147*a14*c + 
        0.517214425785854357*a12*c2 - 
        0.10675645342312009*a10*c3)*scx6*
      tax10 + (0.00403769070435737102*a14*c - 
        0.00388577912387436197*a12*c2)*scx4*
      tax12 - 4.9333382666716e-7*a14*c*
      scx2*tax14) + 
  eps3*xbar8*((0.0382156526600971045*a14*c - 
        0.0196946498533800121*a12*c2)*scx16 + 
     (-1.80067274289496512*a14*c + 
        1.16904283253489603*a12*c2)*scx14*
      tax2 + (9.25117894451227785*a14*c - 
        6.19710859393399076*a12*c2)*scx12*
      tax4 + (-11.2242440686885131*a14*c + 
        7.52936070396387857*a12*c2)*scx10*
      tax6 + (3.65689824578713468*a14*c - 
        2.41008491802142596*a12*c2)*scx8*
      tax8 + (-0.276098222764889432*a14*c + 
        0.173264947868122471*a12*c2)*scx6*
      tax10 + (0.00269179380290491402*a14*c - 
        0.00144335382430620526*a12*c2)*scx4*
      tax12 - 3.28889217778106667e-7*a14*c*
      scx2*tax14) + 
  eps2*xbar10*((0.0152862610640388418*a14*c - 
        0.00393892997067600242*a12*c2)*scx16 
+ (-0.720269097157986047*a14*c + 
        0.233808566506979205*a12*c2)*scx14*
      tax2 + (3.70047157780491114*a14*c - 
        1.23942171878679815*a12*c2)*scx12*
      tax4 + (-4.48969762747540525*a14*c + 
        1.50587214079277571*a12*c2)*scx10*
      tax6 + (1.46275929831485387*a14*c - 
        0.482016983604285192*a12*c2)*scx8*
      tax8 + (-0.110439289105955773*a14*c + 
        0.0346529895736244943*a12*c2)*scx6*
      tax10 + (0.00107671752116196561*a14*c - 
        0.000288670764861241052*a12*c2)*scx4*
      tax12 - 1.31555687111242667e-7*a14*c*
      scx2*tax14) + 
  eps*xbar12*(0.00509542035467961394*a14*c*
      scx16 - 0.240089699052662016*a14*c*
      scx14*tax2 + 
     1.23349052593497038*a14*c*scx12*
      tax4 - 1.49656587582513508*a14*c*
      scx10*tax6 + 
     0.487586432771617957*a14*c*scx8*
      tax8 - 0.0368130963686519242*a14*c*
      scx6*tax10 + 
     0.000358905840387321869*a14*c*scx4*
      tax12 - 4.38518957037475556e-8*a14*c*
      scx2*tax14) + 
  xbar14*(0.00145583438705131827*a14*c*
      scx16 - 0.0685970568721891473*a14*c*
      scx14*tax2 + 
     0.35242586455284868*a14*c*scx12*
      tax4 - 0.427590250235752881*a14*c*
      scx10*tax6 + 
     0.139310409363319416*a14*c*scx8*
      tax8 - 0.0105180275339005498*a14*c*
      scx6*tax10 + 
     0.000102544525824949105*a14*c*scx4*
      tax12 - 1.25291130582135873e-8*a14*c*
      scx2*tax14) + 
  eps7*xbar2*((-0.185858643897859584*a16*c + 
        0.226050069859593669*a14*c2 - 
        0.0457946568422758899*a12*c3 + 
        0.000885040885040885041*a10*c4)*scx18 
+ (11.2079619436482182*a16*c - 
        15.0010988658607706*a14*c2 + 
        4.04373775078536983*a12*c3 - 
        0.188590668590668591*a10*c4)*scx16*
      tax2 + (-77.7704089955070347*a16*c + 
        107.894628546057117*a14*c2 - 
        32.2687829278305469*a12*c3 + 
        1.90133718133718134*a10*c4)*scx14*
      tax4 + (138.123473273277195*a16*c - 
        193.684971043066281*a14*c2 + 
        59.7631320355129879*a12*c3 - 
        3.82226070226070226*a10*c4)*scx12*
      tax6 + (-75.1377256004706985*a16*c + 
        104.373751398513303*a14*c2 - 
        31.3736089659899184*a12*c3 + 
        1.89267917267917268*a10*c4)*scx10*
      tax8 + (12.1194328692367908*a16*c - 
        16.259099630528202*a14*c2 + 
        4.39479755517850756*a12*c3 - 
        0.194247234247234247*a10*c4)*scx8*
      tax10 + (-0.453237278335317551*a16*c + 
        0.558575956671194766*a14*c2 - 
        0.110146107860393575*a12*c3)*scx6*
      tax12 + (0.00190133758761209742*a16*c - 
        0.00182448944353706258*a14*c2)*scx4*
      tax14 - 5.80392737255482354e-8*a16*c*
      scx2*tax16) + 
  eps6*xbar4*((-0.185858643897859584*a16*c + 
        0.203924611543659163*a14*c2 - 
        0.0296020405226754433*a12*c3 + 
        0.00011544011544011544*a10*c4)*scx18 
+ (11.2079619436482182*a16*c - 
        13.8531909360480789*a14*c2 + 
        2.9138804616899855*a12*c3 - 
        0.058152958152958153*a10*c4)*scx16*
      tax2 + (-77.7704089955070347*a16*c + 
        99.4877112305683734*a14*c2 - 
        23.2957734329162901*a12*c3 + 
        0.596921596921596922*a10*c4)*scx14*
      tax4 + (138.123473273277195*a16*c - 
        178.250027926218402*a14*c2 + 
        42.9167486716693066*a12*c3 - 
        1.1924963924963925*a10*c4)*scx12*
      tax6 + (-75.1377256004706985*a16*c + 
        96.1311196739768168*a14*c2 - 
        22.5589448294210199*a12*c3 + 
        0.591053391053391053*a10*c4)*scx10*
      tax8 + (12.1194328692367908*a16*c - 
        15.0490802319373748*a14*c2 + 
        3.20175604289890004*a12*c3 - 
        0.0612602212602212602*a10*c4)*scx8*
      tax10 + (-0.453237278335317551*a16*c + 
        0.523194759385235576*a14*c2 - 
        0.0832945208818224691*a12*c3)*scx6*
      tax12 + (0.00190133758761209742*a16*c - 
        0.00175063032205889349*a14*c2)*scx4*
      tax14 - 5.80392737255482354e-8*a16*c*
      scx2*tax16) + 
  eps5*xbar6*((-0.123905762598573056*a16*c + 
        0.117400483114768829*a14*c2 - 
        0.0102164768408154652*a12*c3)*scx18 + 
     (7.47197462909881211*a16*c - 
        8.19425898029072632*a14*c2 + 
        1.14659809796317733*a12*c3)*scx16*
      tax2 + (-51.8469393303380231*a16*c + 
        58.7218594456689695*a14*c2 - 
        9.17379763094048808*a12*c3)*scx14*
      tax4 + (92.0823155155181299*a16*c - 
        105.045261475737666*a14*c2 + 
        16.8408481661391714*a12*c3)*scx12*
      tax6 + (-50.0918170669804657*a16*c + 
        56.6950520144170938*a14*c2 - 
        8.85988602813999639*a12*c3)*scx10*
      tax8 + (8.0796219128245272*a16*c - 
        8.912052462528653*a14*c2 + 
        1.26820357067976116*a12*c3)*scx8*
      tax10 + (-0.302158185556878367*a16*c + 
        0.313038636848160658*a14*c2 - 
        0.0337833626299234765*a12*c3)*scx6*
      tax12 + (0.00126755839174139828*a16*c - 
        0.00107650139396171142*a14*c2)*scx4*
      tax14 - 3.86928491503654902e-8*a16*c*
      scx2*tax16) + 
  eps8*((-0.0929293219489297921*a16*c + 
        0.121721382673763626*a14*c2 - 
        0.0309726064646699567*a12*c3 + 
        0.001282667949334616*a10*c4)*scx18 + 
     (5.60398097182410908*a16*c - 
        7.93101200386914673*a14*c2 + 
        2.51969506507601746*a12*c3 - 
        0.18594997594997595*a10*c4 + 
        0.00136684303350970018*a8*c5)*scx16*
      tax2 + (-38.8852044977535174*a16*c + 
        57.0846957275528704*a14*c2 - 
        20.0409831966974824*a12*c3 + 
        1.83578964245630912*a10*c4 - 
        0.0208994708994708995*a8*c5)*scx14*
      tax4 + (69.0617366366385974*a16*c - 
        102.699346878870688*a14*c2 + 
        37.3511459146379781*a12*c3 - 
        3.72521564854898188*a10*c4 + 
        0.0513227513227513228*a8*c5)*scx12*
      tax6 + (-37.5688628002353493*a16*c + 
        55.3069127697699126*a14*c2 - 
        19.5891233281709472*a12*c3 + 
        1.84754208754208754*a10*c4 - 
        0.0236331569664902998*a8*c5)*scx10*
      tax8 + (6.0597164346183954*a16*c - 
        8.56489404775119061*a14*c2 + 
        2.6950718487861345*a12*c3 - 
        0.181997755331088664*a10*c4)*scx8*
      tax10 + (-0.226618639167658776*a16*c + 
        0.290485740009549533*a14*c2 - 
        0.0646747068334369922*a12*c3)*scx6*
      tax12 + (0.000950668793806048708*a16*c - 
        0.000931449502878074307*a14*c2)*scx4*
      tax14 - 2.90196368627741177e-8*a16*c*
      scx2*tax16) + 
  eps4*xbar8*((-0.061952881299286528*a16*c + 
        0.0472042478391684741*a14*c2 - 
        0.00167763570938174113*a12*c3)*scx18 
+ (3.73598731454940605*a16*c - 
        3.3833464947750662*a14*c2 + 
        0.21498789746408794*a12*c3)*scx16*
      tax2 + (-25.9234696651690116*a16*c + 
        24.1913574961194009*a14*c2 - 
        1.72116581830867545*a12*c3)*scx14*
      tax4 + (46.0411577577590649*a16*c - 
        43.2220304445701271*a14*c2 + 
        3.15677276280450884*a12*c3)*scx12*
      tax6 + (-25.0459085334902328*a16*c + 
        23.3437749552035266*a14*c2 - 
        1.6609766247861486*a12*c3)*scx10*
      tax8 + (4.0398109564122636*a16*c - 
        3.68143087952611762*a14*c2 + 
        0.238059887202744346*a12*c3)*scx8*
      tax10 + (-0.151079092778439184*a16*c + 
        0.130395412935095475*a14*c2 - 
        0.00635937372445308953*a12*c3)*scx6*
      tax12 + (0.000633779195870699139*a16*c - 
        0.000460069031497602926*a14*c2)*scx4*
      tax14 - 1.93464245751827451e-8*a16*c*
      scx2*tax16) + 
  eps3*xbar10*((-0.0247811525197146112*a16*c + 
        0.0132660003136193612*a14*c2)*scx18 + 
     (1.49439492581976242*a16*c - 
        0.968465599068773672*a14*c2)*scx16*
      tax2 + (-10.3693878660676046*a16*c + 
        6.91410284248379486*a14*c2)*scx14*
      tax4 + (18.416463103103626*a16*c - 
        12.3429536953346477*a14*c2)*scx12*
      tax6 + (-10.0183634133960931*a16*c + 
        6.66940781734432528*a14*c2)*scx10*
      tax8 + (1.61592438256490544*a16*c - 
        1.05412262517024422*a14*c2)*scx8*
      tax10 + (-0.0604316371113756735*a16*c + 
        0.0375467072609929753*a14*c2)*scx6*
      tax12 + (0.000253511678348279655*a16*c - 
        0.000134713023601912491*a14*c2)*scx4*
      tax14 - 7.73856983007309805e-9*a16*c*
      scx2*tax16) + 
  eps2*xbar12*((-0.00826038417323820374*a16*c + 
        0.00221100005226989354*a14*c2)*scx18 
+ (0.498131641939920807*a16*c - 
        0.161410933178128945*a14*c2)*scx16*
      tax2 + (-3.45646262202253488*a16*c + 
        1.15235047374729914*a14*c2)*scx14*
      tax4 + (6.13882103436787533*a16*c - 
        2.05715894922244129*a14*c2)*scx12*
      tax6 + (-3.33945447113203104*a16*c + 
        1.11156796955738755*a14*c2)*scx10*
      tax8 + (0.53864146085496848*a16*c - 
        0.175687104195040703*a14*c2)*scx8*
      tax10 + (-0.0201438790371252245*a16*c + 
        0.00625778454349882921*a14*c2)*scx6*
      tax12 + (0.0000845038927827598852*a16*c - 
        0.0000224521706003187485*a14*c2)*
      scx4*tax14 - 
     2.57952327669103268e-9*a16*c*scx2*
      tax16) + eps*xbar14*
   (-0.00236010976378234393*a16*c*scx18 + 
     0.142323326268548802*a16*c*scx16*
      tax2 - 0.987560749149295679*a16*c*
      scx14*tax4 + 
     1.75394886696225009*a16*c*scx12*
      tax6 - 0.954129848894866013*a16*c*
      scx10*tax8 + 
     0.153897560244276709*a16*c*scx8*
      tax10 - 0.005755394010607207*a16*c*
      scx6*tax12 + 
     0.0000241439693665028243*a16*c*scx4*
      tax14 - 7.37006650483152195e-10*a16*c*
      scx2*tax16) + 
  xbar16*(-0.000590027440945585981*a16*c*
      scx18 + 0.0355808315671372005*a16*c*
      scx16*tax2 - 
     0.24689018728732392*a16*c*scx14*
      tax4 + 0.438487216740562523*a16*c*
      scx12*tax6 - 
     0.238532462223716503*a16*c*scx10*
      tax8 + 0.0384743900610691772*a16*c*
      scx8*tax10 - 
     0.00143884850265180175*a16*c*scx6*
      tax12 + 6.03599234162570608e-6*a16*c*
      scx4*tax14 - 
     1.84251662620788049e-10*a16*c*scx2*
      tax16) + eps8*xbar2*
   ((0.338965519440235643*a18*c - 
        0.449331046701105836*a16*c2 + 
        0.118500394960712421*a14*c3 - 
        0.005373902992950612*a12*c4 + 
        1.33611244722355833e-6*a10*c5)*scx20 
+ (-25.4596304188873848*a18*c + 
        36.1209111168712787*a16*c2 - 
        11.5662477710414218*a14*c3 + 
        0.872727989235925744*a12*c4 - 
        0.00682753460531238309*a10*c5)*scx18*
      tax2 + (229.397069225923715*a18*c - 
        335.552056292544932*a16*c2 + 
        116.747472291377053*a14*c3 - 
        10.5339172937585636*a12*c4 + 
        0.118179145956923735*a10*c5)*scx16*
      tax4 + (-561.256004034951403*a18*c + 
        831.351454340635791*a16*c2 - 
        299.179159476619794*a14*c3 + 
        29.1237527669273701*a12*c4 - 
        0.38226177115066004*a10*c5)*scx14*
      tax6 + (459.949290411457594*a18*c - 
        680.155392977646323*a16*c2 + 
        243.785773109900094*a14*c3 - 
        23.5895717216352137*a12*c4 + 
        0.3119555341777564*a10*c5)*scx12*
      tax8 + (-129.632279739524322*a18*c + 
        188.404521602591942*a16*c2 - 
        64.4191093703474656*a14*c3 + 
        5.58471238344254217*a12*c4 - 
        0.0557746779969002191*a10*c5)*scx10*
      tax10 + (11.2480662302953325*a18*c - 
        15.6882867698865209*a16*c2 + 
        4.74847317526682606*a14*c3 - 
        0.289943942007434071*a12*c4)*scx8*
      tax12 + (-0.218294060027806158*a18*c + 
        0.277654091709491647*a16*c2 - 
        0.0602644104866327089*a14*c3)*scx6*
      tax14 + (0.000400356437508140295*a18*c - 
        0.000391761412614198173*a16*c2)*scx4*
      tax16 - 3.05469861713411765e-9*a18*c*
      scx2*tax18) + 
  eps7*xbar4*((0.338965519440235643*a18*c - 
        0.418152411846778482*a16*c2 + 
        0.088688329894679101*a14*c3 - 
        0.0020087425801711516*a12*c4)*scx20 + 
     (-25.4596304188873848*a18*c + 
        34.1460262263125631*a16*c2 - 
        9.27404123683488763*a14*c3 + 
        0.442973999545428117*a12*c4)*scx18*
      tax2 + (229.397069225923715*a18*c - 
        317.100216311912546*a16*c2 + 
        93.924511375749471*a14*c3 - 
        5.44177135034277891*a12*c4)*scx16*
      tax4 + (-561.256004034951403*a18*c + 
        784.425188222113214*a16*c2 - 
        239.756383816066356*a14*c3 + 
        14.9756981642695928*a12*c4)*scx14*
      tax6 + (459.949290411457594*a18*c - 
        641.622560793864871*a16*c2 + 
        195.161895012688663*a14*c3 - 
        12.0957396043110329*a12*c4)*scx12*
      tax8 + (-129.632279739524322*a18*c + 
        178.107047761750532*a16*c2 - 
        51.8578248277295896*a14*c3 + 
        2.88741844398987256*a12*c4)*scx10*
      tax10 + (11.2480662302953325*a18*c - 
        14.9135467674652237*a16*c2 + 
        3.88550743318997287*a14*c3 - 
        0.154389694961123533*a12*c4)*scx8*
      tax12 + (-0.218294060027806158*a18*c + 
        0.266878143354956302*a16*c2 - 
        0.0511479678463805448*a14*c3)*scx6*
      tax14 + (0.000400356437508140295*a18*c - 
        0.000383361379315316446*a16*c2)*scx4*
      tax16 - 3.05469861713411765e-9*a18*c*
      scx2*tax18) + 
  eps6*xbar6*((0.225977012960157095*a18*c - 
        0.252274679553442911*a16*c2 + 
        0.0389700505256060812*a14*c3 - 
        0.00023849871468919088*a12*c4)*scx20 
+ (-16.9730869459249232*a18*c + 
        21.0099136803608222*a16*c2 - 
        4.45005968282158758*a14*c3 + 
        0.0910621935383840146*a12*c4)*scx18*
      tax2 + (152.931379483949143*a18*c - 
        194.941808121063231*a16*c2 + 
        45.1821141962094343*a14*c3 - 
        1.13670238051190432*a12*c4)*scx16*
      tax4 + (-374.170669356634269*a18*c + 
        481.541495992297943*a16*c2 - 
        114.948479715463842*a14*c3 + 
        3.11980915028534076*a12*c4)*scx14*
      tax6 + (306.632860274305063*a18*c - 
        393.84067332267353*a16*c2 + 
        93.5065662379948094*a14*c3 - 
        2.51726996107948489*a12*c4)*scx12*
      tax8 + (-86.4215198263495477*a18*c + 
        109.530871116487882*a16*c2 - 
        24.9545702833321881*a14*c3 + 
        0.602481144957335434*a12*c4)*scx10*
      tax10 + (7.49871082019688831*a18*c - 
        9.21605332716028846*a16*c2 + 
        1.89352242583988616*a14*c3 - 
        0.0324366709128613891*a12*c4)*scx8*
      tax12 + (-0.145529373351870772*a18*c + 
        0.166664818699262106*a16*c2 - 
        0.0257174078126459079*a14*c3)*scx6*
      tax14 + (0.00026690429167209353*a18*c - 
        0.000244941703599240688*a16*c2)*scx4*
      tax16 - 2.03646574475607843e-9*a18*c*
      scx2*tax18) + 
  eps9*((0.169482759720117821*a18*c - 
        0.23689588736585313*a16*c2 + 
        0.0729237229554689872*a14*c3 - 
        0.00507169726217345265*a12*c4 + 
        0.0000342044786489230934*a10*c5)*
      scx20 + (-12.7298152094436924*a18*c + 
        18.8195841345545672*a16*c2 - 
        6.76322534373328024*a14*c3 + 
        0.681922977669009415*a12*c4 - 
        0.0131975843086954198*a10*c5)*scx18*
      tax2 + (114.698534612961858*a18*c - 
        174.80314173233252*a16*c2 + 
        67.9896361592552069*a14*c3 - 
        8.08221088729025237*a12*c4 + 
        0.215121586232697344*a10*c5)*scx16*
      tax4 + (-280.628002017475702*a18*c + 
        433.75849904265715*a16*c2 - 
        174.931479114653718*a14*c3 + 
        22.4658366442493427*a12*c4 - 
        0.697329912885468441*a10*c5)*scx14*
      tax6 + (229.974645205728797*a18*c - 
        355.013650548135453*a16*c2 + 
        142.775170485011755*a14*c3 - 
        18.2805861745544285*a12*c4 + 
        0.573680722569611459*a10*c5)*scx12*
      tax8 + (-64.8161398697621608*a18*c + 
        98.1078630942434242*a16*c2 - 
        37.476140593092974*a14*c3 + 
        4.2724290970640177*a12*c4 - 
        0.100635989524878414*a10*c5)*scx10*
      tax10 + (5.62403311514766623*a18*c - 
        8.11803934500791021*a16*c2 + 
        2.70829198079991731*a14*c3 - 
        0.211942521910775879*a12*c4)*scx8*
      tax12 + (-0.109147030013903079*a18*c + 
        0.142128186622428764*a16*c2 - 
        0.0331326004976798628*a14*c3)*scx6*
      tax14 + (0.000200178218754070147*a18*c - 
        0.000198029080693257475*a16*c2)*scx4*
      tax16 - 1.52734930856705883e-9*a18*c*
      scx2*tax18) + 
  eps5*xbar8*((0.112988506480078548*a18*c - 
        0.109356786850302775*a16*c2 + 
        0.0103719725307026894*a14*c3)*scx20 + 
     (-8.48654347296246161*a18*c + 
        9.31417733592233022*a16*c2 - 
        1.31147809039872532*a14*c3)*scx18*
      tax2 + (76.4656897419745717*a18*c - 
        86.3107319972700199*a16*c2 + 
        13.3405959684054922*a14*c3)*scx16*
      tax4 + (-187.085334678317134*a18*c + 
        212.932005549828975*a16*c2 - 
        33.8628879644752661*a14*c3)*scx14*
      tax6 + (153.316430137152531*a18*c - 
        174.148974476166094*a16*c2 + 
        27.5340345956218972*a14*c3)*scx12*
      tax8 + (-43.2107599131747739*a18*c + 
        48.511124592651722*a16*c2 - 
        7.36907040754659802*a14*c3)*scx10*
      tax10 + (3.74935541009844415*a18*c - 
        4.09869648819747378*a16*c2 + 
        0.563751348005316259*a14*c3)*scx8*
      tax12 + (-0.0727646866759353859*a18*c + 
        0.0748199619617816526*a16*c2 - 
        0.00780965301600222235*a14*c3)*scx6*
      tax14 + (0.000133452145836046765*a18*c - 
        0.000112811151300621163*a16*c2)*scx4*
      tax16 - 1.01823287237803922e-9*a18*c*
      scx2*tax18) + 
  eps4*xbar10*((0.045195402592031419*a18*c - 
        0.0353189692195813163*a16*c2 + 
        0.00140830597973455116*a14*c3)*scx20 
+ (-3.39461738918498464*a18*c + 
        3.07451063750679893*a16*c2 - 
        0.196477568287092097*a14*c3)*scx18*
      tax2 + (30.5862758967898287*a18*c - 
        28.450936435222357*a16*c2 + 
        2.00208445522731237*a14*c3)*scx16*
      tax4 + (-74.8341338713268538*a18*c + 
        70.1159002621643974*a16*c2 - 
        5.07926105640391355*a14*c3)*scx14*
      tax6 + (61.3265720548610125*a18*c - 
        57.3467281932101934*a16*c2 + 
        4.12930089311041692*a14*c3)*scx12*
      tax8 + (-17.2843039652699095*a18*c + 
        15.9956530580653415*a16*c2 - 
        1.1056151467580039*a14*c3)*scx10*
      tax10 + (1.49974216403937766*a18*c - 
        1.35596799077243107*a16*c2 + 
        0.0846769738198309627*a14*c3)*scx8*
      tax12 + (-0.0291058746703741544*a18*c + 
        0.0249459329579674014*a16*c2 - 
        0.00117560041369565179*a14*c3)*scx6*
      tax14 + (0.0000533808583344187059*a18*c - 
        0.0000385208809319194214*a16*c2)*
      scx4*tax16 - 
     4.07293148951215687e-10*a18*c*scx2*
      tax18) + eps3*xbar12*
   ((0.0150651341973438063*a18*c - 
        0.00829522572248304517*a16*c2)*scx20 
+ (-1.13153912972832821*a18*c + 
        0.733048130420195296*a16*c2)*scx18*
      tax2 + (10.1954252989299429*a18*c - 
        6.77713553423454174*a16*c2)*scx16*
      tax4 + (-24.9447112904422846*a18*c + 
        16.689986475541547*a16*c2)*scx14*
      tax6 + (20.4421906849536708*a18*c - 
        13.6507459718885524*a16*c2)*scx12*
      tax8 + (-5.76143465508996985*a18*c + 
        3.81100124495137809*a16*c2)*scx10*
      tax10 + (0.499914054679792554*a18*c - 
        0.323790050271773825*a16*c2)*scx8*
      tax12 + (-0.00970195822345805146*a18*c + 
        0.00598797521189193908*a16*c2)*scx6*
      tax14 + (0.0000177936194448062353*a18*c - 
        9.39175763673463988e-6*a16*c2)*scx4*
      tax16 - 1.35764382983738562e-10*a18*c*
      scx2*tax18) + 
  eps2*xbar14*((0.00430432405638394467*a18*c - 
        0.00118503224606900645*a16*c2)*scx20 
+ (-0.323296894208093776*a18*c + 
        0.104721161488599328*a16*c2)*scx18*
      tax2 + (2.91297865683712654*a18*c - 
        0.968162219176363106*a16*c2)*scx16*
      tax4 + (-7.1270603686977956*a18*c + 
        2.38428378222022099*a16*c2)*scx14*
      tax6 + (5.8406259099867631*a18*c - 
        1.95010656741265034*a16*c2)*scx12*
      tax8 + (-1.64612418716856281*a18*c + 
        0.544428749278768299*a16*c2)*scx10*
      tax10 + (0.142832587051369301*a18*c - 
        0.0462557214673962608*a16*c2)*scx8*
      tax12 + (-0.00277198806384515756*a18*c + 
        0.000855425030270277011*a16*c2)*scx6*
      tax14 + (5.08389126994463866e-6*a18*c - 
        1.34167966239066284e-6*a16*c2)*scx4*
      tax16 - 3.87898237096395892e-11*a18*c*
      scx2*tax18) + 
  eps*xbar16*(0.00107608101409598617*a18*c*
      scx20 - 0.0808242235520234439*a18*c*
      scx18*tax2 + 
     0.728244664209281635*a18*c*scx16*
      tax4 - 1.7817650921744489*a18*c*
      scx14*tax6 + 
     1.46015647749669077*a18*c*scx12*
      tax8 - 0.411531046792140703*a18*c*
      scx10*tax10 + 
     0.0357081467628423253*a18*c*scx8*
      tax12 - 0.00069299701596128939*a18*c*
      scx6*tax14 + 
     1.27097281748615967e-6*a18*c*scx4*
      tax16 - 9.6974559274098973e-12*a18*c*
      scx2*tax18) + 
  xbar18*(0.000239129114243552481*a18*c*
      scx20 - 0.0179609385671163209*a18*c*
      scx18*tax2 + 
     0.161832147602062586*a18*c*scx16*
      tax4 - 0.395947798260988644*a18*c*
      scx14*tax6 + 
     0.324479217221486839*a18*c*scx12*
      tax8 - 0.091451343731586823*a18*c*
      scx10*tax10 + 
     0.00793514372507607228*a18*c*scx8*
      tax12 - 0.000153999336880286531*a18*c*
      scx6*tax14 + 
     2.82438403885813259e-7*a18*c*scx4*
      tax16 - 2.15499020609108829e-12*a18*c*
      scx2*tax18);
}
#endif
