/* SPEEDUP Path Integral Monte Carlo code is developed by A. Balaz,
   D. Stojiljkovic, I. Vidanovic, A. Belic, and A. Bogojevic.
         
   Address: Institute of Physics, Belgrade, Serbia
   Scientific Computing Laboratory, http://www.scl.rs/

   Public use and modification of this code is allowed providing 
   the authors are properly acknowledged. The authors would be   
   grateful for all information and/or comments regarding the use   
   of the code.  
*/

/* Example p.c file for the model-specific approach for the anharmonic
   oscillator potential
                        V(x) = A * x^2 / 2 + g * x^4 / 24

   Parameters: A = par[0], g = par[1], as entered on the command line.

   Maximal implemented level of the effective action is p = 30.
*/

/* Function func(q[]) returns exp(- action + norm), where the variable action is
   the action for the given path (q[0], q[step], ..., q[N]) plus the exponent of
   the Gaussian probability density function (*distrexp), and norm is the normalization
   (*norm) of the path integral (which also includes the normalization of Gaussians).
   Array *norm is defined in main(), array *distrexp in distr().
   The effective potential Wp() for every pair of points (q[i], q[i + step])
   is evaluated at the mid-point x.
*/

#include <p.h>

double func(double *q, double T, int s, int n)
{
   double Wp(void); /* The function that, for a given p, returns the effective potential. */

   int i; /* Loop variable for the loop over the time steps. */

   A = par[0]; /* Initialization of parameters of the potential and their powers. */
   A2 = A * A;
   A3 = A * A2;
   A4 = A * A3;
   A5 = A * A4;
   A6 = A * A5;
   A7 = A * A6;
   A8 = A * A7;
   A9 = A * A8;
   A10 = A * A9;
   A11 = A * A10;
   A12 = A * A11;
   A13 = A * A12;
   A14 = A * A13;
   A15 = A * A14;

   g = par[1];
   g2 = g * g;
   g3 = g * g2;
   g4 = g * g3;
   g5 = g * g4;
   g6 = g * g5;
   g7 = g * g6;
   g8 = g * g7;
   g9 = g * g8;
   g10 = g * g9;
   g11 = g * g10;
   g12 = g * g11;
   g13 = g * g12;
   g14 = g * g13;
   g15 = g * g14;

   action = 0; /* Initialiation of the action. */
   Nmax = two[s]; /* The maximal number of time steps. */
   Nc = two[n]; /* The current number of time steps. */
   step = two[s - n]; /* Index distance of path nodes at current bisection level. */
   eps = T / Nc; /* Current time step and related variables, introduced for optimization. */
   epsinv = 1. / eps;
   eps2 = eps * eps;
   eps3 = eps * eps2;
   eps4 = eps * eps3;
   eps5 = eps * eps4;
   eps6 = eps * eps5;
   eps7 = eps * eps6;
   eps8 = eps * eps7;
   eps9 = eps * eps8;
   eps10 = eps * eps9;
   eps11 = eps * eps10;
   eps12 = eps * eps11;
   eps13 = eps * eps12;
   eps14 = eps * eps13;
   eps15 = eps * eps14;
   eps16 = eps * eps15;
   eps17 = eps * eps16;
   eps18 = eps * eps17;
   eps19 = eps * eps18;
   eps20 = eps * eps19;
   eps21 = eps * eps20;
   eps22 = eps * eps21;
   eps23 = eps * eps22;
   eps24 = eps * eps23;
   eps25 = eps * eps24;
   eps26 = eps * eps25;
   eps27 = eps * eps26;
   eps28 = eps * eps27;
   eps29 = eps * eps28;

   for(i = 0; i < Nmax; i += step) /* Loop over path nodes at current bisection level. */
   {
      x = (q[i + step] + q[i]) * 0.5; /* Mid-point for nearest nodes and its powers. */
      x2 = x * x;
      x4 = x2 * x2;
      x6 = x2 * x4; 
      x8 = x2 * x6; 
      x10 = x2 * x8; 
      x12 = x2 * x10; 
      x14 = x2 * x12; 
      x16 = x2 * x14; 
      x18 = x2 * x16; 
      x20 = x2 * x18; 
      x22 = x2 * x20; 
      x24 = x2 * x22; 
      x26 = x2 * x24; 
      x28 = x2 * x26; 
      x30 = x2 * x28; 
      x32 = x2 * x30; 

      xbar = (q[i + step] - q[i]) * 0.5; /* Half-distance between nearest nodes and its powers. */
      xbar2 = xbar * xbar; /* Square of xbar. */
      xbar4 = xbar2 * xbar2;
      xbar6 = xbar2 * xbar4;
      xbar8 = xbar2 * xbar6;
      xbar10 = xbar2 * xbar8;
      xbar12 = xbar2 * xbar10;
      xbar14 = xbar2 * xbar12;
      xbar16 = xbar2 * xbar14;
      xbar18 = xbar2 * xbar16;
      xbar20 = xbar2 * xbar18;
      xbar22 = xbar2 * xbar20;

      action += 2 * xbar2 * epsinv + eps * Wp() - distrexp[i]; /* Accumulation of the action minus
                                                                     the exponent of the Gaussian. */
   }

   return exp(- action + norm[n]); /* norm[n] includes the path integral norm for a
                                      given number of time steps 2^n and normalization of Gaussians
                                      used as probability density functions. */
}

/* For a chosen p, the function Vp() returns the value of the effective potential.
   This function uses the values of the potential and all its nonvanishing
   derivatives up to order 2p-2, defined in V0(), supplied by the user.

   V00 is the value of the potential, and Vnm (nm = 01, 02, ..., 34) are the
   derivatives of the potential. Additional variables Vnmk = (Vnm)^k and
   xbarn = xbar^n are introduced for optimization purposes.
*/

#ifdef p1
double Wp(void)
{
   return 0.5*A*x2 + 0.0416666666666666667*g*x4;
}
#endif

#ifdef p2
double Wp(void)
{
   return 0.5*A*x2 + 0.0416666666666666667*g*x4 + 
  eps*(0.0833333333333333333*A + 0.0416666666666666667*g*x2) + 
  0.166666666666666667*(A + 0.5*g*x2)*xbar2;
}
#endif

#ifdef p3
double Wp(void)
{
   return 0.5*A*x2 + 0.0416666666666666667*g*x4 + 
  eps*(0.0833333333333333333*A + 0.0416666666666666667*g*x2) + 
  eps2*(0.00416666666666666667*g - 
     0.0416666666666666667*A2*x2 - 
     0.0138888888888888889*A*g*x4 - 
     0.00115740740740740741*g2*x6) + 
  0.00833333333333333333*eps*g*xbar2 + 
  0.166666666666666667*(A + 0.5*g*x2)*xbar2 + 
  0.00833333333333333333*g*xbar4;
}
#endif

#ifdef p4
double Wp(void)
{
   return 0.5*A*x2 + 0.0416666666666666667*g*x4 + 
  eps*(0.0833333333333333333*A + 0.0416666666666666667*g*x2) + 
  eps3*(-0.00277777777777777778*A2 - 
     0.0111111111111111111*A*g*x2 - 
     0.00208333333333333333*g2*x4) + 
  eps2*(0.00416666666666666667*g - 
     0.0416666666666666667*A2*x2 - 
     0.0138888888888888889*A*g*x4 - 
     0.00115740740740740741*g2*x6) + 
  0.00833333333333333333*eps*g*xbar2 + 
  0.166666666666666667*(A + 0.5*g*x2)*xbar2 + 
  eps2*(-0.00277777777777777778*A2 - 
     0.0111111111111111111*A*g*x2 - 
     0.00208333333333333333*g2*x4)*xbar2 + 
  0.00833333333333333333*g*xbar4;
}
#endif

#ifdef p5
double Wp(void)
{
   return 0.5*A*x2 + 0.0416666666666666667*g*x4 + 
  eps*(0.0833333333333333333*A + 0.0416666666666666667*g*x2) + 
  eps3*(-0.00277777777777777778*A2 - 
     0.0111111111111111111*A*g*x2 - 
     0.00208333333333333333*g2*x4) + 
  eps2*(0.00416666666666666667*g - 
     0.0416666666666666667*A2*x2 - 
     0.0138888888888888889*A*g*x4 - 
     0.00115740740740740741*g2*x6) + 
  eps4*(-0.000595238095238095238*A*g + 
     0.00416666666666666667*A3*x2 - 
     0.000868055555555555556*g2*x2 + 
     0.00347222222222222222*A2*g*x4 + 
     0.000810185185185185185*A*g2*x6 + 
     0.0000578703703703703704*g3*x8) + 
  0.00833333333333333333*eps*g*xbar2 + 
  0.166666666666666667*(A + 0.5*g*x2)*xbar2 + 
  eps3*(-0.000793650793650793651*A*g - 
     0.00138888888888888889*g2*x2)*xbar2 + 
  eps2*(-0.00277777777777777778*A2 - 
     0.0111111111111111111*A*g*x2 - 
     0.00208333333333333333*g2*x4)*xbar2 + 
  0.00833333333333333333*g*xbar4 + 
  eps2*(-0.000396825396825396825*A*g - 
     0.000694444444444444444*g2*x2)*xbar4;
}
#endif

#ifdef p6
double Wp(void)
{
   return 0.5*A*x2 + 0.0416666666666666667*g*x4 + 
  eps*(0.0833333333333333333*A + 0.0416666666666666667*g*x2) + 
  eps3*(-0.00277777777777777778*A2 - 
     0.0111111111111111111*A*g*x2 - 
     0.00208333333333333333*g2*x4) + 
  eps2*(0.00416666666666666667*g - 
     0.0416666666666666667*A2*x2 - 
     0.0138888888888888889*A*g*x4 - 
     0.00115740740740740741*g2*x6) + 
  eps5*(0.0001763668430335097*A3 - 
     0.0000388558201058201058*g2 + 
     0.00214947089947089947*A2*g*x2 + 
     0.00124007936507936508*A*g2*x4 + 
     0.000154320987654320988*g3*x6) + 
  eps4*(-0.000595238095238095238*A*g + 
     0.00416666666666666667*A3*x2 - 
     0.000868055555555555556*g2*x2 + 
     0.00347222222222222222*A2*g*x4 + 
     0.000810185185185185185*A*g2*x6 + 
     0.0000578703703703703704*g3*x8) + 
  0.00833333333333333333*eps*g*xbar2 + 
  0.166666666666666667*(A + 0.5*g*x2)*xbar2 + 
  eps3*(-0.000793650793650793651*A*g - 
     0.00138888888888888889*g2*x2)*xbar2 + 
  eps2*(-0.00277777777777777778*A2 - 
     0.0111111111111111111*A*g*x2 - 
     0.00208333333333333333*g2*x4)*xbar2 + 
  eps4*(0.0000661375661375661376*A3 - 
     0.0000644841269841269841*g2 + 
     0.0015873015873015873*A2*g*x2 + 
     0.00094246031746031746*A*g2*x4 + 
     0.000115740740740740741*g3*x6)*xbar2 + 
  0.00833333333333333333*g*xbar4 - 
  0.0000462962962962962963*eps3*g2*xbar4 + 
  eps2*(-0.000396825396825396825*A*g - 
     0.000694444444444444444*g2*x2)*xbar4 - 
  0.0000154320987654320988*eps2*g2*xbar6;
}
#endif

#ifdef p7
double Wp(void)
{
   return 0.5*A*x2 + 0.0416666666666666667*g*x4 + 
  eps*(0.0833333333333333333*A + 0.0416666666666666667*g*x2) + 
  eps3*(-0.00277777777777777778*A2 - 
     0.0111111111111111111*A*g*x2 - 
     0.00208333333333333333*g2*x4) + 
  eps2*(0.00416666666666666667*g - 
     0.0416666666666666667*A2*x2 - 
     0.0138888888888888889*A*g*x4 - 
     0.00115740740740740741*g2*x6) + 
  eps5*(0.0001763668430335097*A3 - 
     0.0000388558201058201058*g2 + 
     0.00214947089947089947*A2*g*x2 + 
     0.00124007936507936508*A*g2*x4 + 
     0.000154320987654320988*g3*x6) + 
  eps4*(-0.000595238095238095238*A*g + 
     0.00416666666666666667*A3*x2 - 
     0.000868055555555555556*g2*x2 + 
     0.00347222222222222222*A2*g*x4 + 
     0.000810185185185185185*A*g2*x6 + 
     0.0000578703703703703704*g3*x8) + 
  eps6*(0.0000793650793650793651*A2*g - 
     0.000421626984126984127*A4*x2 + 
     0.000412533068783068783*A*g2*x2 - 
     0.000710978835978835979*A3*g*x4 + 
     0.00012359457671957672*g3*x4 - 
     0.000332065696649029982*A2*g2*x6 - 
     0.0000592482363315696649*A*g3*x8 - 
     3.61689814814814815e-6*g4*x10) + 
  0.00833333333333333333*eps*g*xbar2 + 
  0.166666666666666667*(A + 0.5*g*x2)*xbar2 + 
  eps3*(-0.000793650793650793651*A*g - 
     0.00138888888888888889*g2*x2)*xbar2 + 
  eps2*(-0.00277777777777777778*A2 - 
     0.0111111111111111111*A*g*x2 - 
     0.00208333333333333333*g2*x4)*xbar2 + 
  eps5*(0.0000727513227513227513*A2*g + 
     0.000522486772486772487*A*g2*x2 + 
     0.000162037037037037037*g3*x4)*xbar2 + 
  eps4*(0.0000661375661375661376*A3 - 
     0.0000644841269841269841*g2 + 
     0.0015873015873015873*A2*g*x2 + 
     0.00094246031746031746*A*g2*x4 + 
     0.000115740740740740741*g3*x6)*xbar2 + 
  0.00833333333333333333*g*xbar4 - 
  0.0000462962962962962963*eps3*g2*xbar4 + 
  eps2*(-0.000396825396825396825*A*g - 
     0.000694444444444444444*g2*x2)*xbar4 + 
  eps4*(0.0000198412698412698413*A2*g + 
     0.000195105820105820106*A*g2*x2 + 
     0.0000617283950617283951*g3*x4)*xbar4 - 
  0.0000154320987654320988*eps2*g2*xbar6;
}
#endif

#ifdef p8
double Wp(void)
{
   return 0.5*A*x2 + 0.0416666666666666667*g*x4 + 
  eps*(0.0833333333333333333*A + 0.0416666666666666667*g*x2) + 
  eps3*(-0.00277777777777777778*A2 - 
     0.0111111111111111111*A*g*x2 - 
     0.00208333333333333333*g2*x4) + 
  eps2*(0.00416666666666666667*g - 
     0.0416666666666666667*A2*x2 - 
     0.0138888888888888889*A*g*x4 - 
     0.00115740740740740741*g2*x6) + 
  eps5*(0.0001763668430335097*A3 - 
     0.0000388558201058201058*g2 + 
     0.00214947089947089947*A2*g*x2 + 
     0.00124007936507936508*A*g2*x4 + 
     0.000154320987654320988*g3*x6) + 
  eps4*(-0.000595238095238095238*A*g + 
     0.00416666666666666667*A3*x2 - 
     0.000868055555555555556*g2*x2 + 
     0.00347222222222222222*A2*g*x4 + 
     0.000810185185185185185*A*g2*x6 + 
     0.0000578703703703703704*g3*x8) + 
  eps7*(-0.0000132275132275132275*A4 + 
     0.000013452982202982203*A*g2 - 
     0.000353835978835978836*A3*g*x2 + 
     0.0000292107583774250441*g3*x2 - 
     0.000438161375661375661*A2*g2*x4 - 
     0.000141369047619047619*A*g3*x6 - 
     0.0000131815843621399177*g4*x8) + 
  eps6*(0.0000793650793650793651*A2*g - 
     0.000421626984126984127*A4*x2 + 
     0.000412533068783068783*A*g2*x2 - 
     0.000710978835978835979*A3*g*x4 + 
     0.00012359457671957672*g3*x4 - 
     0.000332065696649029982*A2*g2*x6 - 
     0.0000592482363315696649*A*g3*x8 - 
     3.61689814814814815e-6*g4*x10) + 
  0.00833333333333333333*eps*g*xbar2 + 
  0.166666666666666667*(A + 0.5*g*x2)*xbar2 + 
  eps3*(-0.000793650793650793651*A*g - 
     0.00138888888888888889*g2*x2)*xbar2 + 
  eps2*(-0.00277777777777777778*A2 - 
     0.0111111111111111111*A*g*x2 - 
     0.00208333333333333333*g2*x4)*xbar2 + 
  eps5*(0.0000727513227513227513*A2*g + 
     0.000522486772486772487*A*g2*x2 + 
     0.000162037037037037037*g3*x4)*xbar2 + 
  eps4*(0.0000661375661375661376*A3 - 
     0.0000644841269841269841*g2 + 
     0.0015873015873015873*A2*g*x2 + 
     0.00094246031746031746*A*g2*x4 + 
     0.000115740740740740741*g3*x6)*xbar2 + 
  eps6*(-1.65343915343915344e-6*A4 + 
     0.0000179623617123617124*A*g2 - 
     0.00021164021164021164*A3*g*x2 + 
     0.0000485008818342151675*g3*x2 - 
     0.000276951058201058201*A2*g2*x4 - 
     0.0000898368606701940035*A*g3*x6 - 
     8.27867798353909465e-6*g4*x8)*xbar2 + 
  0.00833333333333333333*g*xbar4 - 
  0.0000462962962962962963*eps3*g2*xbar4 + 
  eps2*(-0.000396825396825396825*A*g - 
     0.000694444444444444444*g2*x2)*xbar4 + 
  eps5*(9.11896745230078563e-6*A*g2 + 
     0.0000308641975308641975*g3*x2)*xbar4 + 
  eps4*(0.0000198412698412698413*A2*g + 
     0.000195105820105820106*A*g2*x2 + 
     0.0000617283950617283951*g3*x4)*xbar4 - 
  0.0000154320987654320988*eps2*g2*xbar6 + 
  eps4*(1.90396023729357063e-6*A*g2 + 
     7.71604938271604938e-6*g3*x2)*xbar6;
}
#endif

#ifdef p9
double Wp(void)
{
   return 0.5*A*x2 + 0.0416666666666666667*g*x4 + 
  eps*(0.0833333333333333333*A + 0.0416666666666666667*g*x2) + 
  eps3*(-0.00277777777777777778*A2 - 
     0.0111111111111111111*A*g*x2 - 
     0.00208333333333333333*g2*x4) + 
  eps2*(0.00416666666666666667*g - 
     0.0416666666666666667*A2*x2 - 
     0.0138888888888888889*A*g*x4 - 
     0.00115740740740740741*g2*x6) + 
  eps5*(0.0001763668430335097*A3 - 
     0.0000388558201058201058*g2 + 
     0.00214947089947089947*A2*g*x2 + 
     0.00124007936507936508*A*g2*x4 + 
     0.000154320987654320988*g3*x6) + 
  eps4*(-0.000595238095238095238*A*g + 
     0.00416666666666666667*A3*x2 - 
     0.000868055555555555556*g2*x2 + 
     0.00347222222222222222*A2*g*x4 + 
     0.000810185185185185185*A*g2*x6 + 
     0.0000578703703703703704*g3*x8) + 
  eps7*(-0.0000132275132275132275*A4 + 
     0.000013452982202982203*A*g2 - 
     0.000353835978835978836*A3*g*x2 + 
     0.0000292107583774250441*g3*x2 - 
     0.000438161375661375661*A2*g2*x4 - 
     0.000141369047619047619*A*g3*x6 - 
     0.0000131815843621399177*g4*x8) + 
  eps6*(0.0000793650793650793651*A2*g - 
     0.000421626984126984127*A4*x2 + 
     0.000412533068783068783*A*g2*x2 - 
     0.000710978835978835979*A3*g*x4 + 
     0.00012359457671957672*g3*x4 - 
     0.000332065696649029982*A2*g2*x6 - 
     0.0000592482363315696649*A*g3*x8 - 
     3.61689814814814815e-6*g4*x10) + 
  eps8*(-0.0000100208433541766875*A3*g + 
     8.50711788211788212e-7*g3 + 
     0.0000427138447971781305*A5*x2 - 
     0.000120331539602372936*A2*g2*x2 + 
     0.000127911890064667842*A4*g*x4 - 
     0.000098836830607663941*A*g3*x4 + 
     0.000102804110327258475*A3*g2*x6 - 
     0.0000165018585880854399*g4*x6 + 
     0.0000336428938859494415*A2*g3*x8 + 
     4.8512364050558495e-6*A*g4*x10 + 
     2.56755115454961134e-7*g5*x12) + 
  0.00833333333333333333*eps*g*xbar2 + 
  0.166666666666666667*(A + 0.5*g*x2)*xbar2 + 
  eps3*(-0.000793650793650793651*A*g - 
     0.00138888888888888889*g2*x2)*xbar2 + 
  eps2*(-0.00277777777777777778*A2 - 
     0.0111111111111111111*A*g*x2 - 
     0.00208333333333333333*g2*x4)*xbar2 + 
  eps5*(0.0000727513227513227513*A2*g + 
     0.000522486772486772487*A*g2*x2 + 
     0.000162037037037037037*g3*x4)*xbar2 + 
  eps4*(0.0000661375661375661376*A3 - 
     0.0000644841269841269841*g2 + 
     0.0015873015873015873*A2*g*x2 + 
     0.00094246031746031746*A*g2*x4 + 
     0.000115740740740740741*g3*x6)*xbar2 + 
  eps7*(-6.91438191438191438e-6*A3*g + 
     1.41486599819933153e-6*g3 - 
     0.000128066378066378066*A2*g2*x2 - 
     0.000110705266955266955*A*g3*x4 - 
     0.000018647119341563786*g4*x6)*xbar2 + 
  eps6*(-1.65343915343915344e-6*A4 + 
     0.0000179623617123617124*A*g2 - 
     0.00021164021164021164*A3*g*x2 + 
     0.0000485008818342151675*g3*x2 - 
     0.000276951058201058201*A2*g2*x4 - 
     0.0000898368606701940035*A*g3*x6 - 
     8.27867798353909465e-6*g4*x8)*xbar2 + 
  0.00833333333333333333*g*xbar4 - 
  0.0000462962962962962963*eps3*g2*xbar4 + 
  eps2*(-0.000396825396825396825*A*g - 
     0.000694444444444444444*g2*x2)*xbar4 + 
  eps5*(9.11896745230078563e-6*A*g2 + 
     0.0000308641975308641975*g3*x2)*xbar4 + 
  eps4*(0.0000198412698412698413*A2*g + 
     0.000195105820105820106*A*g2*x2 + 
     0.0000617283950617283951*g3*x4)*xbar4 + 
  eps6*(-9.01875901875901876e-7*A3*g + 
     9.90714532381199048e-7*g3 - 
     0.0000389059243225909893*A2*g2*x2 - 
     0.0000351397573619795842*A*g3*x4 - 
     5.9477880658436214e-6*g4*x6)*xbar4 - 
  0.0000154320987654320988*eps2*g2*xbar6 + 
  3.56125356125356125e-7*eps5*g3*xbar6 + 
  eps4*(1.90396023729357063e-6*A*g2 + 
     7.71604938271604938e-6*g3*x2)*xbar6 + 
  5.93542260208926876e-8*eps4*g3*xbar8;
}
#endif

#ifdef p10
double Wp(void)
{
   return 0.5*A*x2 + 0.0416666666666666667*g*x4 + 
  eps*(0.0833333333333333333*A + 0.0416666666666666667*g*x2) + 
  eps3*(-0.00277777777777777778*A2 - 
     0.0111111111111111111*A*g*x2 - 
     0.00208333333333333333*g2*x4) + 
  eps2*(0.00416666666666666667*g - 
     0.0416666666666666667*A2*x2 - 
     0.0138888888888888889*A*g*x4 - 
     0.00115740740740740741*g2*x6) + 
  eps5*(0.0001763668430335097*A3 - 
     0.0000388558201058201058*g2 + 
     0.00214947089947089947*A2*g*x2 + 
     0.00124007936507936508*A*g2*x4 + 
     0.000154320987654320988*g3*x6) + 
  eps4*(-0.000595238095238095238*A*g + 
     0.00416666666666666667*A3*x2 - 
     0.000868055555555555556*g2*x2 + 
     0.00347222222222222222*A2*g*x4 + 
     0.000810185185185185185*A*g2*x6 + 
     0.0000578703703703703704*g3*x8) + 
  eps7*(-0.0000132275132275132275*A4 + 
     0.000013452982202982203*A*g2 - 
     0.000353835978835978836*A3*g*x2 + 
     0.0000292107583774250441*g3*x2 - 
     0.000438161375661375661*A2*g2*x4 - 
     0.000141369047619047619*A*g3*x6 - 
     0.0000131815843621399177*g4*x8) + 
  eps6*(0.0000793650793650793651*A2*g - 
     0.000421626984126984127*A4*x2 + 
     0.000412533068783068783*A*g2*x2 - 
     0.000710978835978835979*A3*g*x4 + 
     0.00012359457671957672*g3*x4 - 
     0.000332065696649029982*A2*g2*x6 - 
     0.0000592482363315696649*A*g3*x8 - 
     3.61689814814814815e-6*g4*x10) + 
  eps9*(1.06888995777884667e-6*A5 - 
     3.09484386865339246e-6*A2*g2 + 
     0.000052889176153065042*A4*g*x2 - 
     0.0000196739667225778337*A*g3*x2 + 
     0.000118621733205066538*A3*g2*x4 - 
     8.12834124466068911e-6*g4*x4 + 
     0.0000723776288012399124*A2*g3*x6 + 
     0.0000162595142340512711*A*g4*x8 + 
     1.2123306755829904e-6*g5*x10) + 
  eps8*(-0.0000100208433541766875*A3*g + 
     8.50711788211788212e-7*g3 + 
     0.0000427138447971781305*A5*x2 - 
     0.000120331539602372936*A2*g2*x2 + 
     0.000127911890064667842*A4*g*x4 - 
     0.000098836830607663941*A*g3*x4 + 
     0.000102804110327258475*A3*g2*x6 - 
     0.0000165018585880854399*g4*x6 + 
     0.0000336428938859494415*A2*g3*x8 + 
     4.8512364050558495e-6*A*g4*x10 + 
     2.56755115454961134e-7*g5*x12) + 
  0.00833333333333333333*eps*g*xbar2 + 
  0.166666666666666667*(A + 0.5*g*x2)*xbar2 + 
  eps3*(-0.000793650793650793651*A*g - 
     0.00138888888888888889*g2*x2)*xbar2 + 
  eps2*(-0.00277777777777777778*A2 - 
     0.0111111111111111111*A*g*x2 - 
     0.00208333333333333333*g2*x4)*xbar2 + 
  eps5*(0.0000727513227513227513*A2*g + 
     0.000522486772486772487*A*g2*x2 + 
     0.000162037037037037037*g3*x4)*xbar2 + 
  eps4*(0.0000661375661375661376*A3 - 
     0.0000644841269841269841*g2 + 
     0.0015873015873015873*A2*g*x2 + 
     0.00094246031746031746*A*g2*x4 + 
     0.000115740740740740741*g3*x6)*xbar2 + 
  eps7*(-6.91438191438191438e-6*A3*g + 
     1.41486599819933153e-6*g3 - 
     0.000128066378066378066*A2*g2*x2 - 
     0.000110705266955266955*A*g3*x4 - 
     0.000018647119341563786*g4*x6)*xbar2 + 
  eps6*(-1.65343915343915344e-6*A4 + 
     0.0000179623617123617124*A*g2 - 
     0.00021164021164021164*A3*g*x2 + 
     0.0000485008818342151675*g3*x2 - 
     0.000276951058201058201*A2*g2*x4 - 
     0.0000898368606701940035*A*g3*x6 - 
     8.27867798353909465e-6*g4*x8)*xbar2 + 
  eps8*(4.1753513975736198e-8*A5 - 
     3.46221514376276281e-6*A2*g2 + 
     0.0000267222489444711667*A4*g*x2 - 
     0.0000281804101248545693*A*g3*x2 + 
     0.0000649475909892576559*A3*g2*x4 - 
     0.0000122030666735527847*g4*x4 + 
     0.0000403965247715247715*A2*g3*x6 + 
     9.0700810463541945e-6*A*g4*x8 + 
     6.69795953360768176e-7*g5*x10)*xbar2 + 
  0.00833333333333333333*g*xbar4 - 
  0.0000462962962962962963*eps3*g2*xbar4 + 
  eps2*(-0.000396825396825396825*A*g - 
     0.000694444444444444444*g2*x2)*xbar4 + 
  eps5*(9.11896745230078563e-6*A*g2 + 
     0.0000308641975308641975*g3*x2)*xbar4 + 
  eps4*(0.0000198412698412698413*A2*g + 
     0.000195105820105820106*A*g2*x2 + 
     0.0000617283950617283951*g3*x4)*xbar4 + 
  eps7*(-1.31581381581381581e-6*A2*g2 - 
     0.0000151318588818588819*A*g3*x2 - 
     6.8455207344096233e-6*g4*x4)*xbar4 + 
  eps6*(-9.01875901875901876e-7*A3*g + 
     9.90714532381199048e-7*g3 - 
     0.0000389059243225909893*A2*g2*x2 - 
     0.0000351397573619795842*A*g3*x4 - 
     5.9477880658436214e-6*g4*x6)*xbar4 - 
  0.0000154320987654320988*eps2*g2*xbar6 + 
  3.56125356125356125e-7*eps5*g3*xbar6 + 
  eps4*(1.90396023729357063e-6*A*g2 + 
     7.71604938271604938e-6*g3*x2)*xbar6 + 
  eps6*(-1.58222876476844731e-7*A2*g2 - 
     3.0990100434544879e-6*A*g3*x2 - 
     1.45170544476100032e-6*g4*x4)*xbar6 + 
  5.93542260208926876e-8*eps4*g3*xbar8;
}
#endif

#ifdef p11
double Wp(void)
{
   return 0.5*A*x2 + 0.0416666666666666667*g*x4 + 
  eps*(0.0833333333333333333*A + 0.0416666666666666667*g*x2) + 
  eps3*(-0.00277777777777777778*A2 - 
     0.0111111111111111111*A*g*x2 - 
     0.00208333333333333333*g2*x4) + 
  eps2*(0.00416666666666666667*g - 
     0.0416666666666666667*A2*x2 - 
     0.0138888888888888889*A*g*x4 - 
     0.00115740740740740741*g2*x6) + 
  eps5*(0.0001763668430335097*A3 - 
     0.0000388558201058201058*g2 + 
     0.00214947089947089947*A2*g*x2 + 
     0.00124007936507936508*A*g2*x4 + 
     0.000154320987654320988*g3*x6) + 
  eps4*(-0.000595238095238095238*A*g + 
     0.00416666666666666667*A3*x2 - 
     0.000868055555555555556*g2*x2 + 
     0.00347222222222222222*A2*g*x4 + 
     0.000810185185185185185*A*g2*x6 + 
     0.0000578703703703703704*g3*x8) + 
  eps7*(-0.0000132275132275132275*A4 + 
     0.000013452982202982203*A*g2 - 
     0.000353835978835978836*A3*g*x2 + 
     0.0000292107583774250441*g3*x2 - 
     0.000438161375661375661*A2*g2*x4 - 
     0.000141369047619047619*A*g3*x6 - 
     0.0000131815843621399177*g4*x8) + 
  eps6*(0.0000793650793650793651*A2*g - 
     0.000421626984126984127*A4*x2 + 
     0.000412533068783068783*A*g2*x2 - 
     0.000710978835978835979*A3*g*x4 + 
     0.00012359457671957672*g3*x4 - 
     0.000332065696649029982*A2*g2*x6 - 
     0.0000592482363315696649*A*g3*x8 - 
     3.61689814814814815e-6*g4*x10) + 
  eps9*(1.06888995777884667e-6*A5 - 
     3.09484386865339246e-6*A2*g2 + 
     0.000052889176153065042*A4*g*x2 - 
     0.0000196739667225778337*A*g3*x2 + 
     0.000118621733205066538*A3*g2*x4 - 
     8.12834124466068911e-6*g4*x4 + 
     0.0000723776288012399124*A2*g3*x6 + 
     0.0000162595142340512711*A*g4*x8 + 
     1.2123306755829904e-6*g5*x10) + 
  eps8*(-0.0000100208433541766875*A3*g + 
     8.50711788211788212e-7*g3 + 
     0.0000427138447971781305*A5*x2 - 
     0.000120331539602372936*A2*g2*x2 + 
     0.000127911890064667842*A4*g*x4 - 
     0.000098836830607663941*A*g3*x4 + 
     0.000102804110327258475*A3*g2*x6 - 
     0.0000165018585880854399*g4*x6 + 
     0.0000336428938859494415*A2*g3*x8 + 
     4.8512364050558495e-6*A*g4*x10 + 
     2.56755115454961134e-7*g5*x12) + 
  eps10*(1.21747740795359843e-6*A4*g - 
     4.62417873132158846e-7*A*g3 - 
     4.32775172358505692e-6*A6*x2 + 
     0.0000276277014248244407*A3*g2*x2 - 
     1.30445706075046353e-6*g4*x2 - 
     0.0000210333326652771097*A5*g*x4 + 
     0.0000447391253752860896*A2*g3*x4 - 
     0.0000265668910778864483*A4*g2*x6 + 
     0.0000184769777868736202*A*g4*x6 - 
     0.0000139376709110505407*A3*g3*x8 + 
     2.13520310814871e-6*g5*x8 - 
     3.5181249916492972e-6*A2*g4*x10 - 
     4.25407416871537242e-7*A*g5*x12 - 
     1.98147969535893919e-8*g6*x14) + 
  0.00833333333333333333*eps*g*xbar2 + 
  0.166666666666666667*(A + 0.5*g*x2)*xbar2 + 
  eps3*(-0.000793650793650793651*A*g - 
     0.00138888888888888889*g2*x2)*xbar2 + 
  eps2*(-0.00277777777777777778*A2 - 
     0.0111111111111111111*A*g*x2 - 
     0.00208333333333333333*g2*x4)*xbar2 + 
  eps5*(0.0000727513227513227513*A2*g + 
     0.000522486772486772487*A*g2*x2 + 
     0.000162037037037037037*g3*x4)*xbar2 + 
  eps4*(0.0000661375661375661376*A3 - 
     0.0000644841269841269841*g2 + 
     0.0015873015873015873*A2*g*x2 + 
     0.00094246031746031746*A*g2*x4 + 
     0.000115740740740740741*g3*x6)*xbar2 + 
  eps7*(-6.91438191438191438e-6*A3*g + 
     1.41486599819933153e-6*g3 - 
     0.000128066378066378066*A2*g2*x2 - 
     0.000110705266955266955*A*g3*x4 - 
     0.000018647119341563786*g4*x6)*xbar2 + 
  eps6*(-1.65343915343915344e-6*A4 + 
     0.0000179623617123617124*A*g2 - 
     0.00021164021164021164*A3*g*x2 + 
     0.0000485008818342151675*g3*x2 - 
     0.000276951058201058201*A2*g2*x4 - 
     0.0000898368606701940035*A*g3*x6 - 
     8.27867798353909465e-6*g4*x8)*xbar2 + 
  eps9*(6.79829796893288957e-7*A4*g - 
     6.72419695237155555e-7*A*g3 + 
     0.0000254975770848786722*A3*g2*x2 - 
     2.25056258042369153e-6*g4*x2 + 
     0.0000441438108848823135*A2*g3*x4 + 
     0.0000185871013417309714*A*g4*x6 + 
     2.15148764772607365e-6*g5*x8)*xbar2 + 
  eps8*(4.1753513975736198e-8*A5 - 
     3.46221514376276281e-6*A2*g2 + 
     0.0000267222489444711667*A4*g*x2 - 
     0.0000281804101248545693*A*g3*x2 + 
     0.0000649475909892576559*A3*g2*x4 - 
     0.0000122030666735527847*g4*x4 + 
     0.0000403965247715247715*A2*g3*x6 + 
     9.0700810463541945e-6*A*g4*x8 + 
     6.69795953360768176e-7*g5*x10)*xbar2 + 
  0.00833333333333333333*g*xbar4 - 
  0.0000462962962962962963*eps3*g2*xbar4 + 
  eps2*(-0.000396825396825396825*A*g - 
     0.000694444444444444444*g2*x2)*xbar4 + 
  eps5*(9.11896745230078563e-6*A*g2 + 
     0.0000308641975308641975*g3*x2)*xbar4 + 
  eps4*(0.0000198412698412698413*A2*g + 
     0.000195105820105820106*A*g2*x2 + 
     0.0000617283950617283951*g3*x4)*xbar4 + 
  eps7*(-1.31581381581381581e-6*A2*g2 - 
     0.0000151318588818588819*A*g3*x2 - 
     6.8455207344096233e-6*g4*x4)*xbar4 + 
  eps6*(-9.01875901875901876e-7*A3*g + 
     9.90714532381199048e-7*g3 - 
     0.0000389059243225909893*A2*g2*x2 - 
     0.0000351397573619795842*A*g3*x4 - 
     5.9477880658436214e-6*g4*x6)*xbar4 + 
  eps8*(3.77616945077262538e-8*A4*g - 
     3.91505723846993688e-7*A*g3 + 
     6.55938527962337486e-6*A3*g2*x2 - 
     1.61985166325444103e-6*g4*x2 + 
     0.0000121547079219036891*A2*g3*x4 + 
     5.20508405346368309e-6*A*g4*x6 + 
     6.02301130368259998e-7*g5*x8)*xbar4 - 
  0.0000154320987654320988*eps2*g2*xbar6 + 
  3.56125356125356125e-7*eps5*g3*xbar6 + 
  eps4*(1.90396023729357063e-6*A*g2 + 
     7.71604938271604938e-6*g3*x2)*xbar6 + 
  eps7*(-1.06760523427190094e-7*A*g3 - 
     5.83649889205444761e-7*g4*x2)*xbar6 + 
  eps6*(-1.58222876476844731e-7*A2*g2 - 
     3.0990100434544879e-6*A*g3*x2 - 
     1.45170544476100032e-6*g4*x4)*xbar6 + 
  5.93542260208926876e-8*eps4*g3*xbar8 + 
  eps6*(-1.14340392118169896e-8*A*g3 - 
     9.02678854067742957e-8*g4*x2)*xbar8;
}
#endif

#ifdef p12
double Wp(void)
{
   return 0.5*A*x2 + 0.0416666666666666667*g*x4 + 
  eps*(0.0833333333333333333*A + 0.0416666666666666667*g*x2) + 
  eps3*(-0.00277777777777777778*A2 - 
     0.0111111111111111111*A*g*x2 - 
     0.00208333333333333333*g2*x4) + 
  eps2*(0.00416666666666666667*g - 
     0.0416666666666666667*A2*x2 - 
     0.0138888888888888889*A*g*x4 - 
     0.00115740740740740741*g2*x6) + 
  eps5*(0.0001763668430335097*A3 - 
     0.0000388558201058201058*g2 + 
     0.00214947089947089947*A2*g*x2 + 
     0.00124007936507936508*A*g2*x4 + 
     0.000154320987654320988*g3*x6) + 
  eps4*(-0.000595238095238095238*A*g + 
     0.00416666666666666667*A3*x2 - 
     0.000868055555555555556*g2*x2 + 
     0.00347222222222222222*A2*g*x4 + 
     0.000810185185185185185*A*g2*x6 + 
     0.0000578703703703703704*g3*x8) + 
  eps7*(-0.0000132275132275132275*A4 + 
     0.000013452982202982203*A*g2 - 
     0.000353835978835978836*A3*g*x2 + 
     0.0000292107583774250441*g3*x2 - 
     0.000438161375661375661*A2*g2*x4 - 
     0.000141369047619047619*A*g3*x6 - 
     0.0000131815843621399177*g4*x8) + 
  eps6*(0.0000793650793650793651*A2*g - 
     0.000421626984126984127*A4*x2 + 
     0.000412533068783068783*A*g2*x2 - 
     0.000710978835978835979*A3*g*x4 + 
     0.00012359457671957672*g3*x4 - 
     0.000332065696649029982*A2*g2*x6 - 
     0.0000592482363315696649*A*g3*x8 - 
     3.61689814814814815e-6*g4*x10) + 
  eps9*(1.06888995777884667e-6*A5 - 
     3.09484386865339246e-6*A2*g2 + 
     0.000052889176153065042*A4*g*x2 - 
     0.0000196739667225778337*A*g3*x2 + 
     0.000118621733205066538*A3*g2*x4 - 
     8.12834124466068911e-6*g4*x4 + 
     0.0000723776288012399124*A2*g3*x6 + 
     0.0000162595142340512711*A*g4*x8 + 
     1.2123306755829904e-6*g5*x10) + 
  eps8*(-0.0000100208433541766875*A3*g + 
     8.50711788211788212e-7*g3 + 
     0.0000427138447971781305*A5*x2 - 
     0.000120331539602372936*A2*g2*x2 + 
     0.000127911890064667842*A4*g*x4 - 
     0.000098836830607663941*A*g3*x4 + 
     0.000102804110327258475*A3*g2*x6 - 
     0.0000165018585880854399*g4*x6 + 
     0.0000336428938859494415*A2*g3*x8 + 
     4.8512364050558495e-6*A*g4*x10 + 
     2.56755115454961134e-7*g5*x12) + 
  eps11*(-9.01835117002665504e-8*A6 + 
     5.87400058299529199e-7*A3*g2 - 
     2.81868399275952575e-8*g4 - 
     7.41416841780598394e-6*A5*g*x2 + 
     7.67116473755031956e-6*A2*g3*x2 - 
     0.000027147462601331649*A4*g2*x4 + 
     8.12031936990601012e-6*A*g4*x4 - 
     0.0000272310450812986086*A3*g3*x6 + 
     1.70667153812408442e-6*g5*x6 - 
     0.0000108933015093453806*A2*g4*x8 - 
     1.87850642976993286e-6*A*g5*x10 - 
     1.16690477054095881e-7*g6*x12) + 
  eps10*(1.21747740795359843e-6*A4*g - 
     4.62417873132158846e-7*A*g3 - 
     4.32775172358505692e-6*A6*x2 + 
     0.0000276277014248244407*A3*g2*x2 - 
     1.30445706075046353e-6*g4*x2 - 
     0.0000210333326652771097*A5*g*x4 + 
     0.0000447391253752860896*A2*g3*x4 - 
     0.0000265668910778864483*A4*g2*x6 + 
     0.0000184769777868736202*A*g4*x6 - 
     0.0000139376709110505407*A3*g3*x8 + 
     2.13520310814871e-6*g5*x8 - 
     3.5181249916492972e-6*A2*g4*x10 - 
     4.25407416871537242e-7*A*g5*x12 - 
     1.98147969535893919e-8*g6*x14) + 
  0.00833333333333333333*eps*g*xbar2 + 
  0.166666666666666667*(A + 0.5*g*x2)*xbar2 + 
  eps3*(-0.000793650793650793651*A*g - 
     0.00138888888888888889*g2*x2)*xbar2 + 
  eps2*(-0.00277777777777777778*A2 - 
     0.0111111111111111111*A*g*x2 - 
     0.00208333333333333333*g2*x4)*xbar2 + 
  eps5*(0.0000727513227513227513*A2*g + 
     0.000522486772486772487*A*g2*x2 + 
     0.000162037037037037037*g3*x4)*xbar2 + 
  eps4*(0.0000661375661375661376*A3 - 
     0.0000644841269841269841*g2 + 
     0.0015873015873015873*A2*g*x2 + 
     0.00094246031746031746*A*g2*x4 + 
     0.000115740740740740741*g3*x6)*xbar2 + 
  eps7*(-6.91438191438191438e-6*A3*g + 
     1.41486599819933153e-6*g3 - 
     0.000128066378066378066*A2*g2*x2 - 
     0.000110705266955266955*A*g3*x4 - 
     0.000018647119341563786*g4*x6)*xbar2 + 
  eps6*(-1.65343915343915344e-6*A4 + 
     0.0000179623617123617124*A*g2 - 
     0.00021164021164021164*A3*g*x2 + 
     0.0000485008818342151675*g3*x2 - 
     0.000276951058201058201*A2*g2*x4 - 
     0.0000898368606701940035*A*g3*x6 - 
     8.27867798353909465e-6*g4*x8)*xbar2 + 
  eps9*(6.79829796893288957e-7*A4*g - 
     6.72419695237155555e-7*A*g3 + 
     0.0000254975770848786722*A3*g2*x2 - 
     2.25056258042369153e-6*g4*x2 + 
     0.0000441438108848823135*A2*g3*x4 + 
     0.0000185871013417309714*A*g4*x6 + 
     2.15148764772607365e-6*g5*x8)*xbar2 + 
  eps8*(4.1753513975736198e-8*A5 - 
     3.46221514376276281e-6*A2*g2 + 
     0.0000267222489444711667*A4*g*x2 - 
     0.0000281804101248545693*A*g3*x2 + 
     0.0000649475909892576559*A3*g2*x4 - 
     0.0000122030666735527847*g4*x4 + 
     0.0000403965247715247715*A2*g3*x6 + 
     9.0700810463541945e-6*A*g4*x8 + 
     6.69795953360768176e-7*g5*x10)*xbar2 + 
  eps10*(-1.05683802773749864e-9*A6 + 
     5.67501373552960855e-7*A3*g2 - 
     4.8511255774108832e-8*g4 - 
     3.24660642120959581e-6*A5*g*x2 + 
     9.71126169538867952e-6*A2*g3*x2 - 
     0.0000131832441790279092*A4*g2*x4 + 
     0.0000108846610427711618*A*g4*x4 - 
     0.0000136365860158849577*A3*g3*x6 + 
     2.33168885512635513e-6*g5*x6 - 
     5.4993290386188865e-6*A2*g4*x8 - 
     9.46094479080590192e-7*A*g5*x10 - 
     5.8302302889011994e-8*g6*x12)*xbar2 + 
  0.00833333333333333333*g*xbar4 - 
  0.0000462962962962962963*eps3*g2*xbar4 + 
  eps2*(-0.000396825396825396825*A*g - 
     0.000694444444444444444*g2*x2)*xbar4 + 
  eps5*(9.11896745230078563e-6*A*g2 + 
     0.0000308641975308641975*g3*x2)*xbar4 + 
  eps4*(0.0000198412698412698413*A2*g + 
     0.000195105820105820106*A*g2*x2 + 
     0.0000617283950617283951*g3*x4)*xbar4 + 
  eps7*(-1.31581381581381581e-6*A2*g2 - 
     0.0000151318588818588819*A*g3*x2 - 
     6.8455207344096233e-6*g4*x4)*xbar4 + 
  eps6*(-9.01875901875901876e-7*A3*g + 
     9.90714532381199048e-7*g3 - 
     0.0000389059243225909893*A2*g2*x2 - 
     0.0000351397573619795842*A*g3*x4 - 
     5.9477880658436214e-6*g4*x6)*xbar4 + 
  eps9*(1.71045640622360199e-7*A3*g2 - 
     3.60906857706966639e-8*g4 + 
     4.53245406122390249e-6*A2*g3*x2 + 
     5.38783061931210079e-6*A*g4*x4 + 
     1.17492514772607365e-6*g5*x6)*xbar4 + 
  eps8*(3.77616945077262538e-8*A4*g - 
     3.91505723846993688e-7*A*g3 + 
     6.55938527962337486e-6*A3*g2*x2 - 
     1.61985166325444103e-6*g4*x2 + 
     0.0000121547079219036891*A2*g3*x4 + 
     5.20508405346368309e-6*A*g4*x6 + 
     6.02301130368259998e-7*g5*x8)*xbar4 - 
  0.0000154320987654320988*eps2*g2*xbar6 + 
  3.56125356125356125e-7*eps5*g3*xbar6 + 
  eps4*(1.90396023729357063e-6*A*g2 + 
     7.71604938271604938e-6*g3*x2)*xbar6 + 
  eps7*(-1.06760523427190094e-7*A*g3 - 
     5.83649889205444761e-7*g4*x2)*xbar6 + 
  eps6*(-1.58222876476844731e-7*A2*g2 - 
     3.0990100434544879e-6*A*g3*x2 - 
     1.45170544476100032e-6*g4*x4)*xbar6 + 
  eps8*(1.0639753805538638e-8*A3*g2 - 
     1.44647796358943781e-8*g4 + 
     7.89019059521705024e-7*A2*g3*x2 + 
     9.93278626380478232e-7*A*g4*x4 + 
     2.19830466744046991e-7*g5*x6)*xbar6 + 
  5.93542260208926876e-8*eps4*g3*xbar8 - 
  3.12288574815807931e-9*eps7*g4*xbar8 + 
  eps6*(-1.14340392118169896e-8*A*g3 - 
     9.02678854067742957e-8*g4*x2)*xbar8 - 
  2.95801289810004407e-10*eps6*g4*xbar10;
}
#endif

#ifdef p13
double Wp(void)
{
   return 0.5*A*x2 + 0.0416666666666666667*g*x4 + 
  eps*(0.0833333333333333333*A + 0.0416666666666666667*g*x2) + 
  eps3*(-0.00277777777777777778*A2 - 
     0.0111111111111111111*A*g*x2 - 
     0.00208333333333333333*g2*x4) + 
  eps2*(0.00416666666666666667*g - 
     0.0416666666666666667*A2*x2 - 
     0.0138888888888888889*A*g*x4 - 
     0.00115740740740740741*g2*x6) + 
  eps5*(0.0001763668430335097*A3 - 
     0.0000388558201058201058*g2 + 
     0.00214947089947089947*A2*g*x2 + 
     0.00124007936507936508*A*g2*x4 + 
     0.000154320987654320988*g3*x6) + 
  eps4*(-0.000595238095238095238*A*g + 
     0.00416666666666666667*A3*x2 - 
     0.000868055555555555556*g2*x2 + 
     0.00347222222222222222*A2*g*x4 + 
     0.000810185185185185185*A*g2*x6 + 
     0.0000578703703703703704*g3*x8) + 
  eps7*(-0.0000132275132275132275*A4 + 
     0.000013452982202982203*A*g2 - 
     0.000353835978835978836*A3*g*x2 + 
     0.0000292107583774250441*g3*x2 - 
     0.000438161375661375661*A2*g2*x4 - 
     0.000141369047619047619*A*g3*x6 - 
     0.0000131815843621399177*g4*x8) + 
  eps6*(0.0000793650793650793651*A2*g - 
     0.000421626984126984127*A4*x2 + 
     0.000412533068783068783*A*g2*x2 - 
     0.000710978835978835979*A3*g*x4 + 
     0.00012359457671957672*g3*x4 - 
     0.000332065696649029982*A2*g2*x6 - 
     0.0000592482363315696649*A*g3*x8 - 
     3.61689814814814815e-6*g4*x10) + 
  eps9*(1.06888995777884667e-6*A5 - 
     3.09484386865339246e-6*A2*g2 + 
     0.000052889176153065042*A4*g*x2 - 
     0.0000196739667225778337*A*g3*x2 + 
     0.000118621733205066538*A3*g2*x4 - 
     8.12834124466068911e-6*g4*x4 + 
     0.0000723776288012399124*A2*g3*x6 + 
     0.0000162595142340512711*A*g4*x8 + 
     1.2123306755829904e-6*g5*x10) + 
  eps8*(-0.0000100208433541766875*A3*g + 
     8.50711788211788212e-7*g3 + 
     0.0000427138447971781305*A5*x2 - 
     0.000120331539602372936*A2*g2*x2 + 
     0.000127911890064667842*A4*g*x4 - 
     0.000098836830607663941*A*g3*x4 + 
     0.000102804110327258475*A3*g2*x6 - 
     0.0000165018585880854399*g4*x6 + 
     0.0000336428938859494415*A2*g3*x8 + 
     4.8512364050558495e-6*A*g4*x10 + 
     2.56755115454961134e-7*g5*x12) + 
  eps11*(-9.01835117002665504e-8*A6 + 
     5.87400058299529199e-7*A3*g2 - 
     2.81868399275952575e-8*g4 - 
     7.41416841780598394e-6*A5*g*x2 + 
     7.67116473755031956e-6*A2*g3*x2 - 
     0.000027147462601331649*A4*g2*x4 + 
     8.12031936990601012e-6*A*g4*x4 - 
     0.0000272310450812986086*A3*g3*x6 + 
     1.70667153812408442e-6*g5*x6 - 
     0.0000108933015093453806*A2*g4*x8 - 
     1.87850642976993286e-6*A*g5*x10 - 
     1.16690477054095881e-7*g6*x12) + 
  eps10*(1.21747740795359843e-6*A4*g - 
     4.62417873132158846e-7*A*g3 - 
     4.32775172358505692e-6*A6*x2 + 
     0.0000276277014248244407*A3*g2*x2 - 
     1.30445706075046353e-6*g4*x2 - 
     0.0000210333326652771097*A5*g*x4 + 
     0.0000447391253752860896*A2*g3*x4 - 
     0.0000265668910778864483*A4*g2*x6 + 
     0.0000184769777868736202*A*g4*x6 - 
     0.0000139376709110505407*A3*g3*x8 + 
     2.13520310814871e-6*g5*x8 - 
     3.5181249916492972e-6*A2*g4*x10 - 
     4.25407416871537242e-7*A*g5*x12 - 
     1.98147969535893919e-8*g6*x14) + 
  eps12*(-1.43889032777921667e-7*A5*g + 
     1.51283642180000723e-7*A2*g3 + 
     4.38492191964414187e-7*A7*x2 - 
     5.47671197834474951e-6*A4*g2*x2 + 
     1.1365151365172641e-6*A*g4*x2 + 
     3.23789133106262736e-6*A6*g*x4 - 
     0.0000150481673660823793*A3*g3*x4 + 
     5.97324614725086198e-7*g5*x4 + 
     6.03932684613625972e-6*A5*g2*x6 - 
     0.0000113106765525436987*A2*g4*x6 + 
     4.69528859165240338e-6*A4*g3*x8 - 
     3.0694501391598228e-6*A*g5*x8 + 
     1.82557370238215146e-6*A3*g4*x10 - 
     2.71046144994230449e-7*g6*x10 + 
     3.7535031778135559e-7*A2*g5*x12 + 
     3.90681314457195373e-8*A*g6*x14 + 
     1.62260932077515154e-9*g7*x16) + 
  0.00833333333333333333*eps*g*xbar2 + 
  0.166666666666666667*(A + 0.5*g*x2)*xbar2 + 
  eps3*(-0.000793650793650793651*A*g - 
     0.00138888888888888889*g2*x2)*xbar2 + 
  eps2*(-0.00277777777777777778*A2 - 
     0.0111111111111111111*A*g*x2 - 
     0.00208333333333333333*g2*x4)*xbar2 + 
  eps5*(0.0000727513227513227513*A2*g + 
     0.000522486772486772487*A*g2*x2 + 
     0.000162037037037037037*g3*x4)*xbar2 + 
  eps4*(0.0000661375661375661376*A3 - 
     0.0000644841269841269841*g2 + 
     0.0015873015873015873*A2*g*x2 + 
     0.00094246031746031746*A*g2*x4 + 
     0.000115740740740740741*g3*x6)*xbar2 + 
  eps7*(-6.91438191438191438e-6*A3*g + 
     1.41486599819933153e-6*g3 - 
     0.000128066378066378066*A2*g2*x2 - 
     0.000110705266955266955*A*g3*x4 - 
     0.000018647119341563786*g4*x6)*xbar2 + 
  eps6*(-1.65343915343915344e-6*A4 + 
     0.0000179623617123617124*A*g2 - 
     0.00021164021164021164*A3*g*x2 + 
     0.0000485008818342151675*g3*x2 - 
     0.000276951058201058201*A2*g2*x4 - 
     0.0000898368606701940035*A*g3*x6 - 
     8.27867798353909465e-6*g4*x8)*xbar2 + 
  eps9*(6.79829796893288957e-7*A4*g - 
     6.72419695237155555e-7*A*g3 + 
     0.0000254975770848786722*A3*g2*x2 - 
     2.25056258042369153e-6*g4*x2 + 
     0.0000441438108848823135*A2*g3*x4 + 
     0.0000185871013417309714*A*g4*x6 + 
     2.15148764772607365e-6*g5*x8)*xbar2 + 
  eps8*(4.1753513975736198e-8*A5 - 
     3.46221514376276281e-6*A2*g2 + 
     0.0000267222489444711667*A4*g*x2 - 
     0.0000281804101248545693*A*g3*x2 + 
     0.0000649475909892576559*A3*g2*x4 - 
     0.0000122030666735527847*g4*x4 + 
     0.0000403965247715247715*A2*g3*x6 + 
     9.0700810463541945e-6*A*g4*x8 + 
     6.69795953360768176e-7*g5*x10)*xbar2 + 
  eps11*(-6.80612866459427306e-8*A5*g + 
     1.95584655809718057e-7*A2*g3 - 
     4.47269759439071608e-6*A4*g2*x2 + 
     1.75829988748211593e-6*A*g4*x2 - 
     0.0000133314481239415102*A3*g3*x4 + 
     9.71399147418687179e-7*g5*x4 - 
     0.0000103064498801381517*A2*g4*x6 - 
     2.82142523293179157e-6*A*g5*x8 - 
     2.4892365507720446e-7*g6*x10)*xbar2 + 
  eps10*(-1.05683802773749864e-9*A6 + 
     5.67501373552960855e-7*A3*g2 - 
     4.8511255774108832e-8*g4 - 
     3.24660642120959581e-6*A5*g*x2 + 
     9.71126169538867952e-6*A2*g3*x2 - 
     0.0000131832441790279092*A4*g2*x4 + 
     0.0000108846610427711618*A*g4*x4 - 
     0.0000136365860158849577*A3*g3*x6 + 
     2.33168885512635513e-6*g5*x6 - 
     5.4993290386188865e-6*A2*g4*x8 - 
     9.46094479080590192e-7*A*g5*x10 - 
     5.8302302889011994e-8*g6*x12)*xbar2 + 
  0.00833333333333333333*g*xbar4 - 
  0.0000462962962962962963*eps3*g2*xbar4 + 
  eps2*(-0.000396825396825396825*A*g - 
     0.000694444444444444444*g2*x2)*xbar4 + 
  eps5*(9.11896745230078563e-6*A*g2 + 
     0.0000308641975308641975*g3*x2)*xbar4 + 
  eps4*(0.0000198412698412698413*A2*g + 
     0.000195105820105820106*A*g2*x2 + 
     0.0000617283950617283951*g3*x4)*xbar4 + 
  eps7*(-1.31581381581381581e-6*A2*g2 - 
     0.0000151318588818588819*A*g3*x2 - 
     6.8455207344096233e-6*g4*x4)*xbar4 + 
  eps6*(-9.01875901875901876e-7*A3*g + 
     9.90714532381199048e-7*g3 - 
     0.0000389059243225909893*A2*g2*x2 - 
     0.0000351397573619795842*A*g3*x4 - 
     5.9477880658436214e-6*g4*x6)*xbar4 + 
  eps9*(1.71045640622360199e-7*A3*g2 - 
     3.60906857706966639e-8*g4 + 
     4.53245406122390249e-6*A2*g3*x2 + 
     5.38783061931210079e-6*A*g4*x4 + 
     1.17492514772607365e-6*g5*x6)*xbar4 + 
  eps8*(3.77616945077262538e-8*A4*g - 
     3.91505723846993688e-7*A*g3 + 
     6.55938527962337486e-6*A3*g2*x2 - 
     1.61985166325444103e-6*g4*x2 + 
     0.0000121547079219036891*A2*g3*x4 + 
     5.20508405346368309e-6*A*g4*x6 + 
     6.02301130368259998e-7*g5*x8)*xbar4 + 
  eps10*(-1.48202033122668043e-9*A5*g + 
     9.77137892841674354e-8*A2*g3 - 
     9.98537198520664129e-7*A4*g2*x2 + 
     1.12096864298613054e-6*A*g4*x2 - 
     3.25929867376075489e-6*A3*g3*x4 + 
     6.52088831782005348e-7*g5*x4 - 
     2.59007734102806854e-6*A2*g4*x6 - 
     7.14333704061713321e-7*A*g5*x8 - 
     6.28878290312510992e-8*g6*x10)*xbar4 - 
  0.0000154320987654320988*eps2*g2*xbar6 + 
  3.56125356125356125e-7*eps5*g3*xbar6 + 
  eps4*(1.90396023729357063e-6*A*g2 + 
     7.71604938271604938e-6*g3*x2)*xbar6 + 
  eps7*(-1.06760523427190094e-7*A*g3 - 
     5.83649889205444761e-7*g4*x2)*xbar6 + 
  eps6*(-1.58222876476844731e-7*A2*g2 - 
     3.0990100434544879e-6*A*g3*x2 - 
     1.45170544476100032e-6*g4*x4)*xbar6 + 
  eps9*(2.10474956623416007e-8*A2*g3 + 
     3.52066889376257568e-7*A*g4*x2 + 
     2.15683591284989252e-7*g5*x4)*xbar6 + 
  eps8*(1.0639753805538638e-8*A3*g2 - 
     1.44647796358943781e-8*g4 + 
     7.89019059521705024e-7*A2*g3*x2 + 
     9.93278626380478232e-7*A*g4*x4 + 
     2.19830466744046991e-7*g5*x6)*xbar6 + 
  5.93542260208926876e-8*eps4*g3*xbar8 - 
  3.12288574815807931e-9*eps7*g4*xbar8 + 
  eps6*(-1.14340392118169896e-8*A*g3 - 
     9.02678854067742957e-8*g4*x2)*xbar8 + 
  eps8*(1.32727772394750297e-9*A2*g3 + 
     4.65033697944917988e-8*A*g4*x2 + 
     2.99054295797669073e-8*g5*x4)*xbar8 - 
  2.95801289810004407e-10*eps6*g4*xbar10;
}
#endif

#ifdef p14
double Wp(void)
{
   return 0.5*A*x2 + 0.0416666666666666667*g*x4 + 
  eps*(0.0833333333333333333*A + 0.0416666666666666667*g*x2) + 
  eps3*(-0.00277777777777777778*A2 - 
     0.0111111111111111111*A*g*x2 - 
     0.00208333333333333333*g2*x4) + 
  eps2*(0.00416666666666666667*g - 
     0.0416666666666666667*A2*x2 - 
     0.0138888888888888889*A*g*x4 - 
     0.00115740740740740741*g2*x6) + 
  eps5*(0.0001763668430335097*A3 - 
     0.0000388558201058201058*g2 + 
     0.00214947089947089947*A2*g*x2 + 
     0.00124007936507936508*A*g2*x4 + 
     0.000154320987654320988*g3*x6) + 
  eps4*(-0.000595238095238095238*A*g + 
     0.00416666666666666667*A3*x2 - 
     0.000868055555555555556*g2*x2 + 
     0.00347222222222222222*A2*g*x4 + 
     0.000810185185185185185*A*g2*x6 + 
     0.0000578703703703703704*g3*x8) + 
  eps7*(-0.0000132275132275132275*A4 + 
     0.000013452982202982203*A*g2 - 
     0.000353835978835978836*A3*g*x2 + 
     0.0000292107583774250441*g3*x2 - 
     0.000438161375661375661*A2*g2*x4 - 
     0.000141369047619047619*A*g3*x6 - 
     0.0000131815843621399177*g4*x8) + 
  eps6*(0.0000793650793650793651*A2*g - 
     0.000421626984126984127*A4*x2 + 
     0.000412533068783068783*A*g2*x2 - 
     0.000710978835978835979*A3*g*x4 + 
     0.00012359457671957672*g3*x4 - 
     0.000332065696649029982*A2*g2*x6 - 
     0.0000592482363315696649*A*g3*x8 - 
     3.61689814814814815e-6*g4*x10) + 
  eps9*(1.06888995777884667e-6*A5 - 
     3.09484386865339246e-6*A2*g2 + 
     0.000052889176153065042*A4*g*x2 - 
     0.0000196739667225778337*A*g3*x2 + 
     0.000118621733205066538*A3*g2*x4 - 
     8.12834124466068911e-6*g4*x4 + 
     0.0000723776288012399124*A2*g3*x6 + 
     0.0000162595142340512711*A*g4*x8 + 
     1.2123306755829904e-6*g5*x10) + 
  eps8*(-0.0000100208433541766875*A3*g + 
     8.50711788211788212e-7*g3 + 
     0.0000427138447971781305*A5*x2 - 
     0.000120331539602372936*A2*g2*x2 + 
     0.000127911890064667842*A4*g*x4 - 
     0.000098836830607663941*A*g3*x4 + 
     0.000102804110327258475*A3*g2*x6 - 
     0.0000165018585880854399*g4*x6 + 
     0.0000336428938859494415*A2*g3*x8 + 
     4.8512364050558495e-6*A*g4*x10 + 
     2.56755115454961134e-7*g5*x12) + 
  eps11*(-9.01835117002665504e-8*A6 + 
     5.87400058299529199e-7*A3*g2 - 
     2.81868399275952575e-8*g4 - 
     7.41416841780598394e-6*A5*g*x2 + 
     7.67116473755031956e-6*A2*g3*x2 - 
     0.000027147462601331649*A4*g2*x4 + 
     8.12031936990601012e-6*A*g4*x4 - 
     0.0000272310450812986086*A3*g3*x6 + 
     1.70667153812408442e-6*g5*x6 - 
     0.0000108933015093453806*A2*g4*x8 - 
     1.87850642976993286e-6*A*g5*x10 - 
     1.16690477054095881e-7*g6*x12) + 
  eps10*(1.21747740795359843e-6*A4*g - 
     4.62417873132158846e-7*A*g3 - 
     4.32775172358505692e-6*A6*x2 + 
     0.0000276277014248244407*A3*g2*x2 - 
     1.30445706075046353e-6*g4*x2 - 
     0.0000210333326652771097*A5*g*x4 + 
     0.0000447391253752860896*A2*g3*x4 - 
     0.0000265668910778864483*A4*g2*x6 + 
     0.0000184769777868736202*A*g4*x6 - 
     0.0000139376709110505407*A3*g3*x8 + 
     2.13520310814871e-6*g5*x8 - 
     3.5181249916492972e-6*A2*g4*x10 - 
     4.25407416871537242e-7*A*g5*x12 - 
     1.98147969535893919e-8*g6*x14) + 
  eps13*(7.83069566138349207e-9*A7 - 
     9.93094869534334209e-8*A4*g2 + 
     2.08755249185163841e-8*A*g4 + 
     9.92791119692574719e-7*A6*g*x2 - 
     2.26246788359770127e-6*A3*g3*x2 + 
     7.19774046753493046e-8*g5*x2 + 
     5.52538741816188906e-6*A5*g2*x4 - 
     4.47883727161149936e-6*A2*g4*x4 + 
     8.38601213983571788e-6*A4*g3*x6 - 
     2.25348627386308778e-6*A*g5*x6 + 
     5.24445855604457162e-6*A3*g4*x8 - 
     3.11392974798759566e-7*g6*x8 + 
     1.55465050346795001e-6*A2*g5*x10 + 
     2.17600880397466046e-7*A*g6*x12 + 
     1.15841884836628278e-8*g7*x14) + 
  eps12*(-1.43889032777921667e-7*A5*g + 
     1.51283642180000723e-7*A2*g3 + 
     4.38492191964414187e-7*A7*x2 - 
     5.47671197834474951e-6*A4*g2*x2 + 
     1.1365151365172641e-6*A*g4*x2 + 
     3.23789133106262736e-6*A6*g*x4 - 
     0.0000150481673660823793*A3*g3*x4 + 
     5.97324614725086198e-7*g5*x4 + 
     6.03932684613625972e-6*A5*g2*x6 - 
     0.0000113106765525436987*A2*g4*x6 + 
     4.69528859165240338e-6*A4*g3*x8 - 
     3.0694501391598228e-6*A*g5*x8 + 
     1.82557370238215146e-6*A3*g4*x10 - 
     2.71046144994230449e-7*g6*x10 + 
     3.7535031778135559e-7*A2*g5*x12 + 
     3.90681314457195373e-8*A*g6*x14 + 
     1.62260932077515154e-9*g7*x16) + 
  0.00833333333333333333*eps*g*xbar2 + 
  0.166666666666666667*(A + 0.5*g*x2)*xbar2 + 
  eps3*(-0.000793650793650793651*A*g - 
     0.00138888888888888889*g2*x2)*xbar2 + 
  eps2*(-0.00277777777777777778*A2 - 
     0.0111111111111111111*A*g*x2 - 
     0.00208333333333333333*g2*x4)*xbar2 + 
  eps5*(0.0000727513227513227513*A2*g + 
     0.000522486772486772487*A*g2*x2 + 
     0.000162037037037037037*g3*x4)*xbar2 + 
  eps4*(0.0000661375661375661376*A3 - 
     0.0000644841269841269841*g2 + 
     0.0015873015873015873*A2*g*x2 + 
     0.00094246031746031746*A*g2*x4 + 
     0.000115740740740740741*g3*x6)*xbar2 + 
  eps7*(-6.91438191438191438e-6*A3*g + 
     1.41486599819933153e-6*g3 - 
     0.000128066378066378066*A2*g2*x2 - 
     0.000110705266955266955*A*g3*x4 - 
     0.000018647119341563786*g4*x6)*xbar2 + 
  eps6*(-1.65343915343915344e-6*A4 + 
     0.0000179623617123617124*A*g2 - 
     0.00021164021164021164*A3*g*x2 + 
     0.0000485008818342151675*g3*x2 - 
     0.000276951058201058201*A2*g2*x4 - 
     0.0000898368606701940035*A*g3*x6 - 
     8.27867798353909465e-6*g4*x8)*xbar2 + 
  eps9*(6.79829796893288957e-7*A4*g - 
     6.72419695237155555e-7*A*g3 + 
     0.0000254975770848786722*A3*g2*x2 - 
     2.25056258042369153e-6*g4*x2 + 
     0.0000441438108848823135*A2*g3*x4 + 
     0.0000185871013417309714*A*g4*x6 + 
     2.15148764772607365e-6*g5*x8)*xbar2 + 
  eps8*(4.1753513975736198e-8*A5 - 
     3.46221514376276281e-6*A2*g2 + 
     0.0000267222489444711667*A4*g*x2 - 
     0.0000281804101248545693*A*g3*x2 + 
     0.0000649475909892576559*A3*g2*x4 - 
     0.0000122030666735527847*g4*x4 + 
     0.0000403965247715247715*A2*g3*x6 + 
     9.0700810463541945e-6*A*g4*x8 + 
     6.69795953360768176e-7*g5*x10)*xbar2 + 
  eps11*(-6.80612866459427306e-8*A5*g + 
     1.95584655809718057e-7*A2*g3 - 
     4.47269759439071608e-6*A4*g2*x2 + 
     1.75829988748211593e-6*A*g4*x2 - 
     0.0000133314481239415102*A3*g3*x4 + 
     9.71399147418687179e-7*g5*x4 - 
     0.0000103064498801381517*A2*g4*x6 - 
     2.82142523293179157e-6*A*g5*x8 - 
     2.4892365507720446e-7*g6*x10)*xbar2 + 
  eps10*(-1.05683802773749864e-9*A6 + 
     5.67501373552960855e-7*A3*g2 - 
     4.8511255774108832e-8*g4 - 
     3.24660642120959581e-6*A5*g*x2 + 
     9.71126169538867952e-6*A2*g3*x2 - 
     0.0000131832441790279092*A4*g2*x4 + 
     0.0000108846610427711618*A*g4*x4 - 
     0.0000136365860158849577*A3*g3*x6 + 
     2.33168885512635513e-6*g5*x6 - 
     5.4993290386188865e-6*A2*g4*x8 - 
     9.46094479080590192e-7*A*g5*x10 - 
     5.8302302889011994e-8*g6*x12)*xbar2 + 
  eps12*(2.67650730613693577e-11*A7 - 
     8.46192910475220622e-8*A4*g2 + 
     3.25142589196534057e-8*A*g4 + 
     3.83704087407791111e-7*A6*g*x2 - 
     2.57283359783619147e-6*A3*g3*x2 + 
     1.27951218977907431e-7*g5*x2 + 
     2.41765559329216737e-6*A5*g2*x4 - 
     5.44480881814382923e-6*A2*g4*x4 + 
     3.82233569685344377e-6*A4*g3*x6 - 
     2.81139544164632672e-6*A*g5*x6 + 
     2.42710273474001612e-6*A3*g4*x8 - 
     3.92027350262991887e-7*g6*x8 + 
     7.21984500196305752e-7*A2*g5*x10 + 
     1.007566064009769e-7*A*g6*x12 + 
     5.32759708629371695e-9*g7*x14)*xbar2 + 
  0.00833333333333333333*g*xbar4 - 
  0.0000462962962962962963*eps3*g2*xbar4 + 
  eps2*(-0.000396825396825396825*A*g - 
     0.000694444444444444444*g2*x2)*xbar4 + 
  eps5*(9.11896745230078563e-6*A*g2 + 
     0.0000308641975308641975*g3*x2)*xbar4 + 
  eps4*(0.0000198412698412698413*A2*g + 
     0.000195105820105820106*A*g2*x2 + 
     0.0000617283950617283951*g3*x4)*xbar4 + 
  eps7*(-1.31581381581381581e-6*A2*g2 - 
     0.0000151318588818588819*A*g3*x2 - 
     6.8455207344096233e-6*g4*x4)*xbar4 + 
  eps6*(-9.01875901875901876e-7*A3*g + 
     9.90714532381199048e-7*g3 - 
     0.0000389059243225909893*A2*g2*x2 - 
     0.0000351397573619795842*A*g3*x4 - 
     5.9477880658436214e-6*g4*x6)*xbar4 + 
  eps9*(1.71045640622360199e-7*A3*g2 - 
     3.60906857706966639e-8*g4 + 
     4.53245406122390249e-6*A2*g3*x2 + 
     5.38783061931210079e-6*A*g4*x4 + 
     1.17492514772607365e-6*g5*x6)*xbar4 + 
  eps8*(3.77616945077262538e-8*A4*g - 
     3.91505723846993688e-7*A*g3 + 
     6.55938527962337486e-6*A3*g2*x2 - 
     1.61985166325444103e-6*g4*x2 + 
     0.0000121547079219036891*A2*g3*x4 + 
     5.20508405346368309e-6*A*g4*x6 + 
     6.02301130368259998e-7*g5*x8)*xbar4 + 
  eps11*(-2.12135350797297057e-8*A4*g2 + 
     2.14460056215349951e-8*A*g4 - 
     1.06401470496877178e-6*A3*g3*x2 + 
     9.9419658966568008e-8*g5*x2 - 
     2.4228308825712602e-6*A2*g4*x4 - 
     1.28380796826126347e-6*A*g5*x6 - 
     1.80516340332649186e-7*g6*x8)*xbar4 + 
  eps10*(-1.48202033122668043e-9*A5*g + 
     9.77137892841674354e-8*A2*g3 - 
     9.98537198520664129e-7*A4*g2*x2 + 
     1.12096864298613054e-6*A*g4*x2 - 
     3.25929867376075489e-6*A3*g3*x4 + 
     6.52088831782005348e-7*g5*x4 - 
     2.59007734102806854e-6*A2*g4*x6 - 
     7.14333704061713321e-7*A*g5*x8 - 
     6.28878290312510992e-8*g6*x10)*xbar4 - 
  0.0000154320987654320988*eps2*g2*xbar6 + 
  3.56125356125356125e-7*eps5*g3*xbar6 + 
  eps4*(1.90396023729357063e-6*A*g2 + 
     7.71604938271604938e-6*g3*x2)*xbar6 + 
  eps7*(-1.06760523427190094e-7*A*g3 - 
     5.83649889205444761e-7*g4*x2)*xbar6 + 
  eps6*(-1.58222876476844731e-7*A2*g2 - 
     3.0990100434544879e-6*A*g3*x2 - 
     1.45170544476100032e-6*g4*x4)*xbar6 + 
  eps9*(2.10474956623416007e-8*A2*g3 + 
     3.52066889376257568e-7*A*g4*x2 + 
     2.15683591284989252e-7*g5*x4)*xbar6 + 
  eps8*(1.0639753805538638e-8*A3*g2 - 
     1.44647796358943781e-8*g4 + 
     7.89019059521705024e-7*A2*g3*x2 + 
     9.93278626380478232e-7*A*g4*x4 + 
     2.19830466744046991e-7*g5*x6)*xbar6 + 
  eps10*(-6.21784885258793341e-10*A4*g2 + 
     7.35917308458240036e-9*A*g4 - 
     1.61082849737015107e-7*A3*g3*x2 + 
     4.25042008023580282e-8*g5*x2 - 
     3.97181909847740069e-7*A2*g4*x4 - 
     2.15693489113968417e-7*A*g5*x6 - 
     3.05361793587726322e-8*g6*x8)*xbar6 + 
  5.93542260208926876e-8*eps4*g3*xbar8 - 
  3.12288574815807931e-9*eps7*g4*xbar8 + 
  eps6*(-1.14340392118169896e-8*A*g3 - 
     9.02678854067742957e-8*g4*x2)*xbar8 + 
  eps9*(1.26121885620031857e-9*A*g4 + 
     1.00859349622512295e-8*g5*x2)*xbar8 + 
  eps8*(1.32727772394750297e-9*A2*g3 + 
     4.65033697944917988e-8*A*g4*x2 + 
     2.99054295797669073e-8*g5*x4)*xbar8 - 
  2.95801289810004407e-10*eps6*g4*xbar10 + 
  eps8*(7.69281785172546935e-11*A*g4 + 
     1.07490632635875918e-9*g5*x2)*xbar10;
}
#endif

#ifdef p15
double Wp(void)
{
   return 0.5*A*x2 + 0.0416666666666666667*g*x4 + 
  eps*(0.0833333333333333333*A + 0.0416666666666666667*g*x2) + 
  eps3*(-0.00277777777777777778*A2 - 
     0.0111111111111111111*A*g*x2 - 
     0.00208333333333333333*g2*x4) + 
  eps2*(0.00416666666666666667*g - 
     0.0416666666666666667*A2*x2 - 
     0.0138888888888888889*A*g*x4 - 
     0.00115740740740740741*g2*x6) + 
  eps5*(0.0001763668430335097*A3 - 
     0.0000388558201058201058*g2 + 
     0.00214947089947089947*A2*g*x2 + 
     0.00124007936507936508*A*g2*x4 + 
     0.000154320987654320988*g3*x6) + 
  eps4*(-0.000595238095238095238*A*g + 
     0.00416666666666666667*A3*x2 - 
     0.000868055555555555556*g2*x2 + 
     0.00347222222222222222*A2*g*x4 + 
     0.000810185185185185185*A*g2*x6 + 
     0.0000578703703703703704*g3*x8) + 
  eps7*(-0.0000132275132275132275*A4 + 
     0.000013452982202982203*A*g2 - 
     0.000353835978835978836*A3*g*x2 + 
     0.0000292107583774250441*g3*x2 - 
     0.000438161375661375661*A2*g2*x4 - 
     0.000141369047619047619*A*g3*x6 - 
     0.0000131815843621399177*g4*x8) + 
  eps6*(0.0000793650793650793651*A2*g - 
     0.000421626984126984127*A4*x2 + 
     0.000412533068783068783*A*g2*x2 - 
     0.000710978835978835979*A3*g*x4 + 
     0.00012359457671957672*g3*x4 - 
     0.000332065696649029982*A2*g2*x6 - 
     0.0000592482363315696649*A*g3*x8 - 
     3.61689814814814815e-6*g4*x10) + 
  eps9*(1.06888995777884667e-6*A5 - 
     3.09484386865339246e-6*A2*g2 + 
     0.000052889176153065042*A4*g*x2 - 
     0.0000196739667225778337*A*g3*x2 + 
     0.000118621733205066538*A3*g2*x4 - 
     8.12834124466068911e-6*g4*x4 + 
     0.0000723776288012399124*A2*g3*x6 + 
     0.0000162595142340512711*A*g4*x8 + 
     1.2123306755829904e-6*g5*x10) + 
  eps8*(-0.0000100208433541766875*A3*g + 
     8.50711788211788212e-7*g3 + 
     0.0000427138447971781305*A5*x2 - 
     0.000120331539602372936*A2*g2*x2 + 
     0.000127911890064667842*A4*g*x4 - 
     0.000098836830607663941*A*g3*x4 + 
     0.000102804110327258475*A3*g2*x6 - 
     0.0000165018585880854399*g4*x6 + 
     0.0000336428938859494415*A2*g3*x8 + 
     4.8512364050558495e-6*A*g4*x10 + 
     2.56755115454961134e-7*g5*x12) + 
  eps11*(-9.01835117002665504e-8*A6 + 
     5.87400058299529199e-7*A3*g2 - 
     2.81868399275952575e-8*g4 - 
     7.41416841780598394e-6*A5*g*x2 + 
     7.67116473755031956e-6*A2*g3*x2 - 
     0.000027147462601331649*A4*g2*x4 + 
     8.12031936990601012e-6*A*g4*x4 - 
     0.0000272310450812986086*A3*g3*x6 + 
     1.70667153812408442e-6*g5*x6 - 
     0.0000108933015093453806*A2*g4*x8 - 
     1.87850642976993286e-6*A*g5*x10 - 
     1.16690477054095881e-7*g6*x12) + 
  eps10*(1.21747740795359843e-6*A4*g - 
     4.62417873132158846e-7*A*g3 - 
     4.32775172358505692e-6*A6*x2 + 
     0.0000276277014248244407*A3*g2*x2 - 
     1.30445706075046353e-6*g4*x2 - 
     0.0000210333326652771097*A5*g*x4 + 
     0.0000447391253752860896*A2*g3*x4 - 
     0.0000265668910778864483*A4*g2*x6 + 
     0.0000184769777868736202*A*g4*x6 - 
     0.0000139376709110505407*A3*g3*x8 + 
     2.13520310814871e-6*g5*x8 - 
     3.5181249916492972e-6*A2*g4*x10 - 
     4.25407416871537242e-7*A*g5*x12 - 
     1.98147969535893919e-8*g6*x14) + 
  eps13*(7.83069566138349207e-9*A7 - 
     9.93094869534334209e-8*A4*g2 + 
     2.08755249185163841e-8*A*g4 + 
     9.92791119692574719e-7*A6*g*x2 - 
     2.26246788359770127e-6*A3*g3*x2 + 
     7.19774046753493046e-8*g5*x2 + 
     5.52538741816188906e-6*A5*g2*x4 - 
     4.47883727161149936e-6*A2*g4*x4 + 
     8.38601213983571788e-6*A4*g3*x6 - 
     2.25348627386308778e-6*A*g5*x6 + 
     5.24445855604457162e-6*A3*g4*x8 - 
     3.11392974798759566e-7*g6*x8 + 
     1.55465050346795001e-6*A2*g5*x10 + 
     2.17600880397466046e-7*A*g6*x12 + 
     1.15841884836628278e-8*g7*x14) + 
  eps12*(-1.43889032777921667e-7*A5*g + 
     1.51283642180000723e-7*A2*g3 + 
     4.38492191964414187e-7*A7*x2 - 
     5.47671197834474951e-6*A4*g2*x2 + 
     1.1365151365172641e-6*A*g4*x2 + 
     3.23789133106262736e-6*A6*g*x4 - 
     0.0000150481673660823793*A3*g3*x4 + 
     5.97324614725086198e-7*g5*x4 + 
     6.03932684613625972e-6*A5*g2*x6 - 
     0.0000113106765525436987*A2*g4*x6 + 
     4.69528859165240338e-6*A4*g3*x8 - 
     3.0694501391598228e-6*A*g5*x8 + 
     1.82557370238215146e-6*A3*g4*x10 - 
     2.71046144994230449e-7*g6*x10 + 
     3.7535031778135559e-7*A2*g5*x12 + 
     3.90681314457195373e-8*A*g6*x14 + 
     1.62260932077515154e-9*g7*x16) + 
  eps14*(1.66609565924847593e-8*A6*g - 
     3.84541066603365207e-8*A3*g3 + 
     1.23616495716322489e-9*g5 - 
     4.44285396439000936e-8*A8*x2 + 
     9.81807578832239391e-7*A5*g2*x2 - 
     5.55101746448534654e-7*A2*g4*x2 - 
     4.73967830600877338e-7*A7*g*x4 + 
     4.18284859452059839e-6*A4*g3*x4 - 
     7.15343253702736788e-7*A*g5*x4 - 
     1.24663165145441196e-6*A6*g2*x6 + 
     5.00514675879205854e-6*A3*g4*x6 - 
     1.81402700349001079e-7*g6*x6 - 
     1.36226318220021373e-6*A5*g3*x8 + 
     2.36606032230627314e-6*A2*g5*x8 - 
     7.58172593612770117e-7*A4*g4*x10 + 
     4.75471890972483691e-7*A*g6*x10 - 
     2.34027522244261325e-7*A3*g5*x12 + 
     3.3963539821117207e-8*g7*x12 - 
     4.06050820222736176e-8*A2*g6*x14 - 
     3.70938742929349711e-9*A*g7*x16 - 
     1.38898528337180163e-10*g8*x18) + 
  0.00833333333333333333*eps*g*xbar2 + 
  0.166666666666666667*(A + 0.5*g*x2)*xbar2 + 
  eps3*(-0.000793650793650793651*A*g - 
     0.00138888888888888889*g2*x2)*xbar2 + 
  eps2*(-0.00277777777777777778*A2 - 
     0.0111111111111111111*A*g*x2 - 
     0.00208333333333333333*g2*x4)*xbar2 + 
  eps5*(0.0000727513227513227513*A2*g + 
     0.000522486772486772487*A*g2*x2 + 
     0.000162037037037037037*g3*x4)*xbar2 + 
  eps4*(0.0000661375661375661376*A3 - 
     0.0000644841269841269841*g2 + 
     0.0015873015873015873*A2*g*x2 + 
     0.00094246031746031746*A*g2*x4 + 
     0.000115740740740740741*g3*x6)*xbar2 + 
  eps7*(-6.91438191438191438e-6*A3*g + 
     1.41486599819933153e-6*g3 - 
     0.000128066378066378066*A2*g2*x2 - 
     0.000110705266955266955*A*g3*x4 - 
     0.000018647119341563786*g4*x6)*xbar2 + 
  eps6*(-1.65343915343915344e-6*A4 + 
     0.0000179623617123617124*A*g2 - 
     0.00021164021164021164*A3*g*x2 + 
     0.0000485008818342151675*g3*x2 - 
     0.000276951058201058201*A2*g2*x4 - 
     0.0000898368606701940035*A*g3*x6 - 
     8.27867798353909465e-6*g4*x8)*xbar2 + 
  eps9*(6.79829796893288957e-7*A4*g - 
     6.72419695237155555e-7*A*g3 + 
     0.0000254975770848786722*A3*g2*x2 - 
     2.25056258042369153e-6*g4*x2 + 
     0.0000441438108848823135*A2*g3*x4 + 
     0.0000185871013417309714*A*g4*x6 + 
     2.15148764772607365e-6*g5*x8)*xbar2 + 
  eps8*(4.1753513975736198e-8*A5 - 
     3.46221514376276281e-6*A2*g2 + 
     0.0000267222489444711667*A4*g*x2 - 
     0.0000281804101248545693*A*g3*x2 + 
     0.0000649475909892576559*A3*g2*x4 - 
     0.0000122030666735527847*g4*x4 + 
     0.0000403965247715247715*A2*g3*x6 + 
     9.0700810463541945e-6*A*g4*x8 + 
     6.69795953360768176e-7*g5*x10)*xbar2 + 
  eps11*(-6.80612866459427306e-8*A5*g + 
     1.95584655809718057e-7*A2*g3 - 
     4.47269759439071608e-6*A4*g2*x2 + 
     1.75829988748211593e-6*A*g4*x2 - 
     0.0000133314481239415102*A3*g3*x4 + 
     9.71399147418687179e-7*g5*x4 - 
     0.0000103064498801381517*A2*g4*x6 - 
     2.82142523293179157e-6*A*g5*x8 - 
     2.4892365507720446e-7*g6*x10)*xbar2 + 
  eps10*(-1.05683802773749864e-9*A6 + 
     5.67501373552960855e-7*A3*g2 - 
     4.8511255774108832e-8*g4 - 
     3.24660642120959581e-6*A5*g*x2 + 
     9.71126169538867952e-6*A2*g3*x2 - 
     0.0000131832441790279092*A4*g2*x4 + 
     0.0000108846610427711618*A*g4*x4 - 
     0.0000136365860158849577*A3*g3*x6 + 
     2.33168885512635513e-6*g5*x6 - 
     5.4993290386188865e-6*A2*g4*x8 - 
     9.46094479080590192e-7*A*g5*x10 - 
     5.8302302889011994e-8*g6*x12)*xbar2 + 
  eps13*(6.86627585651083939e-9*A6*g - 
     4.47785160224899766e-8*A3*g3 + 
     2.19249275444418889e-9*g5 + 
     7.19946098097358602e-7*A5*g2*x2 - 
     7.80379784965903039e-7*A2*g4*x2 + 
     3.37142842641135708e-6*A4*g3*x4 - 
     1.06398186364605041e-6*A*g5*x4 + 
     4.18165456228327982e-6*A3*g4*x6 - 
     2.76351067919865578e-7*g6*x6 + 
     2.00589567077445504e-6*A2*g5*x8 + 
     4.04753308555164946e-7*A*g6*x10 + 
     2.88571475583667131e-8*g7*x12)*xbar2 + 
  eps12*(2.67650730613693577e-11*A7 - 
     8.46192910475220622e-8*A4*g2 + 
     3.25142589196534057e-8*A*g4 + 
     3.83704087407791111e-7*A6*g*x2 - 
     2.57283359783619147e-6*A3*g3*x2 + 
     1.27951218977907431e-7*g5*x2 + 
     2.41765559329216737e-6*A5*g2*x4 - 
     5.44480881814382923e-6*A2*g4*x4 + 
     3.82233569685344377e-6*A4*g3*x6 - 
     2.81139544164632672e-6*A*g5*x6 + 
     2.42710273474001612e-6*A3*g4*x8 - 
     3.92027350262991887e-7*g6*x8 + 
     7.21984500196305752e-7*A2*g5*x10 + 
     1.007566064009769e-7*A*g6*x12 + 
     5.32759708629371695e-9*g7*x14)*xbar2 + 
  0.00833333333333333333*g*xbar4 - 
  0.0000462962962962962963*eps3*g2*xbar4 + 
  eps2*(-0.000396825396825396825*A*g - 
     0.000694444444444444444*g2*x2)*xbar4 + 
  eps5*(9.11896745230078563e-6*A*g2 + 
     0.0000308641975308641975*g3*x2)*xbar4 + 
  eps4*(0.0000198412698412698413*A2*g + 
     0.000195105820105820106*A*g2*x2 + 
     0.0000617283950617283951*g3*x4)*xbar4 + 
  eps7*(-1.31581381581381581e-6*A2*g2 - 
     0.0000151318588818588819*A*g3*x2 - 
     6.8455207344096233e-6*g4*x4)*xbar4 + 
  eps6*(-9.01875901875901876e-7*A3*g + 
     9.90714532381199048e-7*g3 - 
     0.0000389059243225909893*A2*g2*x2 - 
     0.0000351397573619795842*A*g3*x4 - 
     5.9477880658436214e-6*g4*x6)*xbar4 + 
  eps9*(1.71045640622360199e-7*A3*g2 - 
     3.60906857706966639e-8*g4 + 
     4.53245406122390249e-6*A2*g3*x2 + 
     5.38783061931210079e-6*A*g4*x4 + 
     1.17492514772607365e-6*g5*x6)*xbar4 + 
  eps8*(3.77616945077262538e-8*A4*g - 
     3.91505723846993688e-7*A*g3 + 
     6.55938527962337486e-6*A3*g2*x2 - 
     1.61985166325444103e-6*g4*x2 + 
     0.0000121547079219036891*A2*g3*x4 + 
     5.20508405346368309e-6*A*g4*x6 + 
     6.02301130368259998e-7*g5*x8)*xbar4 + 
  eps11*(-2.12135350797297057e-8*A4*g2 + 
     2.14460056215349951e-8*A*g4 - 
     1.06401470496877178e-6*A3*g3*x2 + 
     9.9419658966568008e-8*g5*x2 - 
     2.4228308825712602e-6*A2*g4*x4 - 
     1.28380796826126347e-6*A*g5*x6 - 
     1.80516340332649186e-7*g6*x8)*xbar4 + 
  eps10*(-1.48202033122668043e-9*A5*g + 
     9.77137892841674354e-8*A2*g3 - 
     9.98537198520664129e-7*A4*g2*x2 + 
     1.12096864298613054e-6*A*g4*x2 - 
     3.25929867376075489e-6*A3*g3*x4 + 
     6.52088831782005348e-7*g5*x4 - 
     2.59007734102806854e-6*A2*g4*x6 - 
     7.14333704061713321e-7*A*g5*x8 - 
     6.28878290312510992e-8*g6*x10)*xbar4 + 
  eps12*(5.52620037914155561e-11*A6*g - 
     1.96395897468419557e-8*A3*g3 + 
     1.73105497543500998e-9*g5 + 
     1.41930118072774209e-7*A5*g2*x2 - 
     4.4751871911848506e-7*A2*g4*x2 + 
     7.4329679752095632e-7*A4*g3*x4 - 
     6.48579919839268283e-7*A*g5*x4 + 
     9.56849686940199225e-7*A3*g4*x6 - 
     1.72592309647809413e-7*g6*x6 + 
     4.6549037372399414e-7*A2*g5*x8 + 
     9.4234108977460504e-8*A*g6*x10 + 
     6.6997976279157566e-9*g7*x12)*xbar4 - 
  0.0000154320987654320988*eps2*g2*xbar6 + 
  3.56125356125356125e-7*eps5*g3*xbar6 + 
  eps4*(1.90396023729357063e-6*A*g2 + 
     7.71604938271604938e-6*g3*x2)*xbar6 + 
  eps7*(-1.06760523427190094e-7*A*g3 - 
     5.83649889205444761e-7*g4*x2)*xbar6 + 
  eps6*(-1.58222876476844731e-7*A2*g2 - 
     3.0990100434544879e-6*A*g3*x2 - 
     1.45170544476100032e-6*g4*x4)*xbar6 + 
  eps9*(2.10474956623416007e-8*A2*g3 + 
     3.52066889376257568e-7*A*g4*x2 + 
     2.15683591284989252e-7*g5*x4)*xbar6 + 
  eps8*(1.0639753805538638e-8*A3*g2 - 
     1.44647796358943781e-8*g4 + 
     7.89019059521705024e-7*A2*g3*x2 + 
     9.93278626380478232e-7*A*g4*x4 + 
     2.19830466744046991e-7*g5*x6)*xbar6 + 
  eps11*(-3.48009271425128996e-9*A3*g3 + 
     7.74456172615070677e-10*g5 - 
     1.24759056081950737e-7*A2*g4*x2 - 
     1.93124743183608916e-7*A*g5*x4 - 
     5.26262283781649553e-8*g6*x6)*xbar6 + 
  eps10*(-6.21784885258793341e-10*A4*g2 + 
     7.35917308458240036e-9*A*g4 - 
     1.61082849737015107e-7*A3*g3*x2 + 
     4.25042008023580282e-8*g5*x2 - 
     3.97181909847740069e-7*A2*g4*x4 - 
     2.15693489113968417e-7*A*g5*x6 - 
     3.05361793587726322e-8*g6*x8)*xbar6 + 
  5.93542260208926876e-8*eps4*g3*xbar8 - 
  3.12288574815807931e-9*eps7*g4*xbar8 + 
  eps6*(-1.14340392118169896e-8*A*g3 - 
     9.02678854067742957e-8*g4*x2)*xbar8 + 
  eps9*(1.26121885620031857e-9*A*g4 + 
     1.00859349622512295e-8*g5*x2)*xbar8 + 
  eps8*(1.32727772394750297e-9*A2*g3 + 
     4.65033697944917988e-8*A*g4*x2 + 
     2.99054295797669073e-8*g5*x4)*xbar8 + 
  eps10*(-1.18235613578975095e-10*A3*g3 + 
     2.04522364126337295e-10*g5 - 
     1.4372001684607648e-8*A2*g4*x2 - 
     2.38545902650207871e-8*A*g5*x4 - 
     6.6442647298050802e-9*g6*x6)*xbar8 - 
  2.95801289810004407e-10*eps6*g4*xbar10 + 
  2.94346529368315861e-11*eps9*g5*xbar10 + 
  eps8*(7.69281785172546935e-11*A*g4 + 
     1.07490632635875918e-9*g5*x2)*xbar10 + 
  1.69722051530330397e-12*eps8*g5*xbar12;
}
#endif

#ifdef p16
double Wp(void)
{
   return 0.5*A*x2 + 0.0416666666666666667*g*x4 + 
  eps*(0.0833333333333333333*A + 0.0416666666666666667*g*x2) + 
  eps3*(-0.00277777777777777778*A2 - 
     0.0111111111111111111*A*g*x2 - 
     0.00208333333333333333*g2*x4) + 
  eps2*(0.00416666666666666667*g - 
     0.0416666666666666667*A2*x2 - 
     0.0138888888888888889*A*g*x4 - 
     0.00115740740740740741*g2*x6) + 
  eps5*(0.0001763668430335097*A3 - 
     0.0000388558201058201058*g2 + 
     0.00214947089947089947*A2*g*x2 + 
     0.00124007936507936508*A*g2*x4 + 
     0.000154320987654320988*g3*x6) + 
  eps4*(-0.000595238095238095238*A*g + 
     0.00416666666666666667*A3*x2 - 
     0.000868055555555555556*g2*x2 + 
     0.00347222222222222222*A2*g*x4 + 
     0.000810185185185185185*A*g2*x6 + 
     0.0000578703703703703704*g3*x8) + 
  eps7*(-0.0000132275132275132275*A4 + 
     0.000013452982202982203*A*g2 - 
     0.000353835978835978836*A3*g*x2 + 
     0.0000292107583774250441*g3*x2 - 
     0.000438161375661375661*A2*g2*x4 - 
     0.000141369047619047619*A*g3*x6 - 
     0.0000131815843621399177*g4*x8) + 
  eps6*(0.0000793650793650793651*A2*g - 
     0.000421626984126984127*A4*x2 + 
     0.000412533068783068783*A*g2*x2 - 
     0.000710978835978835979*A3*g*x4 + 
     0.00012359457671957672*g3*x4 - 
     0.000332065696649029982*A2*g2*x6 - 
     0.0000592482363315696649*A*g3*x8 - 
     3.61689814814814815e-6*g4*x10) + 
  eps9*(1.06888995777884667e-6*A5 - 
     3.09484386865339246e-6*A2*g2 + 
     0.000052889176153065042*A4*g*x2 - 
     0.0000196739667225778337*A*g3*x2 + 
     0.000118621733205066538*A3*g2*x4 - 
     8.12834124466068911e-6*g4*x4 + 
     0.0000723776288012399124*A2*g3*x6 + 
     0.0000162595142340512711*A*g4*x8 + 
     1.2123306755829904e-6*g5*x10) + 
  eps8*(-0.0000100208433541766875*A3*g + 
     8.50711788211788212e-7*g3 + 
     0.0000427138447971781305*A5*x2 - 
     0.000120331539602372936*A2*g2*x2 + 
     0.000127911890064667842*A4*g*x4 - 
     0.000098836830607663941*A*g3*x4 + 
     0.000102804110327258475*A3*g2*x6 - 
     0.0000165018585880854399*g4*x6 + 
     0.0000336428938859494415*A2*g3*x8 + 
     4.8512364050558495e-6*A*g4*x10 + 
     2.56755115454961134e-7*g5*x12) + 
  eps11*(-9.01835117002665504e-8*A6 + 
     5.87400058299529199e-7*A3*g2 - 
     2.81868399275952575e-8*g4 - 
     7.41416841780598394e-6*A5*g*x2 + 
     7.67116473755031956e-6*A2*g3*x2 - 
     0.000027147462601331649*A4*g2*x4 + 
     8.12031936990601012e-6*A*g4*x4 - 
     0.0000272310450812986086*A3*g3*x6 + 
     1.70667153812408442e-6*g5*x6 - 
     0.0000108933015093453806*A2*g4*x8 - 
     1.87850642976993286e-6*A*g5*x10 - 
     1.16690477054095881e-7*g6*x12) + 
  eps10*(1.21747740795359843e-6*A4*g - 
     4.62417873132158846e-7*A*g3 - 
     4.32775172358505692e-6*A6*x2 + 
     0.0000276277014248244407*A3*g2*x2 - 
     1.30445706075046353e-6*g4*x2 - 
     0.0000210333326652771097*A5*g*x4 + 
     0.0000447391253752860896*A2*g3*x4 - 
     0.0000265668910778864483*A4*g2*x6 + 
     0.0000184769777868736202*A*g4*x6 - 
     0.0000139376709110505407*A3*g3*x8 + 
     2.13520310814871e-6*g5*x8 - 
     3.5181249916492972e-6*A2*g4*x10 - 
     4.25407416871537242e-7*A*g5*x12 - 
     1.98147969535893919e-8*g6*x14) + 
  eps13*(7.83069566138349207e-9*A7 - 
     9.93094869534334209e-8*A4*g2 + 
     2.08755249185163841e-8*A*g4 + 
     9.92791119692574719e-7*A6*g*x2 - 
     2.26246788359770127e-6*A3*g3*x2 + 
     7.19774046753493046e-8*g5*x2 + 
     5.52538741816188906e-6*A5*g2*x4 - 
     4.47883727161149936e-6*A2*g4*x4 + 
     8.38601213983571788e-6*A4*g3*x6 - 
     2.25348627386308778e-6*A*g5*x6 + 
     5.24445855604457162e-6*A3*g4*x8 - 
     3.11392974798759566e-7*g6*x8 + 
     1.55465050346795001e-6*A2*g5*x10 + 
     2.17600880397466046e-7*A*g6*x12 + 
     1.15841884836628278e-8*g7*x14) + 
  eps12*(-1.43889032777921667e-7*A5*g + 
     1.51283642180000723e-7*A2*g3 + 
     4.38492191964414187e-7*A7*x2 - 
     5.47671197834474951e-6*A4*g2*x2 + 
     1.1365151365172641e-6*A*g4*x2 + 
     3.23789133106262736e-6*A6*g*x4 - 
     0.0000150481673660823793*A3*g3*x4 + 
     5.97324614725086198e-7*g5*x4 + 
     6.03932684613625972e-6*A5*g2*x6 - 
     0.0000113106765525436987*A2*g4*x6 + 
     4.69528859165240338e-6*A4*g3*x8 - 
     3.0694501391598228e-6*A*g5*x8 + 
     1.82557370238215146e-6*A3*g4*x10 - 
     2.71046144994230449e-7*g6*x10 + 
     3.7535031778135559e-7*A2*g5*x12 + 
     3.90681314457195373e-8*A*g6*x14 + 
     1.62260932077515154e-9*g7*x16) + 
  eps15*(-6.94206524686864971e-10*A8 + 
     1.55258266251201437e-8*A5*g2 - 
     8.87063997906019346e-9*A2*g4 - 
     1.28444091425696105e-7*A7*g*x2 + 
     5.59355511978255916e-7*A4*g3*x2 - 
     7.69591961687451275e-8*A*g5*x2 - 
     1.03084425773136674e-6*A6*g2*x4 + 
     1.80099658500984157e-6*A3*g4*x4 - 
     4.89852640150590245e-8*g6*x4 - 
     2.23744987275327073e-6*A5*g3*x6 + 
     1.60416803829389571e-6*A2*g5*x6 - 
     2.02887475090349778e-6*A4*g4*x8 + 
     5.10536772376168298e-7*A*g6*x8 - 
     9.11746562790846727e-7*A3*g5*x10 + 
     5.21769349658492833e-8*g7*x10 - 
     2.14341780318485671e-7*A2*g6*x12 - 
     2.52490551976121104e-8*A*g7*x14 - 
     1.17600420262660865e-9*g8*x16) + 
  eps14*(1.66609565924847593e-8*A6*g - 
     3.84541066603365207e-8*A3*g3 + 
     1.23616495716322489e-9*g5 - 
     4.44285396439000936e-8*A8*x2 + 
     9.81807578832239391e-7*A5*g2*x2 - 
     5.55101746448534654e-7*A2*g4*x2 - 
     4.73967830600877338e-7*A7*g*x4 + 
     4.18284859452059839e-6*A4*g3*x4 - 
     7.15343253702736788e-7*A*g5*x4 - 
     1.24663165145441196e-6*A6*g2*x6 + 
     5.00514675879205854e-6*A3*g4*x6 - 
     1.81402700349001079e-7*g6*x6 - 
     1.36226318220021373e-6*A5*g3*x8 + 
     2.36606032230627314e-6*A2*g5*x8 - 
     7.58172593612770117e-7*A4*g4*x10 + 
     4.75471890972483691e-7*A*g6*x10 - 
     2.34027522244261325e-7*A3*g5*x12 + 
     3.3963539821117207e-8*g7*x12 - 
     4.06050820222736176e-8*A2*g6*x14 - 
     3.70938742929349711e-9*A*g7*x16 - 
     1.38898528337180163e-10*g8*x18) + 
  0.00833333333333333333*eps*g*xbar2 + 
  0.166666666666666667*(A + 0.5*g*x2)*xbar2 + 
  eps3*(-0.000793650793650793651*A*g - 
     0.00138888888888888889*g2*x2)*xbar2 + 
  eps2*(-0.00277777777777777778*A2 - 
     0.0111111111111111111*A*g*x2 - 
     0.00208333333333333333*g2*x4)*xbar2 + 
  eps5*(0.0000727513227513227513*A2*g + 
     0.000522486772486772487*A*g2*x2 + 
     0.000162037037037037037*g3*x4)*xbar2 + 
  eps4*(0.0000661375661375661376*A3 - 
     0.0000644841269841269841*g2 + 
     0.0015873015873015873*A2*g*x2 + 
     0.00094246031746031746*A*g2*x4 + 
     0.000115740740740740741*g3*x6)*xbar2 + 
  eps7*(-6.91438191438191438e-6*A3*g + 
     1.41486599819933153e-6*g3 - 
     0.000128066378066378066*A2*g2*x2 - 
     0.000110705266955266955*A*g3*x4 - 
     0.000018647119341563786*g4*x6)*xbar2 + 
  eps6*(-1.65343915343915344e-6*A4 + 
     0.0000179623617123617124*A*g2 - 
     0.00021164021164021164*A3*g*x2 + 
     0.0000485008818342151675*g3*x2 - 
     0.000276951058201058201*A2*g2*x4 - 
     0.0000898368606701940035*A*g3*x6 - 
     8.27867798353909465e-6*g4*x8)*xbar2 + 
  eps9*(6.79829796893288957e-7*A4*g - 
     6.72419695237155555e-7*A*g3 + 
     0.0000254975770848786722*A3*g2*x2 - 
     2.25056258042369153e-6*g4*x2 + 
     0.0000441438108848823135*A2*g3*x4 + 
     0.0000185871013417309714*A*g4*x6 + 
     2.15148764772607365e-6*g5*x8)*xbar2 + 
  eps8*(4.1753513975736198e-8*A5 - 
     3.46221514376276281e-6*A2*g2 + 
     0.0000267222489444711667*A4*g*x2 - 
     0.0000281804101248545693*A*g3*x2 + 
     0.0000649475909892576559*A3*g2*x4 - 
     0.0000122030666735527847*g4*x4 + 
     0.0000403965247715247715*A2*g3*x6 + 
     9.0700810463541945e-6*A*g4*x8 + 
     6.69795953360768176e-7*g5*x10)*xbar2 + 
  eps11*(-6.80612866459427306e-8*A5*g + 
     1.95584655809718057e-7*A2*g3 - 
     4.47269759439071608e-6*A4*g2*x2 + 
     1.75829988748211593e-6*A*g4*x2 - 
     0.0000133314481239415102*A3*g3*x4 + 
     9.71399147418687179e-7*g5*x4 - 
     0.0000103064498801381517*A2*g4*x6 - 
     2.82142523293179157e-6*A*g5*x8 - 
     2.4892365507720446e-7*g6*x10)*xbar2 + 
  eps10*(-1.05683802773749864e-9*A6 + 
     5.67501373552960855e-7*A3*g2 - 
     4.8511255774108832e-8*g4 - 
     3.24660642120959581e-6*A5*g*x2 + 
     9.71126169538867952e-6*A2*g3*x2 - 
     0.0000131832441790279092*A4*g2*x4 + 
     0.0000108846610427711618*A*g4*x4 - 
     0.0000136365860158849577*A3*g3*x6 + 
     2.33168885512635513e-6*g5*x6 - 
     5.4993290386188865e-6*A2*g4*x8 - 
     9.46094479080590192e-7*A*g5*x10 - 
     5.8302302889011994e-8*g6*x12)*xbar2 + 
  eps13*(6.86627585651083939e-9*A6*g - 
     4.47785160224899766e-8*A3*g3 + 
     2.19249275444418889e-9*g5 + 
     7.19946098097358602e-7*A5*g2*x2 - 
     7.80379784965903039e-7*A2*g4*x2 + 
     3.37142842641135708e-6*A4*g3*x4 - 
     1.06398186364605041e-6*A*g5*x4 + 
     4.18165456228327982e-6*A3*g4*x6 - 
     2.76351067919865578e-7*g6*x6 + 
     2.00589567077445504e-6*A2*g5*x8 + 
     4.04753308555164946e-7*A*g6*x10 + 
     2.88571475583667131e-8*g7*x12)*xbar2 + 
  eps12*(2.67650730613693577e-11*A7 - 
     8.46192910475220622e-8*A4*g2 + 
     3.25142589196534057e-8*A*g4 + 
     3.83704087407791111e-7*A6*g*x2 - 
     2.57283359783619147e-6*A3*g3*x2 + 
     1.27951218977907431e-7*g5*x2 + 
     2.41765559329216737e-6*A5*g2*x4 - 
     5.44480881814382923e-6*A2*g4*x4 + 
     3.82233569685344377e-6*A4*g3*x6 - 
     2.81139544164632672e-6*A*g5*x6 + 
     2.42710273474001612e-6*A3*g4*x8 - 
     3.92027350262991887e-7*g6*x8 + 
     7.21984500196305752e-7*A2*g5*x10 + 
     1.007566064009769e-7*A*g6*x12 + 
     5.32759708629371695e-9*g7*x14)*xbar2 + 
  eps14*(-6.77936059264516573e-13*A8 + 
     1.18453251754498057e-8*A5*g2 - 
     1.26192122113177278e-8*A2*g4 - 
     4.44292175799593582e-8*A7*g*x2 + 
     5.78235471803035281e-7*A4*g3*x2 - 
     1.25465164813262727e-7*A*g5*x2 - 
     4.11093596933471078e-7*A6*g2*x4 + 
     2.00802343589623813e-6*A3*g4*x4 - 
     8.38456228452171631e-8*g6*x4 - 
     9.37962675222683393e-7*A5*g3*x6 + 
     1.84660973293660698e-6*A2*g5*x6 - 
     8.68952732620502728e-7*A4*g4*x8 + 
     5.95974150882540242e-7*A*g6*x8 - 
     3.93789587968658131e-7*A3*g5*x10 + 
     6.11861559616332661e-8*g7*x10 - 
     9.26911580977221589e-8*A2*g6*x12 - 
     1.08851336477984649e-8*A*g7*x14 - 
     5.04016698893419468e-10*g8*x16)*xbar2 + 
  0.00833333333333333333*g*xbar4 - 
  0.0000462962962962962963*eps3*g2*xbar4 + 
  eps2*(-0.000396825396825396825*A*g - 
     0.000694444444444444444*g2*x2)*xbar4 + 
  eps5*(9.11896745230078563e-6*A*g2 + 
     0.0000308641975308641975*g3*x2)*xbar4 + 
  eps4*(0.0000198412698412698413*A2*g + 
     0.000195105820105820106*A*g2*x2 + 
     0.0000617283950617283951*g3*x4)*xbar4 + 
  eps7*(-1.31581381581381581e-6*A2*g2 - 
     0.0000151318588818588819*A*g3*x2 - 
     6.8455207344096233e-6*g4*x4)*xbar4 + 
  eps6*(-9.01875901875901876e-7*A3*g + 
     9.90714532381199048e-7*g3 - 
     0.0000389059243225909893*A2*g2*x2 - 
     0.0000351397573619795842*A*g3*x4 - 
     5.9477880658436214e-6*g4*x6)*xbar4 + 
  eps9*(1.71045640622360199e-7*A3*g2 - 
     3.60906857706966639e-8*g4 + 
     4.53245406122390249e-6*A2*g3*x2 + 
     5.38783061931210079e-6*A*g4*x4 + 
     1.17492514772607365e-6*g5*x6)*xbar4 + 
  eps8*(3.77616945077262538e-8*A4*g - 
     3.91505723846993688e-7*A*g3 + 
     6.55938527962337486e-6*A3*g2*x2 - 
     1.61985166325444103e-6*g4*x2 + 
     0.0000121547079219036891*A2*g3*x4 + 
     5.20508405346368309e-6*A*g4*x6 + 
     6.02301130368259998e-7*g5*x8)*xbar4 + 
  eps11*(-2.12135350797297057e-8*A4*g2 + 
     2.14460056215349951e-8*A*g4 - 
     1.06401470496877178e-6*A3*g3*x2 + 
     9.9419658966568008e-8*g5*x2 - 
     2.4228308825712602e-6*A2*g4*x4 - 
     1.28380796826126347e-6*A*g5*x6 - 
     1.80516340332649186e-7*g6*x8)*xbar4 + 
  eps10*(-1.48202033122668043e-9*A5*g + 
     9.77137892841674354e-8*A2*g3 - 
     9.98537198520664129e-7*A4*g2*x2 + 
     1.12096864298613054e-6*A*g4*x2 - 
     3.25929867376075489e-6*A3*g3*x4 + 
     6.52088831782005348e-7*g5*x4 - 
     2.59007734102806854e-6*A2*g4*x6 - 
     7.14333704061713321e-7*A*g5*x8 - 
     6.28878290312510992e-8*g6*x10)*xbar4 + 
  eps13*(2.55551047231023315e-9*A5*g2 - 
     7.48454109323006102e-9*A2*g4 + 
     2.14869723911233424e-7*A4*g3*x2 - 
     8.87037184673700903e-8*A*g5*x2 + 
     8.1367411096167446e-7*A3*g4*x4 - 
     6.24554324051377381e-8*g6*x4 + 
     7.73534185148061632e-7*A2*g5*x6 + 
     2.53114332805174734e-7*A*g6*x8 + 
     2.60907174059342559e-8*g7*x10)*xbar4 + 
  eps12*(5.52620037914155561e-11*A6*g - 
     1.96395897468419557e-8*A3*g3 + 
     1.73105497543500998e-9*g5 + 
     1.41930118072774209e-7*A5*g2*x2 - 
     4.4751871911848506e-7*A2*g4*x2 + 
     7.4329679752095632e-7*A4*g3*x4 - 
     6.48579919839268283e-7*A*g5*x4 + 
     9.56849686940199225e-7*A3*g4*x6 - 
     1.72592309647809413e-7*g6*x6 + 
     4.6549037372399414e-7*A2*g5*x8 + 
     9.4234108977460504e-8*A*g6*x10 + 
     6.6997976279157566e-9*g7*x12)*xbar4 - 
  0.0000154320987654320988*eps2*g2*xbar6 + 
  3.56125356125356125e-7*eps5*g3*xbar6 + 
  eps4*(1.90396023729357063e-6*A*g2 + 
     7.71604938271604938e-6*g3*x2)*xbar6 + 
  eps7*(-1.06760523427190094e-7*A*g3 - 
     5.83649889205444761e-7*g4*x2)*xbar6 + 
  eps6*(-1.58222876476844731e-7*A2*g2 - 
     3.0990100434544879e-6*A*g3*x2 - 
     1.45170544476100032e-6*g4*x4)*xbar6 + 
  eps9*(2.10474956623416007e-8*A2*g3 + 
     3.52066889376257568e-7*A*g4*x2 + 
     2.15683591284989252e-7*g5*x4)*xbar6 + 
  eps8*(1.0639753805538638e-8*A3*g2 - 
     1.44647796358943781e-8*g4 + 
     7.89019059521705024e-7*A2*g3*x2 + 
     9.93278626380478232e-7*A*g4*x4 + 
     2.19830466744046991e-7*g5*x6)*xbar6 + 
  eps11*(-3.48009271425128996e-9*A3*g3 + 
     7.74456172615070677e-10*g5 - 
     1.24759056081950737e-7*A2*g4*x2 - 
     1.93124743183608916e-7*A*g5*x4 - 
     5.26262283781649553e-8*g6*x6)*xbar6 + 
  eps10*(-6.21784885258793341e-10*A4*g2 + 
     7.35917308458240036e-9*A*g4 - 
     1.61082849737015107e-7*A3*g3*x2 + 
     4.25042008023580282e-8*g5*x2 - 
     3.97181909847740069e-7*A2*g4*x4 - 
     2.15693489113968417e-7*A*g5*x6 - 
     3.05361793587726322e-8*g6*x8)*xbar6 + 
  eps12*(3.28023733515722384e-11*A5*g2 - 
     2.2483490443839068e-9*A2*g4 + 
     2.87554439944054822e-8*A4*g3*x2 - 
     3.41643318587639607e-8*A*g5*x2 + 
     1.20413081223750724e-7*A3*g4*x4 - 
     2.54382194661358481e-8*g6*x4 + 
     1.18403247344882478e-7*A2*g5*x6 + 
     3.92485363936068314e-8*A*g6*x8 + 
     4.05810532585570662e-9*g7*x10)*xbar6 + 
  5.93542260208926876e-8*eps4*g3*xbar8 - 
  3.12288574815807931e-9*eps7*g4*xbar8 + 
  eps6*(-1.14340392118169896e-8*A*g3 - 
     9.02678854067742957e-8*g4*x2)*xbar8 + 
  eps9*(1.26121885620031857e-9*A*g4 + 
     1.00859349622512295e-8*g5*x2)*xbar8 + 
  eps8*(1.32727772394750297e-9*A2*g3 + 
     4.65033697944917988e-8*A*g4*x2 + 
     2.99054295797669073e-8*g5*x4)*xbar8 + 
  eps11*(-3.15709843216944468e-10*A2*g4 - 
     7.21099301568180965e-9*A*g5*x2 - 
     5.69746824484251863e-9*g6*x4)*xbar8 + 
  eps10*(-1.18235613578975095e-10*A3*g3 + 
     2.04522364126337295e-10*g5 - 
     1.4372001684607648e-8*A2*g4*x2 - 
     2.38545902650207871e-8*A*g5*x4 - 
     6.6442647298050802e-9*g6*x6)*xbar8 - 
  2.95801289810004407e-10*eps6*g4*xbar10 + 
  2.94346529368315861e-11*eps9*g5*xbar10 + 
  eps8*(7.69281785172546935e-11*A*g4 + 
     1.07490632635875918e-9*g5*x2)*xbar10 + 
  eps10*(-1.14623038722347948e-11*A2*g4 - 
     6.72527675714427998e-10*A*g5*x2 - 
     5.64942074025452747e-10*g6*x4)*xbar10 + 
  1.69722051530330397e-12*eps8*g5*xbar12;
}
#endif

#ifdef p17
double Wp(void)
{
   return 0.5*A*x2 + 0.0416666666666666667*g*x4 + 
  eps*(0.0833333333333333333*A + 0.0416666666666666667*g*x2) + 
  eps3*(-0.00277777777777777778*A2 - 
     0.0111111111111111111*A*g*x2 - 
     0.00208333333333333333*g2*x4) + 
  eps2*(0.00416666666666666667*g - 
     0.0416666666666666667*A2*x2 - 
     0.0138888888888888889*A*g*x4 - 
     0.00115740740740740741*g2*x6) + 
  eps5*(0.0001763668430335097*A3 - 
     0.0000388558201058201058*g2 + 
     0.00214947089947089947*A2*g*x2 + 
     0.00124007936507936508*A*g2*x4 + 
     0.000154320987654320988*g3*x6) + 
  eps4*(-0.000595238095238095238*A*g + 
     0.00416666666666666667*A3*x2 - 
     0.000868055555555555556*g2*x2 + 
     0.00347222222222222222*A2*g*x4 + 
     0.000810185185185185185*A*g2*x6 + 
     0.0000578703703703703704*g3*x8) + 
  eps7*(-0.0000132275132275132275*A4 + 
     0.000013452982202982203*A*g2 - 
     0.000353835978835978836*A3*g*x2 + 
     0.0000292107583774250441*g3*x2 - 
     0.000438161375661375661*A2*g2*x4 - 
     0.000141369047619047619*A*g3*x6 - 
     0.0000131815843621399177*g4*x8) + 
  eps6*(0.0000793650793650793651*A2*g - 
     0.000421626984126984127*A4*x2 + 
     0.000412533068783068783*A*g2*x2 - 
     0.000710978835978835979*A3*g*x4 + 
     0.00012359457671957672*g3*x4 - 
     0.000332065696649029982*A2*g2*x6 - 
     0.0000592482363315696649*A*g3*x8 - 
     3.61689814814814815e-6*g4*x10) + 
  eps9*(1.06888995777884667e-6*A5 - 
     3.09484386865339246e-6*A2*g2 + 
     0.000052889176153065042*A4*g*x2 - 
     0.0000196739667225778337*A*g3*x2 + 
     0.000118621733205066538*A3*g2*x4 - 
     8.12834124466068911e-6*g4*x4 + 
     0.0000723776288012399124*A2*g3*x6 + 
     0.0000162595142340512711*A*g4*x8 + 
     1.2123306755829904e-6*g5*x10) + 
  eps8*(-0.0000100208433541766875*A3*g + 
     8.50711788211788212e-7*g3 + 
     0.0000427138447971781305*A5*x2 - 
     0.000120331539602372936*A2*g2*x2 + 
     0.000127911890064667842*A4*g*x4 - 
     0.000098836830607663941*A*g3*x4 + 
     0.000102804110327258475*A3*g2*x6 - 
     0.0000165018585880854399*g4*x6 + 
     0.0000336428938859494415*A2*g3*x8 + 
     4.8512364050558495e-6*A*g4*x10 + 
     2.56755115454961134e-7*g5*x12) + 
  eps11*(-9.01835117002665504e-8*A6 + 
     5.87400058299529199e-7*A3*g2 - 
     2.81868399275952575e-8*g4 - 
     7.41416841780598394e-6*A5*g*x2 + 
     7.67116473755031956e-6*A2*g3*x2 - 
     0.000027147462601331649*A4*g2*x4 + 
     8.12031936990601012e-6*A*g4*x4 - 
     0.0000272310450812986086*A3*g3*x6 + 
     1.70667153812408442e-6*g5*x6 - 
     0.0000108933015093453806*A2*g4*x8 - 
     1.87850642976993286e-6*A*g5*x10 - 
     1.16690477054095881e-7*g6*x12) + 
  eps10*(1.21747740795359843e-6*A4*g - 
     4.62417873132158846e-7*A*g3 - 
     4.32775172358505692e-6*A6*x2 + 
     0.0000276277014248244407*A3*g2*x2 - 
     1.30445706075046353e-6*g4*x2 - 
     0.0000210333326652771097*A5*g*x4 + 
     0.0000447391253752860896*A2*g3*x4 - 
     0.0000265668910778864483*A4*g2*x6 + 
     0.0000184769777868736202*A*g4*x6 - 
     0.0000139376709110505407*A3*g3*x8 + 
     2.13520310814871e-6*g5*x8 - 
     3.5181249916492972e-6*A2*g4*x10 - 
     4.25407416871537242e-7*A*g5*x12 - 
     1.98147969535893919e-8*g6*x14) + 
  eps13*(7.83069566138349207e-9*A7 - 
     9.93094869534334209e-8*A4*g2 + 
     2.08755249185163841e-8*A*g4 + 
     9.92791119692574719e-7*A6*g*x2 - 
     2.26246788359770127e-6*A3*g3*x2 + 
     7.19774046753493046e-8*g5*x2 + 
     5.52538741816188906e-6*A5*g2*x4 - 
     4.47883727161149936e-6*A2*g4*x4 + 
     8.38601213983571788e-6*A4*g3*x6 - 
     2.25348627386308778e-6*A*g5*x6 + 
     5.24445855604457162e-6*A3*g4*x8 - 
     3.11392974798759566e-7*g6*x8 + 
     1.55465050346795001e-6*A2*g5*x10 + 
     2.17600880397466046e-7*A*g6*x12 + 
     1.15841884836628278e-8*g7*x14) + 
  eps12*(-1.43889032777921667e-7*A5*g + 
     1.51283642180000723e-7*A2*g3 + 
     4.38492191964414187e-7*A7*x2 - 
     5.47671197834474951e-6*A4*g2*x2 + 
     1.1365151365172641e-6*A*g4*x2 + 
     3.23789133106262736e-6*A6*g*x4 - 
     0.0000150481673660823793*A3*g3*x4 + 
     5.97324614725086198e-7*g5*x4 + 
     6.03932684613625972e-6*A5*g2*x6 - 
     0.0000113106765525436987*A2*g4*x6 + 
     4.69528859165240338e-6*A4*g3*x8 - 
     3.0694501391598228e-6*A*g5*x8 + 
     1.82557370238215146e-6*A3*g4*x10 - 
     2.71046144994230449e-7*g6*x10 + 
     3.7535031778135559e-7*A2*g5*x12 + 
     3.90681314457195373e-8*A*g6*x14 + 
     1.62260932077515154e-9*g7*x16) + 
  eps15*(-6.94206524686864971e-10*A8 + 
     1.55258266251201437e-8*A5*g2 - 
     8.87063997906019346e-9*A2*g4 - 
     1.28444091425696105e-7*A7*g*x2 + 
     5.59355511978255916e-7*A4*g3*x2 - 
     7.69591961687451275e-8*A*g5*x2 - 
     1.03084425773136674e-6*A6*g2*x4 + 
     1.80099658500984157e-6*A3*g4*x4 - 
     4.89852640150590245e-8*g6*x4 - 
     2.23744987275327073e-6*A5*g3*x6 + 
     1.60416803829389571e-6*A2*g5*x6 - 
     2.02887475090349778e-6*A4*g4*x8 + 
     5.10536772376168298e-7*A*g6*x8 - 
     9.11746562790846727e-7*A3*g5*x10 + 
     5.21769349658492833e-8*g7*x10 - 
     2.14341780318485671e-7*A2*g6*x12 - 
     2.52490551976121104e-8*A*g7*x14 - 
     1.17600420262660865e-9*g8*x16) + 
  eps14*(1.66609565924847593e-8*A6*g - 
     3.84541066603365207e-8*A3*g3 + 
     1.23616495716322489e-9*g5 - 
     4.44285396439000936e-8*A8*x2 + 
     9.81807578832239391e-7*A5*g2*x2 - 
     5.55101746448534654e-7*A2*g4*x2 - 
     4.73967830600877338e-7*A7*g*x4 + 
     4.18284859452059839e-6*A4*g3*x4 - 
     7.15343253702736788e-7*A*g5*x4 - 
     1.24663165145441196e-6*A6*g2*x6 + 
     5.00514675879205854e-6*A3*g4*x6 - 
     1.81402700349001079e-7*g6*x6 - 
     1.36226318220021373e-6*A5*g3*x8 + 
     2.36606032230627314e-6*A2*g5*x8 - 
     7.58172593612770117e-7*A4*g4*x10 + 
     4.75471890972483691e-7*A*g6*x10 - 
     2.34027522244261325e-7*A3*g5*x12 + 
     3.3963539821117207e-8*g7*x12 - 
     4.06050820222736176e-8*A2*g6*x14 - 
     3.70938742929349711e-9*A*g7*x16 - 
     1.38898528337180163e-10*g8*x18) + 
  eps16*(-1.89909954985575877e-9*A7*g + 
     8.35603474047208798e-9*A4*g3 - 
     1.15966243496214952e-9*A*g5 + 
     4.50155213123768602e-9*A9*x2 - 
     1.63520154608933337e-7*A6*g2*x2 + 
     2.00125773929144853e-7*A3*g4*x2 - 
     4.71643935891082883e-9*g6*x2 + 
     6.66827009985439445e-8*A8*g*x4 - 
     1.01569722853466271e-6*A5*g3*x4 + 
     4.653753986331283e-7*A2*g5*x4 + 
     2.38609112997144637e-7*A7*g2*x6 - 
     1.78931879078472604e-6*A4*g4*x6 + 
     2.75782412054904595e-7*A*g6*x6 + 
     3.5257503626825941e-7*A6*g3*x8 - 
     1.29719583644083582e-6*A3*g5*x8 + 
     4.43904638337799842e-8*g7*x8 + 
     2.67563783428073661e-7*A5*g4*x10 - 
     4.41739629456479988e-7*A2*g6*x10 + 
     1.15544405881940575e-7*A4*g5*x12 - 
     7.03094817586759951e-8*A*g7*x12 + 
     2.95627516533174602e-8*A3*g6*x14 - 
     4.21593686904484474e-9*g8*x14 + 
     4.43746780874914946e-9*A2*g7*x16 + 
     3.61167459558351774e-10*A*g8*x18 + 
     1.23066706066192904e-11*g9*x20) + 
  0.00833333333333333333*eps*g*xbar2 + 
  0.166666666666666667*(A + 0.5*g*x2)*xbar2 + 
  eps3*(-0.000793650793650793651*A*g - 
     0.00138888888888888889*g2*x2)*xbar2 + 
  eps2*(-0.00277777777777777778*A2 - 
     0.0111111111111111111*A*g*x2 - 
     0.00208333333333333333*g2*x4)*xbar2 + 
  eps5*(0.0000727513227513227513*A2*g + 
     0.000522486772486772487*A*g2*x2 + 
     0.000162037037037037037*g3*x4)*xbar2 + 
  eps4*(0.0000661375661375661376*A3 - 
     0.0000644841269841269841*g2 + 
     0.0015873015873015873*A2*g*x2 + 
     0.00094246031746031746*A*g2*x4 + 
     0.000115740740740740741*g3*x6)*xbar2 + 
  eps7*(-6.91438191438191438e-6*A3*g + 
     1.41486599819933153e-6*g3 - 
     0.000128066378066378066*A2*g2*x2 - 
     0.000110705266955266955*A*g3*x4 - 
     0.000018647119341563786*g4*x6)*xbar2 + 
  eps6*(-1.65343915343915344e-6*A4 + 
     0.0000179623617123617124*A*g2 - 
     0.00021164021164021164*A3*g*x2 + 
     0.0000485008818342151675*g3*x2 - 
     0.000276951058201058201*A2*g2*x4 - 
     0.0000898368606701940035*A*g3*x6 - 
     8.27867798353909465e-6*g4*x8)*xbar2 + 
  eps9*(6.79829796893288957e-7*A4*g - 
     6.72419695237155555e-7*A*g3 + 
     0.0000254975770848786722*A3*g2*x2 - 
     2.25056258042369153e-6*g4*x2 + 
     0.0000441438108848823135*A2*g3*x4 + 
     0.0000185871013417309714*A*g4*x6 + 
     2.15148764772607365e-6*g5*x8)*xbar2 + 
  eps8*(4.1753513975736198e-8*A5 - 
     3.46221514376276281e-6*A2*g2 + 
     0.0000267222489444711667*A4*g*x2 - 
     0.0000281804101248545693*A*g3*x2 + 
     0.0000649475909892576559*A3*g2*x4 - 
     0.0000122030666735527847*g4*x4 + 
     0.0000403965247715247715*A2*g3*x6 + 
     9.0700810463541945e-6*A*g4*x8 + 
     6.69795953360768176e-7*g5*x10)*xbar2 + 
  eps11*(-6.80612866459427306e-8*A5*g + 
     1.95584655809718057e-7*A2*g3 - 
     4.47269759439071608e-6*A4*g2*x2 + 
     1.75829988748211593e-6*A*g4*x2 - 
     0.0000133314481239415102*A3*g3*x4 + 
     9.71399147418687179e-7*g5*x4 - 
     0.0000103064498801381517*A2*g4*x6 - 
     2.82142523293179157e-6*A*g5*x8 - 
     2.4892365507720446e-7*g6*x10)*xbar2 + 
  eps10*(-1.05683802773749864e-9*A6 + 
     5.67501373552960855e-7*A3*g2 - 
     4.8511255774108832e-8*g4 - 
     3.24660642120959581e-6*A5*g*x2 + 
     9.71126169538867952e-6*A2*g3*x2 - 
     0.0000131832441790279092*A4*g2*x4 + 
     0.0000108846610427711618*A*g4*x4 - 
     0.0000136365860158849577*A3*g3*x6 + 
     2.33168885512635513e-6*g5*x6 - 
     5.4993290386188865e-6*A2*g4*x8 - 
     9.46094479080590192e-7*A*g5*x10 - 
     5.8302302889011994e-8*g6*x12)*xbar2 + 
  eps13*(6.86627585651083939e-9*A6*g - 
     4.47785160224899766e-8*A3*g3 + 
     2.19249275444418889e-9*g5 + 
     7.19946098097358602e-7*A5*g2*x2 - 
     7.80379784965903039e-7*A2*g4*x2 + 
     3.37142842641135708e-6*A4*g3*x4 - 
     1.06398186364605041e-6*A*g5*x4 + 
     4.18165456228327982e-6*A3*g4*x6 - 
     2.76351067919865578e-7*g6*x6 + 
     2.00589567077445504e-6*A2*g5*x8 + 
     4.04753308555164946e-7*A*g6*x10 + 
     2.88571475583667131e-8*g7*x12)*xbar2 + 
  eps12*(2.67650730613693577e-11*A7 - 
     8.46192910475220622e-8*A4*g2 + 
     3.25142589196534057e-8*A*g4 + 
     3.83704087407791111e-7*A6*g*x2 - 
     2.57283359783619147e-6*A3*g3*x2 + 
     1.27951218977907431e-7*g5*x2 + 
     2.41765559329216737e-6*A5*g2*x4 - 
     5.44480881814382923e-6*A2*g4*x4 + 
     3.82233569685344377e-6*A4*g3*x6 - 
     2.81139544164632672e-6*A*g5*x6 + 
     2.42710273474001612e-6*A3*g4*x8 - 
     3.92027350262991887e-7*g6*x8 + 
     7.21984500196305752e-7*A2*g5*x10 + 
     1.007566064009769e-7*A*g6*x12 + 
     5.32759708629371695e-9*g7*x14)*xbar2 + 
  eps15*(-6.94677964495491896e-10*A7*g + 
     8.85485037384606633e-9*A4*g3 - 
     1.89784940868103996e-9*A*g5 - 
     1.08873720111587578e-7*A6*g2*x2 + 
     2.58200627219967634e-7*A3*g4*x2 - 
     8.57415659878293831e-9*g6*x2 - 
     7.52178044272582197e-7*A5*g3*x4 + 
     6.39174172204870162e-7*A2*g5*x4 - 
     1.38311030669262085e-6*A4*g4*x6 + 
     3.89805821462228289e-7*A*g6*x6 - 
     1.02272071613530239e-6*A3*g5*x8 + 
     6.35874554600849527e-8*g7*x8 - 
     3.51191445940869782e-7*A2*g6*x10 - 
     5.59975947545884819e-8*A*g7*x12 - 
     3.35001083013772154e-9*g8*x14)*xbar2 + 
  eps14*(-6.77936059264516573e-13*A8 + 
     1.18453251754498057e-8*A5*g2 - 
     1.26192122113177278e-8*A2*g4 - 
     4.44292175799593582e-8*A7*g*x2 + 
     5.78235471803035281e-7*A4*g3*x2 - 
     1.25465164813262727e-7*A*g5*x2 - 
     4.11093596933471078e-7*A6*g2*x4 + 
     2.00802343589623813e-6*A3*g4*x4 - 
     8.38456228452171631e-8*g6*x4 - 
     9.37962675222683393e-7*A5*g3*x6 + 
     1.84660973293660698e-6*A2*g5*x6 - 
     8.68952732620502728e-7*A4*g4*x8 + 
     5.95974150882540242e-7*A*g6*x8 - 
     3.93789587968658131e-7*A3*g5*x10 + 
     6.11861559616332661e-8*g7*x10 - 
     9.26911580977221589e-8*A2*g6*x12 - 
     1.08851336477984649e-8*A*g7*x14 - 
     5.04016698893419468e-10*g8*x16)*xbar2 + 
  0.00833333333333333333*g*xbar4 - 
  0.0000462962962962962963*eps3*g2*xbar4 + 
  eps2*(-0.000396825396825396825*A*g - 
     0.000694444444444444444*g2*x2)*xbar4 + 
  eps5*(9.11896745230078563e-6*A*g2 + 
     0.0000308641975308641975*g3*x2)*xbar4 + 
  eps4*(0.0000198412698412698413*A2*g + 
     0.000195105820105820106*A*g2*x2 + 
     0.0000617283950617283951*g3*x4)*xbar4 + 
  eps7*(-1.31581381581381581e-6*A2*g2 - 
     0.0000151318588818588819*A*g3*x2 - 
     6.8455207344096233e-6*g4*x4)*xbar4 + 
  eps6*(-9.01875901875901876e-7*A3*g + 
     9.90714532381199048e-7*g3 - 
     0.0000389059243225909893*A2*g2*x2 - 
     0.0000351397573619795842*A*g3*x4 - 
     5.9477880658436214e-6*g4*x6)*xbar4 + 
  eps9*(1.71045640622360199e-7*A3*g2 - 
     3.60906857706966639e-8*g4 + 
     4.53245406122390249e-6*A2*g3*x2 + 
     5.38783061931210079e-6*A*g4*x4 + 
     1.17492514772607365e-6*g5*x6)*xbar4 + 
  eps8*(3.77616945077262538e-8*A4*g - 
     3.91505723846993688e-7*A*g3 + 
     6.55938527962337486e-6*A3*g2*x2 - 
     1.61985166325444103e-6*g4*x2 + 
     0.0000121547079219036891*A2*g3*x4 + 
     5.20508405346368309e-6*A*g4*x6 + 
     6.02301130368259998e-7*g5*x8)*xbar4 + 
  eps11*(-2.12135350797297057e-8*A4*g2 + 
     2.14460056215349951e-8*A*g4 - 
     1.06401470496877178e-6*A3*g3*x2 + 
     9.9419658966568008e-8*g5*x2 - 
     2.4228308825712602e-6*A2*g4*x4 - 
     1.28380796826126347e-6*A*g5*x6 - 
     1.80516340332649186e-7*g6*x8)*xbar4 + 
  eps10*(-1.48202033122668043e-9*A5*g + 
     9.77137892841674354e-8*A2*g3 - 
     9.98537198520664129e-7*A4*g2*x2 + 
     1.12096864298613054e-6*A*g4*x2 - 
     3.25929867376075489e-6*A3*g3*x4 + 
     6.52088831782005348e-7*g5*x4 - 
     2.59007734102806854e-6*A2*g4*x6 - 
     7.14333704061713321e-7*A*g5*x8 - 
     6.28878290312510992e-8*g6*x10)*xbar4 + 
  eps13*(2.55551047231023315e-9*A5*g2 - 
     7.48454109323006102e-9*A2*g4 + 
     2.14869723911233424e-7*A4*g3*x2 - 
     8.87037184673700903e-8*A*g5*x2 + 
     8.1367411096167446e-7*A3*g4*x4 - 
     6.24554324051377381e-8*g6*x4 + 
     7.73534185148061632e-7*A2*g5*x6 + 
     2.53114332805174734e-7*A*g6*x8 + 
     2.60907174059342559e-8*g7*x10)*xbar4 + 
  eps12*(5.52620037914155561e-11*A6*g - 
     1.96395897468419557e-8*A3*g3 + 
     1.73105497543500998e-9*g5 + 
     1.41930118072774209e-7*A5*g2*x2 - 
     4.4751871911848506e-7*A2*g4*x2 + 
     7.4329679752095632e-7*A4*g3*x4 - 
     6.48579919839268283e-7*A*g5*x4 + 
     9.56849686940199225e-7*A3*g4*x6 - 
     1.72592309647809413e-7*g6*x6 + 
     4.6549037372399414e-7*A2*g5*x8 + 
     9.4234108977460504e-8*A*g6*x10 + 
     6.6997976279157566e-9*g7*x12)*xbar4 + 
  eps14*(-1.97753534590218582e-12*A7*g + 
     3.46651613447685113e-9*A4*g3 - 
     1.3675698718070872e-9*A*g5 - 
     1.92080361104674656e-8*A6*g2*x2 + 
     1.34714593349386061e-7*A3*g4*x2 - 
     7.0165116069938331e-9*g6*x2 - 
     1.51234778678998732e-7*A5*g3*x4 + 
     3.57677410764887609e-7*A2*g5*x4 - 
     2.9119323970204683e-7*A4*g4*x6 + 
     2.24757818721415644e-7*A*g6*x6 - 
     2.19654624683123427e-7*A3*g5*x8 + 
     3.71577620957842484e-8*g7*x8 - 
     7.60245440599503551e-8*A2*g6*x10 - 
     1.21363875909823901e-8*A*g7*x12 - 
     7.23898306636066601e-10*g8*x14)*xbar4 - 
  0.0000154320987654320988*eps2*g2*xbar6 + 
  3.56125356125356125e-7*eps5*g3*xbar6 + 
  eps4*(1.90396023729357063e-6*A*g2 + 
     7.71604938271604938e-6*g3*x2)*xbar6 + 
  eps7*(-1.06760523427190094e-7*A*g3 - 
     5.83649889205444761e-7*g4*x2)*xbar6 + 
  eps6*(-1.58222876476844731e-7*A2*g2 - 
     3.0990100434544879e-6*A*g3*x2 - 
     1.45170544476100032e-6*g4*x4)*xbar6 + 
  eps9*(2.10474956623416007e-8*A2*g3 + 
     3.52066889376257568e-7*A*g4*x2 + 
     2.15683591284989252e-7*g5*x4)*xbar6 + 
  eps8*(1.0639753805538638e-8*A3*g2 - 
     1.44647796358943781e-8*g4 + 
     7.89019059521705024e-7*A2*g3*x2 + 
     9.93278626380478232e-7*A*g4*x4 + 
     2.19830466744046991e-7*g5*x6)*xbar6 + 
  eps11*(-3.48009271425128996e-9*A3*g3 + 
     7.74456172615070677e-10*g5 - 
     1.24759056081950737e-7*A2*g4*x2 - 
     1.93124743183608916e-7*A*g5*x4 - 
     5.26262283781649553e-8*g6*x6)*xbar6 + 
  eps10*(-6.21784885258793341e-10*A4*g2 + 
     7.35917308458240036e-9*A*g4 - 
     1.61082849737015107e-7*A3*g3*x2 + 
     4.25042008023580282e-8*g5*x2 - 
     3.97181909847740069e-7*A2*g4*x4 - 
     2.15693489113968417e-7*A*g5*x6 - 
     3.05361793587726322e-8*g6*x8)*xbar6 + 
  eps13*(5.22929181665348026e-10*A4*g3 - 
     5.49761548927799316e-10*A*g5 + 
     3.37795673591345898e-8*A3*g4*x2 - 
     3.32362369023656752e-9*g6*x2 + 
     9.70864128827426103e-8*A2*g5*x4 + 
     6.29082935052959515e-8*A*g6*x6 + 
     1.05359214957493409e-8*g7*x8)*xbar6 + 
  eps12*(3.28023733515722384e-11*A5*g2 - 
     2.2483490443839068e-9*A2*g4 + 
     2.87554439944054822e-8*A4*g3*x2 - 
     3.41643318587639607e-8*A*g5*x2 + 
     1.20413081223750724e-7*A3*g4*x4 - 
     2.54382194661358481e-8*g6*x4 + 
     1.18403247344882478e-7*A2*g5*x6 + 
     3.92485363936068314e-8*A*g6*x8 + 
     4.05810532585570662e-9*g7*x10)*xbar6 + 
  5.93542260208926876e-8*eps4*g3*xbar8 - 
  3.12288574815807931e-9*eps7*g4*xbar8 + 
  eps6*(-1.14340392118169896e-8*A*g3 - 
     9.02678854067742957e-8*g4*x2)*xbar8 + 
  eps9*(1.26121885620031857e-9*A*g4 + 
     1.00859349622512295e-8*g5*x2)*xbar8 + 
  eps8*(1.32727772394750297e-9*A2*g3 + 
     4.65033697944917988e-8*A*g4*x2 + 
     2.99054295797669073e-8*g5*x4)*xbar8 + 
  eps11*(-3.15709843216944468e-10*A2*g4 - 
     7.21099301568180965e-9*A*g5*x2 - 
     5.69746824484251863e-9*g6*x4)*xbar8 + 
  eps10*(-1.18235613578975095e-10*A3*g3 + 
     2.04522364126337295e-10*g5 - 
     1.4372001684607648e-8*A2*g4*x2 - 
     2.38545902650207871e-8*A*g5*x4 - 
     6.6442647298050802e-9*g6*x6)*xbar8 + 
  eps12*(8.85933436332280376e-12*A4*g3 - 
     1.2695043367275619e-10*A*g5 + 
     3.44553148081436095e-9*A3*g4*x2 - 
     9.66117808074637814e-10*g6*x2 + 
     1.08393242236143663e-8*A2*g5*x4 + 
     7.24181767567549532e-9*A*g6*x6 + 
     1.22738677265426237e-9*g7*x8)*xbar8 - 
  2.95801289810004407e-10*eps6*g4*xbar10 + 
  2.94346529368315861e-11*eps9*g5*xbar10 + 
  eps8*(7.69281785172546935e-11*A*g4 + 
     1.07490632635875918e-9*g5*x2)*xbar10 + 
  eps11*(-1.49854878334381416e-11*A*g5 - 
     1.64414869918985145e-10*g6*x2)*xbar10 + 
  eps10*(-1.14623038722347948e-11*A2*g4 - 
     6.72527675714427998e-10*A*g5*x2 - 
     5.64942074025452747e-10*g6*x4)*xbar10 + 
  1.69722051530330397e-12*eps8*g5*xbar12 + 
  eps10*(-5.54575148020670988e-13*A*g5 - 
     1.29008964169185665e-11*g6*x2)*xbar12;
}
#endif

#ifdef p18
double Wp(void)
{
   return 0.5*A*x2 + 0.0416666666666666667*g*x4 + 
  eps*(0.0833333333333333333*A + 0.0416666666666666667*g*x2) + 
  eps3*(-0.00277777777777777778*A2 - 
     0.0111111111111111111*A*g*x2 - 
     0.00208333333333333333*g2*x4) + 
  eps2*(0.00416666666666666667*g - 
     0.0416666666666666667*A2*x2 - 
     0.0138888888888888889*A*g*x4 - 
     0.00115740740740740741*g2*x6) + 
  eps5*(0.0001763668430335097*A3 - 
     0.0000388558201058201058*g2 + 
     0.00214947089947089947*A2*g*x2 + 
     0.00124007936507936508*A*g2*x4 + 
     0.000154320987654320988*g3*x6) + 
  eps4*(-0.000595238095238095238*A*g + 
     0.00416666666666666667*A3*x2 - 
     0.000868055555555555556*g2*x2 + 
     0.00347222222222222222*A2*g*x4 + 
     0.000810185185185185185*A*g2*x6 + 
     0.0000578703703703703704*g3*x8) + 
  eps7*(-0.0000132275132275132275*A4 + 
     0.000013452982202982203*A*g2 - 
     0.000353835978835978836*A3*g*x2 + 
     0.0000292107583774250441*g3*x2 - 
     0.000438161375661375661*A2*g2*x4 - 
     0.000141369047619047619*A*g3*x6 - 
     0.0000131815843621399177*g4*x8) + 
  eps6*(0.0000793650793650793651*A2*g - 
     0.000421626984126984127*A4*x2 + 
     0.000412533068783068783*A*g2*x2 - 
     0.000710978835978835979*A3*g*x4 + 
     0.00012359457671957672*g3*x4 - 
     0.000332065696649029982*A2*g2*x6 - 
     0.0000592482363315696649*A*g3*x8 - 
     3.61689814814814815e-6*g4*x10) + 
  eps9*(1.06888995777884667e-6*A5 - 
     3.09484386865339246e-6*A2*g2 + 
     0.000052889176153065042*A4*g*x2 - 
     0.0000196739667225778337*A*g3*x2 + 
     0.000118621733205066538*A3*g2*x4 - 
     8.12834124466068911e-6*g4*x4 + 
     0.0000723776288012399124*A2*g3*x6 + 
     0.0000162595142340512711*A*g4*x8 + 
     1.2123306755829904e-6*g5*x10) + 
  eps8*(-0.0000100208433541766875*A3*g + 
     8.50711788211788212e-7*g3 + 
     0.0000427138447971781305*A5*x2 - 
     0.000120331539602372936*A2*g2*x2 + 
     0.000127911890064667842*A4*g*x4 - 
     0.000098836830607663941*A*g3*x4 + 
     0.000102804110327258475*A3*g2*x6 - 
     0.0000165018585880854399*g4*x6 + 
     0.0000336428938859494415*A2*g3*x8 + 
     4.8512364050558495e-6*A*g4*x10 + 
     2.56755115454961134e-7*g5*x12) + 
  eps11*(-9.01835117002665504e-8*A6 + 
     5.87400058299529199e-7*A3*g2 - 
     2.81868399275952575e-8*g4 - 
     7.41416841780598394e-6*A5*g*x2 + 
     7.67116473755031956e-6*A2*g3*x2 - 
     0.000027147462601331649*A4*g2*x4 + 
     8.12031936990601012e-6*A*g4*x4 - 
     0.0000272310450812986086*A3*g3*x6 + 
     1.70667153812408442e-6*g5*x6 - 
     0.0000108933015093453806*A2*g4*x8 - 
     1.87850642976993286e-6*A*g5*x10 - 
     1.16690477054095881e-7*g6*x12) + 
  eps10*(1.21747740795359843e-6*A4*g - 
     4.62417873132158846e-7*A*g3 - 
     4.32775172358505692e-6*A6*x2 + 
     0.0000276277014248244407*A3*g2*x2 - 
     1.30445706075046353e-6*g4*x2 - 
     0.0000210333326652771097*A5*g*x4 + 
     0.0000447391253752860896*A2*g3*x4 - 
     0.0000265668910778864483*A4*g2*x6 + 
     0.0000184769777868736202*A*g4*x6 - 
     0.0000139376709110505407*A3*g3*x8 + 
     2.13520310814871e-6*g5*x8 - 
     3.5181249916492972e-6*A2*g4*x10 - 
     4.25407416871537242e-7*A*g5*x12 - 
     1.98147969535893919e-8*g6*x14) + 
  eps13*(7.83069566138349207e-9*A7 - 
     9.93094869534334209e-8*A4*g2 + 
     2.08755249185163841e-8*A*g4 + 
     9.92791119692574719e-7*A6*g*x2 - 
     2.26246788359770127e-6*A3*g3*x2 + 
     7.19774046753493046e-8*g5*x2 + 
     5.52538741816188906e-6*A5*g2*x4 - 
     4.47883727161149936e-6*A2*g4*x4 + 
     8.38601213983571788e-6*A4*g3*x6 - 
     2.25348627386308778e-6*A*g5*x6 + 
     5.24445855604457162e-6*A3*g4*x8 - 
     3.11392974798759566e-7*g6*x8 + 
     1.55465050346795001e-6*A2*g5*x10 + 
     2.17600880397466046e-7*A*g6*x12 + 
     1.15841884836628278e-8*g7*x14) + 
  eps12*(-1.43889032777921667e-7*A5*g + 
     1.51283642180000723e-7*A2*g3 + 
     4.38492191964414187e-7*A7*x2 - 
     5.47671197834474951e-6*A4*g2*x2 + 
     1.1365151365172641e-6*A*g4*x2 + 
     3.23789133106262736e-6*A6*g*x4 - 
     0.0000150481673660823793*A3*g3*x4 + 
     5.97324614725086198e-7*g5*x4 + 
     6.03932684613625972e-6*A5*g2*x6 - 
     0.0000113106765525436987*A2*g4*x6 + 
     4.69528859165240338e-6*A4*g3*x8 - 
     3.0694501391598228e-6*A*g5*x8 + 
     1.82557370238215146e-6*A3*g4*x10 - 
     2.71046144994230449e-7*g6*x10 + 
     3.7535031778135559e-7*A2*g5*x12 + 
     3.90681314457195373e-8*A*g6*x14 + 
     1.62260932077515154e-9*g7*x16) + 
  eps15*(-6.94206524686864971e-10*A8 + 
     1.55258266251201437e-8*A5*g2 - 
     8.87063997906019346e-9*A2*g4 - 
     1.28444091425696105e-7*A7*g*x2 + 
     5.59355511978255916e-7*A4*g3*x2 - 
     7.69591961687451275e-8*A*g5*x2 - 
     1.03084425773136674e-6*A6*g2*x4 + 
     1.80099658500984157e-6*A3*g4*x4 - 
     4.89852640150590245e-8*g6*x4 - 
     2.23744987275327073e-6*A5*g3*x6 + 
     1.60416803829389571e-6*A2*g5*x6 - 
     2.02887475090349778e-6*A4*g4*x8 + 
     5.10536772376168298e-7*A*g6*x8 - 
     9.11746562790846727e-7*A3*g5*x10 + 
     5.21769349658492833e-8*g7*x10 - 
     2.14341780318485671e-7*A2*g6*x12 - 
     2.52490551976121104e-8*A*g7*x14 - 
     1.17600420262660865e-9*g8*x16) + 
  eps14*(1.66609565924847593e-8*A6*g - 
     3.84541066603365207e-8*A3*g3 + 
     1.23616495716322489e-9*g5 - 
     4.44285396439000936e-8*A8*x2 + 
     9.81807578832239391e-7*A5*g2*x2 - 
     5.55101746448534654e-7*A2*g4*x2 - 
     4.73967830600877338e-7*A7*g*x4 + 
     4.18284859452059839e-6*A4*g3*x4 - 
     7.15343253702736788e-7*A*g5*x4 - 
     1.24663165145441196e-6*A6*g2*x6 + 
     5.00514675879205854e-6*A3*g4*x6 - 
     1.81402700349001079e-7*g6*x6 - 
     1.36226318220021373e-6*A5*g3*x8 + 
     2.36606032230627314e-6*A2*g5*x8 - 
     7.58172593612770117e-7*A4*g4*x10 + 
     4.75471890972483691e-7*A*g6*x10 - 
     2.34027522244261325e-7*A3*g5*x12 + 
     3.3963539821117207e-8*g7*x12 - 
     4.06050820222736176e-8*A2*g6*x14 - 
     3.70938742929349711e-9*A*g7*x16 - 
     1.38898528337180163e-10*g8*x18) + 
  eps17*(6.25217958800249802e-11*A9 - 
     2.29312206278746533e-9*A6*g2 + 
     2.8310089717477044e-9*A3*g4 - 
     6.71998649148490015e-11*g6 + 
     1.61783182535963035e-8*A8*g*x2 - 
     1.222198282975496e-7*A5*g3*x2 + 
     4.51903487294323094e-8*A2*g5*x2 + 
     1.79787422789127715e-7*A7*g2*x4 - 
     5.89386352242391962e-7*A4*g4*x4 + 
     6.83924293854497039e-8*A*g6*x4 + 
     5.35385253592035249e-7*A6*g3*x6 - 
     8.16161936426993263e-7*A3*g5*x6 + 
     2.03110694856709656e-8*g7*x6 + 
     6.69429955495357485e-7*A5*g4*x8 - 
     4.44812062546498445e-7*A2*g6*x8 + 
     4.24544759374608395e-7*A4*g5*x10 - 
     1.02125278182278717e-7*A*g7*x10 + 
     1.48190757087105866e-7*A3*g6*x12 - 
     8.25465653164429909e-9*g8*x12 + 
     2.8842218900714868e-8*A2*g7*x14 + 
     2.93316966296752154e-9*A*g8*x16 + 
     1.21426224678902097e-10*g9*x18) + 
  eps16*(-1.89909954985575877e-9*A7*g + 
     8.35603474047208798e-9*A4*g3 - 
     1.15966243496214952e-9*A*g5 + 
     4.50155213123768602e-9*A9*x2 - 
     1.63520154608933337e-7*A6*g2*x2 + 
     2.00125773929144853e-7*A3*g4*x2 - 
     4.71643935891082883e-9*g6*x2 + 
     6.66827009985439445e-8*A8*g*x4 - 
     1.01569722853466271e-6*A5*g3*x4 + 
     4.653753986331283e-7*A2*g5*x4 + 
     2.38609112997144637e-7*A7*g2*x6 - 
     1.78931879078472604e-6*A4*g4*x6 + 
     2.75782412054904595e-7*A*g6*x6 + 
     3.5257503626825941e-7*A6*g3*x8 - 
     1.29719583644083582e-6*A3*g5*x8 + 
     4.43904638337799842e-8*g7*x8 + 
     2.67563783428073661e-7*A5*g4*x10 - 
     4.41739629456479988e-7*A2*g6*x10 + 
     1.15544405881940575e-7*A4*g5*x12 - 
     7.03094817586759951e-8*A*g7*x12 + 
     2.95627516533174602e-8*A3*g6*x14 - 
     4.21593686904484474e-9*g8*x14 + 
     4.43746780874914946e-9*A2*g7*x16 + 
     3.61167459558351774e-10*A*g8*x18 + 
     1.23066706066192904e-11*g9*x20) + 
  0.00833333333333333333*eps*g*xbar2 + 
  0.166666666666666667*(A + 0.5*g*x2)*xbar2 + 
  eps3*(-0.000793650793650793651*A*g - 
     0.00138888888888888889*g2*x2)*xbar2 + 
  eps2*(-0.00277777777777777778*A2 - 
     0.0111111111111111111*A*g*x2 - 
     0.00208333333333333333*g2*x4)*xbar2 + 
  eps5*(0.0000727513227513227513*A2*g + 
     0.000522486772486772487*A*g2*x2 + 
     0.000162037037037037037*g3*x4)*xbar2 + 
  eps4*(0.0000661375661375661376*A3 - 
     0.0000644841269841269841*g2 + 
     0.0015873015873015873*A2*g*x2 + 
     0.00094246031746031746*A*g2*x4 + 
     0.000115740740740740741*g3*x6)*xbar2 + 
  eps7*(-6.91438191438191438e-6*A3*g + 
     1.41486599819933153e-6*g3 - 
     0.000128066378066378066*A2*g2*x2 - 
     0.000110705266955266955*A*g3*x4 - 
     0.000018647119341563786*g4*x6)*xbar2 + 
  eps6*(-1.65343915343915344e-6*A4 + 
     0.0000179623617123617124*A*g2 - 
     0.00021164021164021164*A3*g*x2 + 
     0.0000485008818342151675*g3*x2 - 
     0.000276951058201058201*A2*g2*x4 - 
     0.0000898368606701940035*A*g3*x6 - 
     8.27867798353909465e-6*g4*x8)*xbar2 + 
  eps9*(6.79829796893288957e-7*A4*g - 
     6.72419695237155555e-7*A*g3 + 
     0.0000254975770848786722*A3*g2*x2 - 
     2.25056258042369153e-6*g4*x2 + 
     0.0000441438108848823135*A2*g3*x4 + 
     0.0000185871013417309714*A*g4*x6 + 
     2.15148764772607365e-6*g5*x8)*xbar2 + 
  eps8*(4.1753513975736198e-8*A5 - 
     3.46221514376276281e-6*A2*g2 + 
     0.0000267222489444711667*A4*g*x2 - 
     0.0000281804101248545693*A*g3*x2 + 
     0.0000649475909892576559*A3*g2*x4 - 
     0.0000122030666735527847*g4*x4 + 
     0.0000403965247715247715*A2*g3*x6 + 
     9.0700810463541945e-6*A*g4*x8 + 
     6.69795953360768176e-7*g5*x10)*xbar2 + 
  eps11*(-6.80612866459427306e-8*A5*g + 
     1.95584655809718057e-7*A2*g3 - 
     4.47269759439071608e-6*A4*g2*x2 + 
     1.75829988748211593e-6*A*g4*x2 - 
     0.0000133314481239415102*A3*g3*x4 + 
     9.71399147418687179e-7*g5*x4 - 
     0.0000103064498801381517*A2*g4*x6 - 
     2.82142523293179157e-6*A*g5*x8 - 
     2.4892365507720446e-7*g6*x10)*xbar2 + 
  eps10*(-1.05683802773749864e-9*A6 + 
     5.67501373552960855e-7*A3*g2 - 
     4.8511255774108832e-8*g4 - 
     3.24660642120959581e-6*A5*g*x2 + 
     9.71126169538867952e-6*A2*g3*x2 - 
     0.0000131832441790279092*A4*g2*x4 + 
     0.0000108846610427711618*A*g4*x4 - 
     0.0000136365860158849577*A3*g3*x6 + 
     2.33168885512635513e-6*g5*x6 - 
     5.4993290386188865e-6*A2*g4*x8 - 
     9.46094479080590192e-7*A*g5*x10 - 
     5.8302302889011994e-8*g6*x12)*xbar2 + 
  eps13*(6.86627585651083939e-9*A6*g - 
     4.47785160224899766e-8*A3*g3 + 
     2.19249275444418889e-9*g5 + 
     7.19946098097358602e-7*A5*g2*x2 - 
     7.80379784965903039e-7*A2*g4*x2 + 
     3.37142842641135708e-6*A4*g3*x4 - 
     1.06398186364605041e-6*A*g5*x4 + 
     4.18165456228327982e-6*A3*g4*x6 - 
     2.76351067919865578e-7*g6*x6 + 
     2.00589567077445504e-6*A2*g5*x8 + 
     4.04753308555164946e-7*A*g6*x10 + 
     2.88571475583667131e-8*g7*x12)*xbar2 + 
  eps12*(2.67650730613693577e-11*A7 - 
     8.46192910475220622e-8*A4*g2 + 
     3.25142589196534057e-8*A*g4 + 
     3.83704087407791111e-7*A6*g*x2 - 
     2.57283359783619147e-6*A3*g3*x2 + 
     1.27951218977907431e-7*g5*x2 + 
     2.41765559329216737e-6*A5*g2*x4 - 
     5.44480881814382923e-6*A2*g4*x4 + 
     3.82233569685344377e-6*A4*g3*x6 - 
     2.81139544164632672e-6*A*g5*x6 + 
     2.42710273474001612e-6*A3*g4*x8 - 
     3.92027350262991887e-7*g6*x8 + 
     7.21984500196305752e-7*A2*g5*x10 + 
     1.007566064009769e-7*A*g6*x12 + 
     5.32759708629371695e-9*g7*x14)*xbar2 + 
  eps15*(-6.94677964495491896e-10*A7*g + 
     8.85485037384606633e-9*A4*g3 - 
     1.89784940868103996e-9*A*g5 - 
     1.08873720111587578e-7*A6*g2*x2 + 
     2.58200627219967634e-7*A3*g4*x2 - 
     8.57415659878293831e-9*g6*x2 - 
     7.52178044272582197e-7*A5*g3*x4 + 
     6.39174172204870162e-7*A2*g5*x4 - 
     1.38311030669262085e-6*A4*g4*x6 + 
     3.89805821462228289e-7*A*g6*x6 - 
     1.02272071613530239e-6*A3*g5*x8 + 
     6.35874554600849527e-8*g7*x8 - 
     3.51191445940869782e-7*A2*g6*x10 - 
     5.59975947545884819e-8*A*g7*x12 - 
     3.35001083013772154e-9*g8*x14)*xbar2 + 
  eps14*(-6.77936059264516573e-13*A8 + 
     1.18453251754498057e-8*A5*g2 - 
     1.26192122113177278e-8*A2*g4 - 
     4.44292175799593582e-8*A7*g*x2 + 
     5.78235471803035281e-7*A4*g3*x2 - 
     1.25465164813262727e-7*A*g5*x2 - 
     4.11093596933471078e-7*A6*g2*x4 + 
     2.00802343589623813e-6*A3*g4*x4 - 
     8.38456228452171631e-8*g6*x4 - 
     9.37962675222683393e-7*A5*g3*x6 + 
     1.84660973293660698e-6*A2*g5*x6 - 
     8.68952732620502728e-7*A4*g4*x8 + 
     5.95974150882540242e-7*A*g6*x8 - 
     3.93789587968658131e-7*A3*g5*x10 + 
     6.11861559616332661e-8*g7*x10 - 
     9.26911580977221589e-8*A2*g6*x12 - 
     1.08851336477984649e-8*A*g7*x14 - 
     5.04016698893419468e-10*g8*x16)*xbar2 + 
  eps16*(1.71721241125556891e-14*A9 - 
     1.58463391176416606e-9*A6*g2 + 
     3.70687203668986364e-9*A3*g4 - 
     1.21950914958299276e-10*g6 + 
     5.06426546628202339e-9*A8*g*x2 - 
     1.15919331839795365e-7*A5*g3*x2 + 
     6.813324046201634e-8*A2*g5*x2 + 
     6.59264102615256734e-8*A7*g2*x4 - 
     6.0783143535697607e-7*A4*g4*x4 + 
     1.08734552181364072e-7*A*g6*x4 + 
     2.08077893379438207e-7*A6*g3*x6 - 
     8.7376194571684116e-7*A3*g5*x6 + 
     3.31435423816449871e-8*g7*x6 + 
     2.67286143174399604e-7*A5*g4*x8 - 
     4.84990273878282454e-7*A2*g6*x8 + 
     1.71677767909550515e-7*A4*g5*x10 - 
     1.12268658721773254e-7*A*g7*x10 + 
     6.02176056859808662e-8*A3*g6*x12 - 
     9.09453722352822717e-9*g8*x12 + 
     1.17208819972660499e-8*A2*g7*x14 + 
     1.18834173730462595e-9*A*g8*x16 + 
     4.8940576382579539e-11*g9*x18)*xbar2 + 
  0.00833333333333333333*g*xbar4 - 
  0.0000462962962962962963*eps3*g2*xbar4 + 
  eps2*(-0.000396825396825396825*A*g - 
     0.000694444444444444444*g2*x2)*xbar4 + 
  eps5*(9.11896745230078563e-6*A*g2 + 
     0.0000308641975308641975*g3*x2)*xbar4 + 
  eps4*(0.0000198412698412698413*A2*g + 
     0.000195105820105820106*A*g2*x2 + 
     0.0000617283950617283951*g3*x4)*xbar4 + 
  eps7*(-1.31581381581381581e-6*A2*g2 - 
     0.0000151318588818588819*A*g3*x2 - 
     6.8455207344096233e-6*g4*x4)*xbar4 + 
  eps6*(-9.01875901875901876e-7*A3*g + 
     9.90714532381199048e-7*g3 - 
     0.0000389059243225909893*A2*g2*x2 - 
     0.0000351397573619795842*A*g3*x4 - 
     5.9477880658436214e-6*g4*x6)*xbar4 + 
  eps9*(1.71045640622360199e-7*A3*g2 - 
     3.60906857706966639e-8*g4 + 
     4.53245406122390249e-6*A2*g3*x2 + 
     5.38783061931210079e-6*A*g4*x4 + 
     1.17492514772607365e-6*g5*x6)*xbar4 + 
  eps8*(3.77616945077262538e-8*A4*g - 
     3.91505723846993688e-7*A*g3 + 
     6.55938527962337486e-6*A3*g2*x2 - 
     1.61985166325444103e-6*g4*x2 + 
     0.0000121547079219036891*A2*g3*x4 + 
     5.20508405346368309e-6*A*g4*x6 + 
     6.02301130368259998e-7*g5*x8)*xbar4 + 
  eps11*(-2.12135350797297057e-8*A4*g2 + 
     2.14460056215349951e-8*A*g4 - 
     1.06401470496877178e-6*A3*g3*x2 + 
     9.9419658966568008e-8*g5*x2 - 
     2.4228308825712602e-6*A2*g4*x4 - 
     1.28380796826126347e-6*A*g5*x6 - 
     1.80516340332649186e-7*g6*x8)*xbar4 + 
  eps10*(-1.48202033122668043e-9*A5*g + 
     9.77137892841674354e-8*A2*g3 - 
     9.98537198520664129e-7*A4*g2*x2 + 
     1.12096864298613054e-6*A*g4*x2 - 
     3.25929867376075489e-6*A3*g3*x4 + 
     6.52088831782005348e-7*g5*x4 - 
     2.59007734102806854e-6*A2*g4*x6 - 
     7.14333704061713321e-7*A*g5*x8 - 
     6.28878290312510992e-8*g6*x10)*xbar4 + 
  eps13*(2.55551047231023315e-9*A5*g2 - 
     7.48454109323006102e-9*A2*g4 + 
     2.14869723911233424e-7*A4*g3*x2 - 
     8.87037184673700903e-8*A*g5*x2 + 
     8.1367411096167446e-7*A3*g4*x4 - 
     6.24554324051377381e-8*g6*x4 + 
     7.73534185148061632e-7*A2*g5*x6 + 
     2.53114332805174734e-7*A*g6*x8 + 
     2.60907174059342559e-8*g7*x10)*xbar4 + 
  eps12*(5.52620037914155561e-11*A6*g - 
     1.96395897468419557e-8*A3*g3 + 
     1.73105497543500998e-9*g5 + 
     1.41930118072774209e-7*A5*g2*x2 - 
     4.4751871911848506e-7*A2*g4*x2 + 
     7.4329679752095632e-7*A4*g3*x4 - 
     6.48579919839268283e-7*A*g5*x4 + 
     9.56849686940199225e-7*A3*g4*x6 - 
     1.72592309647809413e-7*g6*x6 + 
     4.6549037372399414e-7*A2*g5*x8 + 
     9.4234108977460504e-8*A*g6*x10 + 
     6.6997976279157566e-9*g7*x12)*xbar4 + 
  eps15*(-3.01110179246578381e-10*A6*g2 + 
     1.99854473307210245e-9*A3*g4 - 
     1.0075222178954846e-10*g6 - 
     3.91236879782746971e-8*A5*g3*x2 + 
     4.42468326545839399e-8*A2*g5*x2 - 
     2.26449722207185509e-7*A4*g4*x4 + 
     7.48610321580336637e-8*A*g6*x4 - 
     3.38794481457344831e-7*A3*g5*x6 + 
     2.34467193453680488e-8*g7*x6 - 
     1.91586076465687549e-7*A2*g6*x8 - 
     4.4705147415174641e-8*A*g7*x10 - 
     3.62790374951045814e-9*g8*x12)*xbar4 + 
  eps14*(-1.97753534590218582e-12*A7*g + 
     3.46651613447685113e-9*A4*g3 - 
     1.3675698718070872e-9*A*g5 - 
     1.92080361104674656e-8*A6*g2*x2 + 
     1.34714593349386061e-7*A3*g4*x2 - 
     7.0165116069938331e-9*g6*x2 - 
     1.51234778678998732e-7*A5*g3*x4 + 
     3.57677410764887609e-7*A2*g5*x4 - 
     2.9119323970204683e-7*A4*g4*x6 + 
     2.24757818721415644e-7*A*g6*x6 - 
     2.19654624683123427e-7*A3*g5*x8 + 
     3.71577620957842484e-8*g7*x8 - 
     7.60245440599503551e-8*A2*g6*x10 - 
     1.21363875909823901e-8*A*g7*x12 - 
     7.23898306636066601e-10*g8*x14)*xbar4 - 
  0.0000154320987654320988*eps2*g2*xbar6 + 
  3.56125356125356125e-7*eps5*g3*xbar6 + 
  eps4*(1.90396023729357063e-6*A*g2 + 
     7.71604938271604938e-6*g3*x2)*xbar6 + 
  eps7*(-1.06760523427190094e-7*A*g3 - 
     5.83649889205444761e-7*g4*x2)*xbar6 + 
  eps6*(-1.58222876476844731e-7*A2*g2 - 
     3.0990100434544879e-6*A*g3*x2 - 
     1.45170544476100032e-6*g4*x4)*xbar6 + 
  eps9*(2.10474956623416007e-8*A2*g3 + 
     3.52066889376257568e-7*A*g4*x2 + 
     2.15683591284989252e-7*g5*x4)*xbar6 + 
  eps8*(1.0639753805538638e-8*A3*g2 - 
     1.44647796358943781e-8*g4 + 
     7.89019059521705024e-7*A2*g3*x2 + 
     9.93278626380478232e-7*A*g4*x4 + 
     2.19830466744046991e-7*g5*x6)*xbar6 + 
  eps11*(-3.48009271425128996e-9*A3*g3 + 
     7.74456172615070677e-10*g5 - 
     1.24759056081950737e-7*A2*g4*x2 - 
     1.93124743183608916e-7*A*g5*x4 - 
     5.26262283781649553e-8*g6*x6)*xbar6 + 
  eps10*(-6.21784885258793341e-10*A4*g2 + 
     7.35917308458240036e-9*A*g4 - 
     1.61082849737015107e-7*A3*g3*x2 + 
     4.25042008023580282e-8*g5*x2 - 
     3.97181909847740069e-7*A2*g4*x4 - 
     2.15693489113968417e-7*A*g5*x6 - 
     3.05361793587726322e-8*g6*x8)*xbar6 + 
  eps13*(5.22929181665348026e-10*A4*g3 - 
     5.49761548927799316e-10*A*g5 + 
     3.37795673591345898e-8*A3*g4*x2 - 
     3.32362369023656752e-9*g6*x2 + 
     9.70864128827426103e-8*A2*g5*x4 + 
     6.29082935052959515e-8*A*g6*x6 + 
     1.05359214957493409e-8*g7*x8)*xbar6 + 
  eps12*(3.28023733515722384e-11*A5*g2 - 
     2.2483490443839068e-9*A2*g4 + 
     2.87554439944054822e-8*A4*g3*x2 - 
     3.41643318587639607e-8*A*g5*x2 + 
     1.20413081223750724e-7*A3*g4*x4 - 
     2.54382194661358481e-8*g6*x4 + 
     1.18403247344882478e-7*A2*g5*x6 + 
     3.92485363936068314e-8*A*g6*x8 + 
     4.05810532585570662e-9*g7*x10)*xbar6 + 
  eps14*(-1.59924972891624396e-12*A6*g2 + 
     5.34559467656326695e-10*A3*g4 - 
     4.89531412255654985e-11*g6 - 
     4.68743656687813986e-9*A5*g3*x2 + 
     1.55203340852120435e-8*A2*g5*x2 - 
     3.05848967636635251e-8*A4*g4*x4 + 
     2.80191583068273077e-8*A*g6*x4 - 
     4.77391188802852923e-8*A3*g5*x6 + 
     9.0249644584421326e-9*g7*x6 - 
     2.7500470429085428e-8*A2*g6*x8 - 
     6.46467617732357999e-9*A*g7*x10 - 
     5.25206836466407194e-10*g8*x12)*xbar6 + 
  5.93542260208926876e-8*eps4*g3*xbar8 - 
  3.12288574815807931e-9*eps7*g4*xbar8 + 
  eps6*(-1.14340392118169896e-8*A*g3 - 
     9.02678854067742957e-8*g4*x2)*xbar8 + 
  eps9*(1.26121885620031857e-9*A*g4 + 
     1.00859349622512295e-8*g5*x2)*xbar8 + 
  eps8*(1.32727772394750297e-9*A2*g3 + 
     4.65033697944917988e-8*A*g4*x2 + 
     2.99054295797669073e-8*g5*x4)*xbar8 + 
  eps11*(-3.15709843216944468e-10*A2*g4 - 
     7.21099301568180965e-9*A*g5*x2 - 
     5.69746824484251863e-9*g6*x4)*xbar8 + 
  eps10*(-1.18235613578975095e-10*A3*g3 + 
     2.04522364126337295e-10*g5 - 
     1.4372001684607648e-8*A2*g4*x2 - 
     2.38545902650207871e-8*A*g5*x4 - 
     6.6442647298050802e-9*g6*x6)*xbar8 + 
  eps13*(6.34254881618462429e-11*A3*g4 - 
     1.4977795563804726e-11*g6 + 
     2.95036268409924151e-9*A2*g5*x2 + 
     5.72733871097688746e-9*A*g6*x4 + 
     1.89780374932858316e-9*g7*x6)*xbar8 + 
  eps12*(8.85933436332280376e-12*A4*g3 - 
     1.2695043367275619e-10*A*g5 + 
     3.44553148081436095e-9*A3*g4*x2 - 
     9.66117808074637814e-10*g6*x2 + 
     1.08393242236143663e-8*A2*g5*x4 + 
     7.24181767567549532e-9*A*g6*x6 + 
     1.22738677265426237e-9*g7*x8)*xbar8 - 
  2.95801289810004407e-10*eps6*g4*xbar10 + 
  2.94346529368315861e-11*eps9*g5*xbar10 + 
  eps8*(7.69281785172546935e-11*A*g4 + 
     1.07490632635875918e-9*g5*x2)*xbar10 + 
  eps11*(-1.49854878334381416e-11*A*g5 - 
     1.64414869918985145e-10*g6*x2)*xbar10 + 
  eps10*(-1.14623038722347948e-11*A2*g4 - 
     6.72527675714427998e-10*A*g5*x2 - 
     5.64942074025452747e-10*g6*x4)*xbar10 + 
  eps12*(1.27157831390982766e-12*A3*g4 - 
     2.82877994364105943e-12*g6 + 
     2.44160830279527547e-10*A2*g5*x2 + 
     5.14076796669365287e-10*A*g6*x4 + 
     1.75139799425245342e-10*g7*x6)*xbar10 + 
  1.69722051530330397e-12*eps8*g5*xbar12 - 
  2.90595190793452012e-13*eps11*g6*xbar12 + 
  eps10*(-5.54575148020670988e-13*A*g5 - 
     1.29008964169185665e-11*g6*x2)*xbar12 - 
  1.06551186196798794e-14*eps10*g6*xbar14;
}
#endif

#ifdef p19
double Wp(void)
{
   return 0.5*A*x2 + 0.0416666666666666667*g*x4 + 
  eps*(0.0833333333333333333*A + 0.0416666666666666667*g*x2) + 
  eps3*(-0.00277777777777777778*A2 - 
     0.0111111111111111111*A*g*x2 - 
     0.00208333333333333333*g2*x4) + 
  eps2*(0.00416666666666666667*g - 
     0.0416666666666666667*A2*x2 - 
     0.0138888888888888889*A*g*x4 - 
     0.00115740740740740741*g2*x6) + 
  eps5*(0.0001763668430335097*A3 - 
     0.0000388558201058201058*g2 + 
     0.00214947089947089947*A2*g*x2 + 
     0.00124007936507936508*A*g2*x4 + 
     0.000154320987654320988*g3*x6) + 
  eps4*(-0.000595238095238095238*A*g + 
     0.00416666666666666667*A3*x2 - 
     0.000868055555555555556*g2*x2 + 
     0.00347222222222222222*A2*g*x4 + 
     0.000810185185185185185*A*g2*x6 + 
     0.0000578703703703703704*g3*x8) + 
  eps7*(-0.0000132275132275132275*A4 + 
     0.000013452982202982203*A*g2 - 
     0.000353835978835978836*A3*g*x2 + 
     0.0000292107583774250441*g3*x2 - 
     0.000438161375661375661*A2*g2*x4 - 
     0.000141369047619047619*A*g3*x6 - 
     0.0000131815843621399177*g4*x8) + 
  eps6*(0.0000793650793650793651*A2*g - 
     0.000421626984126984127*A4*x2 + 
     0.000412533068783068783*A*g2*x2 - 
     0.000710978835978835979*A3*g*x4 + 
     0.00012359457671957672*g3*x4 - 
     0.000332065696649029982*A2*g2*x6 - 
     0.0000592482363315696649*A*g3*x8 - 
     3.61689814814814815e-6*g4*x10) + 
  eps9*(1.06888995777884667e-6*A5 - 
     3.09484386865339246e-6*A2*g2 + 
     0.000052889176153065042*A4*g*x2 - 
     0.0000196739667225778337*A*g3*x2 + 
     0.000118621733205066538*A3*g2*x4 - 
     8.12834124466068911e-6*g4*x4 + 
     0.0000723776288012399124*A2*g3*x6 + 
     0.0000162595142340512711*A*g4*x8 + 
     1.2123306755829904e-6*g5*x10) + 
  eps8*(-0.0000100208433541766875*A3*g + 
     8.50711788211788212e-7*g3 + 
     0.0000427138447971781305*A5*x2 - 
     0.000120331539602372936*A2*g2*x2 + 
     0.000127911890064667842*A4*g*x4 - 
     0.000098836830607663941*A*g3*x4 + 
     0.000102804110327258475*A3*g2*x6 - 
     0.0000165018585880854399*g4*x6 + 
     0.0000336428938859494415*A2*g3*x8 + 
     4.8512364050558495e-6*A*g4*x10 + 
     2.56755115454961134e-7*g5*x12) + 
  eps11*(-9.01835117002665504e-8*A6 + 
     5.87400058299529199e-7*A3*g2 - 
     2.81868399275952575e-8*g4 - 
     7.41416841780598394e-6*A5*g*x2 + 
     7.67116473755031956e-6*A2*g3*x2 - 
     0.000027147462601331649*A4*g2*x4 + 
     8.12031936990601012e-6*A*g4*x4 - 
     0.0000272310450812986086*A3*g3*x6 + 
     1.70667153812408442e-6*g5*x6 - 
     0.0000108933015093453806*A2*g4*x8 - 
     1.87850642976993286e-6*A*g5*x10 - 
     1.16690477054095881e-7*g6*x12) + 
  eps10*(1.21747740795359843e-6*A4*g - 
     4.62417873132158846e-7*A*g3 - 
     4.32775172358505692e-6*A6*x2 + 
     0.0000276277014248244407*A3*g2*x2 - 
     1.30445706075046353e-6*g4*x2 - 
     0.0000210333326652771097*A5*g*x4 + 
     0.0000447391253752860896*A2*g3*x4 - 
     0.0000265668910778864483*A4*g2*x6 + 
     0.0000184769777868736202*A*g4*x6 - 
     0.0000139376709110505407*A3*g3*x8 + 
     2.13520310814871e-6*g5*x8 - 
     3.5181249916492972e-6*A2*g4*x10 - 
     4.25407416871537242e-7*A*g5*x12 - 
     1.98147969535893919e-8*g6*x14) + 
  eps13*(7.83069566138349207e-9*A7 - 
     9.93094869534334209e-8*A4*g2 + 
     2.08755249185163841e-8*A*g4 + 
     9.92791119692574719e-7*A6*g*x2 - 
     2.26246788359770127e-6*A3*g3*x2 + 
     7.19774046753493046e-8*g5*x2 + 
     5.52538741816188906e-6*A5*g2*x4 - 
     4.47883727161149936e-6*A2*g4*x4 + 
     8.38601213983571788e-6*A4*g3*x6 - 
     2.25348627386308778e-6*A*g5*x6 + 
     5.24445855604457162e-6*A3*g4*x8 - 
     3.11392974798759566e-7*g6*x8 + 
     1.55465050346795001e-6*A2*g5*x10 + 
     2.17600880397466046e-7*A*g6*x12 + 
     1.15841884836628278e-8*g7*x14) + 
  eps12*(-1.43889032777921667e-7*A5*g + 
     1.51283642180000723e-7*A2*g3 + 
     4.38492191964414187e-7*A7*x2 - 
     5.47671197834474951e-6*A4*g2*x2 + 
     1.1365151365172641e-6*A*g4*x2 + 
     3.23789133106262736e-6*A6*g*x4 - 
     0.0000150481673660823793*A3*g3*x4 + 
     5.97324614725086198e-7*g5*x4 + 
     6.03932684613625972e-6*A5*g2*x6 - 
     0.0000113106765525436987*A2*g4*x6 + 
     4.69528859165240338e-6*A4*g3*x8 - 
     3.0694501391598228e-6*A*g5*x8 + 
     1.82557370238215146e-6*A3*g4*x10 - 
     2.71046144994230449e-7*g6*x10 + 
     3.7535031778135559e-7*A2*g5*x12 + 
     3.90681314457195373e-8*A*g6*x14 + 
     1.62260932077515154e-9*g7*x16) + 
  eps15*(-6.94206524686864971e-10*A8 + 
     1.55258266251201437e-8*A5*g2 - 
     8.87063997906019346e-9*A2*g4 - 
     1.28444091425696105e-7*A7*g*x2 + 
     5.59355511978255916e-7*A4*g3*x2 - 
     7.69591961687451275e-8*A*g5*x2 - 
     1.03084425773136674e-6*A6*g2*x4 + 
     1.80099658500984157e-6*A3*g4*x4 - 
     4.89852640150590245e-8*g6*x4 - 
     2.23744987275327073e-6*A5*g3*x6 + 
     1.60416803829389571e-6*A2*g5*x6 - 
     2.02887475090349778e-6*A4*g4*x8 + 
     5.10536772376168298e-7*A*g6*x8 - 
     9.11746562790846727e-7*A3*g5*x10 + 
     5.21769349658492833e-8*g7*x10 - 
     2.14341780318485671e-7*A2*g6*x12 - 
     2.52490551976121104e-8*A*g7*x14 - 
     1.17600420262660865e-9*g8*x16) + 
  eps14*(1.66609565924847593e-8*A6*g - 
     3.84541066603365207e-8*A3*g3 + 
     1.23616495716322489e-9*g5 - 
     4.44285396439000936e-8*A8*x2 + 
     9.81807578832239391e-7*A5*g2*x2 - 
     5.55101746448534654e-7*A2*g4*x2 - 
     4.73967830600877338e-7*A7*g*x4 + 
     4.18284859452059839e-6*A4*g3*x4 - 
     7.15343253702736788e-7*A*g5*x4 - 
     1.24663165145441196e-6*A6*g2*x6 + 
     5.00514675879205854e-6*A3*g4*x6 - 
     1.81402700349001079e-7*g6*x6 - 
     1.36226318220021373e-6*A5*g3*x8 + 
     2.36606032230627314e-6*A2*g5*x8 - 
     7.58172593612770117e-7*A4*g4*x10 + 
     4.75471890972483691e-7*A*g6*x10 - 
     2.34027522244261325e-7*A3*g5*x12 + 
     3.3963539821117207e-8*g7*x12 - 
     4.06050820222736176e-8*A2*g6*x14 - 
     3.70938742929349711e-9*A*g7*x16 - 
     1.38898528337180163e-10*g8*x18) + 
  eps17*(6.25217958800249802e-11*A9 - 
     2.29312206278746533e-9*A6*g2 + 
     2.8310089717477044e-9*A3*g4 - 
     6.71998649148490015e-11*g6 + 
     1.61783182535963035e-8*A8*g*x2 - 
     1.222198282975496e-7*A5*g3*x2 + 
     4.51903487294323094e-8*A2*g5*x2 + 
     1.79787422789127715e-7*A7*g2*x4 - 
     5.89386352242391962e-7*A4*g4*x4 + 
     6.83924293854497039e-8*A*g6*x4 + 
     5.35385253592035249e-7*A6*g3*x6 - 
     8.16161936426993263e-7*A3*g5*x6 + 
     2.03110694856709656e-8*g7*x6 + 
     6.69429955495357485e-7*A5*g4*x8 - 
     4.44812062546498445e-7*A2*g6*x8 + 
     4.24544759374608395e-7*A4*g5*x10 - 
     1.02125278182278717e-7*A*g7*x10 + 
     1.48190757087105866e-7*A3*g6*x12 - 
     8.25465653164429909e-9*g8*x12 + 
     2.8842218900714868e-8*A2*g7*x14 + 
     2.93316966296752154e-9*A*g8*x16 + 
     1.21426224678902097e-10*g9*x18) + 
  eps16*(-1.89909954985575877e-9*A7*g + 
     8.35603474047208798e-9*A4*g3 - 
     1.15966243496214952e-9*A*g5 + 
     4.50155213123768602e-9*A9*x2 - 
     1.63520154608933337e-7*A6*g2*x2 + 
     2.00125773929144853e-7*A3*g4*x2 - 
     4.71643935891082883e-9*g6*x2 + 
     6.66827009985439445e-8*A8*g*x4 - 
     1.01569722853466271e-6*A5*g3*x4 + 
     4.653753986331283e-7*A2*g5*x4 + 
     2.38609112997144637e-7*A7*g2*x6 - 
     1.78931879078472604e-6*A4*g4*x6 + 
     2.75782412054904595e-7*A*g6*x6 + 
     3.5257503626825941e-7*A6*g3*x8 - 
     1.29719583644083582e-6*A3*g5*x8 + 
     4.43904638337799842e-8*g7*x8 + 
     2.67563783428073661e-7*A5*g4*x10 - 
     4.41739629456479988e-7*A2*g6*x10 + 
     1.15544405881940575e-7*A4*g5*x12 - 
     7.03094817586759951e-8*A*g7*x12 + 
     2.95627516533174602e-8*A3*g6*x14 - 
     4.21593686904484474e-9*g8*x14 + 
     4.43746780874914946e-9*A2*g7*x16 + 
     3.61167459558351774e-10*A*g8*x18 + 
     1.23066706066192904e-11*g9*x20) + 
  eps18*(2.13798292543051714e-10*A8*g - 
     1.62899940163818617e-9*A5*g3 + 
     6.06739124374671626e-10*A2*g5 - 
     4.56102589118103946e-10*A10*x2 + 
     2.5741194154734252e-8*A7*g2*x2 - 
     5.93202934378594688e-8*A4*g4*x2 + 
     5.97796132442781859e-9*A*g6*x2 - 
     9.086017175115798e-9*A9*g*x4 + 
     2.22788546277779156e-7*A6*g3*x4 - 
     2.17818061292066124e-7*A3*g5*x4 + 
     4.46060201054250811e-9*g7*x4 - 
     4.29736286745591606e-8*A8*g2*x6 + 
     5.48218484132244335e-7*A5*g4*x6 - 
     2.23798601959230444e-7*A2*g6*x6 - 
     8.3334504765293729e-8*A7*g3*x8 + 
     5.66588387939462102e-7*A4*g5*x8 - 
     8.17078651256326395e-8*A*g7*x8 - 
     8.32572408053676287e-8*A6*g4*x10 + 
     2.88769211893932833e-7*A3*g6*x10 - 
     9.49367158787967084e-9*g8*x10 - 
     4.80270155903927102e-8*A5*g5*x12 + 
     7.64234973061525259e-8*A2*g7*x12 - 
     1.69136821548003748e-8*A4*g6*x14 + 
     1.00575293092506873e-8*A*g8*x14 - 
     3.69466622059472975e-9*A3*g7*x16 + 
     5.19597646877020836e-10*g9*x16 - 
     4.88723854749631574e-10*A2*g8*x18 - 
     3.58645537045585288e-11*A*g9*x20 - 
     1.12084057456710382e-12*g10*x22) + 
  0.00833333333333333333*eps*g*xbar2 + 
  0.166666666666666667*(A + 0.5*g*x2)*xbar2 + 
  eps3*(-0.000793650793650793651*A*g - 
     0.00138888888888888889*g2*x2)*xbar2 + 
  eps2*(-0.00277777777777777778*A2 - 
     0.0111111111111111111*A*g*x2 - 
     0.00208333333333333333*g2*x4)*xbar2 + 
  eps5*(0.0000727513227513227513*A2*g + 
     0.000522486772486772487*A*g2*x2 + 
     0.000162037037037037037*g3*x4)*xbar2 + 
  eps4*(0.0000661375661375661376*A3 - 
     0.0000644841269841269841*g2 + 
     0.0015873015873015873*A2*g*x2 + 
     0.00094246031746031746*A*g2*x4 + 
     0.000115740740740740741*g3*x6)*xbar2 + 
  eps7*(-6.91438191438191438e-6*A3*g + 
     1.41486599819933153e-6*g3 - 
     0.000128066378066378066*A2*g2*x2 - 
     0.000110705266955266955*A*g3*x4 - 
     0.000018647119341563786*g4*x6)*xbar2 + 
  eps6*(-1.65343915343915344e-6*A4 + 
     0.0000179623617123617124*A*g2 - 
     0.00021164021164021164*A3*g*x2 + 
     0.0000485008818342151675*g3*x2 - 
     0.000276951058201058201*A2*g2*x4 - 
     0.0000898368606701940035*A*g3*x6 - 
     8.27867798353909465e-6*g4*x8)*xbar2 + 
  eps9*(6.79829796893288957e-7*A4*g - 
     6.72419695237155555e-7*A*g3 + 
     0.0000254975770848786722*A3*g2*x2 - 
     2.25056258042369153e-6*g4*x2 + 
     0.0000441438108848823135*A2*g3*x4 + 
     0.0000185871013417309714*A*g4*x6 + 
     2.15148764772607365e-6*g5*x8)*xbar2 + 
  eps8*(4.1753513975736198e-8*A5 - 
     3.46221514376276281e-6*A2*g2 + 
     0.0000267222489444711667*A4*g*x2 - 
     0.0000281804101248545693*A*g3*x2 + 
     0.0000649475909892576559*A3*g2*x4 - 
     0.0000122030666735527847*g4*x4 + 
     0.0000403965247715247715*A2*g3*x6 + 
     9.0700810463541945e-6*A*g4*x8 + 
     6.69795953360768176e-7*g5*x10)*xbar2 + 
  eps11*(-6.80612866459427306e-8*A5*g + 
     1.95584655809718057e-7*A2*g3 - 
     4.47269759439071608e-6*A4*g2*x2 + 
     1.75829988748211593e-6*A*g4*x2 - 
     0.0000133314481239415102*A3*g3*x4 + 
     9.71399147418687179e-7*g5*x4 - 
     0.0000103064498801381517*A2*g4*x6 - 
     2.82142523293179157e-6*A*g5*x8 - 
     2.4892365507720446e-7*g6*x10)*xbar2 + 
  eps10*(-1.05683802773749864e-9*A6 + 
     5.67501373552960855e-7*A3*g2 - 
     4.8511255774108832e-8*g4 - 
     3.24660642120959581e-6*A5*g*x2 + 
     9.71126169538867952e-6*A2*g3*x2 - 
     0.0000131832441790279092*A4*g2*x4 + 
     0.0000108846610427711618*A*g4*x4 - 
     0.0000136365860158849577*A3*g3*x6 + 
     2.33168885512635513e-6*g5*x6 - 
     5.4993290386188865e-6*A2*g4*x8 - 
     9.46094479080590192e-7*A*g5*x10 - 
     5.8302302889011994e-8*g6*x12)*xbar2 + 
  eps13*(6.86627585651083939e-9*A6*g - 
     4.47785160224899766e-8*A3*g3 + 
     2.19249275444418889e-9*g5 + 
     7.19946098097358602e-7*A5*g2*x2 - 
     7.80379784965903039e-7*A2*g4*x2 + 
     3.37142842641135708e-6*A4*g3*x4 - 
     1.06398186364605041e-6*A*g5*x4 + 
     4.18165456228327982e-6*A3*g4*x6 - 
     2.76351067919865578e-7*g6*x6 + 
     2.00589567077445504e-6*A2*g5*x8 + 
     4.04753308555164946e-7*A*g6*x10 + 
     2.88571475583667131e-8*g7*x12)*xbar2 + 
  eps12*(2.67650730613693577e-11*A7 - 
     8.46192910475220622e-8*A4*g2 + 
     3.25142589196534057e-8*A*g4 + 
     3.83704087407791111e-7*A6*g*x2 - 
     2.57283359783619147e-6*A3*g3*x2 + 
     1.27951218977907431e-7*g5*x2 + 
     2.41765559329216737e-6*A5*g2*x4 - 
     5.44480881814382923e-6*A2*g4*x4 + 
     3.82233569685344377e-6*A4*g3*x6 - 
     2.81139544164632672e-6*A*g5*x6 + 
     2.42710273474001612e-6*A3*g4*x8 - 
     3.92027350262991887e-7*g6*x8 + 
     7.21984500196305752e-7*A2*g5*x10 + 
     1.007566064009769e-7*A*g6*x12 + 
     5.32759708629371695e-9*g7*x14)*xbar2 + 
  eps15*(-6.94677964495491896e-10*A7*g + 
     8.85485037384606633e-9*A4*g3 - 
     1.89784940868103996e-9*A*g5 - 
     1.08873720111587578e-7*A6*g2*x2 + 
     2.58200627219967634e-7*A3*g4*x2 - 
     8.57415659878293831e-9*g6*x2 - 
     7.52178044272582197e-7*A5*g3*x4 + 
     6.39174172204870162e-7*A2*g5*x4 - 
     1.38311030669262085e-6*A4*g4*x6 + 
     3.89805821462228289e-7*A*g6*x6 - 
     1.02272071613530239e-6*A3*g5*x8 + 
     6.35874554600849527e-8*g7*x8 - 
     3.51191445940869782e-7*A2*g6*x10 - 
     5.59975947545884819e-8*A*g7*x12 - 
     3.35001083013772154e-9*g8*x14)*xbar2 + 
  eps14*(-6.77936059264516573e-13*A8 + 
     1.18453251754498057e-8*A5*g2 - 
     1.26192122113177278e-8*A2*g4 - 
     4.44292175799593582e-8*A7*g*x2 + 
     5.78235471803035281e-7*A4*g3*x2 - 
     1.25465164813262727e-7*A*g5*x2 - 
     4.11093596933471078e-7*A6*g2*x4 + 
     2.00802343589623813e-6*A3*g4*x4 - 
     8.38456228452171631e-8*g6*x4 - 
     9.37962675222683393e-7*A5*g3*x6 + 
     1.84660973293660698e-6*A2*g5*x6 - 
     8.68952732620502728e-7*A4*g4*x8 + 
     5.95974150882540242e-7*A*g6*x8 - 
     3.93789587968658131e-7*A3*g5*x10 + 
     6.11861559616332661e-8*g7*x10 - 
     9.26911580977221589e-8*A2*g6*x12 - 
     1.08851336477984649e-8*A*g7*x14 - 
     5.04016698893419468e-10*g8*x16)*xbar2 + 
  eps17*(7.03519796756268115e-11*A8*g - 
     1.58412622695254907e-9*A5*g3 + 
     9.21824723042734146e-10*A2*g5 + 
     1.57013176618403867e-8*A7*g2*x2 - 
     7.07877152349972815e-8*A4*g4*x2 + 
     1.01145514044440416e-8*A*g6*x2 + 
     1.52755677874009072e-7*A6*g3*x4 - 
     2.78303968964189299e-7*A3*g5*x4 + 
     7.90216106829461597e-9*g7*x4 + 
     3.94839847004885584e-7*A5*g4*x6 - 
     2.95546266642869418e-7*A2*g6*x6 + 
     4.1812888733216445e-7*A4*g5*x8 - 
     1.09749260429676339e-7*A*g7*x8 + 
     2.15692160440115788e-7*A3*g6*x10 - 
     1.28547064754435117e-8*g8*x10 + 
     5.73688513495873601e-8*A2*g7*x12 + 
     7.55383153004710777e-9*A*g8*x14 + 
     3.89293296941875901e-10*g9*x16)*xbar2 + 
  eps16*(1.71721241125556891e-14*A9 - 
     1.58463391176416606e-9*A6*g2 + 
     3.70687203668986364e-9*A3*g4 - 
     1.21950914958299276e-10*g6 + 
     5.06426546628202339e-9*A8*g*x2 - 
     1.15919331839795365e-7*A5*g3*x2 + 
     6.813324046201634e-8*A2*g5*x2 + 
     6.59264102615256734e-8*A7*g2*x4 - 
     6.0783143535697607e-7*A4*g4*x4 + 
     1.08734552181364072e-7*A*g6*x4 + 
     2.08077893379438207e-7*A6*g3*x6 - 
     8.7376194571684116e-7*A3*g5*x6 + 
     3.31435423816449871e-8*g7*x6 + 
     2.67286143174399604e-7*A5*g4*x8 - 
     4.84990273878282454e-7*A2*g6*x8 + 
     1.71677767909550515e-7*A4*g5*x10 - 
     1.12268658721773254e-7*A*g7*x10 + 
     6.02176056859808662e-8*A3*g6*x12 - 
     9.09453722352822717e-9*g8*x12 + 
     1.17208819972660499e-8*A2*g7*x14 + 
     1.18834173730462595e-9*A*g8*x16 + 
     4.8940576382579539e-11*g9*x18)*xbar2 + 
  0.00833333333333333333*g*xbar4 - 
  0.0000462962962962962963*eps3*g2*xbar4 + 
  eps2*(-0.000396825396825396825*A*g - 
     0.000694444444444444444*g2*x2)*xbar4 + 
  eps5*(9.11896745230078563e-6*A*g2 + 
     0.0000308641975308641975*g3*x2)*xbar4 + 
  eps4*(0.0000198412698412698413*A2*g + 
     0.000195105820105820106*A*g2*x2 + 
     0.0000617283950617283951*g3*x4)*xbar4 + 
  eps7*(-1.31581381581381581e-6*A2*g2 - 
     0.0000151318588818588819*A*g3*x2 - 
     6.8455207344096233e-6*g4*x4)*xbar4 + 
  eps6*(-9.01875901875901876e-7*A3*g + 
     9.90714532381199048e-7*g3 - 
     0.0000389059243225909893*A2*g2*x2 - 
     0.0000351397573619795842*A*g3*x4 - 
     5.9477880658436214e-6*g4*x6)*xbar4 + 
  eps9*(1.71045640622360199e-7*A3*g2 - 
     3.60906857706966639e-8*g4 + 
     4.53245406122390249e-6*A2*g3*x2 + 
     5.38783061931210079e-6*A*g4*x4 + 
     1.17492514772607365e-6*g5*x6)*xbar4 + 
  eps8*(3.77616945077262538e-8*A4*g - 
     3.91505723846993688e-7*A*g3 + 
     6.55938527962337486e-6*A3*g2*x2 - 
     1.61985166325444103e-6*g4*x2 + 
     0.0000121547079219036891*A2*g3*x4 + 
     5.20508405346368309e-6*A*g4*x6 + 
     6.02301130368259998e-7*g5*x8)*xbar4 + 
  eps11*(-2.12135350797297057e-8*A4*g2 + 
     2.14460056215349951e-8*A*g4 - 
     1.06401470496877178e-6*A3*g3*x2 + 
     9.9419658966568008e-8*g5*x2 - 
     2.4228308825712602e-6*A2*g4*x4 - 
     1.28380796826126347e-6*A*g5*x6 - 
     1.80516340332649186e-7*g6*x8)*xbar4 + 
  eps10*(-1.48202033122668043e-9*A5*g + 
     9.77137892841674354e-8*A2*g3 - 
     9.98537198520664129e-7*A4*g2*x2 + 
     1.12096864298613054e-6*A*g4*x2 - 
     3.25929867376075489e-6*A3*g3*x4 + 
     6.52088831782005348e-7*g5*x4 - 
     2.59007734102806854e-6*A2*g4*x6 - 
     7.14333704061713321e-7*A*g5*x8 - 
     6.28878290312510992e-8*g6*x10)*xbar4 + 
  eps13*(2.55551047231023315e-9*A5*g2 - 
     7.48454109323006102e-9*A2*g4 + 
     2.14869723911233424e-7*A4*g3*x2 - 
     8.87037184673700903e-8*A*g5*x2 + 
     8.1367411096167446e-7*A3*g4*x4 - 
     6.24554324051377381e-8*g6*x4 + 
     7.73534185148061632e-7*A2*g5*x6 + 
     2.53114332805174734e-7*A*g6*x8 + 
     2.60907174059342559e-8*g7*x10)*xbar4 + 
  eps12*(5.52620037914155561e-11*A6*g - 
     1.96395897468419557e-8*A3*g3 + 
     1.73105497543500998e-9*g5 + 
     1.41930118072774209e-7*A5*g2*x2 - 
     4.4751871911848506e-7*A2*g4*x2 + 
     7.4329679752095632e-7*A4*g3*x4 - 
     6.48579919839268283e-7*A*g5*x4 + 
     9.56849686940199225e-7*A3*g4*x6 - 
     1.72592309647809413e-7*g6*x6 + 
     4.6549037372399414e-7*A2*g5*x8 + 
     9.4234108977460504e-8*A*g6*x10 + 
     6.6997976279157566e-9*g7*x12)*xbar4 + 
  eps15*(-3.01110179246578381e-10*A6*g2 + 
     1.99854473307210245e-9*A3*g4 - 
     1.0075222178954846e-10*g6 - 
     3.91236879782746971e-8*A5*g3*x2 + 
     4.42468326545839399e-8*A2*g5*x2 - 
     2.26449722207185509e-7*A4*g4*x4 + 
     7.48610321580336637e-8*A*g6*x4 - 
     3.38794481457344831e-7*A3*g5*x6 + 
     2.34467193453680488e-8*g7*x6 - 
     1.91586076465687549e-7*A2*g6*x8 - 
     4.4705147415174641e-8*A*g7*x10 - 
     3.62790374951045814e-9*g8*x12)*xbar4 + 
  eps14*(-1.97753534590218582e-12*A7*g + 
     3.46651613447685113e-9*A4*g3 - 
     1.3675698718070872e-9*A*g5 - 
     1.92080361104674656e-8*A6*g2*x2 + 
     1.34714593349386061e-7*A3*g4*x2 - 
     7.0165116069938331e-9*g6*x2 - 
     1.51234778678998732e-7*A5*g3*x4 + 
     3.57677410764887609e-7*A2*g5*x4 - 
     2.9119323970204683e-7*A4*g4*x6 + 
     2.24757818721415644e-7*A*g6*x6 - 
     2.19654624683123427e-7*A3*g5*x8 + 
     3.71577620957842484e-8*g7*x8 - 
     7.60245440599503551e-8*A2*g6*x10 - 
     1.21363875909823901e-8*A*g7*x12 - 
     7.23898306636066601e-10*g8*x14)*xbar4 + 
  eps16*(6.84233044511131468e-14*A8*g - 
     5.60464705059266925e-10*A5*g3 + 
     6.1113506912043867e-10*A2*g5 + 
     2.50582201503812155e-9*A7*g2*x2 - 
     3.39024845059116986e-8*A4*g4*x2 + 
     7.66141086125169516e-9*A*g6*x2 + 
     2.82533097805425257e-8*A6*g3*x4 - 
     1.44153074493338505e-7*A3*g5*x4 + 
     6.29165697711773721e-9*g7*x4 + 
     7.70955531949116842e-8*A5*g4*x6 - 
     1.5856345215569678e-7*A2*g6*x6 + 
     8.37319173204484218e-8*A4*g5*x8 - 
     5.99155536147365961e-8*A*g7*x8 + 
     4.37139891312553985e-8*A3*g6*x10 - 
     7.07392441584795305e-9*g8*x10 + 
     1.16805756794796047e-8*A2*g7*x12 + 
     1.53807088851897092e-9*A*g8*x14 + 
     7.90314013633620188e-11*g9*x16)*xbar4 - 
  0.0000154320987654320988*eps2*g2*xbar6 + 
  3.56125356125356125e-7*eps5*g3*xbar6 + 
  eps4*(1.90396023729357063e-6*A*g2 + 
     7.71604938271604938e-6*g3*x2)*xbar6 + 
  eps7*(-1.06760523427190094e-7*A*g3 - 
     5.83649889205444761e-7*g4*x2)*xbar6 + 
  eps6*(-1.58222876476844731e-7*A2*g2 - 
     3.0990100434544879e-6*A*g3*x2 - 
     1.45170544476100032e-6*g4*x4)*xbar6 + 
  eps9*(2.10474956623416007e-8*A2*g3 + 
     3.52066889376257568e-7*A*g4*x2 + 
     2.15683591284989252e-7*g5*x4)*xbar6 + 
  eps8*(1.0639753805538638e-8*A3*g2 - 
     1.44647796358943781e-8*g4 + 
     7.89019059521705024e-7*A2*g3*x2 + 
     9.93278626380478232e-7*A*g4*x4 + 
     2.19830466744046991e-7*g5*x6)*xbar6 + 
  eps11*(-3.48009271425128996e-9*A3*g3 + 
     7.74456172615070677e-10*g5 - 
     1.24759056081950737e-7*A2*g4*x2 - 
     1.93124743183608916e-7*A*g5*x4 - 
     5.26262283781649553e-8*g6*x6)*xbar6 + 
  eps10*(-6.21784885258793341e-10*A4*g2 + 
     7.35917308458240036e-9*A*g4 - 
     1.61082849737015107e-7*A3*g3*x2 + 
     4.25042008023580282e-8*g5*x2 - 
     3.97181909847740069e-7*A2*g4*x4 - 
     2.15693489113968417e-7*A*g5*x6 - 
     3.05361793587726322e-8*g6*x8)*xbar6 + 
  eps13*(5.22929181665348026e-10*A4*g3 - 
     5.49761548927799316e-10*A*g5 + 
     3.37795673591345898e-8*A3*g4*x2 - 
     3.32362369023656752e-9*g6*x2 + 
     9.70864128827426103e-8*A2*g5*x4 + 
     6.29082935052959515e-8*A*g6*x6 + 
     1.05359214957493409e-8*g7*x8)*xbar6 + 
  eps12*(3.28023733515722384e-11*A5*g2 - 
     2.2483490443839068e-9*A2*g4 + 
     2.87554439944054822e-8*A4*g3*x2 - 
     3.41643318587639607e-8*A*g5*x2 + 
     1.20413081223750724e-7*A3*g4*x4 - 
     2.54382194661358481e-8*g6*x4 + 
     1.18403247344882478e-7*A2*g5*x6 + 
     3.92485363936068314e-8*A*g6*x8 + 
     4.05810532585570662e-9*g7*x10)*xbar6 + 
  eps15*(-7.38610165433134699e-11*A5*g3 + 
     2.23185618064230175e-10*A2*g5 - 
     7.72550467360774725e-9*A4*g4*x2 + 
     3.33675225731002428e-9*A*g6*x2 - 
     3.60024022499056884e-8*A3*g5*x4 + 
     2.89391686340197044e-9*g7*x4 - 
     4.11034234008140627e-8*A2*g6*x6 - 
     1.58061594311664227e-8*A*g7*x8 - 
     1.88044966020543737e-9*g8*x10)*xbar6 + 
  eps14*(-1.59924972891624396e-12*A6*g2 + 
     5.34559467656326695e-10*A3*g4 - 
     4.89531412255654985e-11*g6 - 
     4.68743656687813986e-9*A5*g3*x2 + 
     1.55203340852120435e-8*A2*g5*x2 - 
     3.05848967636635251e-8*A4*g4*x4 + 
     2.80191583068273077e-8*A*g6*x4 - 
     4.77391188802852923e-8*A3*g5*x6 + 
     9.0249644584421326e-9*g7*x6 - 
     2.7500470429085428e-8*A2*g6*x8 - 
     6.46467617732357999e-9*A*g7*x10 - 
     5.25206836466407194e-10*g8*x12)*xbar6 + 
  5.93542260208926876e-8*eps4*g3*xbar8 - 
  3.12288574815807931e-9*eps7*g4*xbar8 + 
  eps6*(-1.14340392118169896e-8*A*g3 - 
     9.02678854067742957e-8*g4*x2)*xbar8 + 
  eps9*(1.26121885620031857e-9*A*g4 + 
     1.00859349622512295e-8*g5*x2)*xbar8 + 
  eps8*(1.32727772394750297e-9*A2*g3 + 
     4.65033697944917988e-8*A*g4*x2 + 
     2.99054295797669073e-8*g5*x4)*xbar8 + 
  eps11*(-3.15709843216944468e-10*A2*g4 - 
     7.21099301568180965e-9*A*g5*x2 - 
     5.69746824484251863e-9*g6*x4)*xbar8 + 
  eps10*(-1.18235613578975095e-10*A3*g3 + 
     2.04522364126337295e-10*g5 - 
     1.4372001684607648e-8*A2*g4*x2 - 
     2.38545902650207871e-8*A*g5*x4 - 
     6.6442647298050802e-9*g6*x6)*xbar8 + 
  eps13*(6.34254881618462429e-11*A3*g4 - 
     1.4977795563804726e-11*g6 + 
     2.95036268409924151e-9*A2*g5*x2 + 
     5.72733871097688746e-9*A*g6*x4 + 
     1.89780374932858316e-9*g7*x6)*xbar8 + 
  eps12*(8.85933436332280376e-12*A4*g3 - 
     1.2695043367275619e-10*A*g5 + 
     3.44553148081436095e-9*A3*g4*x2 - 
     9.66117808074637814e-10*g6*x2 + 
     1.08393242236143663e-8*A2*g5*x4 + 
     7.24181767567549532e-9*A*g6*x6 + 
     1.22738677265426237e-9*g7*x8)*xbar8 + 
  eps14*(-5.85591473164617337e-13*A5*g3 + 
     4.58152437519766974e-11*A2*g5 - 
     7.06061940978074562e-10*A4*g4*x2 + 
     8.8437067488213914e-10*A*g6*x2 - 
     3.6718459581734819e-9*A3*g5*x4 + 
     8.14572670487090063e-10*g7*x4 - 
     4.35865819040676537e-9*A2*g6*x6 - 
     1.70511399881374369e-9*A*g7*x8 - 
     2.04267683542374506e-10*g8*x10)*xbar8 - 
  2.95801289810004407e-10*eps6*g4*xbar10 + 
  2.94346529368315861e-11*eps9*g5*xbar10 + 
  eps8*(7.69281785172546935e-11*A*g4 + 
     1.07490632635875918e-9*g5*x2)*xbar10 + 
  eps11*(-1.49854878334381416e-11*A*g5 - 
     1.64414869918985145e-10*g6*x2)*xbar10 + 
  eps10*(-1.14623038722347948e-11*A2*g4 - 
     6.72527675714427998e-10*A*g5*x2 - 
     5.64942074025452747e-10*g6*x4)*xbar10 + 
  eps13*(4.55203920804202245e-12*A2*g5 + 
     1.35763920347428776e-10*A*g6*x2 + 
     1.33652228562929386e-10*g7*x4)*xbar10 + 
  eps12*(1.27157831390982766e-12*A3*g4 - 
     2.82877994364105943e-12*g6 + 
     2.44160830279527547e-10*A2*g5*x2 + 
     5.14076796669365287e-10*A*g6*x4 + 
     1.75139799425245342e-10*g7*x6)*xbar10 + 
  1.69722051530330397e-12*eps8*g5*xbar12 - 
  2.90595190793452012e-13*eps11*g6*xbar12 + 
  eps10*(-5.54575148020670988e-13*A*g5 - 
     1.29008964169185665e-11*g6*x2)*xbar12 + 
  eps12*(1.00869657097464141e-13*A2*g5 + 
     9.47632013657176953e-12*A*g6*x2 + 
     1.00368310409322369e-11*g7*x4)*xbar12 - 
  1.06551186196798794e-14*eps10*g6*xbar14;
}
#endif

#ifdef p20
double Wp(void)
{
   return 0.5*A*x2 + 0.0416666666666666667*g*x4 + 
  eps*(0.0833333333333333333*A + 0.0416666666666666667*g*x2) + 
  eps3*(-0.00277777777777777778*A2 - 
     0.0111111111111111111*A*g*x2 - 
     0.00208333333333333333*g2*x4) + 
  eps2*(0.00416666666666666667*g - 
     0.0416666666666666667*A2*x2 - 
     0.0138888888888888889*A*g*x4 - 
     0.00115740740740740741*g2*x6) + 
  eps5*(0.0001763668430335097*A3 - 
     0.0000388558201058201058*g2 + 
     0.00214947089947089947*A2*g*x2 + 
     0.00124007936507936508*A*g2*x4 + 
     0.000154320987654320988*g3*x6) + 
  eps4*(-0.000595238095238095238*A*g + 
     0.00416666666666666667*A3*x2 - 
     0.000868055555555555556*g2*x2 + 
     0.00347222222222222222*A2*g*x4 + 
     0.000810185185185185185*A*g2*x6 + 
     0.0000578703703703703704*g3*x8) + 
  eps7*(-0.0000132275132275132275*A4 + 
     0.000013452982202982203*A*g2 - 
     0.000353835978835978836*A3*g*x2 + 
     0.0000292107583774250441*g3*x2 - 
     0.000438161375661375661*A2*g2*x4 - 
     0.000141369047619047619*A*g3*x6 - 
     0.0000131815843621399177*g4*x8) + 
  eps6*(0.0000793650793650793651*A2*g - 
     0.000421626984126984127*A4*x2 + 
     0.000412533068783068783*A*g2*x2 - 
     0.000710978835978835979*A3*g*x4 + 
     0.00012359457671957672*g3*x4 - 
     0.000332065696649029982*A2*g2*x6 - 
     0.0000592482363315696649*A*g3*x8 - 
     3.61689814814814815e-6*g4*x10) + 
  eps9*(1.06888995777884667e-6*A5 - 
     3.09484386865339246e-6*A2*g2 + 
     0.000052889176153065042*A4*g*x2 - 
     0.0000196739667225778337*A*g3*x2 + 
     0.000118621733205066538*A3*g2*x4 - 
     8.12834124466068911e-6*g4*x4 + 
     0.0000723776288012399124*A2*g3*x6 + 
     0.0000162595142340512711*A*g4*x8 + 
     1.2123306755829904e-6*g5*x10) + 
  eps8*(-0.0000100208433541766875*A3*g + 
     8.50711788211788212e-7*g3 + 
     0.0000427138447971781305*A5*x2 - 
     0.000120331539602372936*A2*g2*x2 + 
     0.000127911890064667842*A4*g*x4 - 
     0.000098836830607663941*A*g3*x4 + 
     0.000102804110327258475*A3*g2*x6 - 
     0.0000165018585880854399*g4*x6 + 
     0.0000336428938859494415*A2*g3*x8 + 
     4.8512364050558495e-6*A*g4*x10 + 
     2.56755115454961134e-7*g5*x12) + 
  eps11*(-9.01835117002665504e-8*A6 + 
     5.87400058299529199e-7*A3*g2 - 
     2.81868399275952575e-8*g4 - 
     7.41416841780598394e-6*A5*g*x2 + 
     7.67116473755031956e-6*A2*g3*x2 - 
     0.000027147462601331649*A4*g2*x4 + 
     8.12031936990601012e-6*A*g4*x4 - 
     0.0000272310450812986086*A3*g3*x6 + 
     1.70667153812408442e-6*g5*x6 - 
     0.0000108933015093453806*A2*g4*x8 - 
     1.87850642976993286e-6*A*g5*x10 - 
     1.16690477054095881e-7*g6*x12) + 
  eps10*(1.21747740795359843e-6*A4*g - 
     4.62417873132158846e-7*A*g3 - 
     4.32775172358505692e-6*A6*x2 + 
     0.0000276277014248244407*A3*g2*x2 - 
     1.30445706075046353e-6*g4*x2 - 
     0.0000210333326652771097*A5*g*x4 + 
     0.0000447391253752860896*A2*g3*x4 - 
     0.0000265668910778864483*A4*g2*x6 + 
     0.0000184769777868736202*A*g4*x6 - 
     0.0000139376709110505407*A3*g3*x8 + 
     2.13520310814871e-6*g5*x8 - 
     3.5181249916492972e-6*A2*g4*x10 - 
     4.25407416871537242e-7*A*g5*x12 - 
     1.98147969535893919e-8*g6*x14) + 
  eps13*(7.83069566138349207e-9*A7 - 
     9.93094869534334209e-8*A4*g2 + 
     2.08755249185163841e-8*A*g4 + 
     9.92791119692574719e-7*A6*g*x2 - 
     2.26246788359770127e-6*A3*g3*x2 + 
     7.19774046753493046e-8*g5*x2 + 
     5.52538741816188906e-6*A5*g2*x4 - 
     4.47883727161149936e-6*A2*g4*x4 + 
     8.38601213983571788e-6*A4*g3*x6 - 
     2.25348627386308778e-6*A*g5*x6 + 
     5.24445855604457162e-6*A3*g4*x8 - 
     3.11392974798759566e-7*g6*x8 + 
     1.55465050346795001e-6*A2*g5*x10 + 
     2.17600880397466046e-7*A*g6*x12 + 
     1.15841884836628278e-8*g7*x14) + 
  eps12*(-1.43889032777921667e-7*A5*g + 
     1.51283642180000723e-7*A2*g3 + 
     4.38492191964414187e-7*A7*x2 - 
     5.47671197834474951e-6*A4*g2*x2 + 
     1.1365151365172641e-6*A*g4*x2 + 
     3.23789133106262736e-6*A6*g*x4 - 
     0.0000150481673660823793*A3*g3*x4 + 
     5.97324614725086198e-7*g5*x4 + 
     6.03932684613625972e-6*A5*g2*x6 - 
     0.0000113106765525436987*A2*g4*x6 + 
     4.69528859165240338e-6*A4*g3*x8 - 
     3.0694501391598228e-6*A*g5*x8 + 
     1.82557370238215146e-6*A3*g4*x10 - 
     2.71046144994230449e-7*g6*x10 + 
     3.7535031778135559e-7*A2*g5*x12 + 
     3.90681314457195373e-8*A*g6*x14 + 
     1.62260932077515154e-9*g7*x16) + 
  eps15*(-6.94206524686864971e-10*A8 + 
     1.55258266251201437e-8*A5*g2 - 
     8.87063997906019346e-9*A2*g4 - 
     1.28444091425696105e-7*A7*g*x2 + 
     5.59355511978255916e-7*A4*g3*x2 - 
     7.69591961687451275e-8*A*g5*x2 - 
     1.03084425773136674e-6*A6*g2*x4 + 
     1.80099658500984157e-6*A3*g4*x4 - 
     4.89852640150590245e-8*g6*x4 - 
     2.23744987275327073e-6*A5*g3*x6 + 
     1.60416803829389571e-6*A2*g5*x6 - 
     2.02887475090349778e-6*A4*g4*x8 + 
     5.10536772376168298e-7*A*g6*x8 - 
     9.11746562790846727e-7*A3*g5*x10 + 
     5.21769349658492833e-8*g7*x10 - 
     2.14341780318485671e-7*A2*g6*x12 - 
     2.52490551976121104e-8*A*g7*x14 - 
     1.17600420262660865e-9*g8*x16) + 
  eps14*(1.66609565924847593e-8*A6*g - 
     3.84541066603365207e-8*A3*g3 + 
     1.23616495716322489e-9*g5 - 
     4.44285396439000936e-8*A8*x2 + 
     9.81807578832239391e-7*A5*g2*x2 - 
     5.55101746448534654e-7*A2*g4*x2 - 
     4.73967830600877338e-7*A7*g*x4 + 
     4.18284859452059839e-6*A4*g3*x4 - 
     7.15343253702736788e-7*A*g5*x4 - 
     1.24663165145441196e-6*A6*g2*x6 + 
     5.00514675879205854e-6*A3*g4*x6 - 
     1.81402700349001079e-7*g6*x6 - 
     1.36226318220021373e-6*A5*g3*x8 + 
     2.36606032230627314e-6*A2*g5*x8 - 
     7.58172593612770117e-7*A4*g4*x10 + 
     4.75471890972483691e-7*A*g6*x10 - 
     2.34027522244261325e-7*A3*g5*x12 + 
     3.3963539821117207e-8*g7*x12 - 
     4.06050820222736176e-8*A2*g6*x14 - 
     3.70938742929349711e-9*A*g7*x16 - 
     1.38898528337180163e-10*g8*x18) + 
  eps17*(6.25217958800249802e-11*A9 - 
     2.29312206278746533e-9*A6*g2 + 
     2.8310089717477044e-9*A3*g4 - 
     6.71998649148490015e-11*g6 + 
     1.61783182535963035e-8*A8*g*x2 - 
     1.222198282975496e-7*A5*g3*x2 + 
     4.51903487294323094e-8*A2*g5*x2 + 
     1.79787422789127715e-7*A7*g2*x4 - 
     5.89386352242391962e-7*A4*g4*x4 + 
     6.83924293854497039e-8*A*g6*x4 + 
     5.35385253592035249e-7*A6*g3*x6 - 
     8.16161936426993263e-7*A3*g5*x6 + 
     2.03110694856709656e-8*g7*x6 + 
     6.69429955495357485e-7*A5*g4*x8 - 
     4.44812062546498445e-7*A2*g6*x8 + 
     4.24544759374608395e-7*A4*g5*x10 - 
     1.02125278182278717e-7*A*g7*x10 + 
     1.48190757087105866e-7*A3*g6*x12 - 
     8.25465653164429909e-9*g8*x12 + 
     2.8842218900714868e-8*A2*g7*x14 + 
     2.93316966296752154e-9*A*g8*x16 + 
     1.21426224678902097e-10*g9*x18) + 
  eps16*(-1.89909954985575877e-9*A7*g + 
     8.35603474047208798e-9*A4*g3 - 
     1.15966243496214952e-9*A*g5 + 
     4.50155213123768602e-9*A9*x2 - 
     1.63520154608933337e-7*A6*g2*x2 + 
     2.00125773929144853e-7*A3*g4*x2 - 
     4.71643935891082883e-9*g6*x2 + 
     6.66827009985439445e-8*A8*g*x4 - 
     1.01569722853466271e-6*A5*g3*x4 + 
     4.653753986331283e-7*A2*g5*x4 + 
     2.38609112997144637e-7*A7*g2*x6 - 
     1.78931879078472604e-6*A4*g4*x6 + 
     2.75782412054904595e-7*A*g6*x6 + 
     3.5257503626825941e-7*A6*g3*x8 - 
     1.29719583644083582e-6*A3*g5*x8 + 
     4.43904638337799842e-8*g7*x8 + 
     2.67563783428073661e-7*A5*g4*x10 - 
     4.41739629456479988e-7*A2*g6*x10 + 
     1.15544405881940575e-7*A4*g5*x12 - 
     7.03094817586759951e-8*A*g7*x12 + 
     2.95627516533174602e-8*A3*g6*x14 - 
     4.21593686904484474e-9*g8*x14 + 
     4.43746780874914946e-9*A2*g7*x16 + 
     3.61167459558351774e-10*A*g8*x18 + 
     1.23066706066192904e-11*g9*x20) + 
  eps19*(-5.70128780114804572e-12*A10 + 
     3.24325759393455769e-10*A7*g2 - 
     7.52920392642037898e-10*A4*g4 + 
     7.63432039813829238e-11*A*g6 - 
     1.99446765051272661e-9*A9*g*x2 + 
     2.43560018179573397e-8*A6*g3*x2 - 
     1.92651473964731419e-8*A3*g5*x2 + 
     3.57664504054283011e-10*g7*x2 - 
     2.97138844105769473e-8*A8*g2*x4 + 
     1.66367899286352586e-7*A5*g4*x4 - 
     5.12763843043703477e-8*A2*g6*x4 - 
     1.17558487781038256e-7*A7*g3*x6 + 
     3.32274083849900958e-7*A4*g5*x6 - 
     3.49339293457975036e-8*A*g7*x6 - 
     1.95421595481198395e-7*A6*g4*x8 + 
     2.73546099832218964e-7*A3*g6*x8 - 
     6.42119893976624269e-9*g8*x8 - 
     1.66845932629322826e-7*A5*g5*x10 + 
     1.05196992302604677e-7*A2*g7*x10 - 
     8.06653736383214643e-8*A4*g6*x12 + 
     1.87723844343482559e-8*A*g8*x12 - 
     2.29644918467110207e-8*A3*g7*x14 + 
     1.25288025697957571e-9*g9*x14 - 
     3.81165485194947533e-9*A2*g8*x16 - 
     3.41033212304414905e-10*A*g9*x18 - 
     1.27053709821831841e-11*g10*x20) + 
  eps18*(2.13798292543051714e-10*A8*g - 
     1.62899940163818617e-9*A5*g3 + 
     6.06739124374671626e-10*A2*g5 - 
     4.56102589118103946e-10*A10*x2 + 
     2.5741194154734252e-8*A7*g2*x2 - 
     5.93202934378594688e-8*A4*g4*x2 + 
     5.97796132442781859e-9*A*g6*x2 - 
     9.086017175115798e-9*A9*g*x4 + 
     2.22788546277779156e-7*A6*g3*x4 - 
     2.17818061292066124e-7*A3*g5*x4 + 
     4.46060201054250811e-9*g7*x4 - 
     4.29736286745591606e-8*A8*g2*x6 + 
     5.48218484132244335e-7*A5*g4*x6 - 
     2.23798601959230444e-7*A2*g6*x6 - 
     8.3334504765293729e-8*A7*g3*x8 + 
     5.66588387939462102e-7*A4*g5*x8 - 
     8.17078651256326395e-8*A*g7*x8 - 
     8.32572408053676287e-8*A6*g4*x10 + 
     2.88769211893932833e-7*A3*g6*x10 - 
     9.49367158787967084e-9*g8*x10 - 
     4.80270155903927102e-8*A5*g5*x12 + 
     7.64234973061525259e-8*A2*g7*x12 - 
     1.69136821548003748e-8*A4*g6*x14 + 
     1.00575293092506873e-8*A*g8*x14 - 
     3.69466622059472975e-9*A3*g7*x16 + 
     5.19597646877020836e-10*g9*x16 - 
     4.88723854749631574e-10*A2*g8*x18 - 
     3.58645537045585288e-11*A*g9*x20 - 
     1.12084057456710382e-12*g10*x22) + 
  0.00833333333333333333*eps*g*xbar2 + 
  0.166666666666666667*(A + 0.5*g*x2)*xbar2 + 
  eps3*(-0.000793650793650793651*A*g - 
     0.00138888888888888889*g2*x2)*xbar2 + 
  eps2*(-0.00277777777777777778*A2 - 
     0.0111111111111111111*A*g*x2 - 
     0.00208333333333333333*g2*x4)*xbar2 + 
  eps5*(0.0000727513227513227513*A2*g + 
     0.000522486772486772487*A*g2*x2 + 
     0.000162037037037037037*g3*x4)*xbar2 + 
  eps4*(0.0000661375661375661376*A3 - 
     0.0000644841269841269841*g2 + 
     0.0015873015873015873*A2*g*x2 + 
     0.00094246031746031746*A*g2*x4 + 
     0.000115740740740740741*g3*x6)*xbar2 + 
  eps7*(-6.91438191438191438e-6*A3*g + 
     1.41486599819933153e-6*g3 - 
     0.000128066378066378066*A2*g2*x2 - 
     0.000110705266955266955*A*g3*x4 - 
     0.000018647119341563786*g4*x6)*xbar2 + 
  eps6*(-1.65343915343915344e-6*A4 + 
     0.0000179623617123617124*A*g2 - 
     0.00021164021164021164*A3*g*x2 + 
     0.0000485008818342151675*g3*x2 - 
     0.000276951058201058201*A2*g2*x4 - 
     0.0000898368606701940035*A*g3*x6 - 
     8.27867798353909465e-6*g4*x8)*xbar2 + 
  eps9*(6.79829796893288957e-7*A4*g - 
     6.72419695237155555e-7*A*g3 + 
     0.0000254975770848786722*A3*g2*x2 - 
     2.25056258042369153e-6*g4*x2 + 
     0.0000441438108848823135*A2*g3*x4 + 
     0.0000185871013417309714*A*g4*x6 + 
     2.15148764772607365e-6*g5*x8)*xbar2 + 
  eps8*(4.1753513975736198e-8*A5 - 
     3.46221514376276281e-6*A2*g2 + 
     0.0000267222489444711667*A4*g*x2 - 
     0.0000281804101248545693*A*g3*x2 + 
     0.0000649475909892576559*A3*g2*x4 - 
     0.0000122030666735527847*g4*x4 + 
     0.0000403965247715247715*A2*g3*x6 + 
     9.0700810463541945e-6*A*g4*x8 + 
     6.69795953360768176e-7*g5*x10)*xbar2 + 
  eps11*(-6.80612866459427306e-8*A5*g + 
     1.95584655809718057e-7*A2*g3 - 
     4.47269759439071608e-6*A4*g2*x2 + 
     1.75829988748211593e-6*A*g4*x2 - 
     0.0000133314481239415102*A3*g3*x4 + 
     9.71399147418687179e-7*g5*x4 - 
     0.0000103064498801381517*A2*g4*x6 - 
     2.82142523293179157e-6*A*g5*x8 - 
     2.4892365507720446e-7*g6*x10)*xbar2 + 
  eps10*(-1.05683802773749864e-9*A6 + 
     5.67501373552960855e-7*A3*g2 - 
     4.8511255774108832e-8*g4 - 
     3.24660642120959581e-6*A5*g*x2 + 
     9.71126169538867952e-6*A2*g3*x2 - 
     0.0000131832441790279092*A4*g2*x4 + 
     0.0000108846610427711618*A*g4*x4 - 
     0.0000136365860158849577*A3*g3*x6 + 
     2.33168885512635513e-6*g5*x6 - 
     5.4993290386188865e-6*A2*g4*x8 - 
     9.46094479080590192e-7*A*g5*x10 - 
     5.8302302889011994e-8*g6*x12)*xbar2 + 
  eps13*(6.86627585651083939e-9*A6*g - 
     4.47785160224899766e-8*A3*g3 + 
     2.19249275444418889e-9*g5 + 
     7.19946098097358602e-7*A5*g2*x2 - 
     7.80379784965903039e-7*A2*g4*x2 + 
     3.37142842641135708e-6*A4*g3*x4 - 
     1.06398186364605041e-6*A*g5*x4 + 
     4.18165456228327982e-6*A3*g4*x6 - 
     2.76351067919865578e-7*g6*x6 + 
     2.00589567077445504e-6*A2*g5*x8 + 
     4.04753308555164946e-7*A*g6*x10 + 
     2.88571475583667131e-8*g7*x12)*xbar2 + 
  eps12*(2.67650730613693577e-11*A7 - 
     8.46192910475220622e-8*A4*g2 + 
     3.25142589196534057e-8*A*g4 + 
     3.83704087407791111e-7*A6*g*x2 - 
     2.57283359783619147e-6*A3*g3*x2 + 
     1.27951218977907431e-7*g5*x2 + 
     2.41765559329216737e-6*A5*g2*x4 - 
     5.44480881814382923e-6*A2*g4*x4 + 
     3.82233569685344377e-6*A4*g3*x6 - 
     2.81139544164632672e-6*A*g5*x6 + 
     2.42710273474001612e-6*A3*g4*x8 - 
     3.92027350262991887e-7*g6*x8 + 
     7.21984500196305752e-7*A2*g5*x10 + 
     1.007566064009769e-7*A*g6*x12 + 
     5.32759708629371695e-9*g7*x14)*xbar2 + 
  eps15*(-6.94677964495491896e-10*A7*g + 
     8.85485037384606633e-9*A4*g3 - 
     1.89784940868103996e-9*A*g5 - 
     1.08873720111587578e-7*A6*g2*x2 + 
     2.58200627219967634e-7*A3*g4*x2 - 
     8.57415659878293831e-9*g6*x2 - 
     7.52178044272582197e-7*A5*g3*x4 + 
     6.39174172204870162e-7*A2*g5*x4 - 
     1.38311030669262085e-6*A4*g4*x6 + 
     3.89805821462228289e-7*A*g6*x6 - 
     1.02272071613530239e-6*A3*g5*x8 + 
     6.35874554600849527e-8*g7*x8 - 
     3.51191445940869782e-7*A2*g6*x10 - 
     5.59975947545884819e-8*A*g7*x12 - 
     3.35001083013772154e-9*g8*x14)*xbar2 + 
  eps14*(-6.77936059264516573e-13*A8 + 
     1.18453251754498057e-8*A5*g2 - 
     1.26192122113177278e-8*A2*g4 - 
     4.44292175799593582e-8*A7*g*x2 + 
     5.78235471803035281e-7*A4*g3*x2 - 
     1.25465164813262727e-7*A*g5*x2 - 
     4.11093596933471078e-7*A6*g2*x4 + 
     2.00802343589623813e-6*A3*g4*x4 - 
     8.38456228452171631e-8*g6*x4 - 
     9.37962675222683393e-7*A5*g3*x6 + 
     1.84660973293660698e-6*A2*g5*x6 - 
     8.68952732620502728e-7*A4*g4*x8 + 
     5.95974150882540242e-7*A*g6*x8 - 
     3.93789587968658131e-7*A3*g5*x10 + 
     6.11861559616332661e-8*g7*x10 - 
     9.26911580977221589e-8*A2*g6*x12 - 
     1.08851336477984649e-8*A*g7*x14 - 
     5.04016698893419468e-10*g8*x16)*xbar2 + 
  eps17*(7.03519796756268115e-11*A8*g - 
     1.58412622695254907e-9*A5*g3 + 
     9.21824723042734146e-10*A2*g5 + 
     1.57013176618403867e-8*A7*g2*x2 - 
     7.07877152349972815e-8*A4*g4*x2 + 
     1.01145514044440416e-8*A*g6*x2 + 
     1.52755677874009072e-7*A6*g3*x4 - 
     2.78303968964189299e-7*A3*g5*x4 + 
     7.90216106829461597e-9*g7*x4 + 
     3.94839847004885584e-7*A5*g4*x6 - 
     2.95546266642869418e-7*A2*g6*x6 + 
     4.1812888733216445e-7*A4*g5*x8 - 
     1.09749260429676339e-7*A*g7*x8 + 
     2.15692160440115788e-7*A3*g6*x10 - 
     1.28547064754435117e-8*g8*x10 + 
     5.73688513495873601e-8*A2*g7*x12 + 
     7.55383153004710777e-9*A*g8*x14 + 
     3.89293296941875901e-10*g9*x16)*xbar2 + 
  eps16*(1.71721241125556891e-14*A9 - 
     1.58463391176416606e-9*A6*g2 + 
     3.70687203668986364e-9*A3*g4 - 
     1.21950914958299276e-10*g6 + 
     5.06426546628202339e-9*A8*g*x2 - 
     1.15919331839795365e-7*A5*g3*x2 + 
     6.813324046201634e-8*A2*g5*x2 + 
     6.59264102615256734e-8*A7*g2*x4 - 
     6.0783143535697607e-7*A4*g4*x4 + 
     1.08734552181364072e-7*A*g6*x4 + 
     2.08077893379438207e-7*A6*g3*x6 - 
     8.7376194571684116e-7*A3*g5*x6 + 
     3.31435423816449871e-8*g7*x6 + 
     2.67286143174399604e-7*A5*g4*x8 - 
     4.84990273878282454e-7*A2*g6*x8 + 
     1.71677767909550515e-7*A4*g5*x10 - 
     1.12268658721773254e-7*A*g7*x10 + 
     6.02176056859808662e-8*A3*g6*x12 - 
     9.09453722352822717e-9*g8*x12 + 
     1.17208819972660499e-8*A2*g7*x14 + 
     1.18834173730462595e-9*A*g8*x16 + 
     4.8940576382579539e-11*g9*x18)*xbar2 + 
  eps18*(-4.34973739711612375e-16*A10 + 
     2.04866596742209561e-10*A7*g2 - 
     9.13337973503563032e-10*A4*g4 + 
     1.29494994082815314e-10*A*g6 - 
     5.70128780114804572e-10*A9*g*x2 + 
     2.13523668994309077e-8*A6*g3*x2 - 
     2.7041278749459319e-8*A3*g5*x2 + 
     6.61136770529593115e-10*g7*x2 - 
     1.00900226220693725e-8*A8*g2*x4 + 
     1.59771473522731497e-7*A5*g4*x4 - 
     7.62149977963186539e-8*A2*g6*x4 - 
     4.26288251723329756e-8*A7*g3*x6 + 
     3.32905368200259132e-7*A4*g5*x6 - 
     5.34789893441100738e-8*A*g7*x6 - 
     7.31666710191171495e-8*A6*g4*x8 + 
     2.80197106079331506e-7*A3*g6*x8 - 
     9.98659790379859243e-9*g8*x8 - 
     6.35106992331774466e-8*A5*g5*x10 + 
     1.08995209478400767e-7*A2*g7*x10 - 
     3.09539659674895079e-8*A4*g6*x12 + 
     1.95483783519714526e-8*A*g8*x12 - 
     8.83724740598401241e-9*A3*g7*x14 + 
     1.30582050443893102e-9*g9*x14 - 
     1.46593717511110234e-9*A2*g8*x16 - 
     1.30772635674859038e-10*A*g9*x18 - 
     4.84955398928857724e-12*g10*x20)*xbar2 + 
  0.00833333333333333333*g*xbar4 - 
  0.0000462962962962962963*eps3*g2*xbar4 + 
  eps2*(-0.000396825396825396825*A*g - 
     0.000694444444444444444*g2*x2)*xbar4 + 
  eps5*(9.11896745230078563e-6*A*g2 + 
     0.0000308641975308641975*g3*x2)*xbar4 + 
  eps4*(0.0000198412698412698413*A2*g + 
     0.000195105820105820106*A*g2*x2 + 
     0.0000617283950617283951*g3*x4)*xbar4 + 
  eps7*(-1.31581381581381581e-6*A2*g2 - 
     0.0000151318588818588819*A*g3*x2 - 
     6.8455207344096233e-6*g4*x4)*xbar4 + 
  eps6*(-9.01875901875901876e-7*A3*g + 
     9.90714532381199048e-7*g3 - 
     0.0000389059243225909893*A2*g2*x2 - 
     0.0000351397573619795842*A*g3*x4 - 
     5.9477880658436214e-6*g4*x6)*xbar4 + 
  eps9*(1.71045640622360199e-7*A3*g2 - 
     3.60906857706966639e-8*g4 + 
     4.53245406122390249e-6*A2*g3*x2 + 
     5.38783061931210079e-6*A*g4*x4 + 
     1.17492514772607365e-6*g5*x6)*xbar4 + 
  eps8*(3.77616945077262538e-8*A4*g - 
     3.91505723846993688e-7*A*g3 + 
     6.55938527962337486e-6*A3*g2*x2 - 
     1.61985166325444103e-6*g4*x2 + 
     0.0000121547079219036891*A2*g3*x4 + 
     5.20508405346368309e-6*A*g4*x6 + 
     6.02301130368259998e-7*g5*x8)*xbar4 + 
  eps11*(-2.12135350797297057e-8*A4*g2 + 
     2.14460056215349951e-8*A*g4 - 
     1.06401470496877178e-6*A3*g3*x2 + 
     9.9419658966568008e-8*g5*x2 - 
     2.4228308825712602e-6*A2*g4*x4 - 
     1.28380796826126347e-6*A*g5*x6 - 
     1.80516340332649186e-7*g6*x8)*xbar4 + 
  eps10*(-1.48202033122668043e-9*A5*g + 
     9.77137892841674354e-8*A2*g3 - 
     9.98537198520664129e-7*A4*g2*x2 + 
     1.12096864298613054e-6*A*g4*x2 - 
     3.25929867376075489e-6*A3*g3*x4 + 
     6.52088831782005348e-7*g5*x4 - 
     2.59007734102806854e-6*A2*g4*x6 - 
     7.14333704061713321e-7*A*g5*x8 - 
     6.28878290312510992e-8*g6*x10)*xbar4 + 
  eps13*(2.55551047231023315e-9*A5*g2 - 
     7.48454109323006102e-9*A2*g4 + 
     2.14869723911233424e-7*A4*g3*x2 - 
     8.87037184673700903e-8*A*g5*x2 + 
     8.1367411096167446e-7*A3*g4*x4 - 
     6.24554324051377381e-8*g6*x4 + 
     7.73534185148061632e-7*A2*g5*x6 + 
     2.53114332805174734e-7*A*g6*x8 + 
     2.60907174059342559e-8*g7*x10)*xbar4 + 
  eps12*(5.52620037914155561e-11*A6*g - 
     1.96395897468419557e-8*A3*g3 + 
     1.73105497543500998e-9*g5 + 
     1.41930118072774209e-7*A5*g2*x2 - 
     4.4751871911848506e-7*A2*g4*x2 + 
     7.4329679752095632e-7*A4*g3*x4 - 
     6.48579919839268283e-7*A*g5*x4 + 
     9.56849686940199225e-7*A3*g4*x6 - 
     1.72592309647809413e-7*g6*x6 + 
     4.6549037372399414e-7*A2*g5*x8 + 
     9.4234108977460504e-8*A*g6*x10 + 
     6.6997976279157566e-9*g7*x12)*xbar4 + 
  eps15*(-3.01110179246578381e-10*A6*g2 + 
     1.99854473307210245e-9*A3*g4 - 
     1.0075222178954846e-10*g6 - 
     3.91236879782746971e-8*A5*g3*x2 + 
     4.42468326545839399e-8*A2*g5*x2 - 
     2.26449722207185509e-7*A4*g4*x4 + 
     7.48610321580336637e-8*A*g6*x4 - 
     3.38794481457344831e-7*A3*g5*x6 + 
     2.34467193453680488e-8*g7*x6 - 
     1.91586076465687549e-7*A2*g6*x8 - 
     4.4705147415174641e-8*A*g7*x10 - 
     3.62790374951045814e-9*g8*x12)*xbar4 + 
  eps14*(-1.97753534590218582e-12*A7*g + 
     3.46651613447685113e-9*A4*g3 - 
     1.3675698718070872e-9*A*g5 - 
     1.92080361104674656e-8*A6*g2*x2 + 
     1.34714593349386061e-7*A3*g4*x2 - 
     7.0165116069938331e-9*g6*x2 - 
     1.51234778678998732e-7*A5*g3*x4 + 
     3.57677410764887609e-7*A2*g5*x4 - 
     2.9119323970204683e-7*A4*g4*x6 + 
     2.24757818721415644e-7*A*g6*x6 - 
     2.19654624683123427e-7*A3*g5*x8 + 
     3.71577620957842484e-8*g7*x8 - 
     7.60245440599503551e-8*A2*g6*x10 - 
     1.21363875909823901e-8*A*g7*x12 - 
     7.23898306636066601e-10*g8*x14)*xbar4 + 
  eps17*(3.48460743277465292e-11*A7*g2 - 
     4.51506468378503526e-10*A4*g4 + 
     9.93046484625324211e-11*A*g6 + 
     6.6025042810186813e-9*A6*g3*x2 - 
     1.62520631488663842e-8*A3*g5*x2 + 
     5.61230122018474251e-10*g7*x2 + 
     5.51380920101008308e-8*A5*g4*x4 - 
     4.88479275078761747e-8*A2*g6*x4 + 
     1.20320332856371923e-7*A4*g5*x6 - 
     3.5365653527819202e-8*A*g7*x6 + 
     1.03628614951869648e-7*A3*g6*x8 - 
     6.71263413921269682e-9*g8*x8 + 
     4.07776601703241782e-8*A2*g7*x10 + 
     7.34880420888892836e-9*A*g8*x12 + 
     4.91163816649064884e-10*g9*x14)*xbar4 + 
  eps16*(6.84233044511131468e-14*A8*g - 
     5.60464705059266925e-10*A5*g3 + 
     6.1113506912043867e-10*A2*g5 + 
     2.50582201503812155e-9*A7*g2*x2 - 
     3.39024845059116986e-8*A4*g4*x2 + 
     7.66141086125169516e-9*A*g6*x2 + 
     2.82533097805425257e-8*A6*g3*x4 - 
     1.44153074493338505e-7*A3*g5*x4 + 
     6.29165697711773721e-9*g7*x4 + 
     7.70955531949116842e-8*A5*g4*x6 - 
     1.5856345215569678e-7*A2*g6*x6 + 
     8.37319173204484218e-8*A4*g5*x8 - 
     5.99155536147365961e-8*A*g7*x8 + 
     4.37139891312553985e-8*A3*g6*x10 - 
     7.07392441584795305e-9*g8*x10 + 
     1.16805756794796047e-8*A2*g7*x12 + 
     1.53807088851897092e-9*A*g8*x14 + 
     7.90314013633620188e-11*g9*x16)*xbar4 - 
  0.0000154320987654320988*eps2*g2*xbar6 + 
  3.56125356125356125e-7*eps5*g3*xbar6 + 
  eps4*(1.90396023729357063e-6*A*g2 + 
     7.71604938271604938e-6*g3*x2)*xbar6 + 
  eps7*(-1.06760523427190094e-7*A*g3 - 
     5.83649889205444761e-7*g4*x2)*xbar6 + 
  eps6*(-1.58222876476844731e-7*A2*g2 - 
     3.0990100434544879e-6*A*g3*x2 - 
     1.45170544476100032e-6*g4*x4)*xbar6 + 
  eps9*(2.10474956623416007e-8*A2*g3 + 
     3.52066889376257568e-7*A*g4*x2 + 
     2.15683591284989252e-7*g5*x4)*xbar6 + 
  eps8*(1.0639753805538638e-8*A3*g2 - 
     1.44647796358943781e-8*g4 + 
     7.89019059521705024e-7*A2*g3*x2 + 
     9.93278626380478232e-7*A*g4*x4 + 
     2.19830466744046991e-7*g5*x6)*xbar6 + 
  eps11*(-3.48009271425128996e-9*A3*g3 + 
     7.74456172615070677e-10*g5 - 
     1.24759056081950737e-7*A2*g4*x2 - 
     1.93124743183608916e-7*A*g5*x4 - 
     5.26262283781649553e-8*g6*x6)*xbar6 + 
  eps10*(-6.21784885258793341e-10*A4*g2 + 
     7.35917308458240036e-9*A*g4 - 
     1.61082849737015107e-7*A3*g3*x2 + 
     4.25042008023580282e-8*g5*x2 - 
     3.97181909847740069e-7*A2*g4*x4 - 
     2.15693489113968417e-7*A*g5*x6 - 
     3.05361793587726322e-8*g6*x8)*xbar6 + 
  eps13*(5.22929181665348026e-10*A4*g3 - 
     5.49761548927799316e-10*A*g5 + 
     3.37795673591345898e-8*A3*g4*x2 - 
     3.32362369023656752e-9*g6*x2 + 
     9.70864128827426103e-8*A2*g5*x4 + 
     6.29082935052959515e-8*A*g6*x6 + 
     1.05359214957493409e-8*g7*x8)*xbar6 + 
  eps12*(3.28023733515722384e-11*A5*g2 - 
     2.2483490443839068e-9*A2*g4 + 
     2.87554439944054822e-8*A4*g3*x2 - 
     3.41643318587639607e-8*A*g5*x2 + 
     1.20413081223750724e-7*A3*g4*x4 - 
     2.54382194661358481e-8*g6*x4 + 
     1.18403247344882478e-7*A2*g5*x6 + 
     3.92485363936068314e-8*A*g6*x8 + 
     4.05810532585570662e-9*g7*x10)*xbar6 + 
  eps15*(-7.38610165433134699e-11*A5*g3 + 
     2.23185618064230175e-10*A2*g5 - 
     7.72550467360774725e-9*A4*g4*x2 + 
     3.33675225731002428e-9*A*g6*x2 - 
     3.60024022499056884e-8*A3*g5*x4 + 
     2.89391686340197044e-9*g7*x4 - 
     4.11034234008140627e-8*A2*g6*x6 - 
     1.58061594311664227e-8*A*g7*x8 - 
     1.88044966020543737e-9*g8*x10)*xbar6 + 
  eps14*(-1.59924972891624396e-12*A6*g2 + 
     5.34559467656326695e-10*A3*g4 - 
     4.89531412255654985e-11*g6 - 
     4.68743656687813986e-9*A5*g3*x2 + 
     1.55203340852120435e-8*A2*g5*x2 - 
     3.05848967636635251e-8*A4*g4*x4 + 
     2.80191583068273077e-8*A*g6*x4 - 
     4.77391188802852923e-8*A3*g5*x6 + 
     9.0249644584421326e-9*g7*x6 - 
     2.7500470429085428e-8*A2*g6*x8 - 
     6.46467617732357999e-9*A*g7*x10 - 
     5.25206836466407194e-10*g8*x12)*xbar6 + 
  eps16*(7.32043787188737753e-14*A7*g2 - 
     1.08932623361419343e-10*A4*g4 + 
     4.43882953795228996e-11*A*g6 + 
     7.1553877265847084e-10*A6*g3*x2 - 
     5.23629960443907472e-9*A3*g5*x2 + 
     2.84608830720512483e-10*g7*x2 + 
     6.85430762519816909e-9*A5*g4*x4 - 
     1.69359418456327738e-8*A2*g6*x4 + 
     1.57308771746978335e-8*A4*g5*x6 - 
     1.26738239683828291e-8*A*g7*x6 + 
     1.38726146998630169e-8*A3*g6*x8 - 
     2.44574523622132431e-9*g8*x8 + 
     5.52081375700205184e-9*A2*g7*x10 + 
     9.99298373572599506e-10*A*g8*x12 + 
     6.67917519196695508e-11*g9*x14)*xbar6 + 
  5.93542260208926876e-8*eps4*g3*xbar8 - 
  3.12288574815807931e-9*eps7*g4*xbar8 + 
  eps6*(-1.14340392118169896e-8*A*g3 - 
     9.02678854067742957e-8*g4*x2)*xbar8 + 
  eps9*(1.26121885620031857e-9*A*g4 + 
     1.00859349622512295e-8*g5*x2)*xbar8 + 
  eps8*(1.32727772394750297e-9*A2*g3 + 
     4.65033697944917988e-8*A*g4*x2 + 
     2.99054295797669073e-8*g5*x4)*xbar8 + 
  eps11*(-3.15709843216944468e-10*A2*g4 - 
     7.21099301568180965e-9*A*g5*x2 - 
     5.69746824484251863e-9*g6*x4)*xbar8 + 
  eps10*(-1.18235613578975095e-10*A3*g3 + 
     2.04522364126337295e-10*g5 - 
     1.4372001684607648e-8*A2*g4*x2 - 
     2.38545902650207871e-8*A*g5*x4 - 
     6.6442647298050802e-9*g6*x6)*xbar8 + 
  eps13*(6.34254881618462429e-11*A3*g4 - 
     1.4977795563804726e-11*g6 + 
     2.95036268409924151e-9*A2*g5*x2 + 
     5.72733871097688746e-9*A*g6*x4 + 
     1.89780374932858316e-9*g7*x6)*xbar8 + 
  eps12*(8.85933436332280376e-12*A4*g3 - 
     1.2695043367275619e-10*A*g5 + 
     3.44553148081436095e-9*A3*g4*x2 - 
     9.66117808074637814e-10*g6*x2 + 
     1.08393242236143663e-8*A2*g5*x4 + 
     7.24181767567549532e-9*A*g6*x6 + 
     1.22738677265426237e-9*g7*x8)*xbar8 + 
  eps15*(-1.1209244129052603e-11*A4*g4 + 
     1.23354796462055584e-11*A*g6 - 
     9.05322252904213583e-10*A3*g5*x2 + 
     9.34529456546429641e-11*g7*x2 - 
     3.18804749658072552e-9*A2*g6*x4 - 
     2.46989894878460521e-9*A*g7*x6 - 
     4.84553260391626981e-10*g8*x8)*xbar8 + 
  eps14*(-5.85591473164617337e-13*A5*g3 + 
     4.58152437519766974e-11*A2*g5 - 
     7.06061940978074562e-10*A4*g4*x2 + 
     8.8437067488213914e-10*A*g6*x2 - 
     3.6718459581734819e-9*A3*g5*x4 + 
     8.14572670487090063e-10*g7*x4 - 
     4.35865819040676537e-9*A2*g6*x6 - 
     1.70511399881374369e-9*A*g7*x8 - 
     2.04267683542374506e-10*g8*x10)*xbar8 - 
  2.95801289810004407e-10*eps6*g4*xbar10 + 
  2.94346529368315861e-11*eps9*g5*xbar10 + 
  eps8*(7.69281785172546935e-11*A*g4 + 
     1.07490632635875918e-9*g5*x2)*xbar10 + 
  eps11*(-1.49854878334381416e-11*A*g5 - 
     1.64414869918985145e-10*g6*x2)*xbar10 + 
  eps10*(-1.14623038722347948e-11*A2*g4 - 
     6.72527675714427998e-10*A*g5*x2 - 
     5.64942074025452747e-10*g6*x4)*xbar10 + 
  eps13*(4.55203920804202245e-12*A2*g5 + 
     1.35763920347428776e-10*A*g6*x2 + 
     1.33652228562929386e-10*g7*x4)*xbar10 + 
  eps12*(1.27157831390982766e-12*A3*g4 - 
     2.82877994364105943e-12*g6 + 
     2.44160830279527547e-10*A2*g5*x2 + 
     5.14076796669365287e-10*A*g6*x4 + 
     1.75139799425245342e-10*g7*x6)*xbar10 + 
  eps14*(-1.16205790093287907e-13*A4*g4 + 
     2.06949189356323779e-12*A*g6 - 
     6.72146134669773312e-11*A3*g5*x2 + 
     1.99437288401862085e-11*g7*x2 - 
     2.61681510848862049e-10*A2*g6*x4 - 
     2.10127602166714473e-10*A*g7*x6 - 
     4.18842380479881739e-11*g8*x8)*xbar10 + 
  1.69722051530330397e-12*eps8*g5*xbar12 - 
  2.90595190793452012e-13*eps11*g6*xbar12 + 
  eps10*(-5.54575148020670988e-13*A*g5 - 
     1.29008964169185665e-11*g6*x2)*xbar12 + 
  eps13*(1.78798720202615632e-13*A*g6 + 
     2.57210159823889116e-12*g7*x2)*xbar12 + 
  eps12*(1.00869657097464141e-13*A2*g5 + 
     9.47632013657176953e-12*A*g6*x2 + 
     1.00368310409322369e-11*g7*x4)*xbar12 - 
  1.06551186196798794e-14*eps10*g6*xbar14 + 
  eps12*(4.1883104771160436e-15*A*g6 + 
     1.55454784378046993e-13*g7*x2)*xbar14;
}
#endif

#ifdef p21
double Wp(void)
{
   return 0.5*A*x2 + 0.0416666666666666667*g*x4 + 
  eps*(0.0833333333333333333*A + 0.0416666666666666667*g*x2) + 
  eps3*(-0.00277777777777777778*A2 - 
     0.0111111111111111111*A*g*x2 - 
     0.00208333333333333333*g2*x4) + 
  eps2*(0.00416666666666666667*g - 
     0.0416666666666666667*A2*x2 - 
     0.0138888888888888889*A*g*x4 - 
     0.00115740740740740741*g2*x6) + 
  eps5*(0.0001763668430335097*A3 - 
     0.0000388558201058201058*g2 + 
     0.00214947089947089947*A2*g*x2 + 
     0.00124007936507936508*A*g2*x4 + 
     0.000154320987654320988*g3*x6) + 
  eps4*(-0.000595238095238095238*A*g + 
     0.00416666666666666667*A3*x2 - 
     0.000868055555555555556*g2*x2 + 
     0.00347222222222222222*A2*g*x4 + 
     0.000810185185185185185*A*g2*x6 + 
     0.0000578703703703703704*g3*x8) + 
  eps7*(-0.0000132275132275132275*A4 + 
     0.000013452982202982203*A*g2 - 
     0.000353835978835978836*A3*g*x2 + 
     0.0000292107583774250441*g3*x2 - 
     0.000438161375661375661*A2*g2*x4 - 
     0.000141369047619047619*A*g3*x6 - 
     0.0000131815843621399177*g4*x8) + 
  eps6*(0.0000793650793650793651*A2*g - 
     0.000421626984126984127*A4*x2 + 
     0.000412533068783068783*A*g2*x2 - 
     0.000710978835978835979*A3*g*x4 + 
     0.00012359457671957672*g3*x4 - 
     0.000332065696649029982*A2*g2*x6 - 
     0.0000592482363315696649*A*g3*x8 - 
     3.61689814814814815e-6*g4*x10) + 
  eps9*(1.06888995777884667e-6*A5 - 
     3.09484386865339246e-6*A2*g2 + 
     0.000052889176153065042*A4*g*x2 - 
     0.0000196739667225778337*A*g3*x2 + 
     0.000118621733205066538*A3*g2*x4 - 
     8.12834124466068911e-6*g4*x4 + 
     0.0000723776288012399124*A2*g3*x6 + 
     0.0000162595142340512711*A*g4*x8 + 
     1.2123306755829904e-6*g5*x10) + 
  eps8*(-0.0000100208433541766875*A3*g + 
     8.50711788211788212e-7*g3 + 
     0.0000427138447971781305*A5*x2 - 
     0.000120331539602372936*A2*g2*x2 + 
     0.000127911890064667842*A4*g*x4 - 
     0.000098836830607663941*A*g3*x4 + 
     0.000102804110327258475*A3*g2*x6 - 
     0.0000165018585880854399*g4*x6 + 
     0.0000336428938859494415*A2*g3*x8 + 
     4.8512364050558495e-6*A*g4*x10 + 
     2.56755115454961134e-7*g5*x12) + 
  eps11*(-9.01835117002665504e-8*A6 + 
     5.87400058299529199e-7*A3*g2 - 
     2.81868399275952575e-8*g4 - 
     7.41416841780598394e-6*A5*g*x2 + 
     7.67116473755031956e-6*A2*g3*x2 - 
     0.000027147462601331649*A4*g2*x4 + 
     8.12031936990601012e-6*A*g4*x4 - 
     0.0000272310450812986086*A3*g3*x6 + 
     1.70667153812408442e-6*g5*x6 - 
     0.0000108933015093453806*A2*g4*x8 - 
     1.87850642976993286e-6*A*g5*x10 - 
     1.16690477054095881e-7*g6*x12) + 
  eps10*(1.21747740795359843e-6*A4*g - 
     4.62417873132158846e-7*A*g3 - 
     4.32775172358505692e-6*A6*x2 + 
     0.0000276277014248244407*A3*g2*x2 - 
     1.30445706075046353e-6*g4*x2 - 
     0.0000210333326652771097*A5*g*x4 + 
     0.0000447391253752860896*A2*g3*x4 - 
     0.0000265668910778864483*A4*g2*x6 + 
     0.0000184769777868736202*A*g4*x6 - 
     0.0000139376709110505407*A3*g3*x8 + 
     2.13520310814871e-6*g5*x8 - 
     3.5181249916492972e-6*A2*g4*x10 - 
     4.25407416871537242e-7*A*g5*x12 - 
     1.98147969535893919e-8*g6*x14) + 
  eps13*(7.83069566138349207e-9*A7 - 
     9.93094869534334209e-8*A4*g2 + 
     2.08755249185163841e-8*A*g4 + 
     9.92791119692574719e-7*A6*g*x2 - 
     2.26246788359770127e-6*A3*g3*x2 + 
     7.19774046753493046e-8*g5*x2 + 
     5.52538741816188906e-6*A5*g2*x4 - 
     4.47883727161149936e-6*A2*g4*x4 + 
     8.38601213983571788e-6*A4*g3*x6 - 
     2.25348627386308778e-6*A*g5*x6 + 
     5.24445855604457162e-6*A3*g4*x8 - 
     3.11392974798759566e-7*g6*x8 + 
     1.55465050346795001e-6*A2*g5*x10 + 
     2.17600880397466046e-7*A*g6*x12 + 
     1.15841884836628278e-8*g7*x14) + 
  eps12*(-1.43889032777921667e-7*A5*g + 
     1.51283642180000723e-7*A2*g3 + 
     4.38492191964414187e-7*A7*x2 - 
     5.47671197834474951e-6*A4*g2*x2 + 
     1.1365151365172641e-6*A*g4*x2 + 
     3.23789133106262736e-6*A6*g*x4 - 
     0.0000150481673660823793*A3*g3*x4 + 
     5.97324614725086198e-7*g5*x4 + 
     6.03932684613625972e-6*A5*g2*x6 - 
     0.0000113106765525436987*A2*g4*x6 + 
     4.69528859165240338e-6*A4*g3*x8 - 
     3.0694501391598228e-6*A*g5*x8 + 
     1.82557370238215146e-6*A3*g4*x10 - 
     2.71046144994230449e-7*g6*x10 + 
     3.7535031778135559e-7*A2*g5*x12 + 
     3.90681314457195373e-8*A*g6*x14 + 
     1.62260932077515154e-9*g7*x16) + 
  eps15*(-6.94206524686864971e-10*A8 + 
     1.55258266251201437e-8*A5*g2 - 
     8.87063997906019346e-9*A2*g4 - 
     1.28444091425696105e-7*A7*g*x2 + 
     5.59355511978255916e-7*A4*g3*x2 - 
     7.69591961687451275e-8*A*g5*x2 - 
     1.03084425773136674e-6*A6*g2*x4 + 
     1.80099658500984157e-6*A3*g4*x4 - 
     4.89852640150590245e-8*g6*x4 - 
     2.23744987275327073e-6*A5*g3*x6 + 
     1.60416803829389571e-6*A2*g5*x6 - 
     2.02887475090349778e-6*A4*g4*x8 + 
     5.10536772376168298e-7*A*g6*x8 - 
     9.11746562790846727e-7*A3*g5*x10 + 
     5.21769349658492833e-8*g7*x10 - 
     2.14341780318485671e-7*A2*g6*x12 - 
     2.52490551976121104e-8*A*g7*x14 - 
     1.17600420262660865e-9*g8*x16) + 
  eps14*(1.66609565924847593e-8*A6*g - 
     3.84541066603365207e-8*A3*g3 + 
     1.23616495716322489e-9*g5 - 
     4.44285396439000936e-8*A8*x2 + 
     9.81807578832239391e-7*A5*g2*x2 - 
     5.55101746448534654e-7*A2*g4*x2 - 
     4.73967830600877338e-7*A7*g*x4 + 
     4.18284859452059839e-6*A4*g3*x4 - 
     7.15343253702736788e-7*A*g5*x4 - 
     1.24663165145441196e-6*A6*g2*x6 + 
     5.00514675879205854e-6*A3*g4*x6 - 
     1.81402700349001079e-7*g6*x6 - 
     1.36226318220021373e-6*A5*g3*x8 + 
     2.36606032230627314e-6*A2*g5*x8 - 
     7.58172593612770117e-7*A4*g4*x10 + 
     4.75471890972483691e-7*A*g6*x10 - 
     2.34027522244261325e-7*A3*g5*x12 + 
     3.3963539821117207e-8*g7*x12 - 
     4.06050820222736176e-8*A2*g6*x14 - 
     3.70938742929349711e-9*A*g7*x16 - 
     1.38898528337180163e-10*g8*x18) + 
  eps17*(6.25217958800249802e-11*A9 - 
     2.29312206278746533e-9*A6*g2 + 
     2.8310089717477044e-9*A3*g4 - 
     6.71998649148490015e-11*g6 + 
     1.61783182535963035e-8*A8*g*x2 - 
     1.222198282975496e-7*A5*g3*x2 + 
     4.51903487294323094e-8*A2*g5*x2 + 
     1.79787422789127715e-7*A7*g2*x4 - 
     5.89386352242391962e-7*A4*g4*x4 + 
     6.83924293854497039e-8*A*g6*x4 + 
     5.35385253592035249e-7*A6*g3*x6 - 
     8.16161936426993263e-7*A3*g5*x6 + 
     2.03110694856709656e-8*g7*x6 + 
     6.69429955495357485e-7*A5*g4*x8 - 
     4.44812062546498445e-7*A2*g6*x8 + 
     4.24544759374608395e-7*A4*g5*x10 - 
     1.02125278182278717e-7*A*g7*x10 + 
     1.48190757087105866e-7*A3*g6*x12 - 
     8.25465653164429909e-9*g8*x12 + 
     2.8842218900714868e-8*A2*g7*x14 + 
     2.93316966296752154e-9*A*g8*x16 + 
     1.21426224678902097e-10*g9*x18) + 
  eps16*(-1.89909954985575877e-9*A7*g + 
     8.35603474047208798e-9*A4*g3 - 
     1.15966243496214952e-9*A*g5 + 
     4.50155213123768602e-9*A9*x2 - 
     1.63520154608933337e-7*A6*g2*x2 + 
     2.00125773929144853e-7*A3*g4*x2 - 
     4.71643935891082883e-9*g6*x2 + 
     6.66827009985439445e-8*A8*g*x4 - 
     1.01569722853466271e-6*A5*g3*x4 + 
     4.653753986331283e-7*A2*g5*x4 + 
     2.38609112997144637e-7*A7*g2*x6 - 
     1.78931879078472604e-6*A4*g4*x6 + 
     2.75782412054904595e-7*A*g6*x6 + 
     3.5257503626825941e-7*A6*g3*x8 - 
     1.29719583644083582e-6*A3*g5*x8 + 
     4.43904638337799842e-8*g7*x8 + 
     2.67563783428073661e-7*A5*g4*x10 - 
     4.41739629456479988e-7*A2*g6*x10 + 
     1.15544405881940575e-7*A4*g5*x12 - 
     7.03094817586759951e-8*A*g7*x12 + 
     2.95627516533174602e-8*A3*g6*x14 - 
     4.21593686904484474e-9*g8*x14 + 
     4.43746780874914946e-9*A2*g7*x16 + 
     3.61167459558351774e-10*A*g8*x18 + 
     1.23066706066192904e-11*g9*x20) + 
  eps19*(-5.70128780114804572e-12*A10 + 
     3.24325759393455769e-10*A7*g2 - 
     7.52920392642037898e-10*A4*g4 + 
     7.63432039813829238e-11*A*g6 - 
     1.99446765051272661e-9*A9*g*x2 + 
     2.43560018179573397e-8*A6*g3*x2 - 
     1.92651473964731419e-8*A3*g5*x2 + 
     3.57664504054283011e-10*g7*x2 - 
     2.97138844105769473e-8*A8*g2*x4 + 
     1.66367899286352586e-7*A5*g4*x4 - 
     5.12763843043703477e-8*A2*g6*x4 - 
     1.17558487781038256e-7*A7*g3*x6 + 
     3.32274083849900958e-7*A4*g5*x6 - 
     3.49339293457975036e-8*A*g7*x6 - 
     1.95421595481198395e-7*A6*g4*x8 + 
     2.73546099832218964e-7*A3*g6*x8 - 
     6.42119893976624269e-9*g8*x8 - 
     1.66845932629322826e-7*A5*g5*x10 + 
     1.05196992302604677e-7*A2*g7*x10 - 
     8.06653736383214643e-8*A4*g6*x12 + 
     1.87723844343482559e-8*A*g8*x12 - 
     2.29644918467110207e-8*A3*g7*x14 + 
     1.25288025697957571e-9*g9*x14 - 
     3.81165485194947533e-9*A2*g8*x16 - 
     3.41033212304414905e-10*A*g9*x18 - 
     1.27053709821831841e-11*g10*x20) + 
  eps18*(2.13798292543051714e-10*A8*g - 
     1.62899940163818617e-9*A5*g3 + 
     6.06739124374671626e-10*A2*g5 - 
     4.56102589118103946e-10*A10*x2 + 
     2.5741194154734252e-8*A7*g2*x2 - 
     5.93202934378594688e-8*A4*g4*x2 + 
     5.97796132442781859e-9*A*g6*x2 - 
     9.086017175115798e-9*A9*g*x4 + 
     2.22788546277779156e-7*A6*g3*x4 - 
     2.17818061292066124e-7*A3*g5*x4 + 
     4.46060201054250811e-9*g7*x4 - 
     4.29736286745591606e-8*A8*g2*x6 + 
     5.48218484132244335e-7*A5*g4*x6 - 
     2.23798601959230444e-7*A2*g6*x6 - 
     8.3334504765293729e-8*A7*g3*x8 + 
     5.66588387939462102e-7*A4*g5*x8 - 
     8.17078651256326395e-8*A*g7*x8 - 
     8.32572408053676287e-8*A6*g4*x10 + 
     2.88769211893932833e-7*A3*g6*x10 - 
     9.49367158787967084e-9*g8*x10 - 
     4.80270155903927102e-8*A5*g5*x12 + 
     7.64234973061525259e-8*A2*g7*x12 - 
     1.69136821548003748e-8*A4*g6*x14 + 
     1.00575293092506873e-8*A*g8*x14 - 
     3.69466622059472975e-9*A3*g7*x16 + 
     5.19597646877020836e-10*g9*x16 - 
     4.88723854749631574e-10*A2*g8*x18 - 
     3.58645537045585288e-11*A*g9*x20 - 
     1.12084057456710382e-12*g10*x22) + 
  eps20*(-2.38285086177214561e-11*A9*g + 
     2.93087835503767857e-10*A6*g3 - 
     2.33284850513311582e-10*A3*g5 + 
     4.35358687387975124e-12*g7 + 
     4.62128541799995915e-11*A11*x2 - 
     3.87512747715920683e-9*A8*g2*x2 + 
     1.52963831343981389e-8*A5*g4*x2 - 
     4.10201649274809254e-9*A2*g6*x2 + 
     1.2058131859727143e-9*A10*g*x4 - 
     4.51251014708823542e-8*A7*g3*x4 + 
     8.20524658045556169e-8*A4*g5*x4 - 
     7.11455083461241557e-9*A*g7*x4 + 
     7.36094104464716057e-9*A9*g2*x6 - 
     1.49255884116928141e-7*A6*g4*x6 + 
     1.28707565844365563e-7*A3*g6*x6 - 
     2.42078453530071715e-9*g8*x6 + 
     1.82893288628610935e-8*A8*g3*x8 - 
     2.09524543137285467e-7*A5*g5*x8 + 
     7.93810679543179244e-8*A2*g7*x8 + 
     2.34179153309909358e-8*A7*g4*x10 - 
     1.48969846228119514e-7*A4*g6*x10 + 
     2.05019199855671562e-8*A*g8*x10 + 
     1.74575105847696841e-8*A6*g5*x12 - 
     5.80036979689224998e-8*A3*g7*x12 + 
     1.8510046912641176e-9*g9*x12 + 
     8.09148869608194122e-9*A5*g6*x14 - 
     1.251808839252206e-8*A2*g8*x14 + 
     2.40348962003249252e-9*A4*g7*x16 - 
     1.40328230011170153e-9*A*g9*x16 + 
     4.58007384146693616e-10*A3*g8*x18 - 
     6.36787892934133022e-11*g10*x18 + 
     5.41571641768509377e-11*A2*g9*x20 + 
     3.61823810155023661e-12*A*g10*x22 + 
     1.04407319287969897e-13*g11*x24) + 
  0.00833333333333333333*eps*g*xbar2 + 
  0.166666666666666667*(A + 0.5*g*x2)*xbar2 + 
  eps3*(-0.000793650793650793651*A*g - 
     0.00138888888888888889*g2*x2)*xbar2 + 
  eps2*(-0.00277777777777777778*A2 - 
     0.0111111111111111111*A*g*x2 - 
     0.00208333333333333333*g2*x4)*xbar2 + 
  eps5*(0.0000727513227513227513*A2*g + 
     0.000522486772486772487*A*g2*x2 + 
     0.000162037037037037037*g3*x4)*xbar2 + 
  eps4*(0.0000661375661375661376*A3 - 
     0.0000644841269841269841*g2 + 
     0.0015873015873015873*A2*g*x2 + 
     0.00094246031746031746*A*g2*x4 + 
     0.000115740740740740741*g3*x6)*xbar2 + 
  eps7*(-6.91438191438191438e-6*A3*g + 
     1.41486599819933153e-6*g3 - 
     0.000128066378066378066*A2*g2*x2 - 
     0.000110705266955266955*A*g3*x4 - 
     0.000018647119341563786*g4*x6)*xbar2 + 
  eps6*(-1.65343915343915344e-6*A4 + 
     0.0000179623617123617124*A*g2 - 
     0.00021164021164021164*A3*g*x2 + 
     0.0000485008818342151675*g3*x2 - 
     0.000276951058201058201*A2*g2*x4 - 
     0.0000898368606701940035*A*g3*x6 - 
     8.27867798353909465e-6*g4*x8)*xbar2 + 
  eps9*(6.79829796893288957e-7*A4*g - 
     6.72419695237155555e-7*A*g3 + 
     0.0000254975770848786722*A3*g2*x2 - 
     2.25056258042369153e-6*g4*x2 + 
     0.0000441438108848823135*A2*g3*x4 + 
     0.0000185871013417309714*A*g4*x6 + 
     2.15148764772607365e-6*g5*x8)*xbar2 + 
  eps8*(4.1753513975736198e-8*A5 - 
     3.46221514376276281e-6*A2*g2 + 
     0.0000267222489444711667*A4*g*x2 - 
     0.0000281804101248545693*A*g3*x2 + 
     0.0000649475909892576559*A3*g2*x4 - 
     0.0000122030666735527847*g4*x4 + 
     0.0000403965247715247715*A2*g3*x6 + 
     9.0700810463541945e-6*A*g4*x8 + 
     6.69795953360768176e-7*g5*x10)*xbar2 + 
  eps11*(-6.80612866459427306e-8*A5*g + 
     1.95584655809718057e-7*A2*g3 - 
     4.47269759439071608e-6*A4*g2*x2 + 
     1.75829988748211593e-6*A*g4*x2 - 
     0.0000133314481239415102*A3*g3*x4 + 
     9.71399147418687179e-7*g5*x4 - 
     0.0000103064498801381517*A2*g4*x6 - 
     2.82142523293179157e-6*A*g5*x8 - 
     2.4892365507720446e-7*g6*x10)*xbar2 + 
  eps10*(-1.05683802773749864e-9*A6 + 
     5.67501373552960855e-7*A3*g2 - 
     4.8511255774108832e-8*g4 - 
     3.24660642120959581e-6*A5*g*x2 + 
     9.71126169538867952e-6*A2*g3*x2 - 
     0.0000131832441790279092*A4*g2*x4 + 
     0.0000108846610427711618*A*g4*x4 - 
     0.0000136365860158849577*A3*g3*x6 + 
     2.33168885512635513e-6*g5*x6 - 
     5.4993290386188865e-6*A2*g4*x8 - 
     9.46094479080590192e-7*A*g5*x10 - 
     5.8302302889011994e-8*g6*x12)*xbar2 + 
  eps13*(6.86627585651083939e-9*A6*g - 
     4.47785160224899766e-8*A3*g3 + 
     2.19249275444418889e-9*g5 + 
     7.19946098097358602e-7*A5*g2*x2 - 
     7.80379784965903039e-7*A2*g4*x2 + 
     3.37142842641135708e-6*A4*g3*x4 - 
     1.06398186364605041e-6*A*g5*x4 + 
     4.18165456228327982e-6*A3*g4*x6 - 
     2.76351067919865578e-7*g6*x6 + 
     2.00589567077445504e-6*A2*g5*x8 + 
     4.04753308555164946e-7*A*g6*x10 + 
     2.88571475583667131e-8*g7*x12)*xbar2 + 
  eps12*(2.67650730613693577e-11*A7 - 
     8.46192910475220622e-8*A4*g2 + 
     3.25142589196534057e-8*A*g4 + 
     3.83704087407791111e-7*A6*g*x2 - 
     2.57283359783619147e-6*A3*g3*x2 + 
     1.27951218977907431e-7*g5*x2 + 
     2.41765559329216737e-6*A5*g2*x4 - 
     5.44480881814382923e-6*A2*g4*x4 + 
     3.82233569685344377e-6*A4*g3*x6 - 
     2.81139544164632672e-6*A*g5*x6 + 
     2.42710273474001612e-6*A3*g4*x8 - 
     3.92027350262991887e-7*g6*x8 + 
     7.21984500196305752e-7*A2*g5*x10 + 
     1.007566064009769e-7*A*g6*x12 + 
     5.32759708629371695e-9*g7*x14)*xbar2 + 
  eps15*(-6.94677964495491896e-10*A7*g + 
     8.85485037384606633e-9*A4*g3 - 
     1.89784940868103996e-9*A*g5 - 
     1.08873720111587578e-7*A6*g2*x2 + 
     2.58200627219967634e-7*A3*g4*x2 - 
     8.57415659878293831e-9*g6*x2 - 
     7.52178044272582197e-7*A5*g3*x4 + 
     6.39174172204870162e-7*A2*g5*x4 - 
     1.38311030669262085e-6*A4*g4*x6 + 
     3.89805821462228289e-7*A*g6*x6 - 
     1.02272071613530239e-6*A3*g5*x8 + 
     6.35874554600849527e-8*g7*x8 - 
     3.51191445940869782e-7*A2*g6*x10 - 
     5.59975947545884819e-8*A*g7*x12 - 
     3.35001083013772154e-9*g8*x14)*xbar2 + 
  eps14*(-6.77936059264516573e-13*A8 + 
     1.18453251754498057e-8*A5*g2 - 
     1.26192122113177278e-8*A2*g4 - 
     4.44292175799593582e-8*A7*g*x2 + 
     5.78235471803035281e-7*A4*g3*x2 - 
     1.25465164813262727e-7*A*g5*x2 - 
     4.11093596933471078e-7*A6*g2*x4 + 
     2.00802343589623813e-6*A3*g4*x4 - 
     8.38456228452171631e-8*g6*x4 - 
     9.37962675222683393e-7*A5*g3*x6 + 
     1.84660973293660698e-6*A2*g5*x6 - 
     8.68952732620502728e-7*A4*g4*x8 + 
     5.95974150882540242e-7*A*g6*x8 - 
     3.93789587968658131e-7*A3*g5*x10 + 
     6.11861559616332661e-8*g7*x10 - 
     9.26911580977221589e-8*A2*g6*x12 - 
     1.08851336477984649e-8*A*g7*x14 - 
     5.04016698893419468e-10*g8*x16)*xbar2 + 
  eps17*(7.03519796756268115e-11*A8*g - 
     1.58412622695254907e-9*A5*g3 + 
     9.21824723042734146e-10*A2*g5 + 
     1.57013176618403867e-8*A7*g2*x2 - 
     7.07877152349972815e-8*A4*g4*x2 + 
     1.01145514044440416e-8*A*g6*x2 + 
     1.52755677874009072e-7*A6*g3*x4 - 
     2.78303968964189299e-7*A3*g5*x4 + 
     7.90216106829461597e-9*g7*x4 + 
     3.94839847004885584e-7*A5*g4*x6 - 
     2.95546266642869418e-7*A2*g6*x6 + 
     4.1812888733216445e-7*A4*g5*x8 - 
     1.09749260429676339e-7*A*g7*x8 + 
     2.15692160440115788e-7*A3*g6*x10 - 
     1.28547064754435117e-8*g8*x10 + 
     5.73688513495873601e-8*A2*g7*x12 + 
     7.55383153004710777e-9*A*g8*x14 + 
     3.89293296941875901e-10*g9*x16)*xbar2 + 
  eps16*(1.71721241125556891e-14*A9 - 
     1.58463391176416606e-9*A6*g2 + 
     3.70687203668986364e-9*A3*g4 - 
     1.21950914958299276e-10*g6 + 
     5.06426546628202339e-9*A8*g*x2 - 
     1.15919331839795365e-7*A5*g3*x2 + 
     6.813324046201634e-8*A2*g5*x2 + 
     6.59264102615256734e-8*A7*g2*x4 - 
     6.0783143535697607e-7*A4*g4*x4 + 
     1.08734552181364072e-7*A*g6*x4 + 
     2.08077893379438207e-7*A6*g3*x6 - 
     8.7376194571684116e-7*A3*g5*x6 + 
     3.31435423816449871e-8*g7*x6 + 
     2.67286143174399604e-7*A5*g4*x8 - 
     4.84990273878282454e-7*A2*g6*x8 + 
     1.71677767909550515e-7*A4*g5*x10 - 
     1.12268658721773254e-7*A*g7*x10 + 
     6.02176056859808662e-8*A3*g6*x12 - 
     9.09453722352822717e-9*g8*x12 + 
     1.17208819972660499e-8*A2*g7*x14 + 
     1.18834173730462595e-9*A*g8*x16 + 
     4.8940576382579539e-11*g9*x18)*xbar2 + 
  eps19*(-7.12707337587569786e-12*A9*g + 
     2.63376364359160315e-10*A6*g3 - 
     3.30780046645030994e-10*A3*g5 + 
     8.03679335161609342e-12*g7 - 
     2.18139573549146275e-9*A8*g2*x2 + 
     1.6989863583308778e-8*A5*g4*x2 - 
     6.4969385102430346e-9*A2*g6*x2 - 
     2.88250590711040757e-8*A7*g3*x4 + 
     9.81072496878526138e-8*A4*g5*x4 - 
     1.18346882869724656e-8*A*g7*x4 - 
     1.00731210992033847e-7*A6*g4*x6 + 
     1.59691202088983395e-7*A3*g6*x6 - 
     4.13548363870289057e-9*g8*x6 - 
     1.45496453255537213e-7*A5*g5*x8 + 
     1.00501516554651165e-7*A2*g7*x8 - 
     1.05051610378898918e-7*A4*g6*x10 + 
     2.62399674415998082e-8*A*g8*x10 - 
     4.12244346987175346e-8*A3*g7*x12 + 
     2.38101241880130705e-9*g9*x12 - 
     8.92371773273422321e-9*A2*g8*x14 - 
     1.00013636391153993e-9*A*g9*x16 - 
     4.52724718151082609e-11*g10*x18)*xbar2 + 
  eps18*(-4.34973739711612375e-16*A10 + 
     2.04866596742209561e-10*A7*g2 - 
     9.13337973503563032e-10*A4*g4 + 
     1.29494994082815314e-10*A*g6 - 
     5.70128780114804572e-10*A9*g*x2 + 
     2.13523668994309077e-8*A6*g3*x2 - 
     2.7041278749459319e-8*A3*g5*x2 + 
     6.61136770529593115e-10*g7*x2 - 
     1.00900226220693725e-8*A8*g2*x4 + 
     1.59771473522731497e-7*A5*g4*x4 - 
     7.62149977963186539e-8*A2*g6*x4 - 
     4.26288251723329756e-8*A7*g3*x6 + 
     3.32905368200259132e-7*A4*g5*x6 - 
     5.34789893441100738e-8*A*g7*x6 - 
     7.31666710191171495e-8*A6*g4*x8 + 
     2.80197106079331506e-7*A3*g6*x8 - 
     9.98659790379859243e-9*g8*x8 - 
     6.35106992331774466e-8*A5*g5*x10 + 
     1.08995209478400767e-7*A2*g7*x10 - 
     3.09539659674895079e-8*A4*g6*x12 + 
     1.95483783519714526e-8*A*g8*x12 - 
     8.83724740598401241e-9*A3*g7*x14 + 
     1.30582050443893102e-9*g9*x14 - 
     1.46593717511110234e-9*A2*g8*x16 - 
     1.30772635674859038e-10*A*g9*x18 - 
     4.84955398928857724e-12*g10*x20)*xbar2 + 
  0.00833333333333333333*g*xbar4 - 
  0.0000462962962962962963*eps3*g2*xbar4 + 
  eps2*(-0.000396825396825396825*A*g - 
     0.000694444444444444444*g2*x2)*xbar4 + 
  eps5*(9.11896745230078563e-6*A*g2 + 
     0.0000308641975308641975*g3*x2)*xbar4 + 
  eps4*(0.0000198412698412698413*A2*g + 
     0.000195105820105820106*A*g2*x2 + 
     0.0000617283950617283951*g3*x4)*xbar4 + 
  eps7*(-1.31581381581381581e-6*A2*g2 - 
     0.0000151318588818588819*A*g3*x2 - 
     6.8455207344096233e-6*g4*x4)*xbar4 + 
  eps6*(-9.01875901875901876e-7*A3*g + 
     9.90714532381199048e-7*g3 - 
     0.0000389059243225909893*A2*g2*x2 - 
     0.0000351397573619795842*A*g3*x4 - 
     5.9477880658436214e-6*g4*x6)*xbar4 + 
  eps9*(1.71045640622360199e-7*A3*g2 - 
     3.60906857706966639e-8*g4 + 
     4.53245406122390249e-6*A2*g3*x2 + 
     5.38783061931210079e-6*A*g4*x4 + 
     1.17492514772607365e-6*g5*x6)*xbar4 + 
  eps8*(3.77616945077262538e-8*A4*g - 
     3.91505723846993688e-7*A*g3 + 
     6.55938527962337486e-6*A3*g2*x2 - 
     1.61985166325444103e-6*g4*x2 + 
     0.0000121547079219036891*A2*g3*x4 + 
     5.20508405346368309e-6*A*g4*x6 + 
     6.02301130368259998e-7*g5*x8)*xbar4 + 
  eps11*(-2.12135350797297057e-8*A4*g2 + 
     2.14460056215349951e-8*A*g4 - 
     1.06401470496877178e-6*A3*g3*x2 + 
     9.9419658966568008e-8*g5*x2 - 
     2.4228308825712602e-6*A2*g4*x4 - 
     1.28380796826126347e-6*A*g5*x6 - 
     1.80516340332649186e-7*g6*x8)*xbar4 + 
  eps10*(-1.48202033122668043e-9*A5*g + 
     9.77137892841674354e-8*A2*g3 - 
     9.98537198520664129e-7*A4*g2*x2 + 
     1.12096864298613054e-6*A*g4*x2 - 
     3.25929867376075489e-6*A3*g3*x4 + 
     6.52088831782005348e-7*g5*x4 - 
     2.59007734102806854e-6*A2*g4*x6 - 
     7.14333704061713321e-7*A*g5*x8 - 
     6.28878290312510992e-8*g6*x10)*xbar4 + 
  eps13*(2.55551047231023315e-9*A5*g2 - 
     7.48454109323006102e-9*A2*g4 + 
     2.14869723911233424e-7*A4*g3*x2 - 
     8.87037184673700903e-8*A*g5*x2 + 
     8.1367411096167446e-7*A3*g4*x4 - 
     6.24554324051377381e-8*g6*x4 + 
     7.73534185148061632e-7*A2*g5*x6 + 
     2.53114332805174734e-7*A*g6*x8 + 
     2.60907174059342559e-8*g7*x10)*xbar4 + 
  eps12*(5.52620037914155561e-11*A6*g - 
     1.96395897468419557e-8*A3*g3 + 
     1.73105497543500998e-9*g5 + 
     1.41930118072774209e-7*A5*g2*x2 - 
     4.4751871911848506e-7*A2*g4*x2 + 
     7.4329679752095632e-7*A4*g3*x4 - 
     6.48579919839268283e-7*A*g5*x4 + 
     9.56849686940199225e-7*A3*g4*x6 - 
     1.72592309647809413e-7*g6*x6 + 
     4.6549037372399414e-7*A2*g5*x8 + 
     9.4234108977460504e-8*A*g6*x10 + 
     6.6997976279157566e-9*g7*x12)*xbar4 + 
  eps15*(-3.01110179246578381e-10*A6*g2 + 
     1.99854473307210245e-9*A3*g4 - 
     1.0075222178954846e-10*g6 - 
     3.91236879782746971e-8*A5*g3*x2 + 
     4.42468326545839399e-8*A2*g5*x2 - 
     2.26449722207185509e-7*A4*g4*x4 + 
     7.48610321580336637e-8*A*g6*x4 - 
     3.38794481457344831e-7*A3*g5*x6 + 
     2.34467193453680488e-8*g7*x6 - 
     1.91586076465687549e-7*A2*g6*x8 - 
     4.4705147415174641e-8*A*g7*x10 - 
     3.62790374951045814e-9*g8*x12)*xbar4 + 
  eps14*(-1.97753534590218582e-12*A7*g + 
     3.46651613447685113e-9*A4*g3 - 
     1.3675698718070872e-9*A*g5 - 
     1.92080361104674656e-8*A6*g2*x2 + 
     1.34714593349386061e-7*A3*g4*x2 - 
     7.0165116069938331e-9*g6*x2 - 
     1.51234778678998732e-7*A5*g3*x4 + 
     3.57677410764887609e-7*A2*g5*x4 - 
     2.9119323970204683e-7*A4*g4*x6 + 
     2.24757818721415644e-7*A*g6*x6 - 
     2.19654624683123427e-7*A3*g5*x8 + 
     3.71577620957842484e-8*g7*x8 - 
     7.60245440599503551e-8*A2*g6*x10 - 
     1.21363875909823901e-8*A*g7*x12 - 
     7.23898306636066601e-10*g8*x14)*xbar4 + 
  eps17*(3.48460743277465292e-11*A7*g2 - 
     4.51506468378503526e-10*A4*g4 + 
     9.93046484625324211e-11*A*g6 + 
     6.6025042810186813e-9*A6*g3*x2 - 
     1.62520631488663842e-8*A3*g5*x2 + 
     5.61230122018474251e-10*g7*x2 + 
     5.51380920101008308e-8*A5*g4*x4 - 
     4.88479275078761747e-8*A2*g6*x4 + 
     1.20320332856371923e-7*A4*g5*x6 - 
     3.5365653527819202e-8*A*g7*x6 + 
     1.03628614951869648e-7*A3*g6*x8 - 
     6.71263413921269682e-9*g8*x8 + 
     4.07776601703241782e-8*A2*g7*x10 + 
     7.34880420888892836e-9*A*g8*x12 + 
     4.91163816649064884e-10*g9*x14)*xbar4 + 
  eps16*(6.84233044511131468e-14*A8*g - 
     5.60464705059266925e-10*A5*g3 + 
     6.1113506912043867e-10*A2*g5 + 
     2.50582201503812155e-9*A7*g2*x2 - 
     3.39024845059116986e-8*A4*g4*x2 + 
     7.66141086125169516e-9*A*g6*x2 + 
     2.82533097805425257e-8*A6*g3*x4 - 
     1.44153074493338505e-7*A3*g5*x4 + 
     6.29165697711773721e-9*g7*x4 + 
     7.70955531949116842e-8*A5*g4*x6 - 
     1.5856345215569678e-7*A2*g6*x6 + 
     8.37319173204484218e-8*A4*g5*x8 - 
     5.99155536147365961e-8*A*g7*x8 + 
     4.37139891312553985e-8*A3*g6*x10 - 
     7.07392441584795305e-9*g8*x10 + 
     1.16805756794796047e-8*A2*g7*x12 + 
     1.53807088851897092e-9*A*g8*x14 + 
     7.90314013633620188e-11*g9*x16)*xbar4 + 
  eps18*(-2.30220514713186019e-15*A9*g + 
     8.50336672523331952e-11*A6*g3 - 
     2.03099120170330866e-10*A3*g5 + 
     6.86599038065945835e-12*g7 - 
     3.17730510813967685e-10*A8*g2*x2 + 
     7.52334651318304606e-9*A5*g4*x2 - 
     4.58441975864061026e-9*A2*g6*x2 - 
     4.93856631341031329e-9*A7*g3*x4 + 
     4.73460373170155555e-8*A4*g5*x4 - 
     8.81541701496240287e-9*A*g7*x4 - 
     1.83568265106518087e-8*A6*g4*x6 + 
     8.0214964397589886e-8*A3*g6*x6 - 
     3.16831385872351314e-9*g8*x6 - 
     2.73264771648576643e-8*A5*g5*x8 + 
     5.15584868924249984e-8*A2*g7*x8 - 
     2.00422243527645685e-8*A4*g6*x10 + 
     1.36105580520898305e-8*A*g8*x10 - 
     7.92549659107905268e-9*A3*g7*x12 + 
     1.24112226442452554e-9*g9*x12 - 
     1.72024465137340275e-9*A2*g8*x14 - 
     1.92684278620064115e-10*A*g9*x16 - 
     8.69704747258045207e-12*g10*x18)*xbar4 - 
  0.0000154320987654320988*eps2*g2*xbar6 + 
  3.56125356125356125e-7*eps5*g3*xbar6 + 
  eps4*(1.90396023729357063e-6*A*g2 + 
     7.71604938271604938e-6*g3*x2)*xbar6 + 
  eps7*(-1.06760523427190094e-7*A*g3 - 
     5.83649889205444761e-7*g4*x2)*xbar6 + 
  eps6*(-1.58222876476844731e-7*A2*g2 - 
     3.0990100434544879e-6*A*g3*x2 - 
     1.45170544476100032e-6*g4*x4)*xbar6 + 
  eps9*(2.10474956623416007e-8*A2*g3 + 
     3.52066889376257568e-7*A*g4*x2 + 
     2.15683591284989252e-7*g5*x4)*xbar6 + 
  eps8*(1.0639753805538638e-8*A3*g2 - 
     1.44647796358943781e-8*g4 + 
     7.89019059521705024e-7*A2*g3*x2 + 
     9.93278626380478232e-7*A*g4*x4 + 
     2.19830466744046991e-7*g5*x6)*xbar6 + 
  eps11*(-3.48009271425128996e-9*A3*g3 + 
     7.74456172615070677e-10*g5 - 
     1.24759056081950737e-7*A2*g4*x2 - 
     1.93124743183608916e-7*A*g5*x4 - 
     5.26262283781649553e-8*g6*x6)*xbar6 + 
  eps10*(-6.21784885258793341e-10*A4*g2 + 
     7.35917308458240036e-9*A*g4 - 
     1.61082849737015107e-7*A3*g3*x2 + 
     4.25042008023580282e-8*g5*x2 - 
     3.97181909847740069e-7*A2*g4*x4 - 
     2.15693489113968417e-7*A*g5*x6 - 
     3.05361793587726322e-8*g6*x8)*xbar6 + 
  eps13*(5.22929181665348026e-10*A4*g3 - 
     5.49761548927799316e-10*A*g5 + 
     3.37795673591345898e-8*A3*g4*x2 - 
     3.32362369023656752e-9*g6*x2 + 
     9.70864128827426103e-8*A2*g5*x4 + 
     6.29082935052959515e-8*A*g6*x6 + 
     1.05359214957493409e-8*g7*x8)*xbar6 + 
  eps12*(3.28023733515722384e-11*A5*g2 - 
     2.2483490443839068e-9*A2*g4 + 
     2.87554439944054822e-8*A4*g3*x2 - 
     3.41643318587639607e-8*A*g5*x2 + 
     1.20413081223750724e-7*A3*g4*x4 - 
     2.54382194661358481e-8*g6*x4 + 
     1.18403247344882478e-7*A2*g5*x6 + 
     3.92485363936068314e-8*A*g6*x8 + 
     4.05810532585570662e-9*g7*x10)*xbar6 + 
  eps15*(-7.38610165433134699e-11*A5*g3 + 
     2.23185618064230175e-10*A2*g5 - 
     7.72550467360774725e-9*A4*g4*x2 + 
     3.33675225731002428e-9*A*g6*x2 - 
     3.60024022499056884e-8*A3*g5*x4 + 
     2.89391686340197044e-9*g7*x4 - 
     4.11034234008140627e-8*A2*g6*x6 - 
     1.58061594311664227e-8*A*g7*x8 - 
     1.88044966020543737e-9*g8*x10)*xbar6 + 
  eps14*(-1.59924972891624396e-12*A6*g2 + 
     5.34559467656326695e-10*A3*g4 - 
     4.89531412255654985e-11*g6 - 
     4.68743656687813986e-9*A5*g3*x2 + 
     1.55203340852120435e-8*A2*g5*x2 - 
     3.05848967636635251e-8*A4*g4*x4 + 
     2.80191583068273077e-8*A*g6*x4 - 
     4.77391188802852923e-8*A3*g5*x6 + 
     9.0249644584421326e-9*g7*x6 - 
     2.7500470429085428e-8*A2*g6*x8 - 
     6.46467617732357999e-9*A*g7*x10 - 
     5.25206836466407194e-10*g8*x12)*xbar6 + 
  eps17*(9.97455222947976728e-12*A6*g3 - 
     6.79725936335510667e-11*A3*g5 + 
     3.53973893285757087e-12*g7 + 
     1.57106382527547975e-9*A5*g4*x2 - 
     1.84906281043290629e-9*A2*g6*x2 + 
     1.0959810274248971e-8*A4*g5*x4 - 
     3.77750956813660573e-9*A*g7*x4 + 
     1.93914172243944712e-8*A3*g6*x6 - 
     1.39852236310538808e-9*g8*x6 + 
     1.27378874003962749e-8*A2*g7*x8 + 
     3.39967157316226349e-9*A*g8*x10 + 
     3.11454821672654227e-10*g9*x12)*xbar6 + 
  eps16*(7.32043787188737753e-14*A7*g2 - 
     1.08932623361419343e-10*A4*g4 + 
     4.43882953795228996e-11*A*g6 + 
     7.1553877265847084e-10*A6*g3*x2 - 
     5.23629960443907472e-9*A3*g5*x2 + 
     2.84608830720512483e-10*g7*x2 + 
     6.85430762519816909e-9*A5*g4*x4 - 
     1.69359418456327738e-8*A2*g6*x4 + 
     1.57308771746978335e-8*A4*g5*x6 - 
     1.26738239683828291e-8*A*g7*x6 + 
     1.38726146998630169e-8*A3*g6*x8 - 
     2.44574523622132431e-9*g8*x8 + 
     5.52081375700205184e-9*A2*g7*x10 + 
     9.99298373572599506e-10*A*g8*x12 + 
     6.67917519196695508e-11*g9*x14)*xbar6 + 
  5.93542260208926876e-8*eps4*g3*xbar8 - 
  3.12288574815807931e-9*eps7*g4*xbar8 + 
  eps6*(-1.14340392118169896e-8*A*g3 - 
     9.02678854067742957e-8*g4*x2)*xbar8 + 
  eps9*(1.26121885620031857e-9*A*g4 + 
     1.00859349622512295e-8*g5*x2)*xbar8 + 
  eps8*(1.32727772394750297e-9*A2*g3 + 
     4.65033697944917988e-8*A*g4*x2 + 
     2.99054295797669073e-8*g5*x4)*xbar8 + 
  eps11*(-3.15709843216944468e-10*A2*g4 - 
     7.21099301568180965e-9*A*g5*x2 - 
     5.69746824484251863e-9*g6*x4)*xbar8 + 
  eps10*(-1.18235613578975095e-10*A3*g3 + 
     2.04522364126337295e-10*g5 - 
     1.4372001684607648e-8*A2*g4*x2 - 
     2.38545902650207871e-8*A*g5*x4 - 
     6.6442647298050802e-9*g6*x6)*xbar8 + 
  eps13*(6.34254881618462429e-11*A3*g4 - 
     1.4977795563804726e-11*g6 + 
     2.95036268409924151e-9*A2*g5*x2 + 
     5.72733871097688746e-9*A*g6*x4 + 
     1.89780374932858316e-9*g7*x6)*xbar8 + 
  eps12*(8.85933436332280376e-12*A4*g3 - 
     1.2695043367275619e-10*A*g5 + 
     3.44553148081436095e-9*A3*g4*x2 - 
     9.66117808074637814e-10*g6*x2 + 
     1.08393242236143663e-8*A2*g5*x4 + 
     7.24181767567549532e-9*A*g6*x6 + 
     1.22738677265426237e-9*g7*x8)*xbar8 + 
  eps15*(-1.1209244129052603e-11*A4*g4 + 
     1.23354796462055584e-11*A*g6 - 
     9.05322252904213583e-10*A3*g5*x2 + 
     9.34529456546429641e-11*g7*x2 - 
     3.18804749658072552e-9*A2*g6*x4 - 
     2.46989894878460521e-9*A*g7*x6 - 
     4.84553260391626981e-10*g8*x8)*xbar8 + 
  eps14*(-5.85591473164617337e-13*A5*g3 + 
     4.58152437519766974e-11*A2*g5 - 
     7.06061940978074562e-10*A4*g4*x2 + 
     8.8437067488213914e-10*A*g6*x2 - 
     3.6718459581734819e-9*A3*g5*x4 + 
     8.14572670487090063e-10*g7*x4 - 
     4.35865819040676537e-9*A2*g6*x6 - 
     1.70511399881374369e-9*A*g7*x8 - 
     2.04267683542374506e-10*g8*x10)*xbar8 + 
  eps16*(3.51441987362562031e-14*A6*g3 - 
     1.25669585862967901e-11*A3*g5 + 
     1.19873609386538047e-12*g7 + 
     1.29917477297039227e-10*A5*g4*x2 - 
     4.50505663684441363e-10*A2*g6*x2 + 
     1.0294836459233229e-9*A4*g5*x4 - 
     9.85762364733873057e-10*A*g7*x4 + 
     1.90892686734913978e-9*A3*g6*x6 - 
     3.76480107979462358e-10*g8*x6 + 
     1.28194605951425965e-9*A2*g7*x8 + 
     3.45797358676807567e-10*A*g8*x10 + 
     3.18111454415424726e-11*g9*x12)*xbar8 - 
  2.95801289810004407e-10*eps6*g4*xbar10 + 
  2.94346529368315861e-11*eps9*g5*xbar10 + 
  eps8*(7.69281785172546935e-11*A*g4 + 
     1.07490632635875918e-9*g5*x2)*xbar10 + 
  eps11*(-1.49854878334381416e-11*A*g5 - 
     1.64414869918985145e-10*g6*x2)*xbar10 + 
  eps10*(-1.14623038722347948e-11*A2*g4 - 
     6.72527675714427998e-10*A*g5*x2 - 
     5.64942074025452747e-10*g6*x4)*xbar10 + 
  eps13*(4.55203920804202245e-12*A2*g5 + 
     1.35763920347428776e-10*A*g6*x2 + 
     1.33652228562929386e-10*g7*x4)*xbar10 + 
  eps12*(1.27157831390982766e-12*A3*g4 - 
     2.82877994364105943e-12*g6 + 
     2.44160830279527547e-10*A2*g5*x2 + 
     5.14076796669365287e-10*A*g6*x4 + 
     1.75139799425245342e-10*g7*x6)*xbar10 + 
  eps15*(-1.07685636895144654e-12*A3*g5 + 
     2.70026199694243437e-13*g7 - 
     6.29652746661281415e-11*A2*g6*x2 - 
     1.49092240439933003e-10*A*g7*x4 - 
     5.88096054052166419e-11*g8*x6)*xbar10 + 
  eps14*(-1.16205790093287907e-13*A4*g4 + 
     2.06949189356323779e-12*A*g6 - 
     6.72146134669773312e-11*A3*g5*x2 + 
     1.99437288401862085e-11*g7*x2 - 
     2.61681510848862049e-10*A2*g6*x4 - 
     2.10127602166714473e-10*A*g7*x6 - 
     4.18842380479881739e-11*g8*x8)*xbar10 + 
  1.69722051530330397e-12*eps8*g5*xbar12 - 
  2.90595190793452012e-13*eps11*g6*xbar12 + 
  eps10*(-5.54575148020670988e-13*A*g5 - 
     1.29008964169185665e-11*g6*x2)*xbar12 + 
  eps13*(1.78798720202615632e-13*A*g6 + 
     2.57210159823889116e-12*g7*x2)*xbar12 + 
  eps12*(1.00869657097464141e-13*A2*g5 + 
     9.47632013657176953e-12*A*g6*x2 + 
     1.00368310409322369e-11*g7*x4)*xbar12 + 
  eps14*(-1.33953977785016062e-14*A3*g5 + 
     3.84980892713537606e-14*g7 - 
     3.94928486633783273e-12*A2*g6*x2 - 
     1.02511581325767213e-11*A*g7*x4 - 
     4.17899415533904787e-12*g8*x6)*xbar12 - 
  1.06551186196798794e-14*eps10*g6*xbar14 + 
  2.96371424137457707e-15*eps13*g7*xbar14 + 
  eps12*(4.1883104771160436e-15*A*g6 + 
     1.55454784378046993e-13*g7*x2)*xbar14 + 
  7.1230636127202905e-17*eps12*g7*xbar16;
}
#endif

#ifdef p22
double Wp(void)
{
   return 0.5*A*x2 + 0.0416666666666666667*g*x4 + 
  eps*(0.0833333333333333333*A + 0.0416666666666666667*g*x2) + 
  eps3*(-0.00277777777777777778*A2 - 
     0.0111111111111111111*A*g*x2 - 
     0.00208333333333333333*g2*x4) + 
  eps2*(0.00416666666666666667*g - 
     0.0416666666666666667*A2*x2 - 
     0.0138888888888888889*A*g*x4 - 
     0.00115740740740740741*g2*x6) + 
  eps5*(0.0001763668430335097*A3 - 
     0.0000388558201058201058*g2 + 
     0.00214947089947089947*A2*g*x2 + 
     0.00124007936507936508*A*g2*x4 + 
     0.000154320987654320988*g3*x6) + 
  eps4*(-0.000595238095238095238*A*g + 
     0.00416666666666666667*A3*x2 - 
     0.000868055555555555556*g2*x2 + 
     0.00347222222222222222*A2*g*x4 + 
     0.000810185185185185185*A*g2*x6 + 
     0.0000578703703703703704*g3*x8) + 
  eps7*(-0.0000132275132275132275*A4 + 
     0.000013452982202982203*A*g2 - 
     0.000353835978835978836*A3*g*x2 + 
     0.0000292107583774250441*g3*x2 - 
     0.000438161375661375661*A2*g2*x4 - 
     0.000141369047619047619*A*g3*x6 - 
     0.0000131815843621399177*g4*x8) + 
  eps6*(0.0000793650793650793651*A2*g - 
     0.000421626984126984127*A4*x2 + 
     0.000412533068783068783*A*g2*x2 - 
     0.000710978835978835979*A3*g*x4 + 
     0.00012359457671957672*g3*x4 - 
     0.000332065696649029982*A2*g2*x6 - 
     0.0000592482363315696649*A*g3*x8 - 
     3.61689814814814815e-6*g4*x10) + 
  eps9*(1.06888995777884667e-6*A5 - 
     3.09484386865339246e-6*A2*g2 + 
     0.000052889176153065042*A4*g*x2 - 
     0.0000196739667225778337*A*g3*x2 + 
     0.000118621733205066538*A3*g2*x4 - 
     8.12834124466068911e-6*g4*x4 + 
     0.0000723776288012399124*A2*g3*x6 + 
     0.0000162595142340512711*A*g4*x8 + 
     1.2123306755829904e-6*g5*x10) + 
  eps8*(-0.0000100208433541766875*A3*g + 
     8.50711788211788212e-7*g3 + 
     0.0000427138447971781305*A5*x2 - 
     0.000120331539602372936*A2*g2*x2 + 
     0.000127911890064667842*A4*g*x4 - 
     0.000098836830607663941*A*g3*x4 + 
     0.000102804110327258475*A3*g2*x6 - 
     0.0000165018585880854399*g4*x6 + 
     0.0000336428938859494415*A2*g3*x8 + 
     4.8512364050558495e-6*A*g4*x10 + 
     2.56755115454961134e-7*g5*x12) + 
  eps11*(-9.01835117002665504e-8*A6 + 
     5.87400058299529199e-7*A3*g2 - 
     2.81868399275952575e-8*g4 - 
     7.41416841780598394e-6*A5*g*x2 + 
     7.67116473755031956e-6*A2*g3*x2 - 
     0.000027147462601331649*A4*g2*x4 + 
     8.12031936990601012e-6*A*g4*x4 - 
     0.0000272310450812986086*A3*g3*x6 + 
     1.70667153812408442e-6*g5*x6 - 
     0.0000108933015093453806*A2*g4*x8 - 
     1.87850642976993286e-6*A*g5*x10 - 
     1.16690477054095881e-7*g6*x12) + 
  eps10*(1.21747740795359843e-6*A4*g - 
     4.62417873132158846e-7*A*g3 - 
     4.32775172358505692e-6*A6*x2 + 
     0.0000276277014248244407*A3*g2*x2 - 
     1.30445706075046353e-6*g4*x2 - 
     0.0000210333326652771097*A5*g*x4 + 
     0.0000447391253752860896*A2*g3*x4 - 
     0.0000265668910778864483*A4*g2*x6 + 
     0.0000184769777868736202*A*g4*x6 - 
     0.0000139376709110505407*A3*g3*x8 + 
     2.13520310814871e-6*g5*x8 - 
     3.5181249916492972e-6*A2*g4*x10 - 
     4.25407416871537242e-7*A*g5*x12 - 
     1.98147969535893919e-8*g6*x14) + 
  eps13*(7.83069566138349207e-9*A7 - 
     9.93094869534334209e-8*A4*g2 + 
     2.08755249185163841e-8*A*g4 + 
     9.92791119692574719e-7*A6*g*x2 - 
     2.26246788359770127e-6*A3*g3*x2 + 
     7.19774046753493046e-8*g5*x2 + 
     5.52538741816188906e-6*A5*g2*x4 - 
     4.47883727161149936e-6*A2*g4*x4 + 
     8.38601213983571788e-6*A4*g3*x6 - 
     2.25348627386308778e-6*A*g5*x6 + 
     5.24445855604457162e-6*A3*g4*x8 - 
     3.11392974798759566e-7*g6*x8 + 
     1.55465050346795001e-6*A2*g5*x10 + 
     2.17600880397466046e-7*A*g6*x12 + 
     1.15841884836628278e-8*g7*x14) + 
  eps12*(-1.43889032777921667e-7*A5*g + 
     1.51283642180000723e-7*A2*g3 + 
     4.38492191964414187e-7*A7*x2 - 
     5.47671197834474951e-6*A4*g2*x2 + 
     1.1365151365172641e-6*A*g4*x2 + 
     3.23789133106262736e-6*A6*g*x4 - 
     0.0000150481673660823793*A3*g3*x4 + 
     5.97324614725086198e-7*g5*x4 + 
     6.03932684613625972e-6*A5*g2*x6 - 
     0.0000113106765525436987*A2*g4*x6 + 
     4.69528859165240338e-6*A4*g3*x8 - 
     3.0694501391598228e-6*A*g5*x8 + 
     1.82557370238215146e-6*A3*g4*x10 - 
     2.71046144994230449e-7*g6*x10 + 
     3.7535031778135559e-7*A2*g5*x12 + 
     3.90681314457195373e-8*A*g6*x14 + 
     1.62260932077515154e-9*g7*x16) + 
  eps15*(-6.94206524686864971e-10*A8 + 
     1.55258266251201437e-8*A5*g2 - 
     8.87063997906019346e-9*A2*g4 - 
     1.28444091425696105e-7*A7*g*x2 + 
     5.59355511978255916e-7*A4*g3*x2 - 
     7.69591961687451275e-8*A*g5*x2 - 
     1.03084425773136674e-6*A6*g2*x4 + 
     1.80099658500984157e-6*A3*g4*x4 - 
     4.89852640150590245e-8*g6*x4 - 
     2.23744987275327073e-6*A5*g3*x6 + 
     1.60416803829389571e-6*A2*g5*x6 - 
     2.02887475090349778e-6*A4*g4*x8 + 
     5.10536772376168298e-7*A*g6*x8 - 
     9.11746562790846727e-7*A3*g5*x10 + 
     5.21769349658492833e-8*g7*x10 - 
     2.14341780318485671e-7*A2*g6*x12 - 
     2.52490551976121104e-8*A*g7*x14 - 
     1.17600420262660865e-9*g8*x16) + 
  eps14*(1.66609565924847593e-8*A6*g - 
     3.84541066603365207e-8*A3*g3 + 
     1.23616495716322489e-9*g5 - 
     4.44285396439000936e-8*A8*x2 + 
     9.81807578832239391e-7*A5*g2*x2 - 
     5.55101746448534654e-7*A2*g4*x2 - 
     4.73967830600877338e-7*A7*g*x4 + 
     4.18284859452059839e-6*A4*g3*x4 - 
     7.15343253702736788e-7*A*g5*x4 - 
     1.24663165145441196e-6*A6*g2*x6 + 
     5.00514675879205854e-6*A3*g4*x6 - 
     1.81402700349001079e-7*g6*x6 - 
     1.36226318220021373e-6*A5*g3*x8 + 
     2.36606032230627314e-6*A2*g5*x8 - 
     7.58172593612770117e-7*A4*g4*x10 + 
     4.75471890972483691e-7*A*g6*x10 - 
     2.34027522244261325e-7*A3*g5*x12 + 
     3.3963539821117207e-8*g7*x12 - 
     4.06050820222736176e-8*A2*g6*x14 - 
     3.70938742929349711e-9*A*g7*x16 - 
     1.38898528337180163e-10*g8*x18) + 
  eps17*(6.25217958800249802e-11*A9 - 
     2.29312206278746533e-9*A6*g2 + 
     2.8310089717477044e-9*A3*g4 - 
     6.71998649148490015e-11*g6 + 
     1.61783182535963035e-8*A8*g*x2 - 
     1.222198282975496e-7*A5*g3*x2 + 
     4.51903487294323094e-8*A2*g5*x2 + 
     1.79787422789127715e-7*A7*g2*x4 - 
     5.89386352242391962e-7*A4*g4*x4 + 
     6.83924293854497039e-8*A*g6*x4 + 
     5.35385253592035249e-7*A6*g3*x6 - 
     8.16161936426993263e-7*A3*g5*x6 + 
     2.03110694856709656e-8*g7*x6 + 
     6.69429955495357485e-7*A5*g4*x8 - 
     4.44812062546498445e-7*A2*g6*x8 + 
     4.24544759374608395e-7*A4*g5*x10 - 
     1.02125278182278717e-7*A*g7*x10 + 
     1.48190757087105866e-7*A3*g6*x12 - 
     8.25465653164429909e-9*g8*x12 + 
     2.8842218900714868e-8*A2*g7*x14 + 
     2.93316966296752154e-9*A*g8*x16 + 
     1.21426224678902097e-10*g9*x18) + 
  eps16*(-1.89909954985575877e-9*A7*g + 
     8.35603474047208798e-9*A4*g3 - 
     1.15966243496214952e-9*A*g5 + 
     4.50155213123768602e-9*A9*x2 - 
     1.63520154608933337e-7*A6*g2*x2 + 
     2.00125773929144853e-7*A3*g4*x2 - 
     4.71643935891082883e-9*g6*x2 + 
     6.66827009985439445e-8*A8*g*x4 - 
     1.01569722853466271e-6*A5*g3*x4 + 
     4.653753986331283e-7*A2*g5*x4 + 
     2.38609112997144637e-7*A7*g2*x6 - 
     1.78931879078472604e-6*A4*g4*x6 + 
     2.75782412054904595e-7*A*g6*x6 + 
     3.5257503626825941e-7*A6*g3*x8 - 
     1.29719583644083582e-6*A3*g5*x8 + 
     4.43904638337799842e-8*g7*x8 + 
     2.67563783428073661e-7*A5*g4*x10 - 
     4.41739629456479988e-7*A2*g6*x10 + 
     1.15544405881940575e-7*A4*g5*x12 - 
     7.03094817586759951e-8*A*g7*x12 + 
     2.95627516533174602e-8*A3*g6*x14 - 
     4.21593686904484474e-9*g8*x14 + 
     4.43746780874914946e-9*A2*g7*x16 + 
     3.61167459558351774e-10*A*g8*x18 + 
     1.23066706066192904e-11*g9*x20) + 
  eps19*(-5.70128780114804572e-12*A10 + 
     3.24325759393455769e-10*A7*g2 - 
     7.52920392642037898e-10*A4*g4 + 
     7.63432039813829238e-11*A*g6 - 
     1.99446765051272661e-9*A9*g*x2 + 
     2.43560018179573397e-8*A6*g3*x2 - 
     1.92651473964731419e-8*A3*g5*x2 + 
     3.57664504054283011e-10*g7*x2 - 
     2.97138844105769473e-8*A8*g2*x4 + 
     1.66367899286352586e-7*A5*g4*x4 - 
     5.12763843043703477e-8*A2*g6*x4 - 
     1.17558487781038256e-7*A7*g3*x6 + 
     3.32274083849900958e-7*A4*g5*x6 - 
     3.49339293457975036e-8*A*g7*x6 - 
     1.95421595481198395e-7*A6*g4*x8 + 
     2.73546099832218964e-7*A3*g6*x8 - 
     6.42119893976624269e-9*g8*x8 - 
     1.66845932629322826e-7*A5*g5*x10 + 
     1.05196992302604677e-7*A2*g7*x10 - 
     8.06653736383214643e-8*A4*g6*x12 + 
     1.87723844343482559e-8*A*g8*x12 - 
     2.29644918467110207e-8*A3*g7*x14 + 
     1.25288025697957571e-9*g9*x14 - 
     3.81165485194947533e-9*A2*g8*x16 - 
     3.41033212304414905e-10*A*g9*x18 - 
     1.27053709821831841e-11*g10*x20) + 
  eps18*(2.13798292543051714e-10*A8*g - 
     1.62899940163818617e-9*A5*g3 + 
     6.06739124374671626e-10*A2*g5 - 
     4.56102589118103946e-10*A10*x2 + 
     2.5741194154734252e-8*A7*g2*x2 - 
     5.93202934378594688e-8*A4*g4*x2 + 
     5.97796132442781859e-9*A*g6*x2 - 
     9.086017175115798e-9*A9*g*x4 + 
     2.22788546277779156e-7*A6*g3*x4 - 
     2.17818061292066124e-7*A3*g5*x4 + 
     4.46060201054250811e-9*g7*x4 - 
     4.29736286745591606e-8*A8*g2*x6 + 
     5.48218484132244335e-7*A5*g4*x6 - 
     2.23798601959230444e-7*A2*g6*x6 - 
     8.3334504765293729e-8*A7*g3*x8 + 
     5.66588387939462102e-7*A4*g5*x8 - 
     8.17078651256326395e-8*A*g7*x8 - 
     8.32572408053676287e-8*A6*g4*x10 + 
     2.88769211893932833e-7*A3*g6*x10 - 
     9.49367158787967084e-9*g8*x10 - 
     4.80270155903927102e-8*A5*g5*x12 + 
     7.64234973061525259e-8*A2*g7*x12 - 
     1.69136821548003748e-8*A4*g6*x14 + 
     1.00575293092506873e-8*A*g8*x14 - 
     3.69466622059472975e-9*A3*g7*x16 + 
     5.19597646877020836e-10*g9*x16 - 
     4.88723854749631574e-10*A2*g8*x18 - 
     3.58645537045585288e-11*A*g9*x20 - 
     1.12084057456710382e-12*g10*x22) + 
  eps21*(5.2514619543187782e-13*A11 - 
     4.43285954755604869e-11*A8*g2 + 
     1.76083788279021689e-10*A5*g4 - 
     4.74728753998211342e-11*A2*g6 + 
     2.41589075467910444e-10*A10*g*x2 - 
     4.51824485857656974e-9*A7*g3*x2 + 
     6.66083029216207287e-9*A4*g5*x2 - 
     5.24335874922835697e-10*A*g7*x2 + 
     4.69949475640663485e-9*A9*g2*x4 - 
     4.19656758646856316e-8*A6*g4*x4 + 
     2.73885212294566607e-8*A3*g6*x4 - 
     4.48244578272414887e-10*g8*x4 + 
     2.40727904510809782e-8*A8*g3*x6 - 
     1.14987302708287038e-7*A5*g5*x6 + 
     3.18314156293579248e-8*A2*g7*x6 + 
     5.1729556293745067e-8*A7*g4*x8 - 
     1.33139310440523761e-7*A4*g6*x8 + 
     1.31084047358048264e-8*A*g8*x8 + 
     5.74763592331078553e-8*A6*g5*x10 - 
     7.58285646214704478e-8*A3*g7*x10 + 
     1.70719938146989968e-9*g9*x10 + 
     3.67818305341475603e-8*A5*g6*x12 - 
     2.23107719453182269e-8*A2*g8*x12 + 
     1.43062528484956471e-8*A4*g7*x14 - 
     3.24546888412113238e-9*A*g9*x14 + 
     3.43426667042232431e-9*A3*g8*x16 - 
     1.84284319077257175e-10*g10*x16 + 
     4.96756814596081739e-10*A2*g9*x18 + 
     3.96764099826891058e-11*A*g10*x20 + 
     1.34372144042558418e-12*g11*x22) + 
  eps20*(-2.38285086177214561e-11*A9*g + 
     2.93087835503767857e-10*A6*g3 - 
     2.33284850513311582e-10*A3*g5 + 
     4.35358687387975124e-12*g7 + 
     4.62128541799995915e-11*A11*x2 - 
     3.87512747715920683e-9*A8*g2*x2 + 
     1.52963831343981389e-8*A5*g4*x2 - 
     4.10201649274809254e-9*A2*g6*x2 + 
     1.2058131859727143e-9*A10*g*x4 - 
     4.51251014708823542e-8*A7*g3*x4 + 
     8.20524658045556169e-8*A4*g5*x4 - 
     7.11455083461241557e-9*A*g7*x4 + 
     7.36094104464716057e-9*A9*g2*x6 - 
     1.49255884116928141e-7*A6*g4*x6 + 
     1.28707565844365563e-7*A3*g6*x6 - 
     2.42078453530071715e-9*g8*x6 + 
     1.82893288628610935e-8*A8*g3*x8 - 
     2.09524543137285467e-7*A5*g5*x8 + 
     7.93810679543179244e-8*A2*g7*x8 + 
     2.34179153309909358e-8*A7*g4*x10 - 
     1.48969846228119514e-7*A4*g6*x10 + 
     2.05019199855671562e-8*A*g8*x10 + 
     1.74575105847696841e-8*A6*g5*x12 - 
     5.80036979689224998e-8*A3*g7*x12 + 
     1.8510046912641176e-9*g9*x12 + 
     8.09148869608194122e-9*A5*g6*x14 - 
     1.251808839252206e-8*A2*g8*x14 + 
     2.40348962003249252e-9*A4*g7*x16 - 
     1.40328230011170153e-9*A*g9*x16 + 
     4.58007384146693616e-10*A3*g8*x18 - 
     6.36787892934133022e-11*g10*x18 + 
     5.41571641768509377e-11*A2*g9*x20 + 
     3.61823810155023661e-12*A*g10*x22 + 
     1.04407319287969897e-13*g11*x24) + 
  0.00833333333333333333*eps*g*xbar2 + 
  0.166666666666666667*(A + 0.5*g*x2)*xbar2 + 
  eps3*(-0.000793650793650793651*A*g - 
     0.00138888888888888889*g2*x2)*xbar2 + 
  eps2*(-0.00277777777777777778*A2 - 
     0.0111111111111111111*A*g*x2 - 
     0.00208333333333333333*g2*x4)*xbar2 + 
  eps5*(0.0000727513227513227513*A2*g + 
     0.000522486772486772487*A*g2*x2 + 
     0.000162037037037037037*g3*x4)*xbar2 + 
  eps4*(0.0000661375661375661376*A3 - 
     0.0000644841269841269841*g2 + 
     0.0015873015873015873*A2*g*x2 + 
     0.00094246031746031746*A*g2*x4 + 
     0.000115740740740740741*g3*x6)*xbar2 + 
  eps7*(-6.91438191438191438e-6*A3*g + 
     1.41486599819933153e-6*g3 - 
     0.000128066378066378066*A2*g2*x2 - 
     0.000110705266955266955*A*g3*x4 - 
     0.000018647119341563786*g4*x6)*xbar2 + 
  eps6*(-1.65343915343915344e-6*A4 + 
     0.0000179623617123617124*A*g2 - 
     0.00021164021164021164*A3*g*x2 + 
     0.0000485008818342151675*g3*x2 - 
     0.000276951058201058201*A2*g2*x4 - 
     0.0000898368606701940035*A*g3*x6 - 
     8.27867798353909465e-6*g4*x8)*xbar2 + 
  eps9*(6.79829796893288957e-7*A4*g - 
     6.72419695237155555e-7*A*g3 + 
     0.0000254975770848786722*A3*g2*x2 - 
     2.25056258042369153e-6*g4*x2 + 
     0.0000441438108848823135*A2*g3*x4 + 
     0.0000185871013417309714*A*g4*x6 + 
     2.15148764772607365e-6*g5*x8)*xbar2 + 
  eps8*(4.1753513975736198e-8*A5 - 
     3.46221514376276281e-6*A2*g2 + 
     0.0000267222489444711667*A4*g*x2 - 
     0.0000281804101248545693*A*g3*x2 + 
     0.0000649475909892576559*A3*g2*x4 - 
     0.0000122030666735527847*g4*x4 + 
     0.0000403965247715247715*A2*g3*x6 + 
     9.0700810463541945e-6*A*g4*x8 + 
     6.69795953360768176e-7*g5*x10)*xbar2 + 
  eps11*(-6.80612866459427306e-8*A5*g + 
     1.95584655809718057e-7*A2*g3 - 
     4.47269759439071608e-6*A4*g2*x2 + 
     1.75829988748211593e-6*A*g4*x2 - 
     0.0000133314481239415102*A3*g3*x4 + 
     9.71399147418687179e-7*g5*x4 - 
     0.0000103064498801381517*A2*g4*x6 - 
     2.82142523293179157e-6*A*g5*x8 - 
     2.4892365507720446e-7*g6*x10)*xbar2 + 
  eps10*(-1.05683802773749864e-9*A6 + 
     5.67501373552960855e-7*A3*g2 - 
     4.8511255774108832e-8*g4 - 
     3.24660642120959581e-6*A5*g*x2 + 
     9.71126169538867952e-6*A2*g3*x2 - 
     0.0000131832441790279092*A4*g2*x4 + 
     0.0000108846610427711618*A*g4*x4 - 
     0.0000136365860158849577*A3*g3*x6 + 
     2.33168885512635513e-6*g5*x6 - 
     5.4993290386188865e-6*A2*g4*x8 - 
     9.46094479080590192e-7*A*g5*x10 - 
     5.8302302889011994e-8*g6*x12)*xbar2 + 
  eps13*(6.86627585651083939e-9*A6*g - 
     4.47785160224899766e-8*A3*g3 + 
     2.19249275444418889e-9*g5 + 
     7.19946098097358602e-7*A5*g2*x2 - 
     7.80379784965903039e-7*A2*g4*x2 + 
     3.37142842641135708e-6*A4*g3*x4 - 
     1.06398186364605041e-6*A*g5*x4 + 
     4.18165456228327982e-6*A3*g4*x6 - 
     2.76351067919865578e-7*g6*x6 + 
     2.00589567077445504e-6*A2*g5*x8 + 
     4.04753308555164946e-7*A*g6*x10 + 
     2.88571475583667131e-8*g7*x12)*xbar2 + 
  eps12*(2.67650730613693577e-11*A7 - 
     8.46192910475220622e-8*A4*g2 + 
     3.25142589196534057e-8*A*g4 + 
     3.83704087407791111e-7*A6*g*x2 - 
     2.57283359783619147e-6*A3*g3*x2 + 
     1.27951218977907431e-7*g5*x2 + 
     2.41765559329216737e-6*A5*g2*x4 - 
     5.44480881814382923e-6*A2*g4*x4 + 
     3.82233569685344377e-6*A4*g3*x6 - 
     2.81139544164632672e-6*A*g5*x6 + 
     2.42710273474001612e-6*A3*g4*x8 - 
     3.92027350262991887e-7*g6*x8 + 
     7.21984500196305752e-7*A2*g5*x10 + 
     1.007566064009769e-7*A*g6*x12 + 
     5.32759708629371695e-9*g7*x14)*xbar2 + 
  eps15*(-6.94677964495491896e-10*A7*g + 
     8.85485037384606633e-9*A4*g3 - 
     1.89784940868103996e-9*A*g5 - 
     1.08873720111587578e-7*A6*g2*x2 + 
     2.58200627219967634e-7*A3*g4*x2 - 
     8.57415659878293831e-9*g6*x2 - 
     7.52178044272582197e-7*A5*g3*x4 + 
     6.39174172204870162e-7*A2*g5*x4 - 
     1.38311030669262085e-6*A4*g4*x6 + 
     3.89805821462228289e-7*A*g6*x6 - 
     1.02272071613530239e-6*A3*g5*x8 + 
     6.35874554600849527e-8*g7*x8 - 
     3.51191445940869782e-7*A2*g6*x10 - 
     5.59975947545884819e-8*A*g7*x12 - 
     3.35001083013772154e-9*g8*x14)*xbar2 + 
  eps14*(-6.77936059264516573e-13*A8 + 
     1.18453251754498057e-8*A5*g2 - 
     1.26192122113177278e-8*A2*g4 - 
     4.44292175799593582e-8*A7*g*x2 + 
     5.78235471803035281e-7*A4*g3*x2 - 
     1.25465164813262727e-7*A*g5*x2 - 
     4.11093596933471078e-7*A6*g2*x4 + 
     2.00802343589623813e-6*A3*g4*x4 - 
     8.38456228452171631e-8*g6*x4 - 
     9.37962675222683393e-7*A5*g3*x6 + 
     1.84660973293660698e-6*A2*g5*x6 - 
     8.68952732620502728e-7*A4*g4*x8 + 
     5.95974150882540242e-7*A*g6*x8 - 
     3.93789587968658131e-7*A3*g5*x10 + 
     6.11861559616332661e-8*g7*x10 - 
     9.26911580977221589e-8*A2*g6*x12 - 
     1.08851336477984649e-8*A*g7*x14 - 
     5.04016698893419468e-10*g8*x16)*xbar2 + 
  eps17*(7.03519796756268115e-11*A8*g - 
     1.58412622695254907e-9*A5*g3 + 
     9.21824723042734146e-10*A2*g5 + 
     1.57013176618403867e-8*A7*g2*x2 - 
     7.07877152349972815e-8*A4*g4*x2 + 
     1.01145514044440416e-8*A*g6*x2 + 
     1.52755677874009072e-7*A6*g3*x4 - 
     2.78303968964189299e-7*A3*g5*x4 + 
     7.90216106829461597e-9*g7*x4 + 
     3.94839847004885584e-7*A5*g4*x6 - 
     2.95546266642869418e-7*A2*g6*x6 + 
     4.1812888733216445e-7*A4*g5*x8 - 
     1.09749260429676339e-7*A*g7*x8 + 
     2.15692160440115788e-7*A3*g6*x10 - 
     1.28547064754435117e-8*g8*x10 + 
     5.73688513495873601e-8*A2*g7*x12 + 
     7.55383153004710777e-9*A*g8*x14 + 
     3.89293296941875901e-10*g9*x16)*xbar2 + 
  eps16*(1.71721241125556891e-14*A9 - 
     1.58463391176416606e-9*A6*g2 + 
     3.70687203668986364e-9*A3*g4 - 
     1.21950914958299276e-10*g6 + 
     5.06426546628202339e-9*A8*g*x2 - 
     1.15919331839795365e-7*A5*g3*x2 + 
     6.813324046201634e-8*A2*g5*x2 + 
     6.59264102615256734e-8*A7*g2*x4 - 
     6.0783143535697607e-7*A4*g4*x4 + 
     1.08734552181364072e-7*A*g6*x4 + 
     2.08077893379438207e-7*A6*g3*x6 - 
     8.7376194571684116e-7*A3*g5*x6 + 
     3.31435423816449871e-8*g7*x6 + 
     2.67286143174399604e-7*A5*g4*x8 - 
     4.84990273878282454e-7*A2*g6*x8 + 
     1.71677767909550515e-7*A4*g5*x10 - 
     1.12268658721773254e-7*A*g7*x10 + 
     6.02176056859808662e-8*A3*g6*x12 - 
     9.09453722352822717e-9*g8*x12 + 
     1.17208819972660499e-8*A2*g7*x14 + 
     1.18834173730462595e-9*A*g8*x16 + 
     4.8940576382579539e-11*g9*x18)*xbar2 + 
  eps19*(-7.12707337587569786e-12*A9*g + 
     2.63376364359160315e-10*A6*g3 - 
     3.30780046645030994e-10*A3*g5 + 
     8.03679335161609342e-12*g7 - 
     2.18139573549146275e-9*A8*g2*x2 + 
     1.6989863583308778e-8*A5*g4*x2 - 
     6.4969385102430346e-9*A2*g6*x2 - 
     2.88250590711040757e-8*A7*g3*x4 + 
     9.81072496878526138e-8*A4*g5*x4 - 
     1.18346882869724656e-8*A*g7*x4 - 
     1.00731210992033847e-7*A6*g4*x6 + 
     1.59691202088983395e-7*A3*g6*x6 - 
     4.13548363870289057e-9*g8*x6 - 
     1.45496453255537213e-7*A5*g5*x8 + 
     1.00501516554651165e-7*A2*g7*x8 - 
     1.05051610378898918e-7*A4*g6*x10 + 
     2.62399674415998082e-8*A*g8*x10 - 
     4.12244346987175346e-8*A3*g7*x12 + 
     2.38101241880130705e-9*g9*x12 - 
     8.92371773273422321e-9*A2*g8*x14 - 
     1.00013636391153993e-9*A*g9*x16 - 
     4.52724718151082609e-11*g10*x18)*xbar2 + 
  eps18*(-4.34973739711612375e-16*A10 + 
     2.04866596742209561e-10*A7*g2 - 
     9.13337973503563032e-10*A4*g4 + 
     1.29494994082815314e-10*A*g6 - 
     5.70128780114804572e-10*A9*g*x2 + 
     2.13523668994309077e-8*A6*g3*x2 - 
     2.7041278749459319e-8*A3*g5*x2 + 
     6.61136770529593115e-10*g7*x2 - 
     1.00900226220693725e-8*A8*g2*x4 + 
     1.59771473522731497e-7*A5*g4*x4 - 
     7.62149977963186539e-8*A2*g6*x4 - 
     4.26288251723329756e-8*A7*g3*x6 + 
     3.32905368200259132e-7*A4*g5*x6 - 
     5.34789893441100738e-8*A*g7*x6 - 
     7.31666710191171495e-8*A6*g4*x8 + 
     2.80197106079331506e-7*A3*g6*x8 - 
     9.98659790379859243e-9*g8*x8 - 
     6.35106992331774466e-8*A5*g5*x10 + 
     1.08995209478400767e-7*A2*g7*x10 - 
     3.09539659674895079e-8*A4*g6*x12 + 
     1.95483783519714526e-8*A*g8*x12 - 
     8.83724740598401241e-9*A3*g7*x14 + 
     1.30582050443893102e-9*g9*x14 - 
     1.46593717511110234e-9*A2*g8*x16 - 
     1.30772635674859038e-10*A*g9*x18 - 
     4.84955398928857724e-12*g10*x20)*xbar2 + 
  eps20*(1.1018005656720459e-17*A11 - 
     2.57889246901160178e-11*A8*g2 + 
     1.98990234155769708e-10*A5*g4 - 
     7.55965424361672699e-11*A2*g6 + 
     6.35426896472572163e-11*A10*g*x2 - 
     3.68388963577669912e-9*A7*g3*x2 + 
     8.75177480890399108e-9*A4*g5*x2 - 
     9.11535637885301799e-10*A*g7*x2 + 
     1.48649455332149944e-9*A9*g2*x4 - 
     3.77359746051647268e-8*A6*g4*x4 + 
     3.82594204726996217e-8*A3*g6*x4 - 
     8.13304101172221063e-10*g8*x4 + 
     8.18713369443791778e-9*A8*g3*x6 - 
     1.08366523313337395e-7*A5*g5*x6 + 
     4.5944289943616577e-8*A2*g7*x6 + 
     1.82487684327326814e-8*A7*g4*x8 - 
     1.28729795350649249e-7*A4*g6*x8 + 
     1.92747318307891877e-8*A*g8*x8 + 
     2.06867607666613227e-8*A6*g5*x10 - 
     7.43763204190519753e-8*A3*g7*x10 + 
     2.53626156501045944e-9*g9*x10 + 
     1.33838352059798451e-8*A5*g6*x12 - 
     2.20494122463979174e-8*A2*g8*x12 + 
     5.23330987914141423e-9*A4*g7*x14 - 
     3.21750395058170305e-9*A*g9*x14 + 
     1.25827561244148185e-9*A3*g8*x16 - 
     1.82713361623688652e-10*g10*x16 + 
     1.81827783439828152e-10*A2*g9*x18 + 
     1.44818570824073778e-11*A*g10*x20 + 
     4.88417660313835094e-13*g11*x22)*xbar2 + 
  0.00833333333333333333*g*xbar4 - 
  0.0000462962962962962963*eps3*g2*xbar4 + 
  eps2*(-0.000396825396825396825*A*g - 
     0.000694444444444444444*g2*x2)*xbar4 + 
  eps5*(9.11896745230078563e-6*A*g2 + 
     0.0000308641975308641975*g3*x2)*xbar4 + 
  eps4*(0.0000198412698412698413*A2*g + 
     0.000195105820105820106*A*g2*x2 + 
     0.0000617283950617283951*g3*x4)*xbar4 + 
  eps7*(-1.31581381581381581e-6*A2*g2 - 
     0.0000151318588818588819*A*g3*x2 - 
     6.8455207344096233e-6*g4*x4)*xbar4 + 
  eps6*(-9.01875901875901876e-7*A3*g + 
     9.90714532381199048e-7*g3 - 
     0.0000389059243225909893*A2*g2*x2 - 
     0.0000351397573619795842*A*g3*x4 - 
     5.9477880658436214e-6*g4*x6)*xbar4 + 
  eps9*(1.71045640622360199e-7*A3*g2 - 
     3.60906857706966639e-8*g4 + 
     4.53245406122390249e-6*A2*g3*x2 + 
     5.38783061931210079e-6*A*g4*x4 + 
     1.17492514772607365e-6*g5*x6)*xbar4 + 
  eps8*(3.77616945077262538e-8*A4*g - 
     3.91505723846993688e-7*A*g3 + 
     6.55938527962337486e-6*A3*g2*x2 - 
     1.61985166325444103e-6*g4*x2 + 
     0.0000121547079219036891*A2*g3*x4 + 
     5.20508405346368309e-6*A*g4*x6 + 
     6.02301130368259998e-7*g5*x8)*xbar4 + 
  eps11*(-2.12135350797297057e-8*A4*g2 + 
     2.14460056215349951e-8*A*g4 - 
     1.06401470496877178e-6*A3*g3*x2 + 
     9.9419658966568008e-8*g5*x2 - 
     2.4228308825712602e-6*A2*g4*x4 - 
     1.28380796826126347e-6*A*g5*x6 - 
     1.80516340332649186e-7*g6*x8)*xbar4 + 
  eps10*(-1.48202033122668043e-9*A5*g + 
     9.77137892841674354e-8*A2*g3 - 
     9.98537198520664129e-7*A4*g2*x2 + 
     1.12096864298613054e-6*A*g4*x2 - 
     3.25929867376075489e-6*A3*g3*x4 + 
     6.52088831782005348e-7*g5*x4 - 
     2.59007734102806854e-6*A2*g4*x6 - 
     7.14333704061713321e-7*A*g5*x8 - 
     6.28878290312510992e-8*g6*x10)*xbar4 + 
  eps13*(2.55551047231023315e-9*A5*g2 - 
     7.48454109323006102e-9*A2*g4 + 
     2.14869723911233424e-7*A4*g3*x2 - 
     8.87037184673700903e-8*A*g5*x2 + 
     8.1367411096167446e-7*A3*g4*x4 - 
     6.24554324051377381e-8*g6*x4 + 
     7.73534185148061632e-7*A2*g5*x6 + 
     2.53114332805174734e-7*A*g6*x8 + 
     2.60907174059342559e-8*g7*x10)*xbar4 + 
  eps12*(5.52620037914155561e-11*A6*g - 
     1.96395897468419557e-8*A3*g3 + 
     1.73105497543500998e-9*g5 + 
     1.41930118072774209e-7*A5*g2*x2 - 
     4.4751871911848506e-7*A2*g4*x2 + 
     7.4329679752095632e-7*A4*g3*x4 - 
     6.48579919839268283e-7*A*g5*x4 + 
     9.56849686940199225e-7*A3*g4*x6 - 
     1.72592309647809413e-7*g6*x6 + 
     4.6549037372399414e-7*A2*g5*x8 + 
     9.4234108977460504e-8*A*g6*x10 + 
     6.6997976279157566e-9*g7*x12)*xbar4 + 
  eps15*(-3.01110179246578381e-10*A6*g2 + 
     1.99854473307210245e-9*A3*g4 - 
     1.0075222178954846e-10*g6 - 
     3.91236879782746971e-8*A5*g3*x2 + 
     4.42468326545839399e-8*A2*g5*x2 - 
     2.26449722207185509e-7*A4*g4*x4 + 
     7.48610321580336637e-8*A*g6*x4 - 
     3.38794481457344831e-7*A3*g5*x6 + 
     2.34467193453680488e-8*g7*x6 - 
     1.91586076465687549e-7*A2*g6*x8 - 
     4.4705147415174641e-8*A*g7*x10 - 
     3.62790374951045814e-9*g8*x12)*xbar4 + 
  eps14*(-1.97753534590218582e-12*A7*g + 
     3.46651613447685113e-9*A4*g3 - 
     1.3675698718070872e-9*A*g5 - 
     1.92080361104674656e-8*A6*g2*x2 + 
     1.34714593349386061e-7*A3*g4*x2 - 
     7.0165116069938331e-9*g6*x2 - 
     1.51234778678998732e-7*A5*g3*x4 + 
     3.57677410764887609e-7*A2*g5*x4 - 
     2.9119323970204683e-7*A4*g4*x6 + 
     2.24757818721415644e-7*A*g6*x6 - 
     2.19654624683123427e-7*A3*g5*x8 + 
     3.71577620957842484e-8*g7*x8 - 
     7.60245440599503551e-8*A2*g6*x10 - 
     1.21363875909823901e-8*A*g7*x12 - 
     7.23898306636066601e-10*g8*x14)*xbar4 + 
  eps17*(3.48460743277465292e-11*A7*g2 - 
     4.51506468378503526e-10*A4*g4 + 
     9.93046484625324211e-11*A*g6 + 
     6.6025042810186813e-9*A6*g3*x2 - 
     1.62520631488663842e-8*A3*g5*x2 + 
     5.61230122018474251e-10*g7*x2 + 
     5.51380920101008308e-8*A5*g4*x4 - 
     4.88479275078761747e-8*A2*g6*x4 + 
     1.20320332856371923e-7*A4*g5*x6 - 
     3.5365653527819202e-8*A*g7*x6 + 
     1.03628614951869648e-7*A3*g6*x8 - 
     6.71263413921269682e-9*g8*x8 + 
     4.07776601703241782e-8*A2*g7*x10 + 
     7.34880420888892836e-9*A*g8*x12 + 
     4.91163816649064884e-10*g9*x14)*xbar4 + 
  eps16*(6.84233044511131468e-14*A8*g - 
     5.60464705059266925e-10*A5*g3 + 
     6.1113506912043867e-10*A2*g5 + 
     2.50582201503812155e-9*A7*g2*x2 - 
     3.39024845059116986e-8*A4*g4*x2 + 
     7.66141086125169516e-9*A*g6*x2 + 
     2.82533097805425257e-8*A6*g3*x4 - 
     1.44153074493338505e-7*A3*g5*x4 + 
     6.29165697711773721e-9*g7*x4 + 
     7.70955531949116842e-8*A5*g4*x6 - 
     1.5856345215569678e-7*A2*g6*x6 + 
     8.37319173204484218e-8*A4*g5*x8 - 
     5.99155536147365961e-8*A*g7*x8 + 
     4.37139891312553985e-8*A3*g6*x10 - 
     7.07392441584795305e-9*g8*x10 + 
     1.16805756794796047e-8*A2*g7*x12 + 
     1.53807088851897092e-9*A*g8*x14 + 
     7.90314013633620188e-11*g9*x16)*xbar4 + 
  eps19*(-3.97340865876564659e-12*A8*g2 + 
     9.08389634660042267e-11*A5*g4 - 
     5.40989729447639056e-11*A2*g6 - 
     1.05114495716806379e-9*A7*g3*x2 + 
     4.89773729086143515e-9*A4*g5*x2 - 
     7.24791876301819899e-10*A*g7*x2 - 
     1.21370267986698838e-8*A6*g4*x4 + 
     2.29597017376750524e-8*A3*g6*x4 - 
     6.7748721115604107e-10*g8*x4 - 
     3.67138156717417151e-8*A5*g5*x6 + 
     2.85584385486008741e-8*A2*g7*x6 - 
     4.48093489348219503e-8*A4*g6*x8 + 
     1.22153837054061484e-8*A*g8*x8 - 
     2.6272947304230525e-8*A3*g7*x10 + 
     1.62436680861277498e-9*g9*x10 - 
     7.84757421369128482e-9*A2*g8*x12 - 
     1.1484952449755475e-9*A*g9*x14 - 
     6.52079226899128072e-11*g10*x16)*xbar4 + 
  eps18*(-2.30220514713186019e-15*A9*g + 
     8.50336672523331952e-11*A6*g3 - 
     2.03099120170330866e-10*A3*g5 + 
     6.86599038065945835e-12*g7 - 
     3.17730510813967685e-10*A8*g2*x2 + 
     7.52334651318304606e-9*A5*g4*x2 - 
     4.58441975864061026e-9*A2*g6*x2 - 
     4.93856631341031329e-9*A7*g3*x4 + 
     4.73460373170155555e-8*A4*g5*x4 - 
     8.81541701496240287e-9*A*g7*x4 - 
     1.83568265106518087e-8*A6*g4*x6 + 
     8.0214964397589886e-8*A3*g6*x6 - 
     3.16831385872351314e-9*g8*x6 - 
     2.73264771648576643e-8*A5*g5*x8 + 
     5.15584868924249984e-8*A2*g7*x8 - 
     2.00422243527645685e-8*A4*g6*x10 + 
     1.36105580520898305e-8*A*g8*x10 - 
     7.92549659107905268e-9*A3*g7*x12 + 
     1.24112226442452554e-9*g9*x12 - 
     1.72024465137340275e-9*A2*g8*x14 - 
     1.92684278620064115e-10*A*g9*x16 - 
     8.69704747258045207e-12*g10*x18)*xbar4 - 
  0.0000154320987654320988*eps2*g2*xbar6 + 
  3.56125356125356125e-7*eps5*g3*xbar6 + 
  eps4*(1.90396023729357063e-6*A*g2 + 
     7.71604938271604938e-6*g3*x2)*xbar6 + 
  eps7*(-1.06760523427190094e-7*A*g3 - 
     5.83649889205444761e-7*g4*x2)*xbar6 + 
  eps6*(-1.58222876476844731e-7*A2*g2 - 
     3.0990100434544879e-6*A*g3*x2 - 
     1.45170544476100032e-6*g4*x4)*xbar6 + 
  eps9*(2.10474956623416007e-8*A2*g3 + 
     3.52066889376257568e-7*A*g4*x2 + 
     2.15683591284989252e-7*g5*x4)*xbar6 + 
  eps8*(1.0639753805538638e-8*A3*g2 - 
     1.44647796358943781e-8*g4 + 
     7.89019059521705024e-7*A2*g3*x2 + 
     9.93278626380478232e-7*A*g4*x4 + 
     2.19830466744046991e-7*g5*x6)*xbar6 + 
  eps11*(-3.48009271425128996e-9*A3*g3 + 
     7.74456172615070677e-10*g5 - 
     1.24759056081950737e-7*A2*g4*x2 - 
     1.93124743183608916e-7*A*g5*x4 - 
     5.26262283781649553e-8*g6*x6)*xbar6 + 
  eps10*(-6.21784885258793341e-10*A4*g2 + 
     7.35917308458240036e-9*A*g4 - 
     1.61082849737015107e-7*A3*g3*x2 + 
     4.25042008023580282e-8*g5*x2 - 
     3.97181909847740069e-7*A2*g4*x4 - 
     2.15693489113968417e-7*A*g5*x6 - 
     3.05361793587726322e-8*g6*x8)*xbar6 + 
  eps13*(5.22929181665348026e-10*A4*g3 - 
     5.49761548927799316e-10*A*g5 + 
     3.37795673591345898e-8*A3*g4*x2 - 
     3.32362369023656752e-9*g6*x2 + 
     9.70864128827426103e-8*A2*g5*x4 + 
     6.29082935052959515e-8*A*g6*x6 + 
     1.05359214957493409e-8*g7*x8)*xbar6 + 
  eps12*(3.28023733515722384e-11*A5*g2 - 
     2.2483490443839068e-9*A2*g4 + 
     2.87554439944054822e-8*A4*g3*x2 - 
     3.41643318587639607e-8*A*g5*x2 + 
     1.20413081223750724e-7*A3*g4*x4 - 
     2.54382194661358481e-8*g6*x4 + 
     1.18403247344882478e-7*A2*g5*x6 + 
     3.92485363936068314e-8*A*g6*x8 + 
     4.05810532585570662e-9*g7*x10)*xbar6 + 
  eps15*(-7.38610165433134699e-11*A5*g3 + 
     2.23185618064230175e-10*A2*g5 - 
     7.72550467360774725e-9*A4*g4*x2 + 
     3.33675225731002428e-9*A*g6*x2 - 
     3.60024022499056884e-8*A3*g5*x4 + 
     2.89391686340197044e-9*g7*x4 - 
     4.11034234008140627e-8*A2*g6*x6 - 
     1.58061594311664227e-8*A*g7*x8 - 
     1.88044966020543737e-9*g8*x10)*xbar6 + 
  eps14*(-1.59924972891624396e-12*A6*g2 + 
     5.34559467656326695e-10*A3*g4 - 
     4.89531412255654985e-11*g6 - 
     4.68743656687813986e-9*A5*g3*x2 + 
     1.55203340852120435e-8*A2*g5*x2 - 
     3.05848967636635251e-8*A4*g4*x4 + 
     2.80191583068273077e-8*A*g6*x4 - 
     4.77391188802852923e-8*A3*g5*x6 + 
     9.0249644584421326e-9*g7*x6 - 
     2.7500470429085428e-8*A2*g6*x8 - 
     6.46467617732357999e-9*A*g7*x10 - 
     5.25206836466407194e-10*g8*x12)*xbar6 + 
  eps17*(9.97455222947976728e-12*A6*g3 - 
     6.79725936335510667e-11*A3*g5 + 
     3.53973893285757087e-12*g7 + 
     1.57106382527547975e-9*A5*g4*x2 - 
     1.84906281043290629e-9*A2*g6*x2 + 
     1.0959810274248971e-8*A4*g5*x4 - 
     3.77750956813660573e-9*A*g7*x4 + 
     1.93914172243944712e-8*A3*g6*x6 - 
     1.39852236310538808e-9*g8*x6 + 
     1.27378874003962749e-8*A2*g7*x8 + 
     3.39967157316226349e-9*A*g8*x10 + 
     3.11454821672654227e-10*g9*x12)*xbar6 + 
  eps16*(7.32043787188737753e-14*A7*g2 - 
     1.08932623361419343e-10*A4*g4 + 
     4.43882953795228996e-11*A*g6 + 
     7.1553877265847084e-10*A6*g3*x2 - 
     5.23629960443907472e-9*A3*g5*x2 + 
     2.84608830720512483e-10*g7*x2 + 
     6.85430762519816909e-9*A5*g4*x4 - 
     1.69359418456327738e-8*A2*g6*x4 + 
     1.57308771746978335e-8*A4*g5*x6 - 
     1.26738239683828291e-8*A*g7*x6 + 
     1.38726146998630169e-8*A3*g6*x8 - 
     2.44574523622132431e-9*g8*x8 + 
     5.52081375700205184e-9*A2*g7*x10 + 
     9.99298373572599506e-10*A*g8*x12 + 
     6.67917519196695508e-11*g9*x14)*xbar6 + 
  eps18*(-3.18177848990088646e-15*A8*g2 + 
     1.99695443999379049e-11*A5*g4 - 
     2.23943125358944015e-11*A2*g6 - 
     1.03933552034436454e-10*A7*g3*x2 + 
     1.45959832999336206e-9*A4*g5*x2 - 
     3.42631031918890525e-10*A*g7*x2 - 
     1.39812800630481225e-9*A6*g4*x4 + 
     7.42096889844293084e-9*A3*g6*x4 - 
     3.37099552457525213e-10*g8*x4 - 
     4.48155653124553849e-9*A5*g5*x6 + 
     9.58666614025997167e-9*A2*g7*x6 - 
     5.62734416286699799e-9*A4*g6*x8 + 
     4.18363357640745376e-9*A*g8*x8 - 
     3.34880212849529458e-9*A3*g7*x10 + 
     5.62255597605531686e-10*g9*x10 - 
     1.00758346454303337e-9*A2*g8*x12 - 
     1.478403576160079e-10*A*g9*x14 - 
     8.38903736074731077e-12*g10*x16)*xbar6 + 
  5.93542260208926876e-8*eps4*g3*xbar8 - 
  3.12288574815807931e-9*eps7*g4*xbar8 + 
  eps6*(-1.14340392118169896e-8*A*g3 - 
     9.02678854067742957e-8*g4*x2)*xbar8 + 
  eps9*(1.26121885620031857e-9*A*g4 + 
     1.00859349622512295e-8*g5*x2)*xbar8 + 
  eps8*(1.32727772394750297e-9*A2*g3 + 
     4.65033697944917988e-8*A*g4*x2 + 
     2.99054295797669073e-8*g5*x4)*xbar8 + 
  eps11*(-3.15709843216944468e-10*A2*g4 - 
     7.21099301568180965e-9*A*g5*x2 - 
     5.69746824484251863e-9*g6*x4)*xbar8 + 
  eps10*(-1.18235613578975095e-10*A3*g3 + 
     2.04522364126337295e-10*g5 - 
     1.4372001684607648e-8*A2*g4*x2 - 
     2.38545902650207871e-8*A*g5*x4 - 
     6.6442647298050802e-9*g6*x6)*xbar8 + 
  eps13*(6.34254881618462429e-11*A3*g4 - 
     1.4977795563804726e-11*g6 + 
     2.95036268409924151e-9*A2*g5*x2 + 
     5.72733871097688746e-9*A*g6*x4 + 
     1.89780374932858316e-9*g7*x6)*xbar8 + 
  eps12*(8.85933436332280376e-12*A4*g3 - 
     1.2695043367275619e-10*A*g5 + 
     3.44553148081436095e-9*A3*g4*x2 - 
     9.66117808074637814e-10*g6*x2 + 
     1.08393242236143663e-8*A2*g5*x4 + 
     7.24181767567549532e-9*A*g6*x6 + 
     1.22738677265426237e-9*g7*x8)*xbar8 + 
  eps15*(-1.1209244129052603e-11*A4*g4 + 
     1.23354796462055584e-11*A*g6 - 
     9.05322252904213583e-10*A3*g5*x2 + 
     9.34529456546429641e-11*g7*x2 - 
     3.18804749658072552e-9*A2*g6*x4 - 
     2.46989894878460521e-9*A*g7*x6 - 
     4.84553260391626981e-10*g8*x8)*xbar8 + 
  eps14*(-5.85591473164617337e-13*A5*g3 + 
     4.58152437519766974e-11*A2*g5 - 
     7.06061940978074562e-10*A4*g4*x2 + 
     8.8437067488213914e-10*A*g6*x2 - 
     3.6718459581734819e-9*A3*g5*x4 + 
     8.14572670487090063e-10*g7*x4 - 
     4.35865819040676537e-9*A2*g6*x6 - 
     1.70511399881374369e-9*A*g7*x8 - 
     2.04267683542374506e-10*g8*x10)*xbar8 + 
  eps17*(1.81850832862627129e-12*A5*g4 - 
     5.7018133606605742e-12*A2*g6 + 
     2.31363157692796144e-10*A4*g5*x2 - 
     1.04268313475235866e-10*A*g7*x2 + 
     1.29559671265166405e-9*A3*g6*x4 - 
     1.08608812804810835e-10*g8*x4 + 
     1.74321237740579218e-9*A2*g7*x6 + 
     7.76515634579396129e-10*A*g8*x8 + 
     1.05455124124405657e-10*g9*x10)*xbar8 + 
  eps16*(3.51441987362562031e-14*A6*g3 - 
     1.25669585862967901e-11*A3*g5 + 
     1.19873609386538047e-12*g7 + 
     1.29917477297039227e-10*A5*g4*x2 - 
     4.50505663684441363e-10*A2*g6*x2 + 
     1.0294836459233229e-9*A4*g5*x4 - 
     9.85762364733873057e-10*A*g7*x4 + 
     1.90892686734913978e-9*A3*g6*x6 - 
     3.76480107979462358e-10*g8*x6 + 
     1.28194605951425965e-9*A2*g7*x8 + 
     3.45797358676807567e-10*A*g8*x10 + 
     3.18111454415424726e-11*g9*x12)*xbar8 - 
  2.95801289810004407e-10*eps6*g4*xbar10 + 
  2.94346529368315861e-11*eps9*g5*xbar10 + 
  eps8*(7.69281785172546935e-11*A*g4 + 
     1.07490632635875918e-9*g5*x2)*xbar10 + 
  eps11*(-1.49854878334381416e-11*A*g5 - 
     1.64414869918985145e-10*g6*x2)*xbar10 + 
  eps10*(-1.14623038722347948e-11*A2*g4 - 
     6.72527675714427998e-10*A*g5*x2 - 
     5.64942074025452747e-10*g6*x4)*xbar10 + 
  eps13*(4.55203920804202245e-12*A2*g5 + 
     1.35763920347428776e-10*A*g6*x2 + 
     1.33652228562929386e-10*g7*x4)*xbar10 + 
  eps12*(1.27157831390982766e-12*A3*g4 - 
     2.82877994364105943e-12*g6 + 
     2.44160830279527547e-10*A2*g5*x2 + 
     5.14076796669365287e-10*A*g6*x4 + 
     1.75139799425245342e-10*g7*x6)*xbar10 + 
  eps15*(-1.07685636895144654e-12*A3*g5 + 
     2.70026199694243437e-13*g7 - 
     6.29652746661281415e-11*A2*g6*x2 - 
     1.49092240439933003e-10*A*g7*x4 - 
     5.88096054052166419e-11*g8*x6)*xbar10 + 
  eps14*(-1.16205790093287907e-13*A4*g4 + 
     2.06949189356323779e-12*A*g6 - 
     6.72146134669773312e-11*A3*g5*x2 + 
     1.99437288401862085e-11*g7*x2 - 
     2.61681510848862049e-10*A2*g6*x4 - 
     2.10127602166714473e-10*A*g7*x6 - 
     4.18842380479881739e-11*g8*x8)*xbar10 + 
  eps16*(9.22277143780367963e-15*A5*g4 - 
     8.60637474674818858e-13*A2*g6 + 
     1.55522012194999734e-11*A4*g5*x2 - 
     2.04738873511014663e-11*A*g7*x2 + 
     9.80212032242431517e-11*A3*g6*x4 - 
     2.27433206141358192e-11*g8*x4 + 
     1.3776069368825939e-10*A2*g7*x6 + 
     6.26447221848720574e-11*A*g8*x8 + 
     8.59289553201749293e-12*g9*x10)*xbar10 + 
  1.69722051530330397e-12*eps8*g5*xbar12 - 
  2.90595190793452012e-13*eps11*g6*xbar12 + 
  eps10*(-5.54575148020670988e-13*A*g5 - 
     1.29008964169185665e-11*g6*x2)*xbar12 + 
  eps13*(1.78798720202615632e-13*A*g6 + 
     2.57210159823889116e-12*g7*x2)*xbar12 + 
  eps12*(1.00869657097464141e-13*A2*g5 + 
     9.47632013657176953e-12*A*g6*x2 + 
     1.00368310409322369e-11*g7*x4)*xbar12 + 
  eps15*(-6.39010493062016058e-14*A2*g6 - 
     2.40693363499189255e-12*A*g7*x2 - 
     2.87715768832048683e-12*g8*x4)*xbar12 + 
  eps14*(-1.33953977785016062e-14*A3*g5 + 
     3.84980892713537606e-14*g7 - 
     3.94928486633783273e-12*A2*g6*x2 - 
     1.02511581325767213e-11*A*g7*x4 - 
     4.17899415533904787e-12*g8*x6)*xbar12 - 
  1.06551186196798794e-14*eps10*g6*xbar14 + 
  2.96371424137457707e-15*eps13*g7*xbar14 + 
  eps12*(4.1883104771160436e-15*A*g6 + 
     1.55454784378046993e-13*g7*x2)*xbar14 + 
  eps14*(-8.99454744512618591e-16*A2*g6 - 
     1.30968415155813316e-13*A*g7*x2 - 
     1.70308449198607365e-13*g8*x4)*xbar14 + 
  7.1230636127202905e-17*eps12*g7*xbar16;
}
#endif

#ifdef p23
double Wp(void)
{
   return 0.5*A*x2 + 0.0416666666666666667*g*x4 + 
  eps*(0.0833333333333333333*A + 0.0416666666666666667*g*x2) + 
  eps3*(-0.00277777777777777778*A2 - 
     0.0111111111111111111*A*g*x2 - 
     0.00208333333333333333*g2*x4) + 
  eps2*(0.00416666666666666667*g - 
     0.0416666666666666667*A2*x2 - 
     0.0138888888888888889*A*g*x4 - 
     0.00115740740740740741*g2*x6) + 
  eps5*(0.0001763668430335097*A3 - 
     0.0000388558201058201058*g2 + 
     0.00214947089947089947*A2*g*x2 + 
     0.00124007936507936508*A*g2*x4 + 
     0.000154320987654320988*g3*x6) + 
  eps4*(-0.000595238095238095238*A*g + 
     0.00416666666666666667*A3*x2 - 
     0.000868055555555555556*g2*x2 + 
     0.00347222222222222222*A2*g*x4 + 
     0.000810185185185185185*A*g2*x6 + 
     0.0000578703703703703704*g3*x8) + 
  eps7*(-0.0000132275132275132275*A4 + 
     0.000013452982202982203*A*g2 - 
     0.000353835978835978836*A3*g*x2 + 
     0.0000292107583774250441*g3*x2 - 
     0.000438161375661375661*A2*g2*x4 - 
     0.000141369047619047619*A*g3*x6 - 
     0.0000131815843621399177*g4*x8) + 
  eps6*(0.0000793650793650793651*A2*g - 
     0.000421626984126984127*A4*x2 + 
     0.000412533068783068783*A*g2*x2 - 
     0.000710978835978835979*A3*g*x4 + 
     0.00012359457671957672*g3*x4 - 
     0.000332065696649029982*A2*g2*x6 - 
     0.0000592482363315696649*A*g3*x8 - 
     3.61689814814814815e-6*g4*x10) + 
  eps9*(1.06888995777884667e-6*A5 - 
     3.09484386865339246e-6*A2*g2 + 
     0.000052889176153065042*A4*g*x2 - 
     0.0000196739667225778337*A*g3*x2 + 
     0.000118621733205066538*A3*g2*x4 - 
     8.12834124466068911e-6*g4*x4 + 
     0.0000723776288012399124*A2*g3*x6 + 
     0.0000162595142340512711*A*g4*x8 + 
     1.2123306755829904e-6*g5*x10) + 
  eps8*(-0.0000100208433541766875*A3*g + 
     8.50711788211788212e-7*g3 + 
     0.0000427138447971781305*A5*x2 - 
     0.000120331539602372936*A2*g2*x2 + 
     0.000127911890064667842*A4*g*x4 - 
     0.000098836830607663941*A*g3*x4 + 
     0.000102804110327258475*A3*g2*x6 - 
     0.0000165018585880854399*g4*x6 + 
     0.0000336428938859494415*A2*g3*x8 + 
     4.8512364050558495e-6*A*g4*x10 + 
     2.56755115454961134e-7*g5*x12) + 
  eps11*(-9.01835117002665504e-8*A6 + 
     5.87400058299529199e-7*A3*g2 - 
     2.81868399275952575e-8*g4 - 
     7.41416841780598394e-6*A5*g*x2 + 
     7.67116473755031956e-6*A2*g3*x2 - 
     0.000027147462601331649*A4*g2*x4 + 
     8.12031936990601012e-6*A*g4*x4 - 
     0.0000272310450812986086*A3*g3*x6 + 
     1.70667153812408442e-6*g5*x6 - 
     0.0000108933015093453806*A2*g4*x8 - 
     1.87850642976993286e-6*A*g5*x10 - 
     1.16690477054095881e-7*g6*x12) + 
  eps10*(1.21747740795359843e-6*A4*g - 
     4.62417873132158846e-7*A*g3 - 
     4.32775172358505692e-6*A6*x2 + 
     0.0000276277014248244407*A3*g2*x2 - 
     1.30445706075046353e-6*g4*x2 - 
     0.0000210333326652771097*A5*g*x4 + 
     0.0000447391253752860896*A2*g3*x4 - 
     0.0000265668910778864483*A4*g2*x6 + 
     0.0000184769777868736202*A*g4*x6 - 
     0.0000139376709110505407*A3*g3*x8 + 
     2.13520310814871e-6*g5*x8 - 
     3.5181249916492972e-6*A2*g4*x10 - 
     4.25407416871537242e-7*A*g5*x12 - 
     1.98147969535893919e-8*g6*x14) + 
  eps13*(7.83069566138349207e-9*A7 - 
     9.93094869534334209e-8*A4*g2 + 
     2.08755249185163841e-8*A*g4 + 
     9.92791119692574719e-7*A6*g*x2 - 
     2.26246788359770127e-6*A3*g3*x2 + 
     7.19774046753493046e-8*g5*x2 + 
     5.52538741816188906e-6*A5*g2*x4 - 
     4.47883727161149936e-6*A2*g4*x4 + 
     8.38601213983571788e-6*A4*g3*x6 - 
     2.25348627386308778e-6*A*g5*x6 + 
     5.24445855604457162e-6*A3*g4*x8 - 
     3.11392974798759566e-7*g6*x8 + 
     1.55465050346795001e-6*A2*g5*x10 + 
     2.17600880397466046e-7*A*g6*x12 + 
     1.15841884836628278e-8*g7*x14) + 
  eps12*(-1.43889032777921667e-7*A5*g + 
     1.51283642180000723e-7*A2*g3 + 
     4.38492191964414187e-7*A7*x2 - 
     5.47671197834474951e-6*A4*g2*x2 + 
     1.1365151365172641e-6*A*g4*x2 + 
     3.23789133106262736e-6*A6*g*x4 - 
     0.0000150481673660823793*A3*g3*x4 + 
     5.97324614725086198e-7*g5*x4 + 
     6.03932684613625972e-6*A5*g2*x6 - 
     0.0000113106765525436987*A2*g4*x6 + 
     4.69528859165240338e-6*A4*g3*x8 - 
     3.0694501391598228e-6*A*g5*x8 + 
     1.82557370238215146e-6*A3*g4*x10 - 
     2.71046144994230449e-7*g6*x10 + 
     3.7535031778135559e-7*A2*g5*x12 + 
     3.90681314457195373e-8*A*g6*x14 + 
     1.62260932077515154e-9*g7*x16) + 
  eps15*(-6.94206524686864971e-10*A8 + 
     1.55258266251201437e-8*A5*g2 - 
     8.87063997906019346e-9*A2*g4 - 
     1.28444091425696105e-7*A7*g*x2 + 
     5.59355511978255916e-7*A4*g3*x2 - 
     7.69591961687451275e-8*A*g5*x2 - 
     1.03084425773136674e-6*A6*g2*x4 + 
     1.80099658500984157e-6*A3*g4*x4 - 
     4.89852640150590245e-8*g6*x4 - 
     2.23744987275327073e-6*A5*g3*x6 + 
     1.60416803829389571e-6*A2*g5*x6 - 
     2.02887475090349778e-6*A4*g4*x8 + 
     5.10536772376168298e-7*A*g6*x8 - 
     9.11746562790846727e-7*A3*g5*x10 + 
     5.21769349658492833e-8*g7*x10 - 
     2.14341780318485671e-7*A2*g6*x12 - 
     2.52490551976121104e-8*A*g7*x14 - 
     1.17600420262660865e-9*g8*x16) + 
  eps14*(1.66609565924847593e-8*A6*g - 
     3.84541066603365207e-8*A3*g3 + 
     1.23616495716322489e-9*g5 - 
     4.44285396439000936e-8*A8*x2 + 
     9.81807578832239391e-7*A5*g2*x2 - 
     5.55101746448534654e-7*A2*g4*x2 - 
     4.73967830600877338e-7*A7*g*x4 + 
     4.18284859452059839e-6*A4*g3*x4 - 
     7.15343253702736788e-7*A*g5*x4 - 
     1.24663165145441196e-6*A6*g2*x6 + 
     5.00514675879205854e-6*A3*g4*x6 - 
     1.81402700349001079e-7*g6*x6 - 
     1.36226318220021373e-6*A5*g3*x8 + 
     2.36606032230627314e-6*A2*g5*x8 - 
     7.58172593612770117e-7*A4*g4*x10 + 
     4.75471890972483691e-7*A*g6*x10 - 
     2.34027522244261325e-7*A3*g5*x12 + 
     3.3963539821117207e-8*g7*x12 - 
     4.06050820222736176e-8*A2*g6*x14 - 
     3.70938742929349711e-9*A*g7*x16 - 
     1.38898528337180163e-10*g8*x18) + 
  eps17*(6.25217958800249802e-11*A9 - 
     2.29312206278746533e-9*A6*g2 + 
     2.8310089717477044e-9*A3*g4 - 
     6.71998649148490015e-11*g6 + 
     1.61783182535963035e-8*A8*g*x2 - 
     1.222198282975496e-7*A5*g3*x2 + 
     4.51903487294323094e-8*A2*g5*x2 + 
     1.79787422789127715e-7*A7*g2*x4 - 
     5.89386352242391962e-7*A4*g4*x4 + 
     6.83924293854497039e-8*A*g6*x4 + 
     5.35385253592035249e-7*A6*g3*x6 - 
     8.16161936426993263e-7*A3*g5*x6 + 
     2.03110694856709656e-8*g7*x6 + 
     6.69429955495357485e-7*A5*g4*x8 - 
     4.44812062546498445e-7*A2*g6*x8 + 
     4.24544759374608395e-7*A4*g5*x10 - 
     1.02125278182278717e-7*A*g7*x10 + 
     1.48190757087105866e-7*A3*g6*x12 - 
     8.25465653164429909e-9*g8*x12 + 
     2.8842218900714868e-8*A2*g7*x14 + 
     2.93316966296752154e-9*A*g8*x16 + 
     1.21426224678902097e-10*g9*x18) + 
  eps16*(-1.89909954985575877e-9*A7*g + 
     8.35603474047208798e-9*A4*g3 - 
     1.15966243496214952e-9*A*g5 + 
     4.50155213123768602e-9*A9*x2 - 
     1.63520154608933337e-7*A6*g2*x2 + 
     2.00125773929144853e-7*A3*g4*x2 - 
     4.71643935891082883e-9*g6*x2 + 
     6.66827009985439445e-8*A8*g*x4 - 
     1.01569722853466271e-6*A5*g3*x4 + 
     4.653753986331283e-7*A2*g5*x4 + 
     2.38609112997144637e-7*A7*g2*x6 - 
     1.78931879078472604e-6*A4*g4*x6 + 
     2.75782412054904595e-7*A*g6*x6 + 
     3.5257503626825941e-7*A6*g3*x8 - 
     1.29719583644083582e-6*A3*g5*x8 + 
     4.43904638337799842e-8*g7*x8 + 
     2.67563783428073661e-7*A5*g4*x10 - 
     4.41739629456479988e-7*A2*g6*x10 + 
     1.15544405881940575e-7*A4*g5*x12 - 
     7.03094817586759951e-8*A*g7*x12 + 
     2.95627516533174602e-8*A3*g6*x14 - 
     4.21593686904484474e-9*g8*x14 + 
     4.43746780874914946e-9*A2*g7*x16 + 
     3.61167459558351774e-10*A*g8*x18 + 
     1.23066706066192904e-11*g9*x20) + 
  eps19*(-5.70128780114804572e-12*A10 + 
     3.24325759393455769e-10*A7*g2 - 
     7.52920392642037898e-10*A4*g4 + 
     7.63432039813829238e-11*A*g6 - 
     1.99446765051272661e-9*A9*g*x2 + 
     2.43560018179573397e-8*A6*g3*x2 - 
     1.92651473964731419e-8*A3*g5*x2 + 
     3.57664504054283011e-10*g7*x2 - 
     2.97138844105769473e-8*A8*g2*x4 + 
     1.66367899286352586e-7*A5*g4*x4 - 
     5.12763843043703477e-8*A2*g6*x4 - 
     1.17558487781038256e-7*A7*g3*x6 + 
     3.32274083849900958e-7*A4*g5*x6 - 
     3.49339293457975036e-8*A*g7*x6 - 
     1.95421595481198395e-7*A6*g4*x8 + 
     2.73546099832218964e-7*A3*g6*x8 - 
     6.42119893976624269e-9*g8*x8 - 
     1.66845932629322826e-7*A5*g5*x10 + 
     1.05196992302604677e-7*A2*g7*x10 - 
     8.06653736383214643e-8*A4*g6*x12 + 
     1.87723844343482559e-8*A*g8*x12 - 
     2.29644918467110207e-8*A3*g7*x14 + 
     1.25288025697957571e-9*g9*x14 - 
     3.81165485194947533e-9*A2*g8*x16 - 
     3.41033212304414905e-10*A*g9*x18 - 
     1.27053709821831841e-11*g10*x20) + 
  eps18*(2.13798292543051714e-10*A8*g - 
     1.62899940163818617e-9*A5*g3 + 
     6.06739124374671626e-10*A2*g5 - 
     4.56102589118103946e-10*A10*x2 + 
     2.5741194154734252e-8*A7*g2*x2 - 
     5.93202934378594688e-8*A4*g4*x2 + 
     5.97796132442781859e-9*A*g6*x2 - 
     9.086017175115798e-9*A9*g*x4 + 
     2.22788546277779156e-7*A6*g3*x4 - 
     2.17818061292066124e-7*A3*g5*x4 + 
     4.46060201054250811e-9*g7*x4 - 
     4.29736286745591606e-8*A8*g2*x6 + 
     5.48218484132244335e-7*A5*g4*x6 - 
     2.23798601959230444e-7*A2*g6*x6 - 
     8.3334504765293729e-8*A7*g3*x8 + 
     5.66588387939462102e-7*A4*g5*x8 - 
     8.17078651256326395e-8*A*g7*x8 - 
     8.32572408053676287e-8*A6*g4*x10 + 
     2.88769211893932833e-7*A3*g6*x10 - 
     9.49367158787967084e-9*g8*x10 - 
     4.80270155903927102e-8*A5*g5*x12 + 
     7.64234973061525259e-8*A2*g7*x12 - 
     1.69136821548003748e-8*A4*g6*x14 + 
     1.00575293092506873e-8*A*g8*x14 - 
     3.69466622059472975e-9*A3*g7*x16 + 
     5.19597646877020836e-10*g9*x16 - 
     4.88723854749631574e-10*A2*g8*x18 - 
     3.58645537045585288e-11*A*g9*x20 - 
     1.12084057456710382e-12*g10*x22) + 
  eps21*(5.2514619543187782e-13*A11 - 
     4.43285954755604869e-11*A8*g2 + 
     1.76083788279021689e-10*A5*g4 - 
     4.74728753998211342e-11*A2*g6 + 
     2.41589075467910444e-10*A10*g*x2 - 
     4.51824485857656974e-9*A7*g3*x2 + 
     6.66083029216207287e-9*A4*g5*x2 - 
     5.24335874922835697e-10*A*g7*x2 + 
     4.69949475640663485e-9*A9*g2*x4 - 
     4.19656758646856316e-8*A6*g4*x4 + 
     2.73885212294566607e-8*A3*g6*x4 - 
     4.48244578272414887e-10*g8*x4 + 
     2.40727904510809782e-8*A8*g3*x6 - 
     1.14987302708287038e-7*A5*g5*x6 + 
     3.18314156293579248e-8*A2*g7*x6 + 
     5.1729556293745067e-8*A7*g4*x8 - 
     1.33139310440523761e-7*A4*g6*x8 + 
     1.31084047358048264e-8*A*g8*x8 + 
     5.74763592331078553e-8*A6*g5*x10 - 
     7.58285646214704478e-8*A3*g7*x10 + 
     1.70719938146989968e-9*g9*x10 + 
     3.67818305341475603e-8*A5*g6*x12 - 
     2.23107719453182269e-8*A2*g8*x12 + 
     1.43062528484956471e-8*A4*g7*x14 - 
     3.24546888412113238e-9*A*g9*x14 + 
     3.43426667042232431e-9*A3*g8*x16 - 
     1.84284319077257175e-10*g10*x16 + 
     4.96756814596081739e-10*A2*g9*x18 + 
     3.96764099826891058e-11*A*g10*x20 + 
     1.34372144042558418e-12*g11*x22) + 
  eps20*(-2.38285086177214561e-11*A9*g + 
     2.93087835503767857e-10*A6*g3 - 
     2.33284850513311582e-10*A3*g5 + 
     4.35358687387975124e-12*g7 + 
     4.62128541799995915e-11*A11*x2 - 
     3.87512747715920683e-9*A8*g2*x2 + 
     1.52963831343981389e-8*A5*g4*x2 - 
     4.10201649274809254e-9*A2*g6*x2 + 
     1.2058131859727143e-9*A10*g*x4 - 
     4.51251014708823542e-8*A7*g3*x4 + 
     8.20524658045556169e-8*A4*g5*x4 - 
     7.11455083461241557e-9*A*g7*x4 + 
     7.36094104464716057e-9*A9*g2*x6 - 
     1.49255884116928141e-7*A6*g4*x6 + 
     1.28707565844365563e-7*A3*g6*x6 - 
     2.42078453530071715e-9*g8*x6 + 
     1.82893288628610935e-8*A8*g3*x8 - 
     2.09524543137285467e-7*A5*g5*x8 + 
     7.93810679543179244e-8*A2*g7*x8 + 
     2.34179153309909358e-8*A7*g4*x10 - 
     1.48969846228119514e-7*A4*g6*x10 + 
     2.05019199855671562e-8*A*g8*x10 + 
     1.74575105847696841e-8*A6*g5*x12 - 
     5.80036979689224998e-8*A3*g7*x12 + 
     1.8510046912641176e-9*g9*x12 + 
     8.09148869608194122e-9*A5*g6*x14 - 
     1.251808839252206e-8*A2*g8*x14 + 
     2.40348962003249252e-9*A4*g7*x16 - 
     1.40328230011170153e-9*A*g9*x16 + 
     4.58007384146693616e-10*A3*g8*x18 - 
     6.36787892934133022e-11*g10*x18 + 
     5.41571641768509377e-11*A2*g9*x20 + 
     3.61823810155023661e-12*A*g10*x22 + 
     1.04407319287969897e-13*g11*x24) + 
  eps22*(2.63381701723029945e-12*A10*g - 
     4.95613474685512438e-11*A7*g3 + 
     7.3461839787322817e-11*A4*g5 - 
     5.80927196941699941e-12*A*g7 - 
     4.68234108487568308e-12*A12*x2 + 
     5.62566165576091132e-10*A9*g2*x2 - 
     3.55029758958278224e-9*A6*g4*x2 + 
     2.01925178972162547e-9*A3*g6*x2 - 
     3.0814593971546122e-11*g8*x2 - 
     1.56527781346397019e-10*A11*g*x4 + 
     8.57069278143073356e-9*A8*g3*x4 - 
     2.64080665694219489e-8*A5*g5*x4 + 
     6.0407259102082057e-9*A2*g7*x4 - 
     1.20889938892283076e-9*A10*g2*x6 + 
     3.69930387182005496e-8*A7*g4*x6 - 
     5.87976309873423814e-8*A4*g6*x6 + 
     4.64691762189073441e-9*A*g8*x6 - 
     3.7731495679189183e-9*A9*g3*x8 + 
     6.81148651466673022e-8*A6*g5*x8 - 
     5.41126426776092471e-8*A3*g7*x8 + 
     9.60423280700958978e-10*g9*x8 - 
     6.06051978329905884e-9*A8*g4*x10 + 
     6.45172101423398301e-8*A5*g6*x10 - 
     2.31853730369969274e-8*A2*g8*x10 - 
     5.69384641167539249e-9*A7*g5*x12 + 
     3.45031778931260666e-8*A4*g7*x12 - 
     4.5856200745095094e-9*A*g9*x12 - 
     3.36446046321516529e-9*A6*g6*x14 + 
     1.08170138123001676e-8*A3*g8*x14 - 
     3.37300366179434001e-10*g10*x14 - 
     1.30060474988550597e-9*A5*g7*x16 + 
     1.9676600421073939e-9*A2*g9*x16 - 
     3.33854146037989048e-10*A4*g8*x18 + 
     1.92027951778477411e-10*A*g10*x18 - 
     5.64147807443152692e-11*A3*g9*x20 + 
     7.76866625886353525e-12*g11*x20 - 
     6.03122771185984168e-12*A2*g10*x22 - 
     3.69809171837544212e-13*A*g11*x24 - 
     9.90994892123906548e-15*g12*x26) + 
  0.00833333333333333333*eps*g*xbar2 + 
  0.166666666666666667*(A + 0.5*g*x2)*xbar2 + 
  eps3*(-0.000793650793650793651*A*g - 
     0.00138888888888888889*g2*x2)*xbar2 + 
  eps2*(-0.00277777777777777778*A2 - 
     0.0111111111111111111*A*g*x2 - 
     0.00208333333333333333*g2*x4)*xbar2 + 
  eps5*(0.0000727513227513227513*A2*g + 
     0.000522486772486772487*A*g2*x2 + 
     0.000162037037037037037*g3*x4)*xbar2 + 
  eps4*(0.0000661375661375661376*A3 - 
     0.0000644841269841269841*g2 + 
     0.0015873015873015873*A2*g*x2 + 
     0.00094246031746031746*A*g2*x4 + 
     0.000115740740740740741*g3*x6)*xbar2 + 
  eps7*(-6.91438191438191438e-6*A3*g + 
     1.41486599819933153e-6*g3 - 
     0.000128066378066378066*A2*g2*x2 - 
     0.000110705266955266955*A*g3*x4 - 
     0.000018647119341563786*g4*x6)*xbar2 + 
  eps6*(-1.65343915343915344e-6*A4 + 
     0.0000179623617123617124*A*g2 - 
     0.00021164021164021164*A3*g*x2 + 
     0.0000485008818342151675*g3*x2 - 
     0.000276951058201058201*A2*g2*x4 - 
     0.0000898368606701940035*A*g3*x6 - 
     8.27867798353909465e-6*g4*x8)*xbar2 + 
  eps9*(6.79829796893288957e-7*A4*g - 
     6.72419695237155555e-7*A*g3 + 
     0.0000254975770848786722*A3*g2*x2 - 
     2.25056258042369153e-6*g4*x2 + 
     0.0000441438108848823135*A2*g3*x4 + 
     0.0000185871013417309714*A*g4*x6 + 
     2.15148764772607365e-6*g5*x8)*xbar2 + 
  eps8*(4.1753513975736198e-8*A5 - 
     3.46221514376276281e-6*A2*g2 + 
     0.0000267222489444711667*A4*g*x2 - 
     0.0000281804101248545693*A*g3*x2 + 
     0.0000649475909892576559*A3*g2*x4 - 
     0.0000122030666735527847*g4*x4 + 
     0.0000403965247715247715*A2*g3*x6 + 
     9.0700810463541945e-6*A*g4*x8 + 
     6.69795953360768176e-7*g5*x10)*xbar2 + 
  eps11*(-6.80612866459427306e-8*A5*g + 
     1.95584655809718057e-7*A2*g3 - 
     4.47269759439071608e-6*A4*g2*x2 + 
     1.75829988748211593e-6*A*g4*x2 - 
     0.0000133314481239415102*A3*g3*x4 + 
     9.71399147418687179e-7*g5*x4 - 
     0.0000103064498801381517*A2*g4*x6 - 
     2.82142523293179157e-6*A*g5*x8 - 
     2.4892365507720446e-7*g6*x10)*xbar2 + 
  eps10*(-1.05683802773749864e-9*A6 + 
     5.67501373552960855e-7*A3*g2 - 
     4.8511255774108832e-8*g4 - 
     3.24660642120959581e-6*A5*g*x2 + 
     9.71126169538867952e-6*A2*g3*x2 - 
     0.0000131832441790279092*A4*g2*x4 + 
     0.0000108846610427711618*A*g4*x4 - 
     0.0000136365860158849577*A3*g3*x6 + 
     2.33168885512635513e-6*g5*x6 - 
     5.4993290386188865e-6*A2*g4*x8 - 
     9.46094479080590192e-7*A*g5*x10 - 
     5.8302302889011994e-8*g6*x12)*xbar2 + 
  eps13*(6.86627585651083939e-9*A6*g - 
     4.47785160224899766e-8*A3*g3 + 
     2.19249275444418889e-9*g5 + 
     7.19946098097358602e-7*A5*g2*x2 - 
     7.80379784965903039e-7*A2*g4*x2 + 
     3.37142842641135708e-6*A4*g3*x4 - 
     1.06398186364605041e-6*A*g5*x4 + 
     4.18165456228327982e-6*A3*g4*x6 - 
     2.76351067919865578e-7*g6*x6 + 
     2.00589567077445504e-6*A2*g5*x8 + 
     4.04753308555164946e-7*A*g6*x10 + 
     2.88571475583667131e-8*g7*x12)*xbar2 + 
  eps12*(2.67650730613693577e-11*A7 - 
     8.46192910475220622e-8*A4*g2 + 
     3.25142589196534057e-8*A*g4 + 
     3.83704087407791111e-7*A6*g*x2 - 
     2.57283359783619147e-6*A3*g3*x2 + 
     1.27951218977907431e-7*g5*x2 + 
     2.41765559329216737e-6*A5*g2*x4 - 
     5.44480881814382923e-6*A2*g4*x4 + 
     3.82233569685344377e-6*A4*g3*x6 - 
     2.81139544164632672e-6*A*g5*x6 + 
     2.42710273474001612e-6*A3*g4*x8 - 
     3.92027350262991887e-7*g6*x8 + 
     7.21984500196305752e-7*A2*g5*x10 + 
     1.007566064009769e-7*A*g6*x12 + 
     5.32759708629371695e-9*g7*x14)*xbar2 + 
  eps15*(-6.94677964495491896e-10*A7*g + 
     8.85485037384606633e-9*A4*g3 - 
     1.89784940868103996e-9*A*g5 - 
     1.08873720111587578e-7*A6*g2*x2 + 
     2.58200627219967634e-7*A3*g4*x2 - 
     8.57415659878293831e-9*g6*x2 - 
     7.52178044272582197e-7*A5*g3*x4 + 
     6.39174172204870162e-7*A2*g5*x4 - 
     1.38311030669262085e-6*A4*g4*x6 + 
     3.89805821462228289e-7*A*g6*x6 - 
     1.02272071613530239e-6*A3*g5*x8 + 
     6.35874554600849527e-8*g7*x8 - 
     3.51191445940869782e-7*A2*g6*x10 - 
     5.59975947545884819e-8*A*g7*x12 - 
     3.35001083013772154e-9*g8*x14)*xbar2 + 
  eps14*(-6.77936059264516573e-13*A8 + 
     1.18453251754498057e-8*A5*g2 - 
     1.26192122113177278e-8*A2*g4 - 
     4.44292175799593582e-8*A7*g*x2 + 
     5.78235471803035281e-7*A4*g3*x2 - 
     1.25465164813262727e-7*A*g5*x2 - 
     4.11093596933471078e-7*A6*g2*x4 + 
     2.00802343589623813e-6*A3*g4*x4 - 
     8.38456228452171631e-8*g6*x4 - 
     9.37962675222683393e-7*A5*g3*x6 + 
     1.84660973293660698e-6*A2*g5*x6 - 
     8.68952732620502728e-7*A4*g4*x8 + 
     5.95974150882540242e-7*A*g6*x8 - 
     3.93789587968658131e-7*A3*g5*x10 + 
     6.11861559616332661e-8*g7*x10 - 
     9.26911580977221589e-8*A2*g6*x12 - 
     1.08851336477984649e-8*A*g7*x14 - 
     5.04016698893419468e-10*g8*x16)*xbar2 + 
  eps17*(7.03519796756268115e-11*A8*g - 
     1.58412622695254907e-9*A5*g3 + 
     9.21824723042734146e-10*A2*g5 + 
     1.57013176618403867e-8*A7*g2*x2 - 
     7.07877152349972815e-8*A4*g4*x2 + 
     1.01145514044440416e-8*A*g6*x2 + 
     1.52755677874009072e-7*A6*g3*x4 - 
     2.78303968964189299e-7*A3*g5*x4 + 
     7.90216106829461597e-9*g7*x4 + 
     3.94839847004885584e-7*A5*g4*x6 - 
     2.95546266642869418e-7*A2*g6*x6 + 
     4.1812888733216445e-7*A4*g5*x8 - 
     1.09749260429676339e-7*A*g7*x8 + 
     2.15692160440115788e-7*A3*g6*x10 - 
     1.28547064754435117e-8*g8*x10 + 
     5.73688513495873601e-8*A2*g7*x12 + 
     7.55383153004710777e-9*A*g8*x14 + 
     3.89293296941875901e-10*g9*x16)*xbar2 + 
  eps16*(1.71721241125556891e-14*A9 - 
     1.58463391176416606e-9*A6*g2 + 
     3.70687203668986364e-9*A3*g4 - 
     1.21950914958299276e-10*g6 + 
     5.06426546628202339e-9*A8*g*x2 - 
     1.15919331839795365e-7*A5*g3*x2 + 
     6.813324046201634e-8*A2*g5*x2 + 
     6.59264102615256734e-8*A7*g2*x4 - 
     6.0783143535697607e-7*A4*g4*x4 + 
     1.08734552181364072e-7*A*g6*x4 + 
     2.08077893379438207e-7*A6*g3*x6 - 
     8.7376194571684116e-7*A3*g5*x6 + 
     3.31435423816449871e-8*g7*x6 + 
     2.67286143174399604e-7*A5*g4*x8 - 
     4.84990273878282454e-7*A2*g6*x8 + 
     1.71677767909550515e-7*A4*g5*x10 - 
     1.12268658721773254e-7*A*g7*x10 + 
     6.02176056859808662e-8*A3*g6*x12 - 
     9.09453722352822717e-9*g8*x12 + 
     1.17208819972660499e-8*A2*g7*x14 + 
     1.18834173730462595e-9*A*g8*x16 + 
     4.8940576382579539e-11*g9*x18)*xbar2 + 
  eps19*(-7.12707337587569786e-12*A9*g + 
     2.63376364359160315e-10*A6*g3 - 
     3.30780046645030994e-10*A3*g5 + 
     8.03679335161609342e-12*g7 - 
     2.18139573549146275e-9*A8*g2*x2 + 
     1.6989863583308778e-8*A5*g4*x2 - 
     6.4969385102430346e-9*A2*g6*x2 - 
     2.88250590711040757e-8*A7*g3*x4 + 
     9.81072496878526138e-8*A4*g5*x4 - 
     1.18346882869724656e-8*A*g7*x4 - 
     1.00731210992033847e-7*A6*g4*x6 + 
     1.59691202088983395e-7*A3*g6*x6 - 
     4.13548363870289057e-9*g8*x6 - 
     1.45496453255537213e-7*A5*g5*x8 + 
     1.00501516554651165e-7*A2*g7*x8 - 
     1.05051610378898918e-7*A4*g6*x10 + 
     2.62399674415998082e-8*A*g8*x10 - 
     4.12244346987175346e-8*A3*g7*x12 + 
     2.38101241880130705e-9*g9*x12 - 
     8.92371773273422321e-9*A2*g8*x14 - 
     1.00013636391153993e-9*A*g9*x16 - 
     4.52724718151082609e-11*g10*x18)*xbar2 + 
  eps18*(-4.34973739711612375e-16*A10 + 
     2.04866596742209561e-10*A7*g2 - 
     9.13337973503563032e-10*A4*g4 + 
     1.29494994082815314e-10*A*g6 - 
     5.70128780114804572e-10*A9*g*x2 + 
     2.13523668994309077e-8*A6*g3*x2 - 
     2.7041278749459319e-8*A3*g5*x2 + 
     6.61136770529593115e-10*g7*x2 - 
     1.00900226220693725e-8*A8*g2*x4 + 
     1.59771473522731497e-7*A5*g4*x4 - 
     7.62149977963186539e-8*A2*g6*x4 - 
     4.26288251723329756e-8*A7*g3*x6 + 
     3.32905368200259132e-7*A4*g5*x6 - 
     5.34789893441100738e-8*A*g7*x6 - 
     7.31666710191171495e-8*A6*g4*x8 + 
     2.80197106079331506e-7*A3*g6*x8 - 
     9.98659790379859243e-9*g8*x8 - 
     6.35106992331774466e-8*A5*g5*x10 + 
     1.08995209478400767e-7*A2*g7*x10 - 
     3.09539659674895079e-8*A4*g6*x12 + 
     1.95483783519714526e-8*A*g8*x12 - 
     8.83724740598401241e-9*A3*g7*x14 + 
     1.30582050443893102e-9*g9*x14 - 
     1.46593717511110234e-9*A2*g8*x16 - 
     1.30772635674859038e-10*A*g9*x18 - 
     4.84955398928857724e-12*g10*x20)*xbar2 + 
  eps21*(7.22090117277105046e-13*A10*g - 
     4.13991085301446953e-11*A7*g3 + 
     9.76589682716262956e-11*A4*g5 - 
     1.01171462635282484e-11*A*g7 + 
     2.94059482872196453e-10*A9*g2*x2 - 
     3.68979054877682005e-9*A6*g4*x2 + 
     3.00808714445394687e-9*A3*g6*x2 - 
     5.76746247671597889e-11*g8*x2 + 
     5.12696720776491515e-9*A8*g3*x4 - 
     2.96928069363177013e-8*A5*g5*x4 + 
     9.47962261651077826e-9*A2*g7*x4 + 
     2.35049540761358863e-8*A7*g4*x6 - 
     6.88556064847354174e-8*A4*g6*x6 + 
     7.5086659172629484e-9*A*g8*x6 + 
     4.47020768444263473e-8*A6*g5*x8 - 
     6.48548347717962229e-8*A3*g7*x8 + 
     1.57872287719044645e-9*g9*x8 + 
     4.31283591778531503e-8*A5*g6*x10 - 
     2.81624636750572854e-8*A2*g8*x10 + 
     2.3304946259676748e-8*A4*g7*x12 - 
     5.6106802334762125e-9*A*g9*x12 + 
     7.34468856466444926e-9*A3*g8*x14 - 
     4.14021761190658312e-10*g10*x14 + 
     1.33841053507869873e-9*A2*g9*x16 + 
     1.30531947930356562e-10*A*g10*x18 + 
     5.26795343697585529e-12*g11*x20)*xbar2 + 
  eps20*(1.1018005656720459e-17*A11 - 
     2.57889246901160178e-11*A8*g2 + 
     1.98990234155769708e-10*A5*g4 - 
     7.55965424361672699e-11*A2*g6 + 
     6.35426896472572163e-11*A10*g*x2 - 
     3.68388963577669912e-9*A7*g3*x2 + 
     8.75177480890399108e-9*A4*g5*x2 - 
     9.11535637885301799e-10*A*g7*x2 + 
     1.48649455332149944e-9*A9*g2*x4 - 
     3.77359746051647268e-8*A6*g4*x4 + 
     3.82594204726996217e-8*A3*g6*x4 - 
     8.13304101172221063e-10*g8*x4 + 
     8.18713369443791778e-9*A8*g3*x6 - 
     1.08366523313337395e-7*A5*g5*x6 + 
     4.5944289943616577e-8*A2*g7*x6 + 
     1.82487684327326814e-8*A7*g4*x8 - 
     1.28729795350649249e-7*A4*g6*x8 + 
     1.92747318307891877e-8*A*g8*x8 + 
     2.06867607666613227e-8*A6*g5*x10 - 
     7.43763204190519753e-8*A3*g7*x10 + 
     2.53626156501045944e-9*g9*x10 + 
     1.33838352059798451e-8*A5*g6*x12 - 
     2.20494122463979174e-8*A2*g8*x12 + 
     5.23330987914141423e-9*A4*g7*x14 - 
     3.21750395058170305e-9*A*g9*x14 + 
     1.25827561244148185e-9*A3*g8*x16 - 
     1.82713361623688652e-10*g10*x16 + 
     1.81827783439828152e-10*A2*g9*x18 + 
     1.44818570824073778e-11*A*g10*x20 + 
     4.88417660313835094e-13*g11*x22)*xbar2 + 
  0.00833333333333333333*g*xbar4 - 
  0.0000462962962962962963*eps3*g2*xbar4 + 
  eps2*(-0.000396825396825396825*A*g - 
     0.000694444444444444444*g2*x2)*xbar4 + 
  eps5*(9.11896745230078563e-6*A*g2 + 
     0.0000308641975308641975*g3*x2)*xbar4 + 
  eps4*(0.0000198412698412698413*A2*g + 
     0.000195105820105820106*A*g2*x2 + 
     0.0000617283950617283951*g3*x4)*xbar4 + 
  eps7*(-1.31581381581381581e-6*A2*g2 - 
     0.0000151318588818588819*A*g3*x2 - 
     6.8455207344096233e-6*g4*x4)*xbar4 + 
  eps6*(-9.01875901875901876e-7*A3*g + 
     9.90714532381199048e-7*g3 - 
     0.0000389059243225909893*A2*g2*x2 - 
     0.0000351397573619795842*A*g3*x4 - 
     5.9477880658436214e-6*g4*x6)*xbar4 + 
  eps9*(1.71045640622360199e-7*A3*g2 - 
     3.60906857706966639e-8*g4 + 
     4.53245406122390249e-6*A2*g3*x2 + 
     5.38783061931210079e-6*A*g4*x4 + 
     1.17492514772607365e-6*g5*x6)*xbar4 + 
  eps8*(3.77616945077262538e-8*A4*g - 
     3.91505723846993688e-7*A*g3 + 
     6.55938527962337486e-6*A3*g2*x2 - 
     1.61985166325444103e-6*g4*x2 + 
     0.0000121547079219036891*A2*g3*x4 + 
     5.20508405346368309e-6*A*g4*x6 + 
     6.02301130368259998e-7*g5*x8)*xbar4 + 
  eps11*(-2.12135350797297057e-8*A4*g2 + 
     2.14460056215349951e-8*A*g4 - 
     1.06401470496877178e-6*A3*g3*x2 + 
     9.9419658966568008e-8*g5*x2 - 
     2.4228308825712602e-6*A2*g4*x4 - 
     1.28380796826126347e-6*A*g5*x6 - 
     1.80516340332649186e-7*g6*x8)*xbar4 + 
  eps10*(-1.48202033122668043e-9*A5*g + 
     9.77137892841674354e-8*A2*g3 - 
     9.98537198520664129e-7*A4*g2*x2 + 
     1.12096864298613054e-6*A*g4*x2 - 
     3.25929867376075489e-6*A3*g3*x4 + 
     6.52088831782005348e-7*g5*x4 - 
     2.59007734102806854e-6*A2*g4*x6 - 
     7.14333704061713321e-7*A*g5*x8 - 
     6.28878290312510992e-8*g6*x10)*xbar4 + 
  eps13*(2.55551047231023315e-9*A5*g2 - 
     7.48454109323006102e-9*A2*g4 + 
     2.14869723911233424e-7*A4*g3*x2 - 
     8.87037184673700903e-8*A*g5*x2 + 
     8.1367411096167446e-7*A3*g4*x4 - 
     6.24554324051377381e-8*g6*x4 + 
     7.73534185148061632e-7*A2*g5*x6 + 
     2.53114332805174734e-7*A*g6*x8 + 
     2.60907174059342559e-8*g7*x10)*xbar4 + 
  eps12*(5.52620037914155561e-11*A6*g - 
     1.96395897468419557e-8*A3*g3 + 
     1.73105497543500998e-9*g5 + 
     1.41930118072774209e-7*A5*g2*x2 - 
     4.4751871911848506e-7*A2*g4*x2 + 
     7.4329679752095632e-7*A4*g3*x4 - 
     6.48579919839268283e-7*A*g5*x4 + 
     9.56849686940199225e-7*A3*g4*x6 - 
     1.72592309647809413e-7*g6*x6 + 
     4.6549037372399414e-7*A2*g5*x8 + 
     9.4234108977460504e-8*A*g6*x10 + 
     6.6997976279157566e-9*g7*x12)*xbar4 + 
  eps15*(-3.01110179246578381e-10*A6*g2 + 
     1.99854473307210245e-9*A3*g4 - 
     1.0075222178954846e-10*g6 - 
     3.91236879782746971e-8*A5*g3*x2 + 
     4.42468326545839399e-8*A2*g5*x2 - 
     2.26449722207185509e-7*A4*g4*x4 + 
     7.48610321580336637e-8*A*g6*x4 - 
     3.38794481457344831e-7*A3*g5*x6 + 
     2.34467193453680488e-8*g7*x6 - 
     1.91586076465687549e-7*A2*g6*x8 - 
     4.4705147415174641e-8*A*g7*x10 - 
     3.62790374951045814e-9*g8*x12)*xbar4 + 
  eps14*(-1.97753534590218582e-12*A7*g + 
     3.46651613447685113e-9*A4*g3 - 
     1.3675698718070872e-9*A*g5 - 
     1.92080361104674656e-8*A6*g2*x2 + 
     1.34714593349386061e-7*A3*g4*x2 - 
     7.0165116069938331e-9*g6*x2 - 
     1.51234778678998732e-7*A5*g3*x4 + 
     3.57677410764887609e-7*A2*g5*x4 - 
     2.9119323970204683e-7*A4*g4*x6 + 
     2.24757818721415644e-7*A*g6*x6 - 
     2.19654624683123427e-7*A3*g5*x8 + 
     3.71577620957842484e-8*g7*x8 - 
     7.60245440599503551e-8*A2*g6*x10 - 
     1.21363875909823901e-8*A*g7*x12 - 
     7.23898306636066601e-10*g8*x14)*xbar4 + 
  eps17*(3.48460743277465292e-11*A7*g2 - 
     4.51506468378503526e-10*A4*g4 + 
     9.93046484625324211e-11*A*g6 + 
     6.6025042810186813e-9*A6*g3*x2 - 
     1.62520631488663842e-8*A3*g5*x2 + 
     5.61230122018474251e-10*g7*x2 + 
     5.51380920101008308e-8*A5*g4*x4 - 
     4.88479275078761747e-8*A2*g6*x4 + 
     1.20320332856371923e-7*A4*g5*x6 - 
     3.5365653527819202e-8*A*g7*x6 + 
     1.03628614951869648e-7*A3*g6*x8 - 
     6.71263413921269682e-9*g8*x8 + 
     4.07776601703241782e-8*A2*g7*x10 + 
     7.34880420888892836e-9*A*g8*x12 + 
     4.91163816649064884e-10*g9*x14)*xbar4 + 
  eps16*(6.84233044511131468e-14*A8*g - 
     5.60464705059266925e-10*A5*g3 + 
     6.1113506912043867e-10*A2*g5 + 
     2.50582201503812155e-9*A7*g2*x2 - 
     3.39024845059116986e-8*A4*g4*x2 + 
     7.66141086125169516e-9*A*g6*x2 + 
     2.82533097805425257e-8*A6*g3*x4 - 
     1.44153074493338505e-7*A3*g5*x4 + 
     6.29165697711773721e-9*g7*x4 + 
     7.70955531949116842e-8*A5*g4*x6 - 
     1.5856345215569678e-7*A2*g6*x6 + 
     8.37319173204484218e-8*A4*g5*x8 - 
     5.99155536147365961e-8*A*g7*x8 + 
     4.37139891312553985e-8*A3*g6*x10 - 
     7.07392441584795305e-9*g8*x10 + 
     1.16805756794796047e-8*A2*g7*x12 + 
     1.53807088851897092e-9*A*g8*x14 + 
     7.90314013633620188e-11*g9*x16)*xbar4 + 
  eps19*(-3.97340865876564659e-12*A8*g2 + 
     9.08389634660042267e-11*A5*g4 - 
     5.40989729447639056e-11*A2*g6 - 
     1.05114495716806379e-9*A7*g3*x2 + 
     4.89773729086143515e-9*A4*g5*x2 - 
     7.24791876301819899e-10*A*g7*x2 - 
     1.21370267986698838e-8*A6*g4*x4 + 
     2.29597017376750524e-8*A3*g6*x4 - 
     6.7748721115604107e-10*g8*x4 - 
     3.67138156717417151e-8*A5*g5*x6 + 
     2.85584385486008741e-8*A2*g7*x6 - 
     4.48093489348219503e-8*A4*g6*x8 + 
     1.22153837054061484e-8*A*g8*x8 - 
     2.6272947304230525e-8*A3*g7*x10 + 
     1.62436680861277498e-9*g9*x10 - 
     7.84757421369128482e-9*A2*g8*x12 - 
     1.1484952449755475e-9*A*g9*x14 - 
     6.52079226899128072e-11*g10*x16)*xbar4 + 
  eps18*(-2.30220514713186019e-15*A9*g + 
     8.50336672523331952e-11*A6*g3 - 
     2.03099120170330866e-10*A3*g5 + 
     6.86599038065945835e-12*g7 - 
     3.17730510813967685e-10*A8*g2*x2 + 
     7.52334651318304606e-9*A5*g4*x2 - 
     4.58441975864061026e-9*A2*g6*x2 - 
     4.93856631341031329e-9*A7*g3*x4 + 
     4.73460373170155555e-8*A4*g5*x4 - 
     8.81541701496240287e-9*A*g7*x4 - 
     1.83568265106518087e-8*A6*g4*x6 + 
     8.0214964397589886e-8*A3*g6*x6 - 
     3.16831385872351314e-9*g8*x6 - 
     2.73264771648576643e-8*A5*g5*x8 + 
     5.15584868924249984e-8*A2*g7*x8 - 
     2.00422243527645685e-8*A4*g6*x10 + 
     1.36105580520898305e-8*A*g8*x10 - 
     7.92549659107905268e-9*A3*g7*x12 + 
     1.24112226442452554e-9*g9*x12 - 
     1.72024465137340275e-9*A2*g8*x14 - 
     1.92684278620064115e-10*A*g9*x16 - 
     8.69704747258045207e-12*g10*x18)*xbar4 + 
  eps20*(7.56595105695415785e-17*A10*g - 
     1.22932630659041053e-11*A7*g3 + 
     5.58459887241763578e-11*A4*g5 - 
     8.11455810014543089e-12*A*g7 + 
     3.9383320785984906e-11*A9*g2*x2 - 
     1.51976152664836327e-9*A6*g4*x2 + 
     1.98780657022334646e-9*A3*g6*x2 - 
     5.0284224652211995e-11*g8*x2 + 
     8.18366713361052766e-10*A8*g3*x4 - 
     1.34227304693417849e-8*A5*g5*x4 + 
     6.6399136914675485e-9*A2*g7*x4 + 
     4.01847928057574067e-9*A7*g4*x6 - 
     3.25458326731869081e-8*A4*g6*x6 + 
     5.42627614195641677e-9*A*g8*x6 + 
     7.91216320845347941e-9*A6*g5*x8 - 
     3.14137939839749592e-8*A3*g7*x8 + 
     1.16149233526855299e-9*g9*x8 + 
     7.7806358292877523e-9*A5*g6*x10 - 
     1.38304354148956577e-8*A2*g8*x10 + 
     4.24844294383596806e-9*A4*g7*x12 - 
     2.77563538429180564e-9*A*g9*x12 + 
     1.34573608785890679e-9*A3*g8*x14 - 
     2.05451606449403644e-10*g10*x14 + 
     2.45603481008104843e-10*A2*g9*x16 + 
     2.39299395598715992e-11*A*g10*x18 + 
     9.63092387870827136e-13*g11*x20)*xbar4 - 
  0.0000154320987654320988*eps2*g2*xbar6 + 
  3.56125356125356125e-7*eps5*g3*xbar6 + 
  eps4*(1.90396023729357063e-6*A*g2 + 
     7.71604938271604938e-6*g3*x2)*xbar6 + 
  eps7*(-1.06760523427190094e-7*A*g3 - 
     5.83649889205444761e-7*g4*x2)*xbar6 + 
  eps6*(-1.58222876476844731e-7*A2*g2 - 
     3.0990100434544879e-6*A*g3*x2 - 
     1.45170544476100032e-6*g4*x4)*xbar6 + 
  eps9*(2.10474956623416007e-8*A2*g3 + 
     3.52066889376257568e-7*A*g4*x2 + 
     2.15683591284989252e-7*g5*x4)*xbar6 + 
  eps8*(1.0639753805538638e-8*A3*g2 - 
     1.44647796358943781e-8*g4 + 
     7.89019059521705024e-7*A2*g3*x2 + 
     9.93278626380478232e-7*A*g4*x4 + 
     2.19830466744046991e-7*g5*x6)*xbar6 + 
  eps11*(-3.48009271425128996e-9*A3*g3 + 
     7.74456172615070677e-10*g5 - 
     1.24759056081950737e-7*A2*g4*x2 - 
     1.93124743183608916e-7*A*g5*x4 - 
     5.26262283781649553e-8*g6*x6)*xbar6 + 
  eps10*(-6.21784885258793341e-10*A4*g2 + 
     7.35917308458240036e-9*A*g4 - 
     1.61082849737015107e-7*A3*g3*x2 + 
     4.25042008023580282e-8*g5*x2 - 
     3.97181909847740069e-7*A2*g4*x4 - 
     2.15693489113968417e-7*A*g5*x6 - 
     3.05361793587726322e-8*g6*x8)*xbar6 + 
  eps13*(5.22929181665348026e-10*A4*g3 - 
     5.49761548927799316e-10*A*g5 + 
     3.37795673591345898e-8*A3*g4*x2 - 
     3.32362369023656752e-9*g6*x2 + 
     9.70864128827426103e-8*A2*g5*x4 + 
     6.29082935052959515e-8*A*g6*x6 + 
     1.05359214957493409e-8*g7*x8)*xbar6 + 
  eps12*(3.28023733515722384e-11*A5*g2 - 
     2.2483490443839068e-9*A2*g4 + 
     2.87554439944054822e-8*A4*g3*x2 - 
     3.41643318587639607e-8*A*g5*x2 + 
     1.20413081223750724e-7*A3*g4*x4 - 
     2.54382194661358481e-8*g6*x4 + 
     1.18403247344882478e-7*A2*g5*x6 + 
     3.92485363936068314e-8*A*g6*x8 + 
     4.05810532585570662e-9*g7*x10)*xbar6 + 
  eps15*(-7.38610165433134699e-11*A5*g3 + 
     2.23185618064230175e-10*A2*g5 - 
     7.72550467360774725e-9*A4*g4*x2 + 
     3.33675225731002428e-9*A*g6*x2 - 
     3.60024022499056884e-8*A3*g5*x4 + 
     2.89391686340197044e-9*g7*x4 - 
     4.11034234008140627e-8*A2*g6*x6 - 
     1.58061594311664227e-8*A*g7*x8 - 
     1.88044966020543737e-9*g8*x10)*xbar6 + 
  eps14*(-1.59924972891624396e-12*A6*g2 + 
     5.34559467656326695e-10*A3*g4 - 
     4.89531412255654985e-11*g6 - 
     4.68743656687813986e-9*A5*g3*x2 + 
     1.55203340852120435e-8*A2*g5*x2 - 
     3.05848967636635251e-8*A4*g4*x4 + 
     2.80191583068273077e-8*A*g6*x4 - 
     4.77391188802852923e-8*A3*g5*x6 + 
     9.0249644584421326e-9*g7*x6 - 
     2.7500470429085428e-8*A2*g6*x8 - 
     6.46467617732357999e-9*A*g7*x10 - 
     5.25206836466407194e-10*g8*x12)*xbar6 + 
  eps17*(9.97455222947976728e-12*A6*g3 - 
     6.79725936335510667e-11*A3*g5 + 
     3.53973893285757087e-12*g7 + 
     1.57106382527547975e-9*A5*g4*x2 - 
     1.84906281043290629e-9*A2*g6*x2 + 
     1.0959810274248971e-8*A4*g5*x4 - 
     3.77750956813660573e-9*A*g7*x4 + 
     1.93914172243944712e-8*A3*g6*x6 - 
     1.39852236310538808e-9*g8*x6 + 
     1.27378874003962749e-8*A2*g7*x8 + 
     3.39967157316226349e-9*A*g8*x10 + 
     3.11454821672654227e-10*g9*x12)*xbar6 + 
  eps16*(7.32043787188737753e-14*A7*g2 - 
     1.08932623361419343e-10*A4*g4 + 
     4.43882953795228996e-11*A*g6 + 
     7.1553877265847084e-10*A6*g3*x2 - 
     5.23629960443907472e-9*A3*g5*x2 + 
     2.84608830720512483e-10*g7*x2 + 
     6.85430762519816909e-9*A5*g4*x4 - 
     1.69359418456327738e-8*A2*g6*x4 + 
     1.57308771746978335e-8*A4*g5*x6 - 
     1.26738239683828291e-8*A*g7*x6 + 
     1.38726146998630169e-8*A3*g6*x8 - 
     2.44574523622132431e-9*g8*x8 + 
     5.52081375700205184e-9*A2*g7*x10 + 
     9.99298373572599506e-10*A*g8*x12 + 
     6.67917519196695508e-11*g9*x14)*xbar6 + 
  eps19*(-1.30114590146037234e-12*A7*g3 + 
     1.72511713934239417e-11*A4*g5 - 
     3.90436685140620179e-12*A*g7 - 
     2.92867814057581221e-10*A6*g4*x2 + 
     7.46902977877224456e-10*A3*g6*x2 - 
     2.67522864508407854e-11*g8*x2 - 
     2.89699505443225961e-9*A5*g5*x4 + 
     2.66562938868512264e-9*A2*g7*x4 - 
     7.37795565467524207e-9*A4*g6*x6 + 
     2.25247153971908075e-9*A*g8*x6 - 
     7.30651817416318482e-9*A3*g7*x8 + 
     4.91176292870876797e-10*g9*x8 - 
     3.26224960924321828e-9*A2*g8*x10 - 
     6.59449314458554338e-10*A*g9*x12 - 
     4.89514760970749125e-11*g10*x14)*xbar6 + 
  eps18*(-3.18177848990088646e-15*A8*g2 + 
     1.99695443999379049e-11*A5*g4 - 
     2.23943125358944015e-11*A2*g6 - 
     1.03933552034436454e-10*A7*g3*x2 + 
     1.45959832999336206e-9*A4*g5*x2 - 
     3.42631031918890525e-10*A*g7*x2 - 
     1.39812800630481225e-9*A6*g4*x4 + 
     7.42096889844293084e-9*A3*g6*x4 - 
     3.37099552457525213e-10*g8*x4 - 
     4.48155653124553849e-9*A5*g5*x6 + 
     9.58666614025997167e-9*A2*g7*x6 - 
     5.62734416286699799e-9*A4*g6*x8 + 
     4.18363357640745376e-9*A*g8*x8 - 
     3.34880212849529458e-9*A3*g7*x10 + 
     5.62255597605531686e-10*g9*x10 - 
     1.00758346454303337e-9*A2*g8*x12 - 
     1.478403576160079e-10*A*g9*x14 - 
     8.38903736074731077e-12*g10*x16)*xbar6 + 
  5.93542260208926876e-8*eps4*g3*xbar8 - 
  3.12288574815807931e-9*eps7*g4*xbar8 + 
  eps6*(-1.14340392118169896e-8*A*g3 - 
     9.02678854067742957e-8*g4*x2)*xbar8 + 
  eps9*(1.26121885620031857e-9*A*g4 + 
     1.00859349622512295e-8*g5*x2)*xbar8 + 
  eps8*(1.32727772394750297e-9*A2*g3 + 
     4.65033697944917988e-8*A*g4*x2 + 
     2.99054295797669073e-8*g5*x4)*xbar8 + 
  eps11*(-3.15709843216944468e-10*A2*g4 - 
     7.21099301568180965e-9*A*g5*x2 - 
     5.69746824484251863e-9*g6*x4)*xbar8 + 
  eps10*(-1.18235613578975095e-10*A3*g3 + 
     2.04522364126337295e-10*g5 - 
     1.4372001684607648e-8*A2*g4*x2 - 
     2.38545902650207871e-8*A*g5*x4 - 
     6.6442647298050802e-9*g6*x6)*xbar8 + 
  eps13*(6.34254881618462429e-11*A3*g4 - 
     1.4977795563804726e-11*g6 + 
     2.95036268409924151e-9*A2*g5*x2 + 
     5.72733871097688746e-9*A*g6*x4 + 
     1.89780374932858316e-9*g7*x6)*xbar8 + 
  eps12*(8.85933436332280376e-12*A4*g3 - 
     1.2695043367275619e-10*A*g5 + 
     3.44553148081436095e-9*A3*g4*x2 - 
     9.66117808074637814e-10*g6*x2 + 
     1.08393242236143663e-8*A2*g5*x4 + 
     7.24181767567549532e-9*A*g6*x6 + 
     1.22738677265426237e-9*g7*x8)*xbar8 + 
  eps15*(-1.1209244129052603e-11*A4*g4 + 
     1.23354796462055584e-11*A*g6 - 
     9.05322252904213583e-10*A3*g5*x2 + 
     9.34529456546429641e-11*g7*x2 - 
     3.18804749658072552e-9*A2*g6*x4 - 
     2.46989894878460521e-9*A*g7*x6 - 
     4.84553260391626981e-10*g8*x8)*xbar8 + 
  eps14*(-5.85591473164617337e-13*A5*g3 + 
     4.58152437519766974e-11*A2*g5 - 
     7.06061940978074562e-10*A4*g4*x2 + 
     8.8437067488213914e-10*A*g6*x2 - 
     3.6718459581734819e-9*A3*g5*x4 + 
     8.14572670487090063e-10*g7*x4 - 
     4.35865819040676537e-9*A2*g6*x6 - 
     1.70511399881374369e-9*A*g7*x8 - 
     2.04267683542374506e-10*g8*x10)*xbar8 + 
  eps17*(1.81850832862627129e-12*A5*g4 - 
     5.7018133606605742e-12*A2*g6 + 
     2.31363157692796144e-10*A4*g5*x2 - 
     1.04268313475235866e-10*A*g7*x2 + 
     1.29559671265166405e-9*A3*g6*x4 - 
     1.08608812804810835e-10*g8*x4 + 
     1.74321237740579218e-9*A2*g7*x6 + 
     7.76515634579396129e-10*A*g8*x8 + 
     1.05455124124405657e-10*g9*x10)*xbar8 + 
  eps16*(3.51441987362562031e-14*A6*g3 - 
     1.25669585862967901e-11*A3*g5 + 
     1.19873609386538047e-12*g7 + 
     1.29917477297039227e-10*A5*g4*x2 - 
     4.50505663684441363e-10*A2*g6*x2 + 
     1.0294836459233229e-9*A4*g5*x4 - 
     9.85762364733873057e-10*A*g7*x4 + 
     1.90892686734913978e-9*A3*g6*x6 - 
     3.76480107979462358e-10*g8*x6 + 
     1.28194605951425965e-9*A2*g7*x8 + 
     3.45797358676807567e-10*A*g8*x10 + 
     3.18111454415424726e-11*g9*x12)*xbar8 + 
  eps18*(-1.95213901631847725e-15*A7*g3 + 
     2.9024042061210064e-12*A4*g5 - 
     1.22464345499091446e-12*A*g7 - 
     2.20948357179324358e-11*A6*g4*x2 + 
     1.68407222784752482e-10*A3*g6*x2 - 
     9.52673617116155421e-12*g8*x2 - 
     2.52285174010719033e-10*A5*g5*x4 + 
     6.48893132761825578e-10*A2*g7*x4 - 
     6.78403369061433162e-10*A4*g6*x6 + 
     5.68290125969521456e-10*A*g8*x6 - 
     6.90033763945661382e-10*A3*g7*x8 + 
     1.26310595431481278e-10*g9*x8 - 
     3.12443265284225916e-10*A2*g8*x10 - 
     6.3597958994265421e-11*A*g9*x12 - 
     4.73255306775791468e-12*g10*x14)*xbar8 - 
  2.95801289810004407e-10*eps6*g4*xbar10 + 
  2.94346529368315861e-11*eps9*g5*xbar10 + 
  eps8*(7.69281785172546935e-11*A*g4 + 
     1.07490632635875918e-9*g5*x2)*xbar10 + 
  eps11*(-1.49854878334381416e-11*A*g5 - 
     1.64414869918985145e-10*g6*x2)*xbar10 + 
  eps10*(-1.14623038722347948e-11*A2*g4 - 
     6.72527675714427998e-10*A*g5*x2 - 
     5.64942074025452747e-10*g6*x4)*xbar10 + 
  eps13*(4.55203920804202245e-12*A2*g5 + 
     1.35763920347428776e-10*A*g6*x2 + 
     1.33652228562929386e-10*g7*x4)*xbar10 + 
  eps12*(1.27157831390982766e-12*A3*g4 - 
     2.82877994364105943e-12*g6 + 
     2.44160830279527547e-10*A2*g5*x2 + 
     5.14076796669365287e-10*A*g6*x4 + 
     1.75139799425245342e-10*g7*x6)*xbar10 + 
  eps15*(-1.07685636895144654e-12*A3*g5 + 
     2.70026199694243437e-13*g7 - 
     6.29652746661281415e-11*A2*g6*x2 - 
     1.49092240439933003e-10*A*g7*x4 - 
     5.88096054052166419e-11*g8*x6)*xbar10 + 
  eps14*(-1.16205790093287907e-13*A4*g4 + 
     2.06949189356323779e-12*A*g6 - 
     6.72146134669773312e-11*A3*g5*x2 + 
     1.99437288401862085e-11*g7*x2 - 
     2.61681510848862049e-10*A2*g6*x4 - 
     2.10127602166714473e-10*A*g7*x6 - 
     4.18842380479881739e-11*g8*x8)*xbar10 + 
  eps17*(2.18937302179867743e-13*A4*g5 - 
     2.52743776628905178e-13*A*g7 + 
     2.15933914153368247e-11*A3*g6*x2 - 
     2.33174044228357075e-12*g8*x2 + 
     9.10889047339860176e-11*A2*g7*x4 + 
     8.28793584781457544e-11*A*g8*x6 + 
     1.87814134450040901e-11*g9*x8)*xbar10 + 
  eps16*(9.22277143780367963e-15*A5*g4 - 
     8.60637474674818858e-13*A2*g6 + 
     1.55522012194999734e-11*A4*g5*x2 - 
     2.04738873511014663e-11*A*g7*x2 + 
     9.80212032242431517e-11*A3*g6*x4 - 
     2.27433206141358192e-11*g8*x4 + 
     1.3776069368825939e-10*A2*g7*x6 + 
     6.26447221848720574e-11*A*g8*x8 + 
     8.59289553201749293e-12*g9*x10)*xbar10 + 
  1.69722051530330397e-12*eps8*g5*xbar12 - 
  2.90595190793452012e-13*eps11*g6*xbar12 + 
  eps10*(-5.54575148020670988e-13*A*g5 - 
     1.29008964169185665e-11*g6*x2)*xbar12 + 
  eps13*(1.78798720202615632e-13*A*g6 + 
     2.57210159823889116e-12*g7*x2)*xbar12 + 
  eps12*(1.00869657097464141e-13*A2*g5 + 
     9.47632013657176953e-12*A*g6*x2 + 
     1.00368310409322369e-11*g7*x4)*xbar12 + 
  eps15*(-6.39010493062016058e-14*A2*g6 - 
     2.40693363499189255e-12*A*g7*x2 - 
     2.87715768832048683e-12*g8*x4)*xbar12 + 
  eps14*(-1.33953977785016062e-14*A3*g5 + 
     3.84980892713537606e-14*g7 - 
     3.94928486633783273e-12*A2*g6*x2 - 
     1.02511581325767213e-11*A*g7*x4 - 
     4.17899415533904787e-12*g8*x6)*xbar12 + 
  eps16*(1.44440682820300384e-15*A4*g5 - 
     3.24022688540454265e-14*A*g7 + 
     1.22741801273679764e-12*A3*g6*x2 - 
     3.84061473377336244e-13*g8*x2 + 
     5.77793844380739442e-12*A2*g7*x4 + 
     5.47447616200335818e-12*A*g8*x6 + 
     1.26471026695269685e-12*g9*x8)*xbar12 - 
  1.06551186196798794e-14*eps10*g6*xbar14 + 
  2.96371424137457707e-15*eps13*g7*xbar14 + 
  eps12*(4.1883104771160436e-15*A*g6 + 
     1.55454784378046993e-13*g7*x2)*xbar14 + 
  eps15*(-2.14017433818550597e-15*A*g7 - 
     3.90198867402243257e-14*g8*x2)*xbar14 + 
  eps14*(-8.99454744512618591e-16*A2*g6 - 
     1.30968415155813316e-13*A*g7*x2 - 
     1.70308449198607365e-13*g8*x4)*xbar14 + 
  7.1230636127202905e-17*eps12*g7*xbar16 + 
  eps14*(-3.27091744222075652e-17*A*g7 - 
     1.87737117146802168e-15*g8*x2)*xbar16;
}
#endif

#ifdef p24
double Wp(void)
{
   return 0.5*A*x2 + 0.0416666666666666667*g*x4 + 
  eps*(0.0833333333333333333*A + 0.0416666666666666667*g*x2) + 
  eps3*(-0.00277777777777777778*A2 - 
     0.0111111111111111111*A*g*x2 - 
     0.00208333333333333333*g2*x4) + 
  eps2*(0.00416666666666666667*g - 
     0.0416666666666666667*A2*x2 - 
     0.0138888888888888889*A*g*x4 - 
     0.00115740740740740741*g2*x6) + 
  eps5*(0.0001763668430335097*A3 - 
     0.0000388558201058201058*g2 + 
     0.00214947089947089947*A2*g*x2 + 
     0.00124007936507936508*A*g2*x4 + 
     0.000154320987654320988*g3*x6) + 
  eps4*(-0.000595238095238095238*A*g + 
     0.00416666666666666667*A3*x2 - 
     0.000868055555555555556*g2*x2 + 
     0.00347222222222222222*A2*g*x4 + 
     0.000810185185185185185*A*g2*x6 + 
     0.0000578703703703703704*g3*x8) + 
  eps7*(-0.0000132275132275132275*A4 + 
     0.000013452982202982203*A*g2 - 
     0.000353835978835978836*A3*g*x2 + 
     0.0000292107583774250441*g3*x2 - 
     0.000438161375661375661*A2*g2*x4 - 
     0.000141369047619047619*A*g3*x6 - 
     0.0000131815843621399177*g4*x8) + 
  eps6*(0.0000793650793650793651*A2*g - 
     0.000421626984126984127*A4*x2 + 
     0.000412533068783068783*A*g2*x2 - 
     0.000710978835978835979*A3*g*x4 + 
     0.00012359457671957672*g3*x4 - 
     0.000332065696649029982*A2*g2*x6 - 
     0.0000592482363315696649*A*g3*x8 - 
     3.61689814814814815e-6*g4*x10) + 
  eps9*(1.06888995777884667e-6*A5 - 
     3.09484386865339246e-6*A2*g2 + 
     0.000052889176153065042*A4*g*x2 - 
     0.0000196739667225778337*A*g3*x2 + 
     0.000118621733205066538*A3*g2*x4 - 
     8.12834124466068911e-6*g4*x4 + 
     0.0000723776288012399124*A2*g3*x6 + 
     0.0000162595142340512711*A*g4*x8 + 
     1.2123306755829904e-6*g5*x10) + 
  eps8*(-0.0000100208433541766875*A3*g + 
     8.50711788211788212e-7*g3 + 
     0.0000427138447971781305*A5*x2 - 
     0.000120331539602372936*A2*g2*x2 + 
     0.000127911890064667842*A4*g*x4 - 
     0.000098836830607663941*A*g3*x4 + 
     0.000102804110327258475*A3*g2*x6 - 
     0.0000165018585880854399*g4*x6 + 
     0.0000336428938859494415*A2*g3*x8 + 
     4.8512364050558495e-6*A*g4*x10 + 
     2.56755115454961134e-7*g5*x12) + 
  eps11*(-9.01835117002665504e-8*A6 + 
     5.87400058299529199e-7*A3*g2 - 
     2.81868399275952575e-8*g4 - 
     7.41416841780598394e-6*A5*g*x2 + 
     7.67116473755031956e-6*A2*g3*x2 - 
     0.000027147462601331649*A4*g2*x4 + 
     8.12031936990601012e-6*A*g4*x4 - 
     0.0000272310450812986086*A3*g3*x6 + 
     1.70667153812408442e-6*g5*x6 - 
     0.0000108933015093453806*A2*g4*x8 - 
     1.87850642976993286e-6*A*g5*x10 - 
     1.16690477054095881e-7*g6*x12) + 
  eps10*(1.21747740795359843e-6*A4*g - 
     4.62417873132158846e-7*A*g3 - 
     4.32775172358505692e-6*A6*x2 + 
     0.0000276277014248244407*A3*g2*x2 - 
     1.30445706075046353e-6*g4*x2 - 
     0.0000210333326652771097*A5*g*x4 + 
     0.0000447391253752860896*A2*g3*x4 - 
     0.0000265668910778864483*A4*g2*x6 + 
     0.0000184769777868736202*A*g4*x6 - 
     0.0000139376709110505407*A3*g3*x8 + 
     2.13520310814871e-6*g5*x8 - 
     3.5181249916492972e-6*A2*g4*x10 - 
     4.25407416871537242e-7*A*g5*x12 - 
     1.98147969535893919e-8*g6*x14) + 
  eps13*(7.83069566138349207e-9*A7 - 
     9.93094869534334209e-8*A4*g2 + 
     2.08755249185163841e-8*A*g4 + 
     9.92791119692574719e-7*A6*g*x2 - 
     2.26246788359770127e-6*A3*g3*x2 + 
     7.19774046753493046e-8*g5*x2 + 
     5.52538741816188906e-6*A5*g2*x4 - 
     4.47883727161149936e-6*A2*g4*x4 + 
     8.38601213983571788e-6*A4*g3*x6 - 
     2.25348627386308778e-6*A*g5*x6 + 
     5.24445855604457162e-6*A3*g4*x8 - 
     3.11392974798759566e-7*g6*x8 + 
     1.55465050346795001e-6*A2*g5*x10 + 
     2.17600880397466046e-7*A*g6*x12 + 
     1.15841884836628278e-8*g7*x14) + 
  eps12*(-1.43889032777921667e-7*A5*g + 
     1.51283642180000723e-7*A2*g3 + 
     4.38492191964414187e-7*A7*x2 - 
     5.47671197834474951e-6*A4*g2*x2 + 
     1.1365151365172641e-6*A*g4*x2 + 
     3.23789133106262736e-6*A6*g*x4 - 
     0.0000150481673660823793*A3*g3*x4 + 
     5.97324614725086198e-7*g5*x4 + 
     6.03932684613625972e-6*A5*g2*x6 - 
     0.0000113106765525436987*A2*g4*x6 + 
     4.69528859165240338e-6*A4*g3*x8 - 
     3.0694501391598228e-6*A*g5*x8 + 
     1.82557370238215146e-6*A3*g4*x10 - 
     2.71046144994230449e-7*g6*x10 + 
     3.7535031778135559e-7*A2*g5*x12 + 
     3.90681314457195373e-8*A*g6*x14 + 
     1.62260932077515154e-9*g7*x16) + 
  eps15*(-6.94206524686864971e-10*A8 + 
     1.55258266251201437e-8*A5*g2 - 
     8.87063997906019346e-9*A2*g4 - 
     1.28444091425696105e-7*A7*g*x2 + 
     5.59355511978255916e-7*A4*g3*x2 - 
     7.69591961687451275e-8*A*g5*x2 - 
     1.03084425773136674e-6*A6*g2*x4 + 
     1.80099658500984157e-6*A3*g4*x4 - 
     4.89852640150590245e-8*g6*x4 - 
     2.23744987275327073e-6*A5*g3*x6 + 
     1.60416803829389571e-6*A2*g5*x6 - 
     2.02887475090349778e-6*A4*g4*x8 + 
     5.10536772376168298e-7*A*g6*x8 - 
     9.11746562790846727e-7*A3*g5*x10 + 
     5.21769349658492833e-8*g7*x10 - 
     2.14341780318485671e-7*A2*g6*x12 - 
     2.52490551976121104e-8*A*g7*x14 - 
     1.17600420262660865e-9*g8*x16) + 
  eps14*(1.66609565924847593e-8*A6*g - 
     3.84541066603365207e-8*A3*g3 + 
     1.23616495716322489e-9*g5 - 
     4.44285396439000936e-8*A8*x2 + 
     9.81807578832239391e-7*A5*g2*x2 - 
     5.55101746448534654e-7*A2*g4*x2 - 
     4.73967830600877338e-7*A7*g*x4 + 
     4.18284859452059839e-6*A4*g3*x4 - 
     7.15343253702736788e-7*A*g5*x4 - 
     1.24663165145441196e-6*A6*g2*x6 + 
     5.00514675879205854e-6*A3*g4*x6 - 
     1.81402700349001079e-7*g6*x6 - 
     1.36226318220021373e-6*A5*g3*x8 + 
     2.36606032230627314e-6*A2*g5*x8 - 
     7.58172593612770117e-7*A4*g4*x10 + 
     4.75471890972483691e-7*A*g6*x10 - 
     2.34027522244261325e-7*A3*g5*x12 + 
     3.3963539821117207e-8*g7*x12 - 
     4.06050820222736176e-8*A2*g6*x14 - 
     3.70938742929349711e-9*A*g7*x16 - 
     1.38898528337180163e-10*g8*x18) + 
  eps17*(6.25217958800249802e-11*A9 - 
     2.29312206278746533e-9*A6*g2 + 
     2.8310089717477044e-9*A3*g4 - 
     6.71998649148490015e-11*g6 + 
     1.61783182535963035e-8*A8*g*x2 - 
     1.222198282975496e-7*A5*g3*x2 + 
     4.51903487294323094e-8*A2*g5*x2 + 
     1.79787422789127715e-7*A7*g2*x4 - 
     5.89386352242391962e-7*A4*g4*x4 + 
     6.83924293854497039e-8*A*g6*x4 + 
     5.35385253592035249e-7*A6*g3*x6 - 
     8.16161936426993263e-7*A3*g5*x6 + 
     2.03110694856709656e-8*g7*x6 + 
     6.69429955495357485e-7*A5*g4*x8 - 
     4.44812062546498445e-7*A2*g6*x8 + 
     4.24544759374608395e-7*A4*g5*x10 - 
     1.02125278182278717e-7*A*g7*x10 + 
     1.48190757087105866e-7*A3*g6*x12 - 
     8.25465653164429909e-9*g8*x12 + 
     2.8842218900714868e-8*A2*g7*x14 + 
     2.93316966296752154e-9*A*g8*x16 + 
     1.21426224678902097e-10*g9*x18) + 
  eps16*(-1.89909954985575877e-9*A7*g + 
     8.35603474047208798e-9*A4*g3 - 
     1.15966243496214952e-9*A*g5 + 
     4.50155213123768602e-9*A9*x2 - 
     1.63520154608933337e-7*A6*g2*x2 + 
     2.00125773929144853e-7*A3*g4*x2 - 
     4.71643935891082883e-9*g6*x2 + 
     6.66827009985439445e-8*A8*g*x4 - 
     1.01569722853466271e-6*A5*g3*x4 + 
     4.653753986331283e-7*A2*g5*x4 + 
     2.38609112997144637e-7*A7*g2*x6 - 
     1.78931879078472604e-6*A4*g4*x6 + 
     2.75782412054904595e-7*A*g6*x6 + 
     3.5257503626825941e-7*A6*g3*x8 - 
     1.29719583644083582e-6*A3*g5*x8 + 
     4.43904638337799842e-8*g7*x8 + 
     2.67563783428073661e-7*A5*g4*x10 - 
     4.41739629456479988e-7*A2*g6*x10 + 
     1.15544405881940575e-7*A4*g5*x12 - 
     7.03094817586759951e-8*A*g7*x12 + 
     2.95627516533174602e-8*A3*g6*x14 - 
     4.21593686904484474e-9*g8*x14 + 
     4.43746780874914946e-9*A2*g7*x16 + 
     3.61167459558351774e-10*A*g8*x18 + 
     1.23066706066192904e-11*g9*x20) + 
  eps19*(-5.70128780114804572e-12*A10 + 
     3.24325759393455769e-10*A7*g2 - 
     7.52920392642037898e-10*A4*g4 + 
     7.63432039813829238e-11*A*g6 - 
     1.99446765051272661e-9*A9*g*x2 + 
     2.43560018179573397e-8*A6*g3*x2 - 
     1.92651473964731419e-8*A3*g5*x2 + 
     3.57664504054283011e-10*g7*x2 - 
     2.97138844105769473e-8*A8*g2*x4 + 
     1.66367899286352586e-7*A5*g4*x4 - 
     5.12763843043703477e-8*A2*g6*x4 - 
     1.17558487781038256e-7*A7*g3*x6 + 
     3.32274083849900958e-7*A4*g5*x6 - 
     3.49339293457975036e-8*A*g7*x6 - 
     1.95421595481198395e-7*A6*g4*x8 + 
     2.73546099832218964e-7*A3*g6*x8 - 
     6.42119893976624269e-9*g8*x8 - 
     1.66845932629322826e-7*A5*g5*x10 + 
     1.05196992302604677e-7*A2*g7*x10 - 
     8.06653736383214643e-8*A4*g6*x12 + 
     1.87723844343482559e-8*A*g8*x12 - 
     2.29644918467110207e-8*A3*g7*x14 + 
     1.25288025697957571e-9*g9*x14 - 
     3.81165485194947533e-9*A2*g8*x16 - 
     3.41033212304414905e-10*A*g9*x18 - 
     1.27053709821831841e-11*g10*x20) + 
  eps18*(2.13798292543051714e-10*A8*g - 
     1.62899940163818617e-9*A5*g3 + 
     6.06739124374671626e-10*A2*g5 - 
     4.56102589118103946e-10*A10*x2 + 
     2.5741194154734252e-8*A7*g2*x2 - 
     5.93202934378594688e-8*A4*g4*x2 + 
     5.97796132442781859e-9*A*g6*x2 - 
     9.086017175115798e-9*A9*g*x4 + 
     2.22788546277779156e-7*A6*g3*x4 - 
     2.17818061292066124e-7*A3*g5*x4 + 
     4.46060201054250811e-9*g7*x4 - 
     4.29736286745591606e-8*A8*g2*x6 + 
     5.48218484132244335e-7*A5*g4*x6 - 
     2.23798601959230444e-7*A2*g6*x6 - 
     8.3334504765293729e-8*A7*g3*x8 + 
     5.66588387939462102e-7*A4*g5*x8 - 
     8.17078651256326395e-8*A*g7*x8 - 
     8.32572408053676287e-8*A6*g4*x10 + 
     2.88769211893932833e-7*A3*g6*x10 - 
     9.49367158787967084e-9*g8*x10 - 
     4.80270155903927102e-8*A5*g5*x12 + 
     7.64234973061525259e-8*A2*g7*x12 - 
     1.69136821548003748e-8*A4*g6*x14 + 
     1.00575293092506873e-8*A*g8*x14 - 
     3.69466622059472975e-9*A3*g7*x16 + 
     5.19597646877020836e-10*g9*x16 - 
     4.88723854749631574e-10*A2*g8*x18 - 
     3.58645537045585288e-11*A*g9*x20 - 
     1.12084057456710382e-12*g10*x22) + 
  eps21*(5.2514619543187782e-13*A11 - 
     4.43285954755604869e-11*A8*g2 + 
     1.76083788279021689e-10*A5*g4 - 
     4.74728753998211342e-11*A2*g6 + 
     2.41589075467910444e-10*A10*g*x2 - 
     4.51824485857656974e-9*A7*g3*x2 + 
     6.66083029216207287e-9*A4*g5*x2 - 
     5.24335874922835697e-10*A*g7*x2 + 
     4.69949475640663485e-9*A9*g2*x4 - 
     4.19656758646856316e-8*A6*g4*x4 + 
     2.73885212294566607e-8*A3*g6*x4 - 
     4.48244578272414887e-10*g8*x4 + 
     2.40727904510809782e-8*A8*g3*x6 - 
     1.14987302708287038e-7*A5*g5*x6 + 
     3.18314156293579248e-8*A2*g7*x6 + 
     5.1729556293745067e-8*A7*g4*x8 - 
     1.33139310440523761e-7*A4*g6*x8 + 
     1.31084047358048264e-8*A*g8*x8 + 
     5.74763592331078553e-8*A6*g5*x10 - 
     7.58285646214704478e-8*A3*g7*x10 + 
     1.70719938146989968e-9*g9*x10 + 
     3.67818305341475603e-8*A5*g6*x12 - 
     2.23107719453182269e-8*A2*g8*x12 + 
     1.43062528484956471e-8*A4*g7*x14 - 
     3.24546888412113238e-9*A*g9*x14 + 
     3.43426667042232431e-9*A3*g8*x16 - 
     1.84284319077257175e-10*g10*x16 + 
     4.96756814596081739e-10*A2*g9*x18 + 
     3.96764099826891058e-11*A*g10*x20 + 
     1.34372144042558418e-12*g11*x22) + 
  eps20*(-2.38285086177214561e-11*A9*g + 
     2.93087835503767857e-10*A6*g3 - 
     2.33284850513311582e-10*A3*g5 + 
     4.35358687387975124e-12*g7 + 
     4.62128541799995915e-11*A11*x2 - 
     3.87512747715920683e-9*A8*g2*x2 + 
     1.52963831343981389e-8*A5*g4*x2 - 
     4.10201649274809254e-9*A2*g6*x2 + 
     1.2058131859727143e-9*A10*g*x4 - 
     4.51251014708823542e-8*A7*g3*x4 + 
     8.20524658045556169e-8*A4*g5*x4 - 
     7.11455083461241557e-9*A*g7*x4 + 
     7.36094104464716057e-9*A9*g2*x6 - 
     1.49255884116928141e-7*A6*g4*x6 + 
     1.28707565844365563e-7*A3*g6*x6 - 
     2.42078453530071715e-9*g8*x6 + 
     1.82893288628610935e-8*A8*g3*x8 - 
     2.09524543137285467e-7*A5*g5*x8 + 
     7.93810679543179244e-8*A2*g7*x8 + 
     2.34179153309909358e-8*A7*g4*x10 - 
     1.48969846228119514e-7*A4*g6*x10 + 
     2.05019199855671562e-8*A*g8*x10 + 
     1.74575105847696841e-8*A6*g5*x12 - 
     5.80036979689224998e-8*A3*g7*x12 + 
     1.8510046912641176e-9*g9*x12 + 
     8.09148869608194122e-9*A5*g6*x14 - 
     1.251808839252206e-8*A2*g8*x14 + 
     2.40348962003249252e-9*A4*g7*x16 - 
     1.40328230011170153e-9*A*g9*x16 + 
     4.58007384146693616e-10*A3*g8*x18 - 
     6.36787892934133022e-11*g10*x18 + 
     5.41571641768509377e-11*A2*g9*x20 + 
     3.61823810155023661e-12*A*g10*x22 + 
     1.04407319287969897e-13*g11*x24) + 
  eps23*(-4.87743892079685082e-14*A12 + 
     5.89316491267758974e-12*A9*g2 - 
     3.73943263170943611e-11*A6*g4 + 
     2.13679155317563112e-11*A3*g6 - 
     3.27361153325515243e-13*g8 - 
     2.88368279506519334e-11*A11*g*x2 + 
     7.91374895139060628e-10*A8*g3*x2 - 
     1.98046179372144604e-9*A5*g5*x2 + 
     4.11786639583657111e-10*A2*g7*x2 - 
     7.16497851551313523e-10*A10*g2*x4 + 
     9.68464471525289276e-9*A7*g4*x4 - 
     1.16748393728030986e-8*A4*g6*x4 + 
     8.04127478183736051e-10*A*g8*x4 - 
     4.65194608412246558e-9*A9*g3*x6 + 
     3.51082372037893695e-8*A6*g5*x6 - 
     2.04201982013264592e-8*A3*g7*x6 + 
     3.08310721156552306e-10*g9*x6 - 
     1.26357673284535273e-8*A8*g4*x8 + 
     5.45476416156654204e-8*A5*g6*x8 - 
     1.40486405551536498e-8*A2*g8*x8 - 
     1.7805212696568686e-8*A7*g5*x10 + 
     4.2926305860153371e-8*A4*g7*x10 - 
     4.0312366550615087e-9*A*g9*x10 - 
     1.46022546131613235e-8*A6*g6*x12 + 
     1.843836447337074e-8*A3*g8*x12 - 
     4.02235197734030437e-10*g10*x12 - 
     7.42369322805527411e-9*A5*g7*x14 + 
     4.37038526225414347e-9*A2*g9*x14 - 
     2.40937437944208411e-9*A4*g8*x16 + 
     5.35568097093309146e-10*A*g10*x16 - 
     4.99603251087911808e-10*A3*g9*x18 + 
     2.64472477748035067e-11*g11*x18 - 
     6.40255800593810452e-11*A2*g10*x20 - 
     4.61829796410311992e-12*A*g11*x22 - 
     1.43368406597132889e-13*g12*x24) + 
  eps22*(2.63381701723029945e-12*A10*g - 
     4.95613474685512438e-11*A7*g3 + 
     7.3461839787322817e-11*A4*g5 - 
     5.80927196941699941e-12*A*g7 - 
     4.68234108487568308e-12*A12*x2 + 
     5.62566165576091132e-10*A9*g2*x2 - 
     3.55029758958278224e-9*A6*g4*x2 + 
     2.01925178972162547e-9*A3*g6*x2 - 
     3.0814593971546122e-11*g8*x2 - 
     1.56527781346397019e-10*A11*g*x4 + 
     8.57069278143073356e-9*A8*g3*x4 - 
     2.64080665694219489e-8*A5*g5*x4 + 
     6.0407259102082057e-9*A2*g7*x4 - 
     1.20889938892283076e-9*A10*g2*x6 + 
     3.69930387182005496e-8*A7*g4*x6 - 
     5.87976309873423814e-8*A4*g6*x6 + 
     4.64691762189073441e-9*A*g8*x6 - 
     3.7731495679189183e-9*A9*g3*x8 + 
     6.81148651466673022e-8*A6*g5*x8 - 
     5.41126426776092471e-8*A3*g7*x8 + 
     9.60423280700958978e-10*g9*x8 - 
     6.06051978329905884e-9*A8*g4*x10 + 
     6.45172101423398301e-8*A5*g6*x10 - 
     2.31853730369969274e-8*A2*g8*x10 - 
     5.69384641167539249e-9*A7*g5*x12 + 
     3.45031778931260666e-8*A4*g7*x12 - 
     4.5856200745095094e-9*A*g9*x12 - 
     3.36446046321516529e-9*A6*g6*x14 + 
     1.08170138123001676e-8*A3*g8*x14 - 
     3.37300366179434001e-10*g10*x14 - 
     1.30060474988550597e-9*A5*g7*x16 + 
     1.9676600421073939e-9*A2*g9*x16 - 
     3.33854146037989048e-10*A4*g8*x18 + 
     1.92027951778477411e-10*A*g10*x18 - 
     5.64147807443152692e-11*A3*g9*x20 + 
     7.76866625886353525e-12*g11*x20 - 
     6.03122771185984168e-12*A2*g10*x22 - 
     3.69809171837544212e-13*A*g11*x24 - 
     9.90994892123906548e-15*g12*x26) + 
  0.00833333333333333333*eps*g*xbar2 + 
  0.166666666666666667*(A + 0.5*g*x2)*xbar2 + 
  eps3*(-0.000793650793650793651*A*g - 
     0.00138888888888888889*g2*x2)*xbar2 + 
  eps2*(-0.00277777777777777778*A2 - 
     0.0111111111111111111*A*g*x2 - 
     0.00208333333333333333*g2*x4)*xbar2 + 
  eps5*(0.0000727513227513227513*A2*g + 
     0.000522486772486772487*A*g2*x2 + 
     0.000162037037037037037*g3*x4)*xbar2 + 
  eps4*(0.0000661375661375661376*A3 - 
     0.0000644841269841269841*g2 + 
     0.0015873015873015873*A2*g*x2 + 
     0.00094246031746031746*A*g2*x4 + 
     0.000115740740740740741*g3*x6)*xbar2 + 
  eps7*(-6.91438191438191438e-6*A3*g + 
     1.41486599819933153e-6*g3 - 
     0.000128066378066378066*A2*g2*x2 - 
     0.000110705266955266955*A*g3*x4 - 
     0.000018647119341563786*g4*x6)*xbar2 + 
  eps6*(-1.65343915343915344e-6*A4 + 
     0.0000179623617123617124*A*g2 - 
     0.00021164021164021164*A3*g*x2 + 
     0.0000485008818342151675*g3*x2 - 
     0.000276951058201058201*A2*g2*x4 - 
     0.0000898368606701940035*A*g3*x6 - 
     8.27867798353909465e-6*g4*x8)*xbar2 + 
  eps9*(6.79829796893288957e-7*A4*g - 
     6.72419695237155555e-7*A*g3 + 
     0.0000254975770848786722*A3*g2*x2 - 
     2.25056258042369153e-6*g4*x2 + 
     0.0000441438108848823135*A2*g3*x4 + 
     0.0000185871013417309714*A*g4*x6 + 
     2.15148764772607365e-6*g5*x8)*xbar2 + 
  eps8*(4.1753513975736198e-8*A5 - 
     3.46221514376276281e-6*A2*g2 + 
     0.0000267222489444711667*A4*g*x2 - 
     0.0000281804101248545693*A*g3*x2 + 
     0.0000649475909892576559*A3*g2*x4 - 
     0.0000122030666735527847*g4*x4 + 
     0.0000403965247715247715*A2*g3*x6 + 
     9.0700810463541945e-6*A*g4*x8 + 
     6.69795953360768176e-7*g5*x10)*xbar2 + 
  eps11*(-6.80612866459427306e-8*A5*g + 
     1.95584655809718057e-7*A2*g3 - 
     4.47269759439071608e-6*A4*g2*x2 + 
     1.75829988748211593e-6*A*g4*x2 - 
     0.0000133314481239415102*A3*g3*x4 + 
     9.71399147418687179e-7*g5*x4 - 
     0.0000103064498801381517*A2*g4*x6 - 
     2.82142523293179157e-6*A*g5*x8 - 
     2.4892365507720446e-7*g6*x10)*xbar2 + 
  eps10*(-1.05683802773749864e-9*A6 + 
     5.67501373552960855e-7*A3*g2 - 
     4.8511255774108832e-8*g4 - 
     3.24660642120959581e-6*A5*g*x2 + 
     9.71126169538867952e-6*A2*g3*x2 - 
     0.0000131832441790279092*A4*g2*x4 + 
     0.0000108846610427711618*A*g4*x4 - 
     0.0000136365860158849577*A3*g3*x6 + 
     2.33168885512635513e-6*g5*x6 - 
     5.4993290386188865e-6*A2*g4*x8 - 
     9.46094479080590192e-7*A*g5*x10 - 
     5.8302302889011994e-8*g6*x12)*xbar2 + 
  eps13*(6.86627585651083939e-9*A6*g - 
     4.47785160224899766e-8*A3*g3 + 
     2.19249275444418889e-9*g5 + 
     7.19946098097358602e-7*A5*g2*x2 - 
     7.80379784965903039e-7*A2*g4*x2 + 
     3.37142842641135708e-6*A4*g3*x4 - 
     1.06398186364605041e-6*A*g5*x4 + 
     4.18165456228327982e-6*A3*g4*x6 - 
     2.76351067919865578e-7*g6*x6 + 
     2.00589567077445504e-6*A2*g5*x8 + 
     4.04753308555164946e-7*A*g6*x10 + 
     2.88571475583667131e-8*g7*x12)*xbar2 + 
  eps12*(2.67650730613693577e-11*A7 - 
     8.46192910475220622e-8*A4*g2 + 
     3.25142589196534057e-8*A*g4 + 
     3.83704087407791111e-7*A6*g*x2 - 
     2.57283359783619147e-6*A3*g3*x2 + 
     1.27951218977907431e-7*g5*x2 + 
     2.41765559329216737e-6*A5*g2*x4 - 
     5.44480881814382923e-6*A2*g4*x4 + 
     3.82233569685344377e-6*A4*g3*x6 - 
     2.81139544164632672e-6*A*g5*x6 + 
     2.42710273474001612e-6*A3*g4*x8 - 
     3.92027350262991887e-7*g6*x8 + 
     7.21984500196305752e-7*A2*g5*x10 + 
     1.007566064009769e-7*A*g6*x12 + 
     5.32759708629371695e-9*g7*x14)*xbar2 + 
  eps15*(-6.94677964495491896e-10*A7*g + 
     8.85485037384606633e-9*A4*g3 - 
     1.89784940868103996e-9*A*g5 - 
     1.08873720111587578e-7*A6*g2*x2 + 
     2.58200627219967634e-7*A3*g4*x2 - 
     8.57415659878293831e-9*g6*x2 - 
     7.52178044272582197e-7*A5*g3*x4 + 
     6.39174172204870162e-7*A2*g5*x4 - 
     1.38311030669262085e-6*A4*g4*x6 + 
     3.89805821462228289e-7*A*g6*x6 - 
     1.02272071613530239e-6*A3*g5*x8 + 
     6.35874554600849527e-8*g7*x8 - 
     3.51191445940869782e-7*A2*g6*x10 - 
     5.59975947545884819e-8*A*g7*x12 - 
     3.35001083013772154e-9*g8*x14)*xbar2 + 
  eps14*(-6.77936059264516573e-13*A8 + 
     1.18453251754498057e-8*A5*g2 - 
     1.26192122113177278e-8*A2*g4 - 
     4.44292175799593582e-8*A7*g*x2 + 
     5.78235471803035281e-7*A4*g3*x2 - 
     1.25465164813262727e-7*A*g5*x2 - 
     4.11093596933471078e-7*A6*g2*x4 + 
     2.00802343589623813e-6*A3*g4*x4 - 
     8.38456228452171631e-8*g6*x4 - 
     9.37962675222683393e-7*A5*g3*x6 + 
     1.84660973293660698e-6*A2*g5*x6 - 
     8.68952732620502728e-7*A4*g4*x8 + 
     5.95974150882540242e-7*A*g6*x8 - 
     3.93789587968658131e-7*A3*g5*x10 + 
     6.11861559616332661e-8*g7*x10 - 
     9.26911580977221589e-8*A2*g6*x12 - 
     1.08851336477984649e-8*A*g7*x14 - 
     5.04016698893419468e-10*g8*x16)*xbar2 + 
  eps17*(7.03519796756268115e-11*A8*g - 
     1.58412622695254907e-9*A5*g3 + 
     9.21824723042734146e-10*A2*g5 + 
     1.57013176618403867e-8*A7*g2*x2 - 
     7.07877152349972815e-8*A4*g4*x2 + 
     1.01145514044440416e-8*A*g6*x2 + 
     1.52755677874009072e-7*A6*g3*x4 - 
     2.78303968964189299e-7*A3*g5*x4 + 
     7.90216106829461597e-9*g7*x4 + 
     3.94839847004885584e-7*A5*g4*x6 - 
     2.95546266642869418e-7*A2*g6*x6 + 
     4.1812888733216445e-7*A4*g5*x8 - 
     1.09749260429676339e-7*A*g7*x8 + 
     2.15692160440115788e-7*A3*g6*x10 - 
     1.28547064754435117e-8*g8*x10 + 
     5.73688513495873601e-8*A2*g7*x12 + 
     7.55383153004710777e-9*A*g8*x14 + 
     3.89293296941875901e-10*g9*x16)*xbar2 + 
  eps16*(1.71721241125556891e-14*A9 - 
     1.58463391176416606e-9*A6*g2 + 
     3.70687203668986364e-9*A3*g4 - 
     1.21950914958299276e-10*g6 + 
     5.06426546628202339e-9*A8*g*x2 - 
     1.15919331839795365e-7*A5*g3*x2 + 
     6.813324046201634e-8*A2*g5*x2 + 
     6.59264102615256734e-8*A7*g2*x4 - 
     6.0783143535697607e-7*A4*g4*x4 + 
     1.08734552181364072e-7*A*g6*x4 + 
     2.08077893379438207e-7*A6*g3*x6 - 
     8.7376194571684116e-7*A3*g5*x6 + 
     3.31435423816449871e-8*g7*x6 + 
     2.67286143174399604e-7*A5*g4*x8 - 
     4.84990273878282454e-7*A2*g6*x8 + 
     1.71677767909550515e-7*A4*g5*x10 - 
     1.12268658721773254e-7*A*g7*x10 + 
     6.02176056859808662e-8*A3*g6*x12 - 
     9.09453722352822717e-9*g8*x12 + 
     1.17208819972660499e-8*A2*g7*x14 + 
     1.18834173730462595e-9*A*g8*x16 + 
     4.8940576382579539e-11*g9*x18)*xbar2 + 
  eps19*(-7.12707337587569786e-12*A9*g + 
     2.63376364359160315e-10*A6*g3 - 
     3.30780046645030994e-10*A3*g5 + 
     8.03679335161609342e-12*g7 - 
     2.18139573549146275e-9*A8*g2*x2 + 
     1.6989863583308778e-8*A5*g4*x2 - 
     6.4969385102430346e-9*A2*g6*x2 - 
     2.88250590711040757e-8*A7*g3*x4 + 
     9.81072496878526138e-8*A4*g5*x4 - 
     1.18346882869724656e-8*A*g7*x4 - 
     1.00731210992033847e-7*A6*g4*x6 + 
     1.59691202088983395e-7*A3*g6*x6 - 
     4.13548363870289057e-9*g8*x6 - 
     1.45496453255537213e-7*A5*g5*x8 + 
     1.00501516554651165e-7*A2*g7*x8 - 
     1.05051610378898918e-7*A4*g6*x10 + 
     2.62399674415998082e-8*A*g8*x10 - 
     4.12244346987175346e-8*A3*g7*x12 + 
     2.38101241880130705e-9*g9*x12 - 
     8.92371773273422321e-9*A2*g8*x14 - 
     1.00013636391153993e-9*A*g9*x16 - 
     4.52724718151082609e-11*g10*x18)*xbar2 + 
  eps18*(-4.34973739711612375e-16*A10 + 
     2.04866596742209561e-10*A7*g2 - 
     9.13337973503563032e-10*A4*g4 + 
     1.29494994082815314e-10*A*g6 - 
     5.70128780114804572e-10*A9*g*x2 + 
     2.13523668994309077e-8*A6*g3*x2 - 
     2.7041278749459319e-8*A3*g5*x2 + 
     6.61136770529593115e-10*g7*x2 - 
     1.00900226220693725e-8*A8*g2*x4 + 
     1.59771473522731497e-7*A5*g4*x4 - 
     7.62149977963186539e-8*A2*g6*x4 - 
     4.26288251723329756e-8*A7*g3*x6 + 
     3.32905368200259132e-7*A4*g5*x6 - 
     5.34789893441100738e-8*A*g7*x6 - 
     7.31666710191171495e-8*A6*g4*x8 + 
     2.80197106079331506e-7*A3*g6*x8 - 
     9.98659790379859243e-9*g8*x8 - 
     6.35106992331774466e-8*A5*g5*x10 + 
     1.08995209478400767e-7*A2*g7*x10 - 
     3.09539659674895079e-8*A4*g6*x12 + 
     1.95483783519714526e-8*A*g8*x12 - 
     8.83724740598401241e-9*A3*g7*x14 + 
     1.30582050443893102e-9*g9*x14 - 
     1.46593717511110234e-9*A2*g8*x16 - 
     1.30772635674859038e-10*A*g9*x18 - 
     4.84955398928857724e-12*g10*x20)*xbar2 + 
  eps21*(7.22090117277105046e-13*A10*g - 
     4.13991085301446953e-11*A7*g3 + 
     9.76589682716262956e-11*A4*g5 - 
     1.01171462635282484e-11*A*g7 + 
     2.94059482872196453e-10*A9*g2*x2 - 
     3.68979054877682005e-9*A6*g4*x2 + 
     3.00808714445394687e-9*A3*g6*x2 - 
     5.76746247671597889e-11*g8*x2 + 
     5.12696720776491515e-9*A8*g3*x4 - 
     2.96928069363177013e-8*A5*g5*x4 + 
     9.47962261651077826e-9*A2*g7*x4 + 
     2.35049540761358863e-8*A7*g4*x6 - 
     6.88556064847354174e-8*A4*g6*x6 + 
     7.5086659172629484e-9*A*g8*x6 + 
     4.47020768444263473e-8*A6*g5*x8 - 
     6.48548347717962229e-8*A3*g7*x8 + 
     1.57872287719044645e-9*g9*x8 + 
     4.31283591778531503e-8*A5*g6*x10 - 
     2.81624636750572854e-8*A2*g8*x10 + 
     2.3304946259676748e-8*A4*g7*x12 - 
     5.6106802334762125e-9*A*g9*x12 + 
     7.34468856466444926e-9*A3*g8*x14 - 
     4.14021761190658312e-10*g10*x14 + 
     1.33841053507869873e-9*A2*g9*x16 + 
     1.30531947930356562e-10*A*g10*x18 + 
     5.26795343697585529e-12*g11*x20)*xbar2 + 
  eps20*(1.1018005656720459e-17*A11 - 
     2.57889246901160178e-11*A8*g2 + 
     1.98990234155769708e-10*A5*g4 - 
     7.55965424361672699e-11*A2*g6 + 
     6.35426896472572163e-11*A10*g*x2 - 
     3.68388963577669912e-9*A7*g3*x2 + 
     8.75177480890399108e-9*A4*g5*x2 - 
     9.11535637885301799e-10*A*g7*x2 + 
     1.48649455332149944e-9*A9*g2*x4 - 
     3.77359746051647268e-8*A6*g4*x4 + 
     3.82594204726996217e-8*A3*g6*x4 - 
     8.13304101172221063e-10*g8*x4 + 
     8.18713369443791778e-9*A8*g3*x6 - 
     1.08366523313337395e-7*A5*g5*x6 + 
     4.5944289943616577e-8*A2*g7*x6 + 
     1.82487684327326814e-8*A7*g4*x8 - 
     1.28729795350649249e-7*A4*g6*x8 + 
     1.92747318307891877e-8*A*g8*x8 + 
     2.06867607666613227e-8*A6*g5*x10 - 
     7.43763204190519753e-8*A3*g7*x10 + 
     2.53626156501045944e-9*g9*x10 + 
     1.33838352059798451e-8*A5*g6*x12 - 
     2.20494122463979174e-8*A2*g8*x12 + 
     5.23330987914141423e-9*A4*g7*x14 - 
     3.21750395058170305e-9*A*g9*x14 + 
     1.25827561244148185e-9*A3*g8*x16 - 
     1.82713361623688652e-10*g10*x16 + 
     1.81827783439828152e-10*A2*g9*x18 + 
     1.44818570824073778e-11*A*g10*x20 + 
     4.88417660313835094e-13*g11*x22)*xbar2 + 
  eps22*(-2.79089293716250467e-19*A12 + 
     3.17766604095748225e-12*A9*g2 - 
     3.95577368582764204e-11*A6*g4 + 
     3.2068101326980409e-11*A3*g6 - 
     6.12076747703341304e-13*g8 - 
     7.02351204594746519e-12*A11*g*x2 + 
     6.03214212931090113e-10*A8*g3*x2 - 
     2.44702734746155151e-9*A5*g5*x2 + 
     6.76097426096149884e-10*A2*g7*x2 - 
     2.12157940796992025e-10*A10*g2*x4 + 
     8.1916797369498686e-9*A7*g4*x4 - 
     1.53944612844692757e-8*A4*g6*x4 + 
     1.38109622177934475e-9*A*g8*x4 - 
     1.49038549899160153e-9*A9*g3*x6 + 
     3.12551588277558658e-8*A6*g5*x6 - 
     2.79047223116628872e-8*A3*g7*x6 + 
     5.436847471574281e-10*g9*x6 - 
     4.21695720957640858e-9*A8*g4*x8 + 
     4.99819767239979985e-8*A5*g6*x8 - 
     1.96069567048585921e-8*A2*g8*x8 - 
     6.0820173561110201e-9*A7*g5*x10 + 
     4.00069800775570726e-8*A4*g7*x10 - 
     5.69705873785929584e-9*A*g9*x10 - 
     5.05592156438231298e-9*A6*g6*x12 + 
     1.73541009641709023e-8*A3*g8*x12 - 
     5.72444406380114732e-10*g10*x12 - 
     2.58984982240261447e-9*A5*g7*x14 + 
     4.13461348937075909e-9*A2*g9*x14 - 
     8.43540110516749951e-10*A4*g8*x16 + 
     5.07648285991122299e-10*A*g10*x16 - 
     1.75053485949267209e-10*A3*g9*x18 + 
     2.50585955675889897e-11*g11*x18 - 
     2.24065847218371337e-11*A2*g10*x20 - 
     1.61190422371025444e-12*A*g11*x22 - 
     4.98497255151051565e-14*g12*x24)*xbar2 + 
  0.00833333333333333333*g*xbar4 - 
  0.0000462962962962962963*eps3*g2*xbar4 + 
  eps2*(-0.000396825396825396825*A*g - 
     0.000694444444444444444*g2*x2)*xbar4 + 
  eps5*(9.11896745230078563e-6*A*g2 + 
     0.0000308641975308641975*g3*x2)*xbar4 + 
  eps4*(0.0000198412698412698413*A2*g + 
     0.000195105820105820106*A*g2*x2 + 
     0.0000617283950617283951*g3*x4)*xbar4 + 
  eps7*(-1.31581381581381581e-6*A2*g2 - 
     0.0000151318588818588819*A*g3*x2 - 
     6.8455207344096233e-6*g4*x4)*xbar4 + 
  eps6*(-9.01875901875901876e-7*A3*g + 
     9.90714532381199048e-7*g3 - 
     0.0000389059243225909893*A2*g2*x2 - 
     0.0000351397573619795842*A*g3*x4 - 
     5.9477880658436214e-6*g4*x6)*xbar4 + 
  eps9*(1.71045640622360199e-7*A3*g2 - 
     3.60906857706966639e-8*g4 + 
     4.53245406122390249e-6*A2*g3*x2 + 
     5.38783061931210079e-6*A*g4*x4 + 
     1.17492514772607365e-6*g5*x6)*xbar4 + 
  eps8*(3.77616945077262538e-8*A4*g - 
     3.91505723846993688e-7*A*g3 + 
     6.55938527962337486e-6*A3*g2*x2 - 
     1.61985166325444103e-6*g4*x2 + 
     0.0000121547079219036891*A2*g3*x4 + 
     5.20508405346368309e-6*A*g4*x6 + 
     6.02301130368259998e-7*g5*x8)*xbar4 + 
  eps11*(-2.12135350797297057e-8*A4*g2 + 
     2.14460056215349951e-8*A*g4 - 
     1.06401470496877178e-6*A3*g3*x2 + 
     9.9419658966568008e-8*g5*x2 - 
     2.4228308825712602e-6*A2*g4*x4 - 
     1.28380796826126347e-6*A*g5*x6 - 
     1.80516340332649186e-7*g6*x8)*xbar4 + 
  eps10*(-1.48202033122668043e-9*A5*g + 
     9.77137892841674354e-8*A2*g3 - 
     9.98537198520664129e-7*A4*g2*x2 + 
     1.12096864298613054e-6*A*g4*x2 - 
     3.25929867376075489e-6*A3*g3*x4 + 
     6.52088831782005348e-7*g5*x4 - 
     2.59007734102806854e-6*A2*g4*x6 - 
     7.14333704061713321e-7*A*g5*x8 - 
     6.28878290312510992e-8*g6*x10)*xbar4 + 
  eps13*(2.55551047231023315e-9*A5*g2 - 
     7.48454109323006102e-9*A2*g4 + 
     2.14869723911233424e-7*A4*g3*x2 - 
     8.87037184673700903e-8*A*g5*x2 + 
     8.1367411096167446e-7*A3*g4*x4 - 
     6.24554324051377381e-8*g6*x4 + 
     7.73534185148061632e-7*A2*g5*x6 + 
     2.53114332805174734e-7*A*g6*x8 + 
     2.60907174059342559e-8*g7*x10)*xbar4 + 
  eps12*(5.52620037914155561e-11*A6*g - 
     1.96395897468419557e-8*A3*g3 + 
     1.73105497543500998e-9*g5 + 
     1.41930118072774209e-7*A5*g2*x2 - 
     4.4751871911848506e-7*A2*g4*x2 + 
     7.4329679752095632e-7*A4*g3*x4 - 
     6.48579919839268283e-7*A*g5*x4 + 
     9.56849686940199225e-7*A3*g4*x6 - 
     1.72592309647809413e-7*g6*x6 + 
     4.6549037372399414e-7*A2*g5*x8 + 
     9.4234108977460504e-8*A*g6*x10 + 
     6.6997976279157566e-9*g7*x12)*xbar4 + 
  eps15*(-3.01110179246578381e-10*A6*g2 + 
     1.99854473307210245e-9*A3*g4 - 
     1.0075222178954846e-10*g6 - 
     3.91236879782746971e-8*A5*g3*x2 + 
     4.42468326545839399e-8*A2*g5*x2 - 
     2.26449722207185509e-7*A4*g4*x4 + 
     7.48610321580336637e-8*A*g6*x4 - 
     3.38794481457344831e-7*A3*g5*x6 + 
     2.34467193453680488e-8*g7*x6 - 
     1.91586076465687549e-7*A2*g6*x8 - 
     4.4705147415174641e-8*A*g7*x10 - 
     3.62790374951045814e-9*g8*x12)*xbar4 + 
  eps14*(-1.97753534590218582e-12*A7*g + 
     3.46651613447685113e-9*A4*g3 - 
     1.3675698718070872e-9*A*g5 - 
     1.92080361104674656e-8*A6*g2*x2 + 
     1.34714593349386061e-7*A3*g4*x2 - 
     7.0165116069938331e-9*g6*x2 - 
     1.51234778678998732e-7*A5*g3*x4 + 
     3.57677410764887609e-7*A2*g5*x4 - 
     2.9119323970204683e-7*A4*g4*x6 + 
     2.24757818721415644e-7*A*g6*x6 - 
     2.19654624683123427e-7*A3*g5*x8 + 
     3.71577620957842484e-8*g7*x8 - 
     7.60245440599503551e-8*A2*g6*x10 - 
     1.21363875909823901e-8*A*g7*x12 - 
     7.23898306636066601e-10*g8*x14)*xbar4 + 
  eps17*(3.48460743277465292e-11*A7*g2 - 
     4.51506468378503526e-10*A4*g4 + 
     9.93046484625324211e-11*A*g6 + 
     6.6025042810186813e-9*A6*g3*x2 - 
     1.62520631488663842e-8*A3*g5*x2 + 
     5.61230122018474251e-10*g7*x2 + 
     5.51380920101008308e-8*A5*g4*x4 - 
     4.88479275078761747e-8*A2*g6*x4 + 
     1.20320332856371923e-7*A4*g5*x6 - 
     3.5365653527819202e-8*A*g7*x6 + 
     1.03628614951869648e-7*A3*g6*x8 - 
     6.71263413921269682e-9*g8*x8 + 
     4.07776601703241782e-8*A2*g7*x10 + 
     7.34880420888892836e-9*A*g8*x12 + 
     4.91163816649064884e-10*g9*x14)*xbar4 + 
  eps16*(6.84233044511131468e-14*A8*g - 
     5.60464705059266925e-10*A5*g3 + 
     6.1113506912043867e-10*A2*g5 + 
     2.50582201503812155e-9*A7*g2*x2 - 
     3.39024845059116986e-8*A4*g4*x2 + 
     7.66141086125169516e-9*A*g6*x2 + 
     2.82533097805425257e-8*A6*g3*x4 - 
     1.44153074493338505e-7*A3*g5*x4 + 
     6.29165697711773721e-9*g7*x4 + 
     7.70955531949116842e-8*A5*g4*x6 - 
     1.5856345215569678e-7*A2*g6*x6 + 
     8.37319173204484218e-8*A4*g5*x8 - 
     5.99155536147365961e-8*A*g7*x8 + 
     4.37139891312553985e-8*A3*g6*x10 - 
     7.07392441584795305e-9*g8*x10 + 
     1.16805756794796047e-8*A2*g7*x12 + 
     1.53807088851897092e-9*A*g8*x14 + 
     7.90314013633620188e-11*g9*x16)*xbar4 + 
  eps19*(-3.97340865876564659e-12*A8*g2 + 
     9.08389634660042267e-11*A5*g4 - 
     5.40989729447639056e-11*A2*g6 - 
     1.05114495716806379e-9*A7*g3*x2 + 
     4.89773729086143515e-9*A4*g5*x2 - 
     7.24791876301819899e-10*A*g7*x2 - 
     1.21370267986698838e-8*A6*g4*x4 + 
     2.29597017376750524e-8*A3*g6*x4 - 
     6.7748721115604107e-10*g8*x4 - 
     3.67138156717417151e-8*A5*g5*x6 + 
     2.85584385486008741e-8*A2*g7*x6 - 
     4.48093489348219503e-8*A4*g6*x8 + 
     1.22153837054061484e-8*A*g8*x8 - 
     2.6272947304230525e-8*A3*g7*x10 + 
     1.62436680861277498e-9*g9*x10 - 
     7.84757421369128482e-9*A2*g8*x12 - 
     1.1484952449755475e-9*A*g9*x14 - 
     6.52079226899128072e-11*g10*x16)*xbar4 + 
  eps18*(-2.30220514713186019e-15*A9*g + 
     8.50336672523331952e-11*A6*g3 - 
     2.03099120170330866e-10*A3*g5 + 
     6.86599038065945835e-12*g7 - 
     3.17730510813967685e-10*A8*g2*x2 + 
     7.52334651318304606e-9*A5*g4*x2 - 
     4.58441975864061026e-9*A2*g6*x2 - 
     4.93856631341031329e-9*A7*g3*x4 + 
     4.73460373170155555e-8*A4*g5*x4 - 
     8.81541701496240287e-9*A*g7*x4 - 
     1.83568265106518087e-8*A6*g4*x6 + 
     8.0214964397589886e-8*A3*g6*x6 - 
     3.16831385872351314e-9*g8*x6 - 
     2.73264771648576643e-8*A5*g5*x8 + 
     5.15584868924249984e-8*A2*g7*x8 - 
     2.00422243527645685e-8*A4*g6*x10 + 
     1.36105580520898305e-8*A*g8*x10 - 
     7.92549659107905268e-9*A3*g7*x12 + 
     1.24112226442452554e-9*g9*x12 - 
     1.72024465137340275e-9*A2*g8*x14 - 
     1.92684278620064115e-10*A*g9*x16 - 
     8.69704747258045207e-12*g10*x18)*xbar4 + 
  eps21*(4.47608018566873029e-13*A9*g2 - 
     1.67753308125991472e-11*A6*g4 + 
     2.15143559796472255e-11*A3*g6 - 
     5.36097713439665228e-13*g8 + 
     1.59789748504864926e-10*A8*g3*x2 - 
     1.28169491309084248e-9*A5*g5*x2 + 
     5.05873112365848404e-10*A2*g7*x2 + 
     2.46793239696357667e-9*A7*g4*x4 - 
     8.69126604407042738e-9*A4*g6*x4 + 
     1.08592337487209441e-9*A*g8*x4 + 
     9.97215933211799948e-9*A6*g5*x6 - 
     1.63775632230861457e-8*A3*g7*x6 + 
     4.39638545658591092e-10*g9*x6 + 
     1.6446217893554322e-8*A5*g6*x8 - 
     1.17661894622675905e-8*A2*g8*x8 + 
     1.33981457517207347e-8*A4*g7*x10 - 
     3.46334251627866228e-9*A*g9*x10 + 
     5.87002262267861254e-9*A3*g8*x12 - 
     3.50481841251753294e-10*g10*x12 + 
     1.40564140813720233e-9*A2*g9*x14 + 
     1.72885003376200776e-10*A*g10*x16 + 
     8.52860757101693105e-12*g11*x18)*xbar4 + 
  eps20*(7.56595105695415785e-17*A10*g - 
     1.22932630659041053e-11*A7*g3 + 
     5.58459887241763578e-11*A4*g5 - 
     8.11455810014543089e-12*A*g7 + 
     3.9383320785984906e-11*A9*g2*x2 - 
     1.51976152664836327e-9*A6*g4*x2 + 
     1.98780657022334646e-9*A3*g6*x2 - 
     5.0284224652211995e-11*g8*x2 + 
     8.18366713361052766e-10*A8*g3*x4 - 
     1.34227304693417849e-8*A5*g5*x4 + 
     6.6399136914675485e-9*A2*g7*x4 + 
     4.01847928057574067e-9*A7*g4*x6 - 
     3.25458326731869081e-8*A4*g6*x6 + 
     5.42627614195641677e-9*A*g8*x6 + 
     7.91216320845347941e-9*A6*g5*x8 - 
     3.14137939839749592e-8*A3*g7*x8 + 
     1.16149233526855299e-9*g9*x8 + 
     7.7806358292877523e-9*A5*g6*x10 - 
     1.38304354148956577e-8*A2*g8*x10 + 
     4.24844294383596806e-9*A4*g7*x12 - 
     2.77563538429180564e-9*A*g9*x12 + 
     1.34573608785890679e-9*A3*g8*x14 - 
     2.05451606449403644e-10*g10*x14 + 
     2.45603481008104843e-10*A2*g9*x16 + 
     2.39299395598715992e-11*A*g10*x18 + 
     9.63092387870827136e-13*g11*x20)*xbar4 - 
  0.0000154320987654320988*eps2*g2*xbar6 + 
  3.56125356125356125e-7*eps5*g3*xbar6 + 
  eps4*(1.90396023729357063e-6*A*g2 + 
     7.71604938271604938e-6*g3*x2)*xbar6 + 
  eps7*(-1.06760523427190094e-7*A*g3 - 
     5.83649889205444761e-7*g4*x2)*xbar6 + 
  eps6*(-1.58222876476844731e-7*A2*g2 - 
     3.0990100434544879e-6*A*g3*x2 - 
     1.45170544476100032e-6*g4*x4)*xbar6 + 
  eps9*(2.10474956623416007e-8*A2*g3 + 
     3.52066889376257568e-7*A*g4*x2 + 
     2.15683591284989252e-7*g5*x4)*xbar6 + 
  eps8*(1.0639753805538638e-8*A3*g2 - 
     1.44647796358943781e-8*g4 + 
     7.89019059521705024e-7*A2*g3*x2 + 
     9.93278626380478232e-7*A*g4*x4 + 
     2.19830466744046991e-7*g5*x6)*xbar6 + 
  eps11*(-3.48009271425128996e-9*A3*g3 + 
     7.74456172615070677e-10*g5 - 
     1.24759056081950737e-7*A2*g4*x2 - 
     1.93124743183608916e-7*A*g5*x4 - 
     5.26262283781649553e-8*g6*x6)*xbar6 + 
  eps10*(-6.21784885258793341e-10*A4*g2 + 
     7.35917308458240036e-9*A*g4 - 
     1.61082849737015107e-7*A3*g3*x2 + 
     4.25042008023580282e-8*g5*x2 - 
     3.97181909847740069e-7*A2*g4*x4 - 
     2.15693489113968417e-7*A*g5*x6 - 
     3.05361793587726322e-8*g6*x8)*xbar6 + 
  eps13*(5.22929181665348026e-10*A4*g3 - 
     5.49761548927799316e-10*A*g5 + 
     3.37795673591345898e-8*A3*g4*x2 - 
     3.32362369023656752e-9*g6*x2 + 
     9.70864128827426103e-8*A2*g5*x4 + 
     6.29082935052959515e-8*A*g6*x6 + 
     1.05359214957493409e-8*g7*x8)*xbar6 + 
  eps12*(3.28023733515722384e-11*A5*g2 - 
     2.2483490443839068e-9*A2*g4 + 
     2.87554439944054822e-8*A4*g3*x2 - 
     3.41643318587639607e-8*A*g5*x2 + 
     1.20413081223750724e-7*A3*g4*x4 - 
     2.54382194661358481e-8*g6*x4 + 
     1.18403247344882478e-7*A2*g5*x6 + 
     3.92485363936068314e-8*A*g6*x8 + 
     4.05810532585570662e-9*g7*x10)*xbar6 + 
  eps15*(-7.38610165433134699e-11*A5*g3 + 
     2.23185618064230175e-10*A2*g5 - 
     7.72550467360774725e-9*A4*g4*x2 + 
     3.33675225731002428e-9*A*g6*x2 - 
     3.60024022499056884e-8*A3*g5*x4 + 
     2.89391686340197044e-9*g7*x4 - 
     4.11034234008140627e-8*A2*g6*x6 - 
     1.58061594311664227e-8*A*g7*x8 - 
     1.88044966020543737e-9*g8*x10)*xbar6 + 
  eps14*(-1.59924972891624396e-12*A6*g2 + 
     5.34559467656326695e-10*A3*g4 - 
     4.89531412255654985e-11*g6 - 
     4.68743656687813986e-9*A5*g3*x2 + 
     1.55203340852120435e-8*A2*g5*x2 - 
     3.05848967636635251e-8*A4*g4*x4 + 
     2.80191583068273077e-8*A*g6*x4 - 
     4.77391188802852923e-8*A3*g5*x6 + 
     9.0249644584421326e-9*g7*x6 - 
     2.7500470429085428e-8*A2*g6*x8 - 
     6.46467617732357999e-9*A*g7*x10 - 
     5.25206836466407194e-10*g8*x12)*xbar6 + 
  eps17*(9.97455222947976728e-12*A6*g3 - 
     6.79725936335510667e-11*A3*g5 + 
     3.53973893285757087e-12*g7 + 
     1.57106382527547975e-9*A5*g4*x2 - 
     1.84906281043290629e-9*A2*g6*x2 + 
     1.0959810274248971e-8*A4*g5*x4 - 
     3.77750956813660573e-9*A*g7*x4 + 
     1.93914172243944712e-8*A3*g6*x6 - 
     1.39852236310538808e-9*g8*x6 + 
     1.27378874003962749e-8*A2*g7*x8 + 
     3.39967157316226349e-9*A*g8*x10 + 
     3.11454821672654227e-10*g9*x12)*xbar6 + 
  eps16*(7.32043787188737753e-14*A7*g2 - 
     1.08932623361419343e-10*A4*g4 + 
     4.43882953795228996e-11*A*g6 + 
     7.1553877265847084e-10*A6*g3*x2 - 
     5.23629960443907472e-9*A3*g5*x2 + 
     2.84608830720512483e-10*g7*x2 + 
     6.85430762519816909e-9*A5*g4*x4 - 
     1.69359418456327738e-8*A2*g6*x4 + 
     1.57308771746978335e-8*A4*g5*x6 - 
     1.26738239683828291e-8*A*g7*x6 + 
     1.38726146998630169e-8*A3*g6*x8 - 
     2.44574523622132431e-9*g8*x8 + 
     5.52081375700205184e-9*A2*g7*x10 + 
     9.99298373572599506e-10*A*g8*x12 + 
     6.67917519196695508e-11*g9*x14)*xbar6 + 
  eps19*(-1.30114590146037234e-12*A7*g3 + 
     1.72511713934239417e-11*A4*g5 - 
     3.90436685140620179e-12*A*g7 - 
     2.92867814057581221e-10*A6*g4*x2 + 
     7.46902977877224456e-10*A3*g6*x2 - 
     2.67522864508407854e-11*g8*x2 - 
     2.89699505443225961e-9*A5*g5*x4 + 
     2.66562938868512264e-9*A2*g7*x4 - 
     7.37795565467524207e-9*A4*g6*x6 + 
     2.25247153971908075e-9*A*g8*x6 - 
     7.30651817416318482e-9*A3*g7*x8 + 
     4.91176292870876797e-10*g9*x8 - 
     3.26224960924321828e-9*A2*g8*x10 - 
     6.59449314458554338e-10*A*g9*x12 - 
     4.89514760970749125e-11*g10*x14)*xbar6 + 
  eps18*(-3.18177848990088646e-15*A8*g2 + 
     1.99695443999379049e-11*A5*g4 - 
     2.23943125358944015e-11*A2*g6 - 
     1.03933552034436454e-10*A7*g3*x2 + 
     1.45959832999336206e-9*A4*g5*x2 - 
     3.42631031918890525e-10*A*g7*x2 - 
     1.39812800630481225e-9*A6*g4*x4 + 
     7.42096889844293084e-9*A3*g6*x4 - 
     3.37099552457525213e-10*g8*x4 - 
     4.48155653124553849e-9*A5*g5*x6 + 
     9.58666614025997167e-9*A2*g7*x6 - 
     5.62734416286699799e-9*A4*g6*x8 + 
     4.18363357640745376e-9*A*g8*x8 - 
     3.34880212849529458e-9*A3*g7*x10 + 
     5.62255597605531686e-10*g9*x10 - 
     1.00758346454303337e-9*A2*g8*x12 - 
     1.478403576160079e-10*A*g9*x14 - 
     8.38903736074731077e-12*g10*x16)*xbar6 + 
  eps20*(1.32423923182168128e-16*A9*g2 - 
     3.38762545168358761e-12*A6*g4 + 
     8.2936742090468515e-12*A3*g6 - 
     2.88553271599458446e-13*g8 + 
     1.45206721816612312e-11*A8*g3*x2 - 
     3.55365267771350475e-10*A5*g5*x2 + 
     2.24067642028217925e-10*A2*g7*x2 + 
     2.64931375976082846e-10*A7*g4*x4 - 
     2.63256077540054192e-9*A4*g6*x4 + 
     5.08380778036583002e-10*A*g8*x4 + 
     1.14232293931335993e-9*A6*g5*x6 - 
     5.17535342835764208e-9*A3*g7*x6 + 
     2.12052573958312186e-10*g9*x6 + 
     1.94686955319541028e-9*A5*g6*x8 - 
     3.80593235862788058e-9*A2*g8*x8 + 
     1.61506335347690598e-9*A4*g7*x10 - 
     1.13519934804077239e-9*A*g9*x10 + 
     7.1467043552215311e-10*A3*g8*x12 - 
     1.15698350133799093e-10*g10*x12 + 
     1.719691436452393e-10*A2*g9*x14 + 
     2.11817828858919301e-11*A*g10*x16 + 
     1.0439296901669795e-12*g11*x18)*xbar6 + 
  5.93542260208926876e-8*eps4*g3*xbar8 - 
  3.12288574815807931e-9*eps7*g4*xbar8 + 
  eps6*(-1.14340392118169896e-8*A*g3 - 
     9.02678854067742957e-8*g4*x2)*xbar8 + 
  eps9*(1.26121885620031857e-9*A*g4 + 
     1.00859349622512295e-8*g5*x2)*xbar8 + 
  eps8*(1.32727772394750297e-9*A2*g3 + 
     4.65033697944917988e-8*A*g4*x2 + 
     2.99054295797669073e-8*g5*x4)*xbar8 + 
  eps11*(-3.15709843216944468e-10*A2*g4 - 
     7.21099301568180965e-9*A*g5*x2 - 
     5.69746824484251863e-9*g6*x4)*xbar8 + 
  eps10*(-1.18235613578975095e-10*A3*g3 + 
     2.04522364126337295e-10*g5 - 
     1.4372001684607648e-8*A2*g4*x2 - 
     2.38545902650207871e-8*A*g5*x4 - 
     6.6442647298050802e-9*g6*x6)*xbar8 + 
  eps13*(6.34254881618462429e-11*A3*g4 - 
     1.4977795563804726e-11*g6 + 
     2.95036268409924151e-9*A2*g5*x2 + 
     5.72733871097688746e-9*A*g6*x4 + 
     1.89780374932858316e-9*g7*x6)*xbar8 + 
  eps12*(8.85933436332280376e-12*A4*g3 - 
     1.2695043367275619e-10*A*g5 + 
     3.44553148081436095e-9*A3*g4*x2 - 
     9.66117808074637814e-10*g6*x2 + 
     1.08393242236143663e-8*A2*g5*x4 + 
     7.24181767567549532e-9*A*g6*x6 + 
     1.22738677265426237e-9*g7*x8)*xbar8 + 
  eps15*(-1.1209244129052603e-11*A4*g4 + 
     1.23354796462055584e-11*A*g6 - 
     9.05322252904213583e-10*A3*g5*x2 + 
     9.34529456546429641e-11*g7*x2 - 
     3.18804749658072552e-9*A2*g6*x4 - 
     2.46989894878460521e-9*A*g7*x6 - 
     4.84553260391626981e-10*g8*x8)*xbar8 + 
  eps14*(-5.85591473164617337e-13*A5*g3 + 
     4.58152437519766974e-11*A2*g5 - 
     7.06061940978074562e-10*A4*g4*x2 + 
     8.8437067488213914e-10*A*g6*x2 - 
     3.6718459581734819e-9*A3*g5*x4 + 
     8.14572670487090063e-10*g7*x4 - 
     4.35865819040676537e-9*A2*g6*x6 - 
     1.70511399881374369e-9*A*g7*x8 - 
     2.04267683542374506e-10*g8*x10)*xbar8 + 
  eps17*(1.81850832862627129e-12*A5*g4 - 
     5.7018133606605742e-12*A2*g6 + 
     2.31363157692796144e-10*A4*g5*x2 - 
     1.04268313475235866e-10*A*g7*x2 + 
     1.29559671265166405e-9*A3*g6*x4 - 
     1.08608812804810835e-10*g8*x4 + 
     1.74321237740579218e-9*A2*g7*x6 + 
     7.76515634579396129e-10*A*g8*x8 + 
     1.05455124124405657e-10*g9*x10)*xbar8 + 
  eps16*(3.51441987362562031e-14*A6*g3 - 
     1.25669585862967901e-11*A3*g5 + 
     1.19873609386538047e-12*g7 + 
     1.29917477297039227e-10*A5*g4*x2 - 
     4.50505663684441363e-10*A2*g6*x2 + 
     1.0294836459233229e-9*A4*g5*x4 - 
     9.85762364733873057e-10*A*g7*x4 + 
     1.90892686734913978e-9*A3*g6*x6 - 
     3.76480107979462358e-10*g8*x6 + 
     1.28194605951425965e-9*A2*g7*x8 + 
     3.45797358676807567e-10*A*g8*x10 + 
     3.18111454415424726e-11*g9*x12)*xbar8 + 
  eps19*(-2.77181792125363476e-13*A6*g4 + 
     1.94851026920691567e-12*A3*g6 - 
     1.04933332657610013e-13*g8 - 
     5.1992259514176436e-11*A5*g5*x2 + 
     6.35571518081156783e-11*A2*g7*x2 - 
     4.28732342024609978e-10*A4*g6*x4 + 
     1.53545689985903239e-10*A*g8*x4 - 
     8.82875940509388448e-10*A3*g7*x6 + 
     6.61143800669246729e-11*g9*x6 - 
     6.65258660548452332e-10*A2*g8*x8 - 
     2.01099007966251153e-10*A*g9*x10 - 
     2.06386033152073184e-11*g10*x12)*xbar8 + 
  eps18*(-1.95213901631847725e-15*A7*g3 + 
     2.9024042061210064e-12*A4*g5 - 
     1.22464345499091446e-12*A*g7 - 
     2.20948357179324358e-11*A6*g4*x2 + 
     1.68407222784752482e-10*A3*g6*x2 - 
     9.52673617116155421e-12*g8*x2 - 
     2.52285174010719033e-10*A5*g5*x4 + 
     6.48893132761825578e-10*A2*g7*x4 - 
     6.78403369061433162e-10*A4*g6*x6 + 
     5.68290125969521456e-10*A*g8*x6 - 
     6.90033763945661382e-10*A3*g7*x8 + 
     1.26310595431481278e-10*g9*x8 - 
     3.12443265284225916e-10*A2*g8*x10 - 
     6.3597958994265421e-11*A*g9*x12 - 
     4.73255306775791468e-12*g10*x14)*xbar8 - 
  2.95801289810004407e-10*eps6*g4*xbar10 + 
  2.94346529368315861e-11*eps9*g5*xbar10 + 
  eps8*(7.69281785172546935e-11*A*g4 + 
     1.07490632635875918e-9*g5*x2)*xbar10 + 
  eps11*(-1.49854878334381416e-11*A*g5 - 
     1.64414869918985145e-10*g6*x2)*xbar10 + 
  eps10*(-1.14623038722347948e-11*A2*g4 - 
     6.72527675714427998e-10*A*g5*x2 - 
     5.64942074025452747e-10*g6*x4)*xbar10 + 
  eps13*(4.55203920804202245e-12*A2*g5 + 
     1.35763920347428776e-10*A*g6*x2 + 
     1.33652228562929386e-10*g7*x4)*xbar10 + 
  eps12*(1.27157831390982766e-12*A3*g4 - 
     2.82877994364105943e-12*g6 + 
     2.44160830279527547e-10*A2*g5*x2 + 
     5.14076796669365287e-10*A*g6*x4 + 
     1.75139799425245342e-10*g7*x6)*xbar10 + 
  eps15*(-1.07685636895144654e-12*A3*g5 + 
     2.70026199694243437e-13*g7 - 
     6.29652746661281415e-11*A2*g6*x2 - 
     1.49092240439933003e-10*A*g7*x4 - 
     5.88096054052166419e-11*g8*x6)*xbar10 + 
  eps14*(-1.16205790093287907e-13*A4*g4 + 
     2.06949189356323779e-12*A*g6 - 
     6.72146134669773312e-11*A3*g5*x2 + 
     1.99437288401862085e-11*g7*x2 - 
     2.61681510848862049e-10*A2*g6*x4 - 
     2.10127602166714473e-10*A*g7*x6 - 
     4.18842380479881739e-11*g8*x8)*xbar10 + 
  eps17*(2.18937302179867743e-13*A4*g5 - 
     2.52743776628905178e-13*A*g7 + 
     2.15933914153368247e-11*A3*g6*x2 - 
     2.33174044228357075e-12*g8*x2 + 
     9.10889047339860176e-11*A2*g7*x4 + 
     8.28793584781457544e-11*A*g8*x6 + 
     1.87814134450040901e-11*g9*x8)*xbar10 + 
  eps16*(9.22277143780367963e-15*A5*g4 - 
     8.60637474674818858e-13*A2*g6 + 
     1.55522012194999734e-11*A4*g5*x2 - 
     2.04738873511014663e-11*A*g7*x2 + 
     9.80212032242431517e-11*A3*g6*x4 - 
     2.27433206141358192e-11*g8*x4 + 
     1.3776069368825939e-10*A2*g7*x6 + 
     6.26447221848720574e-11*A*g8*x8 + 
     8.59289553201749293e-12*g9*x10)*xbar10 + 
  eps18*(-6.56399733698215579e-16*A6*g4 + 
     2.67367086954926804e-13*A3*g6 - 
     2.65773724648037072e-14*g8 - 
     3.1891761064266082e-12*A5*g5*x2 + 
     1.1556733294634019e-11*A2*g7*x2 - 
     3.00891865934477623e-11*A4*g6*x4 + 
     3.00144725725027383e-11*A*g8*x4 - 
     6.52019833501791742e-11*A3*g7*x6 + 
     1.33683467827448483e-11*g9*x6 - 
     5.03812647605675579e-11*A2*g8*x8 - 
     1.54328716110212964e-11*A*g9*x10 - 
     1.5943182436056292e-12*g10*x12)*xbar10 + 
  1.69722051530330397e-12*eps8*g5*xbar12 - 
  2.90595190793452012e-13*eps11*g6*xbar12 + 
  eps10*(-5.54575148020670988e-13*A*g5 - 
     1.29008964169185665e-11*g6*x2)*xbar12 + 
  eps13*(1.78798720202615632e-13*A*g6 + 
     2.57210159823889116e-12*g7*x2)*xbar12 + 
  eps12*(1.00869657097464141e-13*A2*g5 + 
     9.47632013657176953e-12*A*g6*x2 + 
     1.00368310409322369e-11*g7*x4)*xbar12 + 
  eps15*(-6.39010493062016058e-14*A2*g6 - 
     2.40693363499189255e-12*A*g7*x2 - 
     2.87715768832048683e-12*g8*x4)*xbar12 + 
  eps14*(-1.33953977785016062e-14*A3*g5 + 
     3.84980892713537606e-14*g7 - 
     3.94928486633783273e-12*A2*g6*x2 - 
     1.02511581325767213e-11*A*g7*x4 - 
     4.17899415533904787e-12*g8*x6)*xbar12 + 
  eps17*(1.73998403455957848e-14*A3*g6 - 
     4.62636803886378434e-15*g8 + 
     1.24741423146112554e-12*A2*g7*x2 + 
     3.52693455958173369e-12*A*g8*x4 + 
     1.62821302569789988e-12*g9*x6)*xbar12 + 
  eps16*(1.44440682820300384e-15*A4*g5 - 
     3.24022688540454265e-14*A*g7 + 
     1.22741801273679764e-12*A3*g6*x2 - 
     3.84061473377336244e-13*g8*x2 + 
     5.77793844380739442e-12*A2*g7*x4 + 
     5.47447616200335818e-12*A*g8*x6 + 
     1.26471026695269685e-12*g9*x8)*xbar12 - 
  1.06551186196798794e-14*eps10*g6*xbar14 + 
  2.96371424137457707e-15*eps13*g7*xbar14 + 
  eps12*(4.1883104771160436e-15*A*g6 + 
     1.55454784378046993e-13*g7*x2)*xbar14 + 
  eps15*(-2.14017433818550597e-15*A*g7 - 
     3.90198867402243257e-14*g8*x2)*xbar14 + 
  eps14*(-8.99454744512618591e-16*A2*g6 - 
     1.30968415155813316e-13*A*g7*x2 - 
     1.70308449198607365e-13*g8*x4)*xbar14 + 
  eps16*(1.39116436986363771e-16*A3*g6 - 
     5.17467765013076258e-16*g8 + 
     6.15890327064823114e-14*A2*g7*x2 + 
     1.92792938842998867e-13*A*g8*x4 + 
     9.24186997248047774e-14*g9*x6)*xbar14 + 
  7.1230636127202905e-17*eps12*g7*xbar16 - 
  3.09644400991606704e-17*eps15*g8*xbar16 + 
  eps14*(-3.27091744222075652e-17*A*g7 - 
     1.87737117146802168e-15*g8*x2)*xbar16 - 
  4.98845119121947873e-19*eps14*g8*xbar18;
}
#endif

#ifdef p25
double Wp(void)
{
   return 0.5*A*x2 + 0.0416666666666666667*g*x4 + 
  eps*(0.0833333333333333333*A + 0.0416666666666666667*g*x2) + 
  eps3*(-0.00277777777777777778*A2 - 
     0.0111111111111111111*A*g*x2 - 
     0.00208333333333333333*g2*x4) + 
  eps2*(0.00416666666666666667*g - 
     0.0416666666666666667*A2*x2 - 
     0.0138888888888888889*A*g*x4 - 
     0.00115740740740740741*g2*x6) + 
  eps5*(0.0001763668430335097*A3 - 
     0.0000388558201058201058*g2 + 
     0.00214947089947089947*A2*g*x2 + 
     0.00124007936507936508*A*g2*x4 + 
     0.000154320987654320988*g3*x6) + 
  eps4*(-0.000595238095238095238*A*g + 
     0.00416666666666666667*A3*x2 - 
     0.000868055555555555556*g2*x2 + 
     0.00347222222222222222*A2*g*x4 + 
     0.000810185185185185185*A*g2*x6 + 
     0.0000578703703703703704*g3*x8) + 
  eps7*(-0.0000132275132275132275*A4 + 
     0.000013452982202982203*A*g2 - 
     0.000353835978835978836*A3*g*x2 + 
     0.0000292107583774250441*g3*x2 - 
     0.000438161375661375661*A2*g2*x4 - 
     0.000141369047619047619*A*g3*x6 - 
     0.0000131815843621399177*g4*x8) + 
  eps6*(0.0000793650793650793651*A2*g - 
     0.000421626984126984127*A4*x2 + 
     0.000412533068783068783*A*g2*x2 - 
     0.000710978835978835979*A3*g*x4 + 
     0.00012359457671957672*g3*x4 - 
     0.000332065696649029982*A2*g2*x6 - 
     0.0000592482363315696649*A*g3*x8 - 
     3.61689814814814815e-6*g4*x10) + 
  eps9*(1.06888995777884667e-6*A5 - 
     3.09484386865339246e-6*A2*g2 + 
     0.000052889176153065042*A4*g*x2 - 
     0.0000196739667225778337*A*g3*x2 + 
     0.000118621733205066538*A3*g2*x4 - 
     8.12834124466068911e-6*g4*x4 + 
     0.0000723776288012399124*A2*g3*x6 + 
     0.0000162595142340512711*A*g4*x8 + 
     1.2123306755829904e-6*g5*x10) + 
  eps8*(-0.0000100208433541766875*A3*g + 
     8.50711788211788212e-7*g3 + 
     0.0000427138447971781305*A5*x2 - 
     0.000120331539602372936*A2*g2*x2 + 
     0.000127911890064667842*A4*g*x4 - 
     0.000098836830607663941*A*g3*x4 + 
     0.000102804110327258475*A3*g2*x6 - 
     0.0000165018585880854399*g4*x6 + 
     0.0000336428938859494415*A2*g3*x8 + 
     4.8512364050558495e-6*A*g4*x10 + 
     2.56755115454961134e-7*g5*x12) + 
  eps11*(-9.01835117002665504e-8*A6 + 
     5.87400058299529199e-7*A3*g2 - 
     2.81868399275952575e-8*g4 - 
     7.41416841780598394e-6*A5*g*x2 + 
     7.67116473755031956e-6*A2*g3*x2 - 
     0.000027147462601331649*A4*g2*x4 + 
     8.12031936990601012e-6*A*g4*x4 - 
     0.0000272310450812986086*A3*g3*x6 + 
     1.70667153812408442e-6*g5*x6 - 
     0.0000108933015093453806*A2*g4*x8 - 
     1.87850642976993286e-6*A*g5*x10 - 
     1.16690477054095881e-7*g6*x12) + 
  eps10*(1.21747740795359843e-6*A4*g - 
     4.62417873132158846e-7*A*g3 - 
     4.32775172358505692e-6*A6*x2 + 
     0.0000276277014248244407*A3*g2*x2 - 
     1.30445706075046353e-6*g4*x2 - 
     0.0000210333326652771097*A5*g*x4 + 
     0.0000447391253752860896*A2*g3*x4 - 
     0.0000265668910778864483*A4*g2*x6 + 
     0.0000184769777868736202*A*g4*x6 - 
     0.0000139376709110505407*A3*g3*x8 + 
     2.13520310814871e-6*g5*x8 - 
     3.5181249916492972e-6*A2*g4*x10 - 
     4.25407416871537242e-7*A*g5*x12 - 
     1.98147969535893919e-8*g6*x14) + 
  eps13*(7.83069566138349207e-9*A7 - 
     9.93094869534334209e-8*A4*g2 + 
     2.08755249185163841e-8*A*g4 + 
     9.92791119692574719e-7*A6*g*x2 - 
     2.26246788359770127e-6*A3*g3*x2 + 
     7.19774046753493046e-8*g5*x2 + 
     5.52538741816188906e-6*A5*g2*x4 - 
     4.47883727161149936e-6*A2*g4*x4 + 
     8.38601213983571788e-6*A4*g3*x6 - 
     2.25348627386308778e-6*A*g5*x6 + 
     5.24445855604457162e-6*A3*g4*x8 - 
     3.11392974798759566e-7*g6*x8 + 
     1.55465050346795001e-6*A2*g5*x10 + 
     2.17600880397466046e-7*A*g6*x12 + 
     1.15841884836628278e-8*g7*x14) + 
  eps12*(-1.43889032777921667e-7*A5*g + 
     1.51283642180000723e-7*A2*g3 + 
     4.38492191964414187e-7*A7*x2 - 
     5.47671197834474951e-6*A4*g2*x2 + 
     1.1365151365172641e-6*A*g4*x2 + 
     3.23789133106262736e-6*A6*g*x4 - 
     0.0000150481673660823793*A3*g3*x4 + 
     5.97324614725086198e-7*g5*x4 + 
     6.03932684613625972e-6*A5*g2*x6 - 
     0.0000113106765525436987*A2*g4*x6 + 
     4.69528859165240338e-6*A4*g3*x8 - 
     3.0694501391598228e-6*A*g5*x8 + 
     1.82557370238215146e-6*A3*g4*x10 - 
     2.71046144994230449e-7*g6*x10 + 
     3.7535031778135559e-7*A2*g5*x12 + 
     3.90681314457195373e-8*A*g6*x14 + 
     1.62260932077515154e-9*g7*x16) + 
  eps15*(-6.94206524686864971e-10*A8 + 
     1.55258266251201437e-8*A5*g2 - 
     8.87063997906019346e-9*A2*g4 - 
     1.28444091425696105e-7*A7*g*x2 + 
     5.59355511978255916e-7*A4*g3*x2 - 
     7.69591961687451275e-8*A*g5*x2 - 
     1.03084425773136674e-6*A6*g2*x4 + 
     1.80099658500984157e-6*A3*g4*x4 - 
     4.89852640150590245e-8*g6*x4 - 
     2.23744987275327073e-6*A5*g3*x6 + 
     1.60416803829389571e-6*A2*g5*x6 - 
     2.02887475090349778e-6*A4*g4*x8 + 
     5.10536772376168298e-7*A*g6*x8 - 
     9.11746562790846727e-7*A3*g5*x10 + 
     5.21769349658492833e-8*g7*x10 - 
     2.14341780318485671e-7*A2*g6*x12 - 
     2.52490551976121104e-8*A*g7*x14 - 
     1.17600420262660865e-9*g8*x16) + 
  eps14*(1.66609565924847593e-8*A6*g - 
     3.84541066603365207e-8*A3*g3 + 
     1.23616495716322489e-9*g5 - 
     4.44285396439000936e-8*A8*x2 + 
     9.81807578832239391e-7*A5*g2*x2 - 
     5.55101746448534654e-7*A2*g4*x2 - 
     4.73967830600877338e-7*A7*g*x4 + 
     4.18284859452059839e-6*A4*g3*x4 - 
     7.15343253702736788e-7*A*g5*x4 - 
     1.24663165145441196e-6*A6*g2*x6 + 
     5.00514675879205854e-6*A3*g4*x6 - 
     1.81402700349001079e-7*g6*x6 - 
     1.36226318220021373e-6*A5*g3*x8 + 
     2.36606032230627314e-6*A2*g5*x8 - 
     7.58172593612770117e-7*A4*g4*x10 + 
     4.75471890972483691e-7*A*g6*x10 - 
     2.34027522244261325e-7*A3*g5*x12 + 
     3.3963539821117207e-8*g7*x12 - 
     4.06050820222736176e-8*A2*g6*x14 - 
     3.70938742929349711e-9*A*g7*x16 - 
     1.38898528337180163e-10*g8*x18) + 
  eps17*(6.25217958800249802e-11*A9 - 
     2.29312206278746533e-9*A6*g2 + 
     2.8310089717477044e-9*A3*g4 - 
     6.71998649148490015e-11*g6 + 
     1.61783182535963035e-8*A8*g*x2 - 
     1.222198282975496e-7*A5*g3*x2 + 
     4.51903487294323094e-8*A2*g5*x2 + 
     1.79787422789127715e-7*A7*g2*x4 - 
     5.89386352242391962e-7*A4*g4*x4 + 
     6.83924293854497039e-8*A*g6*x4 + 
     5.35385253592035249e-7*A6*g3*x6 - 
     8.16161936426993263e-7*A3*g5*x6 + 
     2.03110694856709656e-8*g7*x6 + 
     6.69429955495357485e-7*A5*g4*x8 - 
     4.44812062546498445e-7*A2*g6*x8 + 
     4.24544759374608395e-7*A4*g5*x10 - 
     1.02125278182278717e-7*A*g7*x10 + 
     1.48190757087105866e-7*A3*g6*x12 - 
     8.25465653164429909e-9*g8*x12 + 
     2.8842218900714868e-8*A2*g7*x14 + 
     2.93316966296752154e-9*A*g8*x16 + 
     1.21426224678902097e-10*g9*x18) + 
  eps16*(-1.89909954985575877e-9*A7*g + 
     8.35603474047208798e-9*A4*g3 - 
     1.15966243496214952e-9*A*g5 + 
     4.50155213123768602e-9*A9*x2 - 
     1.63520154608933337e-7*A6*g2*x2 + 
     2.00125773929144853e-7*A3*g4*x2 - 
     4.71643935891082883e-9*g6*x2 + 
     6.66827009985439445e-8*A8*g*x4 - 
     1.01569722853466271e-6*A5*g3*x4 + 
     4.653753986331283e-7*A2*g5*x4 + 
     2.38609112997144637e-7*A7*g2*x6 - 
     1.78931879078472604e-6*A4*g4*x6 + 
     2.75782412054904595e-7*A*g6*x6 + 
     3.5257503626825941e-7*A6*g3*x8 - 
     1.29719583644083582e-6*A3*g5*x8 + 
     4.43904638337799842e-8*g7*x8 + 
     2.67563783428073661e-7*A5*g4*x10 - 
     4.41739629456479988e-7*A2*g6*x10 + 
     1.15544405881940575e-7*A4*g5*x12 - 
     7.03094817586759951e-8*A*g7*x12 + 
     2.95627516533174602e-8*A3*g6*x14 - 
     4.21593686904484474e-9*g8*x14 + 
     4.43746780874914946e-9*A2*g7*x16 + 
     3.61167459558351774e-10*A*g8*x18 + 
     1.23066706066192904e-11*g9*x20) + 
  eps19*(-5.70128780114804572e-12*A10 + 
     3.24325759393455769e-10*A7*g2 - 
     7.52920392642037898e-10*A4*g4 + 
     7.63432039813829238e-11*A*g6 - 
     1.99446765051272661e-9*A9*g*x2 + 
     2.43560018179573397e-8*A6*g3*x2 - 
     1.92651473964731419e-8*A3*g5*x2 + 
     3.57664504054283011e-10*g7*x2 - 
     2.97138844105769473e-8*A8*g2*x4 + 
     1.66367899286352586e-7*A5*g4*x4 - 
     5.12763843043703477e-8*A2*g6*x4 - 
     1.17558487781038256e-7*A7*g3*x6 + 
     3.32274083849900958e-7*A4*g5*x6 - 
     3.49339293457975036e-8*A*g7*x6 - 
     1.95421595481198395e-7*A6*g4*x8 + 
     2.73546099832218964e-7*A3*g6*x8 - 
     6.42119893976624269e-9*g8*x8 - 
     1.66845932629322826e-7*A5*g5*x10 + 
     1.05196992302604677e-7*A2*g7*x10 - 
     8.06653736383214643e-8*A4*g6*x12 + 
     1.87723844343482559e-8*A*g8*x12 - 
     2.29644918467110207e-8*A3*g7*x14 + 
     1.25288025697957571e-9*g9*x14 - 
     3.81165485194947533e-9*A2*g8*x16 - 
     3.41033212304414905e-10*A*g9*x18 - 
     1.27053709821831841e-11*g10*x20) + 
  eps18*(2.13798292543051714e-10*A8*g - 
     1.62899940163818617e-9*A5*g3 + 
     6.06739124374671626e-10*A2*g5 - 
     4.56102589118103946e-10*A10*x2 + 
     2.5741194154734252e-8*A7*g2*x2 - 
     5.93202934378594688e-8*A4*g4*x2 + 
     5.97796132442781859e-9*A*g6*x2 - 
     9.086017175115798e-9*A9*g*x4 + 
     2.22788546277779156e-7*A6*g3*x4 - 
     2.17818061292066124e-7*A3*g5*x4 + 
     4.46060201054250811e-9*g7*x4 - 
     4.29736286745591606e-8*A8*g2*x6 + 
     5.48218484132244335e-7*A5*g4*x6 - 
     2.23798601959230444e-7*A2*g6*x6 - 
     8.3334504765293729e-8*A7*g3*x8 + 
     5.66588387939462102e-7*A4*g5*x8 - 
     8.17078651256326395e-8*A*g7*x8 - 
     8.32572408053676287e-8*A6*g4*x10 + 
     2.88769211893932833e-7*A3*g6*x10 - 
     9.49367158787967084e-9*g8*x10 - 
     4.80270155903927102e-8*A5*g5*x12 + 
     7.64234973061525259e-8*A2*g7*x12 - 
     1.69136821548003748e-8*A4*g6*x14 + 
     1.00575293092506873e-8*A*g8*x14 - 
     3.69466622059472975e-9*A3*g7*x16 + 
     5.19597646877020836e-10*g9*x16 - 
     4.88723854749631574e-10*A2*g8*x18 - 
     3.58645537045585288e-11*A*g9*x20 - 
     1.12084057456710382e-12*g10*x22) + 
  eps21*(5.2514619543187782e-13*A11 - 
     4.43285954755604869e-11*A8*g2 + 
     1.76083788279021689e-10*A5*g4 - 
     4.74728753998211342e-11*A2*g6 + 
     2.41589075467910444e-10*A10*g*x2 - 
     4.51824485857656974e-9*A7*g3*x2 + 
     6.66083029216207287e-9*A4*g5*x2 - 
     5.24335874922835697e-10*A*g7*x2 + 
     4.69949475640663485e-9*A9*g2*x4 - 
     4.19656758646856316e-8*A6*g4*x4 + 
     2.73885212294566607e-8*A3*g6*x4 - 
     4.48244578272414887e-10*g8*x4 + 
     2.40727904510809782e-8*A8*g3*x6 - 
     1.14987302708287038e-7*A5*g5*x6 + 
     3.18314156293579248e-8*A2*g7*x6 + 
     5.1729556293745067e-8*A7*g4*x8 - 
     1.33139310440523761e-7*A4*g6*x8 + 
     1.31084047358048264e-8*A*g8*x8 + 
     5.74763592331078553e-8*A6*g5*x10 - 
     7.58285646214704478e-8*A3*g7*x10 + 
     1.70719938146989968e-9*g9*x10 + 
     3.67818305341475603e-8*A5*g6*x12 - 
     2.23107719453182269e-8*A2*g8*x12 + 
     1.43062528484956471e-8*A4*g7*x14 - 
     3.24546888412113238e-9*A*g9*x14 + 
     3.43426667042232431e-9*A3*g8*x16 - 
     1.84284319077257175e-10*g10*x16 + 
     4.96756814596081739e-10*A2*g9*x18 + 
     3.96764099826891058e-11*A*g10*x20 + 
     1.34372144042558418e-12*g11*x22) + 
  eps20*(-2.38285086177214561e-11*A9*g + 
     2.93087835503767857e-10*A6*g3 - 
     2.33284850513311582e-10*A3*g5 + 
     4.35358687387975124e-12*g7 + 
     4.62128541799995915e-11*A11*x2 - 
     3.87512747715920683e-9*A8*g2*x2 + 
     1.52963831343981389e-8*A5*g4*x2 - 
     4.10201649274809254e-9*A2*g6*x2 + 
     1.2058131859727143e-9*A10*g*x4 - 
     4.51251014708823542e-8*A7*g3*x4 + 
     8.20524658045556169e-8*A4*g5*x4 - 
     7.11455083461241557e-9*A*g7*x4 + 
     7.36094104464716057e-9*A9*g2*x6 - 
     1.49255884116928141e-7*A6*g4*x6 + 
     1.28707565844365563e-7*A3*g6*x6 - 
     2.42078453530071715e-9*g8*x6 + 
     1.82893288628610935e-8*A8*g3*x8 - 
     2.09524543137285467e-7*A5*g5*x8 + 
     7.93810679543179244e-8*A2*g7*x8 + 
     2.34179153309909358e-8*A7*g4*x10 - 
     1.48969846228119514e-7*A4*g6*x10 + 
     2.05019199855671562e-8*A*g8*x10 + 
     1.74575105847696841e-8*A6*g5*x12 - 
     5.80036979689224998e-8*A3*g7*x12 + 
     1.8510046912641176e-9*g9*x12 + 
     8.09148869608194122e-9*A5*g6*x14 - 
     1.251808839252206e-8*A2*g8*x14 + 
     2.40348962003249252e-9*A4*g7*x16 - 
     1.40328230011170153e-9*A*g9*x16 + 
     4.58007384146693616e-10*A3*g8*x18 - 
     6.36787892934133022e-11*g10*x18 + 
     5.41571641768509377e-11*A2*g9*x20 + 
     3.61823810155023661e-12*A*g10*x22 + 
     1.04407319287969897e-13*g11*x24) + 
  eps23*(-4.87743892079685082e-14*A12 + 
     5.89316491267758974e-12*A9*g2 - 
     3.73943263170943611e-11*A6*g4 + 
     2.13679155317563112e-11*A3*g6 - 
     3.27361153325515243e-13*g8 - 
     2.88368279506519334e-11*A11*g*x2 + 
     7.91374895139060628e-10*A8*g3*x2 - 
     1.98046179372144604e-9*A5*g5*x2 + 
     4.11786639583657111e-10*A2*g7*x2 - 
     7.16497851551313523e-10*A10*g2*x4 + 
     9.68464471525289276e-9*A7*g4*x4 - 
     1.16748393728030986e-8*A4*g6*x4 + 
     8.04127478183736051e-10*A*g8*x4 - 
     4.65194608412246558e-9*A9*g3*x6 + 
     3.51082372037893695e-8*A6*g5*x6 - 
     2.04201982013264592e-8*A3*g7*x6 + 
     3.08310721156552306e-10*g9*x6 - 
     1.26357673284535273e-8*A8*g4*x8 + 
     5.45476416156654204e-8*A5*g6*x8 - 
     1.40486405551536498e-8*A2*g8*x8 - 
     1.7805212696568686e-8*A7*g5*x10 + 
     4.2926305860153371e-8*A4*g7*x10 - 
     4.0312366550615087e-9*A*g9*x10 - 
     1.46022546131613235e-8*A6*g6*x12 + 
     1.843836447337074e-8*A3*g8*x12 - 
     4.02235197734030437e-10*g10*x12 - 
     7.42369322805527411e-9*A5*g7*x14 + 
     4.37038526225414347e-9*A2*g9*x14 - 
     2.40937437944208411e-9*A4*g8*x16 + 
     5.35568097093309146e-10*A*g10*x16 - 
     4.99603251087911808e-10*A3*g9*x18 + 
     2.64472477748035067e-11*g11*x18 - 
     6.40255800593810452e-11*A2*g10*x20 - 
     4.61829796410311992e-12*A*g11*x22 - 
     1.43368406597132889e-13*g12*x24) + 
  eps22*(2.63381701723029945e-12*A10*g - 
     4.95613474685512438e-11*A7*g3 + 
     7.3461839787322817e-11*A4*g5 - 
     5.80927196941699941e-12*A*g7 - 
     4.68234108487568308e-12*A12*x2 + 
     5.62566165576091132e-10*A9*g2*x2 - 
     3.55029758958278224e-9*A6*g4*x2 + 
     2.01925178972162547e-9*A3*g6*x2 - 
     3.0814593971546122e-11*g8*x2 - 
     1.56527781346397019e-10*A11*g*x4 + 
     8.57069278143073356e-9*A8*g3*x4 - 
     2.64080665694219489e-8*A5*g5*x4 + 
     6.0407259102082057e-9*A2*g7*x4 - 
     1.20889938892283076e-9*A10*g2*x6 + 
     3.69930387182005496e-8*A7*g4*x6 - 
     5.87976309873423814e-8*A4*g6*x6 + 
     4.64691762189073441e-9*A*g8*x6 - 
     3.7731495679189183e-9*A9*g3*x8 + 
     6.81148651466673022e-8*A6*g5*x8 - 
     5.41126426776092471e-8*A3*g7*x8 + 
     9.60423280700958978e-10*g9*x8 - 
     6.06051978329905884e-9*A8*g4*x10 + 
     6.45172101423398301e-8*A5*g6*x10 - 
     2.31853730369969274e-8*A2*g8*x10 - 
     5.69384641167539249e-9*A7*g5*x12 + 
     3.45031778931260666e-8*A4*g7*x12 - 
     4.5856200745095094e-9*A*g9*x12 - 
     3.36446046321516529e-9*A6*g6*x14 + 
     1.08170138123001676e-8*A3*g8*x14 - 
     3.37300366179434001e-10*g10*x14 - 
     1.30060474988550597e-9*A5*g7*x16 + 
     1.9676600421073939e-9*A2*g9*x16 - 
     3.33854146037989048e-10*A4*g8*x18 + 
     1.92027951778477411e-10*A*g10*x18 - 
     5.64147807443152692e-11*A3*g9*x20 + 
     7.76866625886353525e-12*g11*x20 - 
     6.03122771185984168e-12*A2*g10*x22 - 
     3.69809171837544212e-13*A*g11*x24 - 
     9.90994892123906548e-15*g12*x26) + 
  eps24*(-2.89099899565347662e-13*A11*g + 
     7.9759930961059578e-12*A8*g3 - 
     2.00555906593283631e-11*A5*g5 + 
     4.18688595364780991e-12*A2*g7 + 
     4.74420340935259007e-13*A13*x2 - 
     7.92461835979771511e-11*A10*g2*x2 + 
     7.58561702147442218e-10*A7*g4*x2 - 
     7.97991543042322495e-10*A4*g6*x2 + 
     5.12980963092851767e-11*A*g8*x2 + 
     1.99411637693229689e-11*A12*g*x4 - 
     1.54367310321517635e-9*A9*g3*x4 + 
     7.53265555420091332e-9*A6*g5*x4 - 
     3.62648374581728425e-9*A3*g7*x4 + 
     4.93947743563747665e-11*g9*x4 + 
     1.91553592353180707e-10*A11*g2*x6 - 
     8.49094217698978774e-9*A8*g4*x6 + 
     2.26856565220020088e-8*A5*g6*x6 - 
     4.69772329949351813e-9*A2*g8*x6 + 
     7.38610816404395504e-10*A10*g3*x8 - 
     1.99662166333330706e-8*A7*g5*x8 + 
     2.9041859633440226e-8*A4*g7*x8 - 
     2.15327269006722961e-9*A*g9*x8 + 
     1.46232224612947612e-9*A9*g4*x10 - 
     2.43772139379355154e-8*A6*g6*x10 + 
     1.82674355319716322e-8*A3*g8*x10 - 
     3.10752555543901178e-10*g10*x10 + 
     1.69732946496891816e-9*A8*g5*x12 - 
     1.71231822209617444e-8*A5*g7*x12 + 
     5.9144501741718517e-9*A2*g9*x12 + 
     1.24827250807789759e-9*A7*g6*x14 - 
     7.28755328956029511e-9*A4*g8*x14 + 
     9.42570128461049658e-10*A*g10*x14 + 
     6.08812904258686911e-10*A6*g7*x16 - 
     1.90694699932313329e-9*A3*g9*x16 + 
     5.83702428173174224e-11*g11*x16 + 
     2.01600973965553078e-10*A5*g8*x18 - 
     2.99487561260952419e-10*A2*g10*x18 + 
     4.5544937416083891e-11*A4*g9*x20 - 
     2.58715552328237504e-11*A*g11*x20 + 
     6.91310656589337861e-12*A3*g10*x22 - 
     9.44207238480244009e-13*g12*x22 + 
     6.74432494205638096e-13*A2*g11*x24 + 
     3.82104888900742578e-14*A*g12*x26 + 
     9.55678585992729762e-16*g13*x28) + 
  0.00833333333333333333*eps*g*xbar2 + 
  0.166666666666666667*(A + 0.5*g*x2)*xbar2 + 
  eps3*(-0.000793650793650793651*A*g - 
     0.00138888888888888889*g2*x2)*xbar2 + 
  eps2*(-0.00277777777777777778*A2 - 
     0.0111111111111111111*A*g*x2 - 
     0.00208333333333333333*g2*x4)*xbar2 + 
  eps5*(0.0000727513227513227513*A2*g + 
     0.000522486772486772487*A*g2*x2 + 
     0.000162037037037037037*g3*x4)*xbar2 + 
  eps4*(0.0000661375661375661376*A3 - 
     0.0000644841269841269841*g2 + 
     0.0015873015873015873*A2*g*x2 + 
     0.00094246031746031746*A*g2*x4 + 
     0.000115740740740740741*g3*x6)*xbar2 + 
  eps7*(-6.91438191438191438e-6*A3*g + 
     1.41486599819933153e-6*g3 - 
     0.000128066378066378066*A2*g2*x2 - 
     0.000110705266955266955*A*g3*x4 - 
     0.000018647119341563786*g4*x6)*xbar2 + 
  eps6*(-1.65343915343915344e-6*A4 + 
     0.0000179623617123617124*A*g2 - 
     0.00021164021164021164*A3*g*x2 + 
     0.0000485008818342151675*g3*x2 - 
     0.000276951058201058201*A2*g2*x4 - 
     0.0000898368606701940035*A*g3*x6 - 
     8.27867798353909465e-6*g4*x8)*xbar2 + 
  eps9*(6.79829796893288957e-7*A4*g - 
     6.72419695237155555e-7*A*g3 + 
     0.0000254975770848786722*A3*g2*x2 - 
     2.25056258042369153e-6*g4*x2 + 
     0.0000441438108848823135*A2*g3*x4 + 
     0.0000185871013417309714*A*g4*x6 + 
     2.15148764772607365e-6*g5*x8)*xbar2 + 
  eps8*(4.1753513975736198e-8*A5 - 
     3.46221514376276281e-6*A2*g2 + 
     0.0000267222489444711667*A4*g*x2 - 
     0.0000281804101248545693*A*g3*x2 + 
     0.0000649475909892576559*A3*g2*x4 - 
     0.0000122030666735527847*g4*x4 + 
     0.0000403965247715247715*A2*g3*x6 + 
     9.0700810463541945e-6*A*g4*x8 + 
     6.69795953360768176e-7*g5*x10)*xbar2 + 
  eps11*(-6.80612866459427306e-8*A5*g + 
     1.95584655809718057e-7*A2*g3 - 
     4.47269759439071608e-6*A4*g2*x2 + 
     1.75829988748211593e-6*A*g4*x2 - 
     0.0000133314481239415102*A3*g3*x4 + 
     9.71399147418687179e-7*g5*x4 - 
     0.0000103064498801381517*A2*g4*x6 - 
     2.82142523293179157e-6*A*g5*x8 - 
     2.4892365507720446e-7*g6*x10)*xbar2 + 
  eps10*(-1.05683802773749864e-9*A6 + 
     5.67501373552960855e-7*A3*g2 - 
     4.8511255774108832e-8*g4 - 
     3.24660642120959581e-6*A5*g*x2 + 
     9.71126169538867952e-6*A2*g3*x2 - 
     0.0000131832441790279092*A4*g2*x4 + 
     0.0000108846610427711618*A*g4*x4 - 
     0.0000136365860158849577*A3*g3*x6 + 
     2.33168885512635513e-6*g5*x6 - 
     5.4993290386188865e-6*A2*g4*x8 - 
     9.46094479080590192e-7*A*g5*x10 - 
     5.8302302889011994e-8*g6*x12)*xbar2 + 
  eps13*(6.86627585651083939e-9*A6*g - 
     4.47785160224899766e-8*A3*g3 + 
     2.19249275444418889e-9*g5 + 
     7.19946098097358602e-7*A5*g2*x2 - 
     7.80379784965903039e-7*A2*g4*x2 + 
     3.37142842641135708e-6*A4*g3*x4 - 
     1.06398186364605041e-6*A*g5*x4 + 
     4.18165456228327982e-6*A3*g4*x6 - 
     2.76351067919865578e-7*g6*x6 + 
     2.00589567077445504e-6*A2*g5*x8 + 
     4.04753308555164946e-7*A*g6*x10 + 
     2.88571475583667131e-8*g7*x12)*xbar2 + 
  eps12*(2.67650730613693577e-11*A7 - 
     8.46192910475220622e-8*A4*g2 + 
     3.25142589196534057e-8*A*g4 + 
     3.83704087407791111e-7*A6*g*x2 - 
     2.57283359783619147e-6*A3*g3*x2 + 
     1.27951218977907431e-7*g5*x2 + 
     2.41765559329216737e-6*A5*g2*x4 - 
     5.44480881814382923e-6*A2*g4*x4 + 
     3.82233569685344377e-6*A4*g3*x6 - 
     2.81139544164632672e-6*A*g5*x6 + 
     2.42710273474001612e-6*A3*g4*x8 - 
     3.92027350262991887e-7*g6*x8 + 
     7.21984500196305752e-7*A2*g5*x10 + 
     1.007566064009769e-7*A*g6*x12 + 
     5.32759708629371695e-9*g7*x14)*xbar2 + 
  eps15*(-6.94677964495491896e-10*A7*g + 
     8.85485037384606633e-9*A4*g3 - 
     1.89784940868103996e-9*A*g5 - 
     1.08873720111587578e-7*A6*g2*x2 + 
     2.58200627219967634e-7*A3*g4*x2 - 
     8.57415659878293831e-9*g6*x2 - 
     7.52178044272582197e-7*A5*g3*x4 + 
     6.39174172204870162e-7*A2*g5*x4 - 
     1.38311030669262085e-6*A4*g4*x6 + 
     3.89805821462228289e-7*A*g6*x6 - 
     1.02272071613530239e-6*A3*g5*x8 + 
     6.35874554600849527e-8*g7*x8 - 
     3.51191445940869782e-7*A2*g6*x10 - 
     5.59975947545884819e-8*A*g7*x12 - 
     3.35001083013772154e-9*g8*x14)*xbar2 + 
  eps14*(-6.77936059264516573e-13*A8 + 
     1.18453251754498057e-8*A5*g2 - 
     1.26192122113177278e-8*A2*g4 - 
     4.44292175799593582e-8*A7*g*x2 + 
     5.78235471803035281e-7*A4*g3*x2 - 
     1.25465164813262727e-7*A*g5*x2 - 
     4.11093596933471078e-7*A6*g2*x4 + 
     2.00802343589623813e-6*A3*g4*x4 - 
     8.38456228452171631e-8*g6*x4 - 
     9.37962675222683393e-7*A5*g3*x6 + 
     1.84660973293660698e-6*A2*g5*x6 - 
     8.68952732620502728e-7*A4*g4*x8 + 
     5.95974150882540242e-7*A*g6*x8 - 
     3.93789587968658131e-7*A3*g5*x10 + 
     6.11861559616332661e-8*g7*x10 - 
     9.26911580977221589e-8*A2*g6*x12 - 
     1.08851336477984649e-8*A*g7*x14 - 
     5.04016698893419468e-10*g8*x16)*xbar2 + 
  eps17*(7.03519796756268115e-11*A8*g - 
     1.58412622695254907e-9*A5*g3 + 
     9.21824723042734146e-10*A2*g5 + 
     1.57013176618403867e-8*A7*g2*x2 - 
     7.07877152349972815e-8*A4*g4*x2 + 
     1.01145514044440416e-8*A*g6*x2 + 
     1.52755677874009072e-7*A6*g3*x4 - 
     2.78303968964189299e-7*A3*g5*x4 + 
     7.90216106829461597e-9*g7*x4 + 
     3.94839847004885584e-7*A5*g4*x6 - 
     2.95546266642869418e-7*A2*g6*x6 + 
     4.1812888733216445e-7*A4*g5*x8 - 
     1.09749260429676339e-7*A*g7*x8 + 
     2.15692160440115788e-7*A3*g6*x10 - 
     1.28547064754435117e-8*g8*x10 + 
     5.73688513495873601e-8*A2*g7*x12 + 
     7.55383153004710777e-9*A*g8*x14 + 
     3.89293296941875901e-10*g9*x16)*xbar2 + 
  eps16*(1.71721241125556891e-14*A9 - 
     1.58463391176416606e-9*A6*g2 + 
     3.70687203668986364e-9*A3*g4 - 
     1.21950914958299276e-10*g6 + 
     5.06426546628202339e-9*A8*g*x2 - 
     1.15919331839795365e-7*A5*g3*x2 + 
     6.813324046201634e-8*A2*g5*x2 + 
     6.59264102615256734e-8*A7*g2*x4 - 
     6.0783143535697607e-7*A4*g4*x4 + 
     1.08734552181364072e-7*A*g6*x4 + 
     2.08077893379438207e-7*A6*g3*x6 - 
     8.7376194571684116e-7*A3*g5*x6 + 
     3.31435423816449871e-8*g7*x6 + 
     2.67286143174399604e-7*A5*g4*x8 - 
     4.84990273878282454e-7*A2*g6*x8 + 
     1.71677767909550515e-7*A4*g5*x10 - 
     1.12268658721773254e-7*A*g7*x10 + 
     6.02176056859808662e-8*A3*g6*x12 - 
     9.09453722352822717e-9*g8*x12 + 
     1.17208819972660499e-8*A2*g7*x14 + 
     1.18834173730462595e-9*A*g8*x16 + 
     4.8940576382579539e-11*g9*x18)*xbar2 + 
  eps19*(-7.12707337587569786e-12*A9*g + 
     2.63376364359160315e-10*A6*g3 - 
     3.30780046645030994e-10*A3*g5 + 
     8.03679335161609342e-12*g7 - 
     2.18139573549146275e-9*A8*g2*x2 + 
     1.6989863583308778e-8*A5*g4*x2 - 
     6.4969385102430346e-9*A2*g6*x2 - 
     2.88250590711040757e-8*A7*g3*x4 + 
     9.81072496878526138e-8*A4*g5*x4 - 
     1.18346882869724656e-8*A*g7*x4 - 
     1.00731210992033847e-7*A6*g4*x6 + 
     1.59691202088983395e-7*A3*g6*x6 - 
     4.13548363870289057e-9*g8*x6 - 
     1.45496453255537213e-7*A5*g5*x8 + 
     1.00501516554651165e-7*A2*g7*x8 - 
     1.05051610378898918e-7*A4*g6*x10 + 
     2.62399674415998082e-8*A*g8*x10 - 
     4.12244346987175346e-8*A3*g7*x12 + 
     2.38101241880130705e-9*g9*x12 - 
     8.92371773273422321e-9*A2*g8*x14 - 
     1.00013636391153993e-9*A*g9*x16 - 
     4.52724718151082609e-11*g10*x18)*xbar2 + 
  eps18*(-4.34973739711612375e-16*A10 + 
     2.04866596742209561e-10*A7*g2 - 
     9.13337973503563032e-10*A4*g4 + 
     1.29494994082815314e-10*A*g6 - 
     5.70128780114804572e-10*A9*g*x2 + 
     2.13523668994309077e-8*A6*g3*x2 - 
     2.7041278749459319e-8*A3*g5*x2 + 
     6.61136770529593115e-10*g7*x2 - 
     1.00900226220693725e-8*A8*g2*x4 + 
     1.59771473522731497e-7*A5*g4*x4 - 
     7.62149977963186539e-8*A2*g6*x4 - 
     4.26288251723329756e-8*A7*g3*x6 + 
     3.32905368200259132e-7*A4*g5*x6 - 
     5.34789893441100738e-8*A*g7*x6 - 
     7.31666710191171495e-8*A6*g4*x8 + 
     2.80197106079331506e-7*A3*g6*x8 - 
     9.98659790379859243e-9*g8*x8 - 
     6.35106992331774466e-8*A5*g5*x10 + 
     1.08995209478400767e-7*A2*g7*x10 - 
     3.09539659674895079e-8*A4*g6*x12 + 
     1.95483783519714526e-8*A*g8*x12 - 
     8.83724740598401241e-9*A3*g7*x14 + 
     1.30582050443893102e-9*g9*x14 - 
     1.46593717511110234e-9*A2*g8*x16 - 
     1.30772635674859038e-10*A*g9*x18 - 
     4.84955398928857724e-12*g10*x20)*xbar2 + 
  eps21*(7.22090117277105046e-13*A10*g - 
     4.13991085301446953e-11*A7*g3 + 
     9.76589682716262956e-11*A4*g5 - 
     1.01171462635282484e-11*A*g7 + 
     2.94059482872196453e-10*A9*g2*x2 - 
     3.68979054877682005e-9*A6*g4*x2 + 
     3.00808714445394687e-9*A3*g6*x2 - 
     5.76746247671597889e-11*g8*x2 + 
     5.12696720776491515e-9*A8*g3*x4 - 
     2.96928069363177013e-8*A5*g5*x4 + 
     9.47962261651077826e-9*A2*g7*x4 + 
     2.35049540761358863e-8*A7*g4*x6 - 
     6.88556064847354174e-8*A4*g6*x6 + 
     7.5086659172629484e-9*A*g8*x6 + 
     4.47020768444263473e-8*A6*g5*x8 - 
     6.48548347717962229e-8*A3*g7*x8 + 
     1.57872287719044645e-9*g9*x8 + 
     4.31283591778531503e-8*A5*g6*x10 - 
     2.81624636750572854e-8*A2*g8*x10 + 
     2.3304946259676748e-8*A4*g7*x12 - 
     5.6106802334762125e-9*A*g9*x12 + 
     7.34468856466444926e-9*A3*g8*x14 - 
     4.14021761190658312e-10*g10*x14 + 
     1.33841053507869873e-9*A2*g9*x16 + 
     1.30531947930356562e-10*A*g10*x18 + 
     5.26795343697585529e-12*g11*x20)*xbar2 + 
  eps20*(1.1018005656720459e-17*A11 - 
     2.57889246901160178e-11*A8*g2 + 
     1.98990234155769708e-10*A5*g4 - 
     7.55965424361672699e-11*A2*g6 + 
     6.35426896472572163e-11*A10*g*x2 - 
     3.68388963577669912e-9*A7*g3*x2 + 
     8.75177480890399108e-9*A4*g5*x2 - 
     9.11535637885301799e-10*A*g7*x2 + 
     1.48649455332149944e-9*A9*g2*x4 - 
     3.77359746051647268e-8*A6*g4*x4 + 
     3.82594204726996217e-8*A3*g6*x4 - 
     8.13304101172221063e-10*g8*x4 + 
     8.18713369443791778e-9*A8*g3*x6 - 
     1.08366523313337395e-7*A5*g5*x6 + 
     4.5944289943616577e-8*A2*g7*x6 + 
     1.82487684327326814e-8*A7*g4*x8 - 
     1.28729795350649249e-7*A4*g6*x8 + 
     1.92747318307891877e-8*A*g8*x8 + 
     2.06867607666613227e-8*A6*g5*x10 - 
     7.43763204190519753e-8*A3*g7*x10 + 
     2.53626156501045944e-9*g9*x10 + 
     1.33838352059798451e-8*A5*g6*x12 - 
     2.20494122463979174e-8*A2*g8*x12 + 
     5.23330987914141423e-9*A4*g7*x14 - 
     3.21750395058170305e-9*A*g9*x14 + 
     1.25827561244148185e-9*A3*g8*x16 - 
     1.82713361623688652e-10*g10*x16 + 
     1.81827783439828152e-10*A2*g9*x18 + 
     1.44818570824073778e-11*A*g10*x20 + 
     4.88417660313835094e-13*g11*x22)*xbar2 + 
  eps23*(-7.31620058828327886e-14*A11*g + 
     6.2244144715351518e-12*A8*g3 - 
     2.50972722113902645e-11*A5*g5 + 
     6.90195578112387954e-12*A2*g7 - 
     3.86661866535845128e-11*A10*g2*x2 + 
     7.40985528302493753e-10*A7*g4*x2 - 
     1.12263534560497836e-9*A4*g6*x2 + 
     9.10038912793887614e-11*A*g8*x2 - 
     8.68557303415569482e-10*A9*g3*x4 + 
     7.99751265225702085e-9*A6*g5*x4 - 
     5.38995025036586533e-9*A3*g7*x4 + 
     9.11682355767971334e-11*g9*x4 - 
     5.09949189194303306e-9*A8*g4*x6 + 
     2.517151280314285e-8*A5*g6*x6 - 
     7.20688202607308513e-9*A2*g8*x6 - 
     1.24293927810383763e-8*A7*g5*x8 + 
     3.30698321741881119e-8*A4*g7*x8 - 
     3.36777220246894258e-9*A*g9*x8 - 
     1.55006071785928367e-8*A6*g6*x10 + 
     2.11300984088409138e-8*A3*g8*x10 - 
     4.91764411032702861e-10*g10*x10 - 
     1.10270946906705895e-8*A5*g7*x12 + 
     6.90528529828172647e-9*A2*g9*x12 - 
     4.72730487747526667e-9*A4*g8*x14 + 
     1.10602336934435099e-9*A*g10*x14 - 
     1.24144324312375269e-9*A3*g9*x16 + 
     6.86305256373542116e-11*g11*x16 - 
     1.95159691471731057e-10*A2*g10*x18 - 
     1.68433306811216689e-11*A*g11*x20 - 
     6.13262463130406207e-13*g12*x22)*xbar2 + 
  eps22*(-2.79089293716250467e-19*A12 + 
     3.17766604095748225e-12*A9*g2 - 
     3.95577368582764204e-11*A6*g4 + 
     3.2068101326980409e-11*A3*g6 - 
     6.12076747703341304e-13*g8 - 
     7.02351204594746519e-12*A11*g*x2 + 
     6.03214212931090113e-10*A8*g3*x2 - 
     2.44702734746155151e-9*A5*g5*x2 + 
     6.76097426096149884e-10*A2*g7*x2 - 
     2.12157940796992025e-10*A10*g2*x4 + 
     8.1916797369498686e-9*A7*g4*x4 - 
     1.53944612844692757e-8*A4*g6*x4 + 
     1.38109622177934475e-9*A*g8*x4 - 
     1.49038549899160153e-9*A9*g3*x6 + 
     3.12551588277558658e-8*A6*g5*x6 - 
     2.79047223116628872e-8*A3*g7*x6 + 
     5.436847471574281e-10*g9*x6 - 
     4.21695720957640858e-9*A8*g4*x8 + 
     4.99819767239979985e-8*A5*g6*x8 - 
     1.96069567048585921e-8*A2*g8*x8 - 
     6.0820173561110201e-9*A7*g5*x10 + 
     4.00069800775570726e-8*A4*g7*x10 - 
     5.69705873785929584e-9*A*g9*x10 - 
     5.05592156438231298e-9*A6*g6*x12 + 
     1.73541009641709023e-8*A3*g8*x12 - 
     5.72444406380114732e-10*g10*x12 - 
     2.58984982240261447e-9*A5*g7*x14 + 
     4.13461348937075909e-9*A2*g9*x14 - 
     8.43540110516749951e-10*A4*g8*x16 + 
     5.07648285991122299e-10*A*g10*x16 - 
     1.75053485949267209e-10*A3*g9*x18 + 
     2.50585955675889897e-11*g11*x18 - 
     2.24065847218371337e-11*A2*g10*x20 - 
     1.61190422371025444e-12*A*g11*x22 - 
     4.98497255151051565e-14*g12*x24)*xbar2 + 
  0.00833333333333333333*g*xbar4 - 
  0.0000462962962962962963*eps3*g2*xbar4 + 
  eps2*(-0.000396825396825396825*A*g - 
     0.000694444444444444444*g2*x2)*xbar4 + 
  eps5*(9.11896745230078563e-6*A*g2 + 
     0.0000308641975308641975*g3*x2)*xbar4 + 
  eps4*(0.0000198412698412698413*A2*g + 
     0.000195105820105820106*A*g2*x2 + 
     0.0000617283950617283951*g3*x4)*xbar4 + 
  eps7*(-1.31581381581381581e-6*A2*g2 - 
     0.0000151318588818588819*A*g3*x2 - 
     6.8455207344096233e-6*g4*x4)*xbar4 + 
  eps6*(-9.01875901875901876e-7*A3*g + 
     9.90714532381199048e-7*g3 - 
     0.0000389059243225909893*A2*g2*x2 - 
     0.0000351397573619795842*A*g3*x4 - 
     5.9477880658436214e-6*g4*x6)*xbar4 + 
  eps9*(1.71045640622360199e-7*A3*g2 - 
     3.60906857706966639e-8*g4 + 
     4.53245406122390249e-6*A2*g3*x2 + 
     5.38783061931210079e-6*A*g4*x4 + 
     1.17492514772607365e-6*g5*x6)*xbar4 + 
  eps8*(3.77616945077262538e-8*A4*g - 
     3.91505723846993688e-7*A*g3 + 
     6.55938527962337486e-6*A3*g2*x2 - 
     1.61985166325444103e-6*g4*x2 + 
     0.0000121547079219036891*A2*g3*x4 + 
     5.20508405346368309e-6*A*g4*x6 + 
     6.02301130368259998e-7*g5*x8)*xbar4 + 
  eps11*(-2.12135350797297057e-8*A4*g2 + 
     2.14460056215349951e-8*A*g4 - 
     1.06401470496877178e-6*A3*g3*x2 + 
     9.9419658966568008e-8*g5*x2 - 
     2.4228308825712602e-6*A2*g4*x4 - 
     1.28380796826126347e-6*A*g5*x6 - 
     1.80516340332649186e-7*g6*x8)*xbar4 + 
  eps10*(-1.48202033122668043e-9*A5*g + 
     9.77137892841674354e-8*A2*g3 - 
     9.98537198520664129e-7*A4*g2*x2 + 
     1.12096864298613054e-6*A*g4*x2 - 
     3.25929867376075489e-6*A3*g3*x4 + 
     6.52088831782005348e-7*g5*x4 - 
     2.59007734102806854e-6*A2*g4*x6 - 
     7.14333704061713321e-7*A*g5*x8 - 
     6.28878290312510992e-8*g6*x10)*xbar4 + 
  eps13*(2.55551047231023315e-9*A5*g2 - 
     7.48454109323006102e-9*A2*g4 + 
     2.14869723911233424e-7*A4*g3*x2 - 
     8.87037184673700903e-8*A*g5*x2 + 
     8.1367411096167446e-7*A3*g4*x4 - 
     6.24554324051377381e-8*g6*x4 + 
     7.73534185148061632e-7*A2*g5*x6 + 
     2.53114332805174734e-7*A*g6*x8 + 
     2.60907174059342559e-8*g7*x10)*xbar4 + 
  eps12*(5.52620037914155561e-11*A6*g - 
     1.96395897468419557e-8*A3*g3 + 
     1.73105497543500998e-9*g5 + 
     1.41930118072774209e-7*A5*g2*x2 - 
     4.4751871911848506e-7*A2*g4*x2 + 
     7.4329679752095632e-7*A4*g3*x4 - 
     6.48579919839268283e-7*A*g5*x4 + 
     9.56849686940199225e-7*A3*g4*x6 - 
     1.72592309647809413e-7*g6*x6 + 
     4.6549037372399414e-7*A2*g5*x8 + 
     9.4234108977460504e-8*A*g6*x10 + 
     6.6997976279157566e-9*g7*x12)*xbar4 + 
  eps15*(-3.01110179246578381e-10*A6*g2 + 
     1.99854473307210245e-9*A3*g4 - 
     1.0075222178954846e-10*g6 - 
     3.91236879782746971e-8*A5*g3*x2 + 
     4.42468326545839399e-8*A2*g5*x2 - 
     2.26449722207185509e-7*A4*g4*x4 + 
     7.48610321580336637e-8*A*g6*x4 - 
     3.38794481457344831e-7*A3*g5*x6 + 
     2.34467193453680488e-8*g7*x6 - 
     1.91586076465687549e-7*A2*g6*x8 - 
     4.4705147415174641e-8*A*g7*x10 - 
     3.62790374951045814e-9*g8*x12)*xbar4 + 
  eps14*(-1.97753534590218582e-12*A7*g + 
     3.46651613447685113e-9*A4*g3 - 
     1.3675698718070872e-9*A*g5 - 
     1.92080361104674656e-8*A6*g2*x2 + 
     1.34714593349386061e-7*A3*g4*x2 - 
     7.0165116069938331e-9*g6*x2 - 
     1.51234778678998732e-7*A5*g3*x4 + 
     3.57677410764887609e-7*A2*g5*x4 - 
     2.9119323970204683e-7*A4*g4*x6 + 
     2.24757818721415644e-7*A*g6*x6 - 
     2.19654624683123427e-7*A3*g5*x8 + 
     3.71577620957842484e-8*g7*x8 - 
     7.60245440599503551e-8*A2*g6*x10 - 
     1.21363875909823901e-8*A*g7*x12 - 
     7.23898306636066601e-10*g8*x14)*xbar4 + 
  eps17*(3.48460743277465292e-11*A7*g2 - 
     4.51506468378503526e-10*A4*g4 + 
     9.93046484625324211e-11*A*g6 + 
     6.6025042810186813e-9*A6*g3*x2 - 
     1.62520631488663842e-8*A3*g5*x2 + 
     5.61230122018474251e-10*g7*x2 + 
     5.51380920101008308e-8*A5*g4*x4 - 
     4.88479275078761747e-8*A2*g6*x4 + 
     1.20320332856371923e-7*A4*g5*x6 - 
     3.5365653527819202e-8*A*g7*x6 + 
     1.03628614951869648e-7*A3*g6*x8 - 
     6.71263413921269682e-9*g8*x8 + 
     4.07776601703241782e-8*A2*g7*x10 + 
     7.34880420888892836e-9*A*g8*x12 + 
     4.91163816649064884e-10*g9*x14)*xbar4 + 
  eps16*(6.84233044511131468e-14*A8*g - 
     5.60464705059266925e-10*A5*g3 + 
     6.1113506912043867e-10*A2*g5 + 
     2.50582201503812155e-9*A7*g2*x2 - 
     3.39024845059116986e-8*A4*g4*x2 + 
     7.66141086125169516e-9*A*g6*x2 + 
     2.82533097805425257e-8*A6*g3*x4 - 
     1.44153074493338505e-7*A3*g5*x4 + 
     6.29165697711773721e-9*g7*x4 + 
     7.70955531949116842e-8*A5*g4*x6 - 
     1.5856345215569678e-7*A2*g6*x6 + 
     8.37319173204484218e-8*A4*g5*x8 - 
     5.99155536147365961e-8*A*g7*x8 + 
     4.37139891312553985e-8*A3*g6*x10 - 
     7.07392441584795305e-9*g8*x10 + 
     1.16805756794796047e-8*A2*g7*x12 + 
     1.53807088851897092e-9*A*g8*x14 + 
     7.90314013633620188e-11*g9*x16)*xbar4 + 
  eps19*(-3.97340865876564659e-12*A8*g2 + 
     9.08389634660042267e-11*A5*g4 - 
     5.40989729447639056e-11*A2*g6 - 
     1.05114495716806379e-9*A7*g3*x2 + 
     4.89773729086143515e-9*A4*g5*x2 - 
     7.24791876301819899e-10*A*g7*x2 - 
     1.21370267986698838e-8*A6*g4*x4 + 
     2.29597017376750524e-8*A3*g6*x4 - 
     6.7748721115604107e-10*g8*x4 - 
     3.67138156717417151e-8*A5*g5*x6 + 
     2.85584385486008741e-8*A2*g7*x6 - 
     4.48093489348219503e-8*A4*g6*x8 + 
     1.22153837054061484e-8*A*g8*x8 - 
     2.6272947304230525e-8*A3*g7*x10 + 
     1.62436680861277498e-9*g9*x10 - 
     7.84757421369128482e-9*A2*g8*x12 - 
     1.1484952449755475e-9*A*g9*x14 - 
     6.52079226899128072e-11*g10*x16)*xbar4 + 
  eps18*(-2.30220514713186019e-15*A9*g + 
     8.50336672523331952e-11*A6*g3 - 
     2.03099120170330866e-10*A3*g5 + 
     6.86599038065945835e-12*g7 - 
     3.17730510813967685e-10*A8*g2*x2 + 
     7.52334651318304606e-9*A5*g4*x2 - 
     4.58441975864061026e-9*A2*g6*x2 - 
     4.93856631341031329e-9*A7*g3*x4 + 
     4.73460373170155555e-8*A4*g5*x4 - 
     8.81541701496240287e-9*A*g7*x4 - 
     1.83568265106518087e-8*A6*g4*x6 + 
     8.0214964397589886e-8*A3*g6*x6 - 
     3.16831385872351314e-9*g8*x6 - 
     2.73264771648576643e-8*A5*g5*x8 + 
     5.15584868924249984e-8*A2*g7*x8 - 
     2.00422243527645685e-8*A4*g6*x10 + 
     1.36105580520898305e-8*A*g8*x10 - 
     7.92549659107905268e-9*A3*g7*x12 + 
     1.24112226442452554e-9*g9*x12 - 
     1.72024465137340275e-9*A2*g8*x14 - 
     1.92684278620064115e-10*A*g9*x16 - 
     8.69704747258045207e-12*g10*x18)*xbar4 + 
  eps21*(4.47608018566873029e-13*A9*g2 - 
     1.67753308125991472e-11*A6*g4 + 
     2.15143559796472255e-11*A3*g6 - 
     5.36097713439665228e-13*g8 + 
     1.59789748504864926e-10*A8*g3*x2 - 
     1.28169491309084248e-9*A5*g5*x2 + 
     5.05873112365848404e-10*A2*g7*x2 + 
     2.46793239696357667e-9*A7*g4*x4 - 
     8.69126604407042738e-9*A4*g6*x4 + 
     1.08592337487209441e-9*A*g8*x4 + 
     9.97215933211799948e-9*A6*g5*x6 - 
     1.63775632230861457e-8*A3*g7*x6 + 
     4.39638545658591092e-10*g9*x6 + 
     1.6446217893554322e-8*A5*g6*x8 - 
     1.17661894622675905e-8*A2*g8*x8 + 
     1.33981457517207347e-8*A4*g7*x10 - 
     3.46334251627866228e-9*A*g9*x10 + 
     5.87002262267861254e-9*A3*g8*x12 - 
     3.50481841251753294e-10*g10*x12 + 
     1.40564140813720233e-9*A2*g9*x14 + 
     1.72885003376200776e-10*A*g10*x16 + 
     8.52860757101693105e-12*g11*x18)*xbar4 + 
  eps20*(7.56595105695415785e-17*A10*g - 
     1.22932630659041053e-11*A7*g3 + 
     5.58459887241763578e-11*A4*g5 - 
     8.11455810014543089e-12*A*g7 + 
     3.9383320785984906e-11*A9*g2*x2 - 
     1.51976152664836327e-9*A6*g4*x2 + 
     1.98780657022334646e-9*A3*g6*x2 - 
     5.0284224652211995e-11*g8*x2 + 
     8.18366713361052766e-10*A8*g3*x4 - 
     1.34227304693417849e-8*A5*g5*x4 + 
     6.6399136914675485e-9*A2*g7*x4 + 
     4.01847928057574067e-9*A7*g4*x6 - 
     3.25458326731869081e-8*A4*g6*x6 + 
     5.42627614195641677e-9*A*g8*x6 + 
     7.91216320845347941e-9*A6*g5*x8 - 
     3.14137939839749592e-8*A3*g7*x8 + 
     1.16149233526855299e-9*g9*x8 + 
     7.7806358292877523e-9*A5*g6*x10 - 
     1.38304354148956577e-8*A2*g8*x10 + 
     4.24844294383596806e-9*A4*g7*x12 - 
     2.77563538429180564e-9*A*g9*x12 + 
     1.34573608785890679e-9*A3*g8*x14 - 
     2.05451606449403644e-10*g10*x14 + 
     2.45603481008104843e-10*A2*g9*x16 + 
     2.39299395598715992e-11*A*g10*x18 + 
     9.63092387870827136e-13*g11*x20)*xbar4 + 
  eps22*(-2.43710422261727909e-18*A11*g + 
     1.71109183419778529e-12*A8*g3 - 
     1.34309072457408887e-11*A5*g5 + 
     5.2173544345517194e-12*A2*g7 - 
     4.7920869812117813e-12*A10*g2*x2 + 
     2.85329265230758798e-10*A7*g4*x2 - 
     6.97857430562307631e-10*A4*g6*x2 + 
     7.49694255924035744e-11*A*g8*x2 - 
     1.29794915911680679e-10*A9*g3*x4 + 
     3.40176751053615467e-9*A6*g5*x4 - 
     3.56524460909925476e-9*A3*g7*x4 + 
     7.84071353306302568e-11*g9*x4 - 
     8.21445917536130217e-10*A8*g4*x6 + 
     1.12426357550003378e-8*A5*g6*x6 - 
     4.93283496356209241e-9*A2*g8*x6 - 
     2.08160234188537877e-9*A7*g5*x8 + 
     1.51837246414786265e-8*A4*g7*x8 - 
     2.35241679748374184e-9*A*g9*x8 - 
     2.65426623474241136e-9*A6*g6*x10 + 
     9.86143500745746335e-9*A3*g8*x10 - 
     3.47704012872899376e-10*g10*x10 - 
     1.91288185358486004e-9*A5*g7*x12 + 
     3.25348485105233778e-9*A2*g9*x12 - 
     8.26008166150946402e-10*A4*g8*x14 + 
     5.23734714713970356e-10*A*g10*x14 - 
     2.17662681277754724e-10*A3*g9*x16 + 
     3.25604627396838786e-11*g11*x16 - 
     3.42430735395904115e-11*A2*g10*x18 - 
     2.95184625537922171e-12*A*g11*x20 - 
     1.07193479659543963e-13*g12*x22)*xbar4 - 
  0.0000154320987654320988*eps2*g2*xbar6 + 
  3.56125356125356125e-7*eps5*g3*xbar6 + 
  eps4*(1.90396023729357063e-6*A*g2 + 
     7.71604938271604938e-6*g3*x2)*xbar6 + 
  eps7*(-1.06760523427190094e-7*A*g3 - 
     5.83649889205444761e-7*g4*x2)*xbar6 + 
  eps6*(-1.58222876476844731e-7*A2*g2 - 
     3.0990100434544879e-6*A*g3*x2 - 
     1.45170544476100032e-6*g4*x4)*xbar6 + 
  eps9*(2.10474956623416007e-8*A2*g3 + 
     3.52066889376257568e-7*A*g4*x2 + 
     2.15683591284989252e-7*g5*x4)*xbar6 + 
  eps8*(1.0639753805538638e-8*A3*g2 - 
     1.44647796358943781e-8*g4 + 
     7.89019059521705024e-7*A2*g3*x2 + 
     9.93278626380478232e-7*A*g4*x4 + 
     2.19830466744046991e-7*g5*x6)*xbar6 + 
  eps11*(-3.48009271425128996e-9*A3*g3 + 
     7.74456172615070677e-10*g5 - 
     1.24759056081950737e-7*A2*g4*x2 - 
     1.93124743183608916e-7*A*g5*x4 - 
     5.26262283781649553e-8*g6*x6)*xbar6 + 
  eps10*(-6.21784885258793341e-10*A4*g2 + 
     7.35917308458240036e-9*A*g4 - 
     1.61082849737015107e-7*A3*g3*x2 + 
     4.25042008023580282e-8*g5*x2 - 
     3.97181909847740069e-7*A2*g4*x4 - 
     2.15693489113968417e-7*A*g5*x6 - 
     3.05361793587726322e-8*g6*x8)*xbar6 + 
  eps13*(5.22929181665348026e-10*A4*g3 - 
     5.49761548927799316e-10*A*g5 + 
     3.37795673591345898e-8*A3*g4*x2 - 
     3.32362369023656752e-9*g6*x2 + 
     9.70864128827426103e-8*A2*g5*x4 + 
     6.29082935052959515e-8*A*g6*x6 + 
     1.05359214957493409e-8*g7*x8)*xbar6 + 
  eps12*(3.28023733515722384e-11*A5*g2 - 
     2.2483490443839068e-9*A2*g4 + 
     2.87554439944054822e-8*A4*g3*x2 - 
     3.41643318587639607e-8*A*g5*x2 + 
     1.20413081223750724e-7*A3*g4*x4 - 
     2.54382194661358481e-8*g6*x4 + 
     1.18403247344882478e-7*A2*g5*x6 + 
     3.92485363936068314e-8*A*g6*x8 + 
     4.05810532585570662e-9*g7*x10)*xbar6 + 
  eps15*(-7.38610165433134699e-11*A5*g3 + 
     2.23185618064230175e-10*A2*g5 - 
     7.72550467360774725e-9*A4*g4*x2 + 
     3.33675225731002428e-9*A*g6*x2 - 
     3.60024022499056884e-8*A3*g5*x4 + 
     2.89391686340197044e-9*g7*x4 - 
     4.11034234008140627e-8*A2*g6*x6 - 
     1.58061594311664227e-8*A*g7*x8 - 
     1.88044966020543737e-9*g8*x10)*xbar6 + 
  eps14*(-1.59924972891624396e-12*A6*g2 + 
     5.34559467656326695e-10*A3*g4 - 
     4.89531412255654985e-11*g6 - 
     4.68743656687813986e-9*A5*g3*x2 + 
     1.55203340852120435e-8*A2*g5*x2 - 
     3.05848967636635251e-8*A4*g4*x4 + 
     2.80191583068273077e-8*A*g6*x4 - 
     4.77391188802852923e-8*A3*g5*x6 + 
     9.0249644584421326e-9*g7*x6 - 
     2.7500470429085428e-8*A2*g6*x8 - 
     6.46467617732357999e-9*A*g7*x10 - 
     5.25206836466407194e-10*g8*x12)*xbar6 + 
  eps17*(9.97455222947976728e-12*A6*g3 - 
     6.79725936335510667e-11*A3*g5 + 
     3.53973893285757087e-12*g7 + 
     1.57106382527547975e-9*A5*g4*x2 - 
     1.84906281043290629e-9*A2*g6*x2 + 
     1.0959810274248971e-8*A4*g5*x4 - 
     3.77750956813660573e-9*A*g7*x4 + 
     1.93914172243944712e-8*A3*g6*x6 - 
     1.39852236310538808e-9*g8*x6 + 
     1.27378874003962749e-8*A2*g7*x8 + 
     3.39967157316226349e-9*A*g8*x10 + 
     3.11454821672654227e-10*g9*x12)*xbar6 + 
  eps16*(7.32043787188737753e-14*A7*g2 - 
     1.08932623361419343e-10*A4*g4 + 
     4.43882953795228996e-11*A*g6 + 
     7.1553877265847084e-10*A6*g3*x2 - 
     5.23629960443907472e-9*A3*g5*x2 + 
     2.84608830720512483e-10*g7*x2 + 
     6.85430762519816909e-9*A5*g4*x4 - 
     1.69359418456327738e-8*A2*g6*x4 + 
     1.57308771746978335e-8*A4*g5*x6 - 
     1.26738239683828291e-8*A*g7*x6 + 
     1.38726146998630169e-8*A3*g6*x8 - 
     2.44574523622132431e-9*g8*x8 + 
     5.52081375700205184e-9*A2*g7*x10 + 
     9.99298373572599506e-10*A*g8*x12 + 
     6.67917519196695508e-11*g9*x14)*xbar6 + 
  eps19*(-1.30114590146037234e-12*A7*g3 + 
     1.72511713934239417e-11*A4*g5 - 
     3.90436685140620179e-12*A*g7 - 
     2.92867814057581221e-10*A6*g4*x2 + 
     7.46902977877224456e-10*A3*g6*x2 - 
     2.67522864508407854e-11*g8*x2 - 
     2.89699505443225961e-9*A5*g5*x4 + 
     2.66562938868512264e-9*A2*g7*x4 - 
     7.37795565467524207e-9*A4*g6*x6 + 
     2.25247153971908075e-9*A*g8*x6 - 
     7.30651817416318482e-9*A3*g7*x8 + 
     4.91176292870876797e-10*g9*x8 - 
     3.26224960924321828e-9*A2*g8*x10 - 
     6.59449314458554338e-10*A*g9*x12 - 
     4.89514760970749125e-11*g10*x14)*xbar6 + 
  eps18*(-3.18177848990088646e-15*A8*g2 + 
     1.99695443999379049e-11*A5*g4 - 
     2.23943125358944015e-11*A2*g6 - 
     1.03933552034436454e-10*A7*g3*x2 + 
     1.45959832999336206e-9*A4*g5*x2 - 
     3.42631031918890525e-10*A*g7*x2 - 
     1.39812800630481225e-9*A6*g4*x4 + 
     7.42096889844293084e-9*A3*g6*x4 - 
     3.37099552457525213e-10*g8*x4 - 
     4.48155653124553849e-9*A5*g5*x6 + 
     9.58666614025997167e-9*A2*g7*x6 - 
     5.62734416286699799e-9*A4*g6*x8 + 
     4.18363357640745376e-9*A*g8*x8 - 
     3.34880212849529458e-9*A3*g7*x10 + 
     5.62255597605531686e-10*g9*x10 - 
     1.00758346454303337e-9*A2*g8*x12 - 
     1.478403576160079e-10*A*g9*x14 - 
     8.38903736074731077e-12*g10*x16)*xbar6 + 
  eps21*(1.65107570494289514e-13*A8*g3 - 
     3.85243170234057994e-12*A5*g5 + 
     2.35361375548192462e-12*A2*g7 + 
     5.10417794581330247e-11*A7*g4*x2 - 
     2.45495411183393324e-10*A4*g6*x2 + 
     3.75511182588112891e-11*A*g8*x2 + 
     6.87936705237642027e-10*A6*g5*x4 - 
     1.34714877461804848e-9*A3*g7*x4 + 
     4.11758068629525797e-11*g9*x4 + 
     2.400949695111526e-9*A5*g6*x6 - 
     1.93419604503727388e-9*A2*g8*x6 + 
     3.33918824376270404e-9*A4*g7*x8 - 
     9.42270610564786763e-10*A*g9*x8 + 
     2.20558587287283118e-9*A3*g8*x10 - 
     1.41026346318580081e-10*g10*x10 + 
     7.34671001558905886e-10*A2*g9*x12 + 
     1.18846098758935012e-10*A*g10*x14 + 
     7.4012085886463764e-12*g11*x16)*xbar6 + 
  eps20*(1.32423923182168128e-16*A9*g2 - 
     3.38762545168358761e-12*A6*g4 + 
     8.2936742090468515e-12*A3*g6 - 
     2.88553271599458446e-13*g8 + 
     1.45206721816612312e-11*A8*g3*x2 - 
     3.55365267771350475e-10*A5*g5*x2 + 
     2.24067642028217925e-10*A2*g7*x2 + 
     2.64931375976082846e-10*A7*g4*x4 - 
     2.63256077540054192e-9*A4*g6*x4 + 
     5.08380778036583002e-10*A*g8*x4 + 
     1.14232293931335993e-9*A6*g5*x6 - 
     5.17535342835764208e-9*A3*g7*x6 + 
     2.12052573958312186e-10*g9*x6 + 
     1.94686955319541028e-9*A5*g6*x8 - 
     3.80593235862788058e-9*A2*g8*x8 + 
     1.61506335347690598e-9*A4*g7*x10 - 
     1.13519934804077239e-9*A*g9*x10 + 
     7.1467043552215311e-10*A3*g8*x12 - 
     1.15698350133799093e-10*g10*x12 + 
     1.719691436452393e-10*A2*g9*x14 + 
     2.11817828858919301e-11*A*g10*x16 + 
     1.0439296901669795e-12*g11*x18)*xbar6 + 
  5.93542260208926876e-8*eps4*g3*xbar8 - 
  3.12288574815807931e-9*eps7*g4*xbar8 + 
  eps6*(-1.14340392118169896e-8*A*g3 - 
     9.02678854067742957e-8*g4*x2)*xbar8 + 
  eps9*(1.26121885620031857e-9*A*g4 + 
     1.00859349622512295e-8*g5*x2)*xbar8 + 
  eps8*(1.32727772394750297e-9*A2*g3 + 
     4.65033697944917988e-8*A*g4*x2 + 
     2.99054295797669073e-8*g5*x4)*xbar8 + 
  eps11*(-3.15709843216944468e-10*A2*g4 - 
     7.21099301568180965e-9*A*g5*x2 - 
     5.69746824484251863e-9*g6*x4)*xbar8 + 
  eps10*(-1.18235613578975095e-10*A3*g3 + 
     2.04522364126337295e-10*g5 - 
     1.4372001684607648e-8*A2*g4*x2 - 
     2.38545902650207871e-8*A*g5*x4 - 
     6.6442647298050802e-9*g6*x6)*xbar8 + 
  eps13*(6.34254881618462429e-11*A3*g4 - 
     1.4977795563804726e-11*g6 + 
     2.95036268409924151e-9*A2*g5*x2 + 
     5.72733871097688746e-9*A*g6*x4 + 
     1.89780374932858316e-9*g7*x6)*xbar8 + 
  eps12*(8.85933436332280376e-12*A4*g3 - 
     1.2695043367275619e-10*A*g5 + 
     3.44553148081436095e-9*A3*g4*x2 - 
     9.66117808074637814e-10*g6*x2 + 
     1.08393242236143663e-8*A2*g5*x4 + 
     7.24181767567549532e-9*A*g6*x6 + 
     1.22738677265426237e-9*g7*x8)*xbar8 + 
  eps15*(-1.1209244129052603e-11*A4*g4 + 
     1.23354796462055584e-11*A*g6 - 
     9.05322252904213583e-10*A3*g5*x2 + 
     9.34529456546429641e-11*g7*x2 - 
     3.18804749658072552e-9*A2*g6*x4 - 
     2.46989894878460521e-9*A*g7*x6 - 
     4.84553260391626981e-10*g8*x8)*xbar8 + 
  eps14*(-5.85591473164617337e-13*A5*g3 + 
     4.58152437519766974e-11*A2*g5 - 
     7.06061940978074562e-10*A4*g4*x2 + 
     8.8437067488213914e-10*A*g6*x2 - 
     3.6718459581734819e-9*A3*g5*x4 + 
     8.14572670487090063e-10*g7*x4 - 
     4.35865819040676537e-9*A2*g6*x6 - 
     1.70511399881374369e-9*A*g7*x8 - 
     2.04267683542374506e-10*g8*x10)*xbar8 + 
  eps17*(1.81850832862627129e-12*A5*g4 - 
     5.7018133606605742e-12*A2*g6 + 
     2.31363157692796144e-10*A4*g5*x2 - 
     1.04268313475235866e-10*A*g7*x2 + 
     1.29559671265166405e-9*A3*g6*x4 - 
     1.08608812804810835e-10*g8*x4 + 
     1.74321237740579218e-9*A2*g7*x6 + 
     7.76515634579396129e-10*A*g8*x8 + 
     1.05455124124405657e-10*g9*x10)*xbar8 + 
  eps16*(3.51441987362562031e-14*A6*g3 - 
     1.25669585862967901e-11*A3*g5 + 
     1.19873609386538047e-12*g7 + 
     1.29917477297039227e-10*A5*g4*x2 - 
     4.50505663684441363e-10*A2*g6*x2 + 
     1.0294836459233229e-9*A4*g5*x4 - 
     9.85762364733873057e-10*A*g7*x4 + 
     1.90892686734913978e-9*A3*g6*x6 - 
     3.76480107979462358e-10*g8*x6 + 
     1.28194605951425965e-9*A2*g7*x8 + 
     3.45797358676807567e-10*A*g8*x10 + 
     3.18111454415424726e-11*g9*x12)*xbar8 + 
  eps19*(-2.77181792125363476e-13*A6*g4 + 
     1.94851026920691567e-12*A3*g6 - 
     1.04933332657610013e-13*g8 - 
     5.1992259514176436e-11*A5*g5*x2 + 
     6.35571518081156783e-11*A2*g7*x2 - 
     4.28732342024609978e-10*A4*g6*x4 + 
     1.53545689985903239e-10*A*g8*x4 - 
     8.82875940509388448e-10*A3*g7*x6 + 
     6.61143800669246729e-11*g9*x6 - 
     6.65258660548452332e-10*A2*g8*x8 - 
     2.01099007966251153e-10*A*g9*x10 - 
     2.06386033152073184e-11*g10*x12)*xbar8 + 
  eps18*(-1.95213901631847725e-15*A7*g3 + 
     2.9024042061210064e-12*A4*g5 - 
     1.22464345499091446e-12*A*g7 - 
     2.20948357179324358e-11*A6*g4*x2 + 
     1.68407222784752482e-10*A3*g6*x2 - 
     9.52673617116155421e-12*g8*x2 - 
     2.52285174010719033e-10*A5*g5*x4 + 
     6.48893132761825578e-10*A2*g7*x4 - 
     6.78403369061433162e-10*A4*g6*x6 + 
     5.68290125969521456e-10*A*g8*x6 - 
     6.90033763945661382e-10*A3*g7*x8 + 
     1.26310595431481278e-10*g9*x8 - 
     3.12443265284225916e-10*A2*g8*x10 - 
     6.3597958994265421e-11*A*g9*x12 - 
     4.73255306775791468e-12*g10*x14)*xbar8 + 
  eps20*(1.01735256778363072e-16*A8*g3 - 
     5.94748498729256522e-13*A5*g5 + 
     6.8752666515941573e-13*A2*g7 + 
     3.53810789377630122e-12*A7*g4*x2 - 
     5.15152807107229022e-11*A4*g6*x2 + 
     1.25362167426384833e-11*A*g8*x2 + 
     5.5847059374569765e-11*A6*g5*x4 - 
     3.07470180635305607e-10*A3*g7*x4 + 
     1.44903732082026135e-11*g9*x4 + 
     2.07246456352654245e-10*A5*g6*x6 - 
     4.59578840273247801e-10*A2*g8*x6 + 
     2.97340805913634912e-10*A4*g7*x8 - 
     2.2892955313025694e-10*A*g9*x8 + 
     1.99809393100334618e-10*A3*g8*x10 - 
     3.47015927264758897e-11*g10*x10 + 
     6.71900005565290136e-11*A2*g9*x12 + 
     1.09198252656076105e-11*A*g10*x14 + 
     6.80982990694437919e-13*g11*x16)*xbar8 - 
  2.95801289810004407e-10*eps6*g4*xbar10 + 
  2.94346529368315861e-11*eps9*g5*xbar10 + 
  eps8*(7.69281785172546935e-11*A*g4 + 
     1.07490632635875918e-9*g5*x2)*xbar10 + 
  eps11*(-1.49854878334381416e-11*A*g5 - 
     1.64414869918985145e-10*g6*x2)*xbar10 + 
  eps10*(-1.14623038722347948e-11*A2*g4 - 
     6.72527675714427998e-10*A*g5*x2 - 
     5.64942074025452747e-10*g6*x4)*xbar10 + 
  eps13*(4.55203920804202245e-12*A2*g5 + 
     1.35763920347428776e-10*A*g6*x2 + 
     1.33652228562929386e-10*g7*x4)*xbar10 + 
  eps12*(1.27157831390982766e-12*A3*g4 - 
     2.82877994364105943e-12*g6 + 
     2.44160830279527547e-10*A2*g5*x2 + 
     5.14076796669365287e-10*A*g6*x4 + 
     1.75139799425245342e-10*g7*x6)*xbar10 + 
  eps15*(-1.07685636895144654e-12*A3*g5 + 
     2.70026199694243437e-13*g7 - 
     6.29652746661281415e-11*A2*g6*x2 - 
     1.49092240439933003e-10*A*g7*x4 - 
     5.88096054052166419e-11*g8*x6)*xbar10 + 
  eps14*(-1.16205790093287907e-13*A4*g4 + 
     2.06949189356323779e-12*A*g6 - 
     6.72146134669773312e-11*A3*g5*x2 + 
     1.99437288401862085e-11*g7*x2 - 
     2.61681510848862049e-10*A2*g6*x4 - 
     2.10127602166714473e-10*A*g7*x6 - 
     4.18842380479881739e-11*g8*x8)*xbar10 + 
  eps17*(2.18937302179867743e-13*A4*g5 - 
     2.52743776628905178e-13*A*g7 + 
     2.15933914153368247e-11*A3*g6*x2 - 
     2.33174044228357075e-12*g8*x2 + 
     9.10889047339860176e-11*A2*g7*x4 + 
     8.28793584781457544e-11*A*g8*x6 + 
     1.87814134450040901e-11*g9*x8)*xbar10 + 
  eps16*(9.22277143780367963e-15*A5*g4 - 
     8.60637474674818858e-13*A2*g6 + 
     1.55522012194999734e-11*A4*g5*x2 - 
     2.04738873511014663e-11*A*g7*x2 + 
     9.80212032242431517e-11*A3*g6*x4 - 
     2.27433206141358192e-11*g8*x4 + 
     1.3776069368825939e-10*A2*g7*x6 + 
     6.26447221848720574e-11*A*g8*x8 + 
     8.59289553201749293e-12*g9*x10)*xbar10 + 
  eps19*(-4.01386516110057917e-14*A5*g5 + 
     1.3091834712452921e-13*A2*g7 - 
     6.0989736648541878e-12*A4*g6*x2 + 
     2.86173201964551467e-12*A*g8*x2 - 
     4.02840475527683715e-11*A3*g7*x4 + 
     3.510880308676512e-12*g9*x4 - 
     6.29106001544106061e-11*A2*g8*x6 - 
     3.20688619604414165e-11*A*g9*x8 - 
     4.92343192873666106e-12*g10*x10)*xbar10 + 
  eps18*(-6.56399733698215579e-16*A6*g4 + 
     2.67367086954926804e-13*A3*g6 - 
     2.65773724648037072e-14*g8 - 
     3.1891761064266082e-12*A5*g5*x2 + 
     1.1556733294634019e-11*A2*g7*x2 - 
     3.00891865934477623e-11*A4*g6*x4 + 
     3.00144725725027383e-11*A*g8*x4 - 
     6.52019833501791742e-11*A3*g7*x6 + 
     1.33683467827448483e-11*g9*x6 - 
     5.03812647605675579e-11*A2*g8*x8 - 
     1.54328716110212964e-11*A*g9*x10 - 
     1.5943182436056292e-12*g10*x12)*xbar10 + 
  1.69722051530330397e-12*eps8*g5*xbar12 - 
  2.90595190793452012e-13*eps11*g6*xbar12 + 
  eps10*(-5.54575148020670988e-13*A*g5 - 
     1.29008964169185665e-11*g6*x2)*xbar12 + 
  eps13*(1.78798720202615632e-13*A*g6 + 
     2.57210159823889116e-12*g7*x2)*xbar12 + 
  eps12*(1.00869657097464141e-13*A2*g5 + 
     9.47632013657176953e-12*A*g6*x2 + 
     1.00368310409322369e-11*g7*x4)*xbar12 + 
  eps15*(-6.39010493062016058e-14*A2*g6 - 
     2.40693363499189255e-12*A*g7*x2 - 
     2.87715768832048683e-12*g8*x4)*xbar12 + 
  eps14*(-1.33953977785016062e-14*A3*g5 + 
     3.84980892713537606e-14*g7 - 
     3.94928486633783273e-12*A2*g6*x2 - 
     1.02511581325767213e-11*A*g7*x4 - 
     4.17899415533904787e-12*g8*x6)*xbar12 + 
  eps17*(1.73998403455957848e-14*A3*g6 - 
     4.62636803886378434e-15*g8 + 
     1.24741423146112554e-12*A2*g7*x2 + 
     3.52693455958173369e-12*A*g8*x4 + 
     1.62821302569789988e-12*g9*x6)*xbar12 + 
  eps16*(1.44440682820300384e-15*A4*g5 - 
     3.24022688540454265e-14*A*g7 + 
     1.22741801273679764e-12*A3*g6*x2 - 
     3.84061473377336244e-13*g8*x2 + 
     5.77793844380739442e-12*A2*g7*x4 + 
     5.47447616200335818e-12*A*g8*x6 + 
     1.26471026695269685e-12*g9*x8)*xbar12 + 
  eps18*(-1.33739060725578634e-16*A5*g5 + 
     1.52467406929696226e-14*A2*g7 - 
     3.16506850006518787e-13*A4*g6*x2 + 
     4.36808508700696498e-13*A*g8*x2 - 
     2.37192884056053272e-12*A3*g7*x4 + 
     5.73811638250132219e-13*g9*x4 - 
     3.88549767072102607e-12*A2*g8*x6 - 
     2.02801867312185292e-12*A*g9*x8 - 
     3.15279597165500734e-13*g10*x10)*xbar12 - 
  1.06551186196798794e-14*eps10*g6*xbar14 + 
  2.96371424137457707e-15*eps13*g7*xbar14 + 
  eps12*(4.1883104771160436e-15*A*g6 + 
     1.55454784378046993e-13*g7*x2)*xbar14 + 
  eps15*(-2.14017433818550597e-15*A*g7 - 
     3.90198867402243257e-14*g8*x2)*xbar14 + 
  eps14*(-8.99454744512618591e-16*A2*g6 - 
     1.30968415155813316e-13*A*g7*x2 - 
     1.70308449198607365e-13*g8*x4)*xbar14 + 
  eps17*(8.79886328932693487e-16*A2*g7 + 
     4.07855521267175371e-14*A*g8*x2 + 
     5.8024185244265147e-14*g9*x4)*xbar14 + 
  eps16*(1.39116436986363771e-16*A3*g6 - 
     5.17467765013076258e-16*g8 + 
     6.15890327064823114e-14*A2*g7*x2 + 
     1.92792938842998867e-13*A*g8*x4 + 
     9.24186997248047774e-14*g9*x6)*xbar14 + 
  7.1230636127202905e-17*eps12*g7*xbar16 - 
  3.09644400991606704e-17*eps15*g8*xbar16 + 
  eps14*(-3.27091744222075652e-17*A*g7 - 
     1.87737117146802168e-15*g8*x2)*xbar16 + 
  eps16*(8.09908041993038944e-18*A2*g7 + 
     1.78317218006896548e-15*A*g8*x2 + 
     2.78832594974046941e-15*g9*x4)*xbar16 - 
  4.98845119121947873e-19*eps14*g8*xbar18;
}
#endif

#ifdef p26
double Wp(void)
{
   return 0.5*A*x2 + 0.0416666666666666667*g*x4 + 
  eps*(0.0833333333333333333*A + 0.0416666666666666667*g*x2) + 
  eps3*(-0.00277777777777777778*A2 - 
     0.0111111111111111111*A*g*x2 - 
     0.00208333333333333333*g2*x4) + 
  eps2*(0.00416666666666666667*g - 
     0.0416666666666666667*A2*x2 - 
     0.0138888888888888889*A*g*x4 - 
     0.00115740740740740741*g2*x6) + 
  eps5*(0.0001763668430335097*A3 - 
     0.0000388558201058201058*g2 + 
     0.00214947089947089947*A2*g*x2 + 
     0.00124007936507936508*A*g2*x4 + 
     0.000154320987654320988*g3*x6) + 
  eps4*(-0.000595238095238095238*A*g + 
     0.00416666666666666667*A3*x2 - 
     0.000868055555555555556*g2*x2 + 
     0.00347222222222222222*A2*g*x4 + 
     0.000810185185185185185*A*g2*x6 + 
     0.0000578703703703703704*g3*x8) + 
  eps7*(-0.0000132275132275132275*A4 + 
     0.000013452982202982203*A*g2 - 
     0.000353835978835978836*A3*g*x2 + 
     0.0000292107583774250441*g3*x2 - 
     0.000438161375661375661*A2*g2*x4 - 
     0.000141369047619047619*A*g3*x6 - 
     0.0000131815843621399177*g4*x8) + 
  eps6*(0.0000793650793650793651*A2*g - 
     0.000421626984126984127*A4*x2 + 
     0.000412533068783068783*A*g2*x2 - 
     0.000710978835978835979*A3*g*x4 + 
     0.00012359457671957672*g3*x4 - 
     0.000332065696649029982*A2*g2*x6 - 
     0.0000592482363315696649*A*g3*x8 - 
     3.61689814814814815e-6*g4*x10) + 
  eps9*(1.06888995777884667e-6*A5 - 
     3.09484386865339246e-6*A2*g2 + 
     0.000052889176153065042*A4*g*x2 - 
     0.0000196739667225778337*A*g3*x2 + 
     0.000118621733205066538*A3*g2*x4 - 
     8.12834124466068911e-6*g4*x4 + 
     0.0000723776288012399124*A2*g3*x6 + 
     0.0000162595142340512711*A*g4*x8 + 
     1.2123306755829904e-6*g5*x10) + 
  eps8*(-0.0000100208433541766875*A3*g + 
     8.50711788211788212e-7*g3 + 
     0.0000427138447971781305*A5*x2 - 
     0.000120331539602372936*A2*g2*x2 + 
     0.000127911890064667842*A4*g*x4 - 
     0.000098836830607663941*A*g3*x4 + 
     0.000102804110327258475*A3*g2*x6 - 
     0.0000165018585880854399*g4*x6 + 
     0.0000336428938859494415*A2*g3*x8 + 
     4.8512364050558495e-6*A*g4*x10 + 
     2.56755115454961134e-7*g5*x12) + 
  eps11*(-9.01835117002665504e-8*A6 + 
     5.87400058299529199e-7*A3*g2 - 
     2.81868399275952575e-8*g4 - 
     7.41416841780598394e-6*A5*g*x2 + 
     7.67116473755031956e-6*A2*g3*x2 - 
     0.000027147462601331649*A4*g2*x4 + 
     8.12031936990601012e-6*A*g4*x4 - 
     0.0000272310450812986086*A3*g3*x6 + 
     1.70667153812408442e-6*g5*x6 - 
     0.0000108933015093453806*A2*g4*x8 - 
     1.87850642976993286e-6*A*g5*x10 - 
     1.16690477054095881e-7*g6*x12) + 
  eps10*(1.21747740795359843e-6*A4*g - 
     4.62417873132158846e-7*A*g3 - 
     4.32775172358505692e-6*A6*x2 + 
     0.0000276277014248244407*A3*g2*x2 - 
     1.30445706075046353e-6*g4*x2 - 
     0.0000210333326652771097*A5*g*x4 + 
     0.0000447391253752860896*A2*g3*x4 - 
     0.0000265668910778864483*A4*g2*x6 + 
     0.0000184769777868736202*A*g4*x6 - 
     0.0000139376709110505407*A3*g3*x8 + 
     2.13520310814871e-6*g5*x8 - 
     3.5181249916492972e-6*A2*g4*x10 - 
     4.25407416871537242e-7*A*g5*x12 - 
     1.98147969535893919e-8*g6*x14) + 
  eps13*(7.83069566138349207e-9*A7 - 
     9.93094869534334209e-8*A4*g2 + 
     2.08755249185163841e-8*A*g4 + 
     9.92791119692574719e-7*A6*g*x2 - 
     2.26246788359770127e-6*A3*g3*x2 + 
     7.19774046753493046e-8*g5*x2 + 
     5.52538741816188906e-6*A5*g2*x4 - 
     4.47883727161149936e-6*A2*g4*x4 + 
     8.38601213983571788e-6*A4*g3*x6 - 
     2.25348627386308778e-6*A*g5*x6 + 
     5.24445855604457162e-6*A3*g4*x8 - 
     3.11392974798759566e-7*g6*x8 + 
     1.55465050346795001e-6*A2*g5*x10 + 
     2.17600880397466046e-7*A*g6*x12 + 
     1.15841884836628278e-8*g7*x14) + 
  eps12*(-1.43889032777921667e-7*A5*g + 
     1.51283642180000723e-7*A2*g3 + 
     4.38492191964414187e-7*A7*x2 - 
     5.47671197834474951e-6*A4*g2*x2 + 
     1.1365151365172641e-6*A*g4*x2 + 
     3.23789133106262736e-6*A6*g*x4 - 
     0.0000150481673660823793*A3*g3*x4 + 
     5.97324614725086198e-7*g5*x4 + 
     6.03932684613625972e-6*A5*g2*x6 - 
     0.0000113106765525436987*A2*g4*x6 + 
     4.69528859165240338e-6*A4*g3*x8 - 
     3.0694501391598228e-6*A*g5*x8 + 
     1.82557370238215146e-6*A3*g4*x10 - 
     2.71046144994230449e-7*g6*x10 + 
     3.7535031778135559e-7*A2*g5*x12 + 
     3.90681314457195373e-8*A*g6*x14 + 
     1.62260932077515154e-9*g7*x16) + 
  eps15*(-6.94206524686864971e-10*A8 + 
     1.55258266251201437e-8*A5*g2 - 
     8.87063997906019346e-9*A2*g4 - 
     1.28444091425696105e-7*A7*g*x2 + 
     5.59355511978255916e-7*A4*g3*x2 - 
     7.69591961687451275e-8*A*g5*x2 - 
     1.03084425773136674e-6*A6*g2*x4 + 
     1.80099658500984157e-6*A3*g4*x4 - 
     4.89852640150590245e-8*g6*x4 - 
     2.23744987275327073e-6*A5*g3*x6 + 
     1.60416803829389571e-6*A2*g5*x6 - 
     2.02887475090349778e-6*A4*g4*x8 + 
     5.10536772376168298e-7*A*g6*x8 - 
     9.11746562790846727e-7*A3*g5*x10 + 
     5.21769349658492833e-8*g7*x10 - 
     2.14341780318485671e-7*A2*g6*x12 - 
     2.52490551976121104e-8*A*g7*x14 - 
     1.17600420262660865e-9*g8*x16) + 
  eps14*(1.66609565924847593e-8*A6*g - 
     3.84541066603365207e-8*A3*g3 + 
     1.23616495716322489e-9*g5 - 
     4.44285396439000936e-8*A8*x2 + 
     9.81807578832239391e-7*A5*g2*x2 - 
     5.55101746448534654e-7*A2*g4*x2 - 
     4.73967830600877338e-7*A7*g*x4 + 
     4.18284859452059839e-6*A4*g3*x4 - 
     7.15343253702736788e-7*A*g5*x4 - 
     1.24663165145441196e-6*A6*g2*x6 + 
     5.00514675879205854e-6*A3*g4*x6 - 
     1.81402700349001079e-7*g6*x6 - 
     1.36226318220021373e-6*A5*g3*x8 + 
     2.36606032230627314e-6*A2*g5*x8 - 
     7.58172593612770117e-7*A4*g4*x10 + 
     4.75471890972483691e-7*A*g6*x10 - 
     2.34027522244261325e-7*A3*g5*x12 + 
     3.3963539821117207e-8*g7*x12 - 
     4.06050820222736176e-8*A2*g6*x14 - 
     3.70938742929349711e-9*A*g7*x16 - 
     1.38898528337180163e-10*g8*x18) + 
  eps17*(6.25217958800249802e-11*A9 - 
     2.29312206278746533e-9*A6*g2 + 
     2.8310089717477044e-9*A3*g4 - 
     6.71998649148490015e-11*g6 + 
     1.61783182535963035e-8*A8*g*x2 - 
     1.222198282975496e-7*A5*g3*x2 + 
     4.51903487294323094e-8*A2*g5*x2 + 
     1.79787422789127715e-7*A7*g2*x4 - 
     5.89386352242391962e-7*A4*g4*x4 + 
     6.83924293854497039e-8*A*g6*x4 + 
     5.35385253592035249e-7*A6*g3*x6 - 
     8.16161936426993263e-7*A3*g5*x6 + 
     2.03110694856709656e-8*g7*x6 + 
     6.69429955495357485e-7*A5*g4*x8 - 
     4.44812062546498445e-7*A2*g6*x8 + 
     4.24544759374608395e-7*A4*g5*x10 - 
     1.02125278182278717e-7*A*g7*x10 + 
     1.48190757087105866e-7*A3*g6*x12 - 
     8.25465653164429909e-9*g8*x12 + 
     2.8842218900714868e-8*A2*g7*x14 + 
     2.93316966296752154e-9*A*g8*x16 + 
     1.21426224678902097e-10*g9*x18) + 
  eps16*(-1.89909954985575877e-9*A7*g + 
     8.35603474047208798e-9*A4*g3 - 
     1.15966243496214952e-9*A*g5 + 
     4.50155213123768602e-9*A9*x2 - 
     1.63520154608933337e-7*A6*g2*x2 + 
     2.00125773929144853e-7*A3*g4*x2 - 
     4.71643935891082883e-9*g6*x2 + 
     6.66827009985439445e-8*A8*g*x4 - 
     1.01569722853466271e-6*A5*g3*x4 + 
     4.653753986331283e-7*A2*g5*x4 + 
     2.38609112997144637e-7*A7*g2*x6 - 
     1.78931879078472604e-6*A4*g4*x6 + 
     2.75782412054904595e-7*A*g6*x6 + 
     3.5257503626825941e-7*A6*g3*x8 - 
     1.29719583644083582e-6*A3*g5*x8 + 
     4.43904638337799842e-8*g7*x8 + 
     2.67563783428073661e-7*A5*g4*x10 - 
     4.41739629456479988e-7*A2*g6*x10 + 
     1.15544405881940575e-7*A4*g5*x12 - 
     7.03094817586759951e-8*A*g7*x12 + 
     2.95627516533174602e-8*A3*g6*x14 - 
     4.21593686904484474e-9*g8*x14 + 
     4.43746780874914946e-9*A2*g7*x16 + 
     3.61167459558351774e-10*A*g8*x18 + 
     1.23066706066192904e-11*g9*x20) + 
  eps19*(-5.70128780114804572e-12*A10 + 
     3.24325759393455769e-10*A7*g2 - 
     7.52920392642037898e-10*A4*g4 + 
     7.63432039813829238e-11*A*g6 - 
     1.99446765051272661e-9*A9*g*x2 + 
     2.43560018179573397e-8*A6*g3*x2 - 
     1.92651473964731419e-8*A3*g5*x2 + 
     3.57664504054283011e-10*g7*x2 - 
     2.97138844105769473e-8*A8*g2*x4 + 
     1.66367899286352586e-7*A5*g4*x4 - 
     5.12763843043703477e-8*A2*g6*x4 - 
     1.17558487781038256e-7*A7*g3*x6 + 
     3.32274083849900958e-7*A4*g5*x6 - 
     3.49339293457975036e-8*A*g7*x6 - 
     1.95421595481198395e-7*A6*g4*x8 + 
     2.73546099832218964e-7*A3*g6*x8 - 
     6.42119893976624269e-9*g8*x8 - 
     1.66845932629322826e-7*A5*g5*x10 + 
     1.05196992302604677e-7*A2*g7*x10 - 
     8.06653736383214643e-8*A4*g6*x12 + 
     1.87723844343482559e-8*A*g8*x12 - 
     2.29644918467110207e-8*A3*g7*x14 + 
     1.25288025697957571e-9*g9*x14 - 
     3.81165485194947533e-9*A2*g8*x16 - 
     3.41033212304414905e-10*A*g9*x18 - 
     1.27053709821831841e-11*g10*x20) + 
  eps18*(2.13798292543051714e-10*A8*g - 
     1.62899940163818617e-9*A5*g3 + 
     6.06739124374671626e-10*A2*g5 - 
     4.56102589118103946e-10*A10*x2 + 
     2.5741194154734252e-8*A7*g2*x2 - 
     5.93202934378594688e-8*A4*g4*x2 + 
     5.97796132442781859e-9*A*g6*x2 - 
     9.086017175115798e-9*A9*g*x4 + 
     2.22788546277779156e-7*A6*g3*x4 - 
     2.17818061292066124e-7*A3*g5*x4 + 
     4.46060201054250811e-9*g7*x4 - 
     4.29736286745591606e-8*A8*g2*x6 + 
     5.48218484132244335e-7*A5*g4*x6 - 
     2.23798601959230444e-7*A2*g6*x6 - 
     8.3334504765293729e-8*A7*g3*x8 + 
     5.66588387939462102e-7*A4*g5*x8 - 
     8.17078651256326395e-8*A*g7*x8 - 
     8.32572408053676287e-8*A6*g4*x10 + 
     2.88769211893932833e-7*A3*g6*x10 - 
     9.49367158787967084e-9*g8*x10 - 
     4.80270155903927102e-8*A5*g5*x12 + 
     7.64234973061525259e-8*A2*g7*x12 - 
     1.69136821548003748e-8*A4*g6*x14 + 
     1.00575293092506873e-8*A*g8*x14 - 
     3.69466622059472975e-9*A3*g7*x16 + 
     5.19597646877020836e-10*g9*x16 - 
     4.88723854749631574e-10*A2*g8*x18 - 
     3.58645537045585288e-11*A*g9*x20 - 
     1.12084057456710382e-12*g10*x22) + 
  eps21*(5.2514619543187782e-13*A11 - 
     4.43285954755604869e-11*A8*g2 + 
     1.76083788279021689e-10*A5*g4 - 
     4.74728753998211342e-11*A2*g6 + 
     2.41589075467910444e-10*A10*g*x2 - 
     4.51824485857656974e-9*A7*g3*x2 + 
     6.66083029216207287e-9*A4*g5*x2 - 
     5.24335874922835697e-10*A*g7*x2 + 
     4.69949475640663485e-9*A9*g2*x4 - 
     4.19656758646856316e-8*A6*g4*x4 + 
     2.73885212294566607e-8*A3*g6*x4 - 
     4.48244578272414887e-10*g8*x4 + 
     2.40727904510809782e-8*A8*g3*x6 - 
     1.14987302708287038e-7*A5*g5*x6 + 
     3.18314156293579248e-8*A2*g7*x6 + 
     5.1729556293745067e-8*A7*g4*x8 - 
     1.33139310440523761e-7*A4*g6*x8 + 
     1.31084047358048264e-8*A*g8*x8 + 
     5.74763592331078553e-8*A6*g5*x10 - 
     7.58285646214704478e-8*A3*g7*x10 + 
     1.70719938146989968e-9*g9*x10 + 
     3.67818305341475603e-8*A5*g6*x12 - 
     2.23107719453182269e-8*A2*g8*x12 + 
     1.43062528484956471e-8*A4*g7*x14 - 
     3.24546888412113238e-9*A*g9*x14 + 
     3.43426667042232431e-9*A3*g8*x16 - 
     1.84284319077257175e-10*g10*x16 + 
     4.96756814596081739e-10*A2*g9*x18 + 
     3.96764099826891058e-11*A*g10*x20 + 
     1.34372144042558418e-12*g11*x22) + 
  eps20*(-2.38285086177214561e-11*A9*g + 
     2.93087835503767857e-10*A6*g3 - 
     2.33284850513311582e-10*A3*g5 + 
     4.35358687387975124e-12*g7 + 
     4.62128541799995915e-11*A11*x2 - 
     3.87512747715920683e-9*A8*g2*x2 + 
     1.52963831343981389e-8*A5*g4*x2 - 
     4.10201649274809254e-9*A2*g6*x2 + 
     1.2058131859727143e-9*A10*g*x4 - 
     4.51251014708823542e-8*A7*g3*x4 + 
     8.20524658045556169e-8*A4*g5*x4 - 
     7.11455083461241557e-9*A*g7*x4 + 
     7.36094104464716057e-9*A9*g2*x6 - 
     1.49255884116928141e-7*A6*g4*x6 + 
     1.28707565844365563e-7*A3*g6*x6 - 
     2.42078453530071715e-9*g8*x6 + 
     1.82893288628610935e-8*A8*g3*x8 - 
     2.09524543137285467e-7*A5*g5*x8 + 
     7.93810679543179244e-8*A2*g7*x8 + 
     2.34179153309909358e-8*A7*g4*x10 - 
     1.48969846228119514e-7*A4*g6*x10 + 
     2.05019199855671562e-8*A*g8*x10 + 
     1.74575105847696841e-8*A6*g5*x12 - 
     5.80036979689224998e-8*A3*g7*x12 + 
     1.8510046912641176e-9*g9*x12 + 
     8.09148869608194122e-9*A5*g6*x14 - 
     1.251808839252206e-8*A2*g8*x14 + 
     2.40348962003249252e-9*A4*g7*x16 - 
     1.40328230011170153e-9*A*g9*x16 + 
     4.58007384146693616e-10*A3*g8*x18 - 
     6.36787892934133022e-11*g10*x18 + 
     5.41571641768509377e-11*A2*g9*x20 + 
     3.61823810155023661e-12*A*g10*x22 + 
     1.04407319287969897e-13*g11*x24) + 
  eps23*(-4.87743892079685082e-14*A12 + 
     5.89316491267758974e-12*A9*g2 - 
     3.73943263170943611e-11*A6*g4 + 
     2.13679155317563112e-11*A3*g6 - 
     3.27361153325515243e-13*g8 - 
     2.88368279506519334e-11*A11*g*x2 + 
     7.91374895139060628e-10*A8*g3*x2 - 
     1.98046179372144604e-9*A5*g5*x2 + 
     4.11786639583657111e-10*A2*g7*x2 - 
     7.16497851551313523e-10*A10*g2*x4 + 
     9.68464471525289276e-9*A7*g4*x4 - 
     1.16748393728030986e-8*A4*g6*x4 + 
     8.04127478183736051e-10*A*g8*x4 - 
     4.65194608412246558e-9*A9*g3*x6 + 
     3.51082372037893695e-8*A6*g5*x6 - 
     2.04201982013264592e-8*A3*g7*x6 + 
     3.08310721156552306e-10*g9*x6 - 
     1.26357673284535273e-8*A8*g4*x8 + 
     5.45476416156654204e-8*A5*g6*x8 - 
     1.40486405551536498e-8*A2*g8*x8 - 
     1.7805212696568686e-8*A7*g5*x10 + 
     4.2926305860153371e-8*A4*g7*x10 - 
     4.0312366550615087e-9*A*g9*x10 - 
     1.46022546131613235e-8*A6*g6*x12 + 
     1.843836447337074e-8*A3*g8*x12 - 
     4.02235197734030437e-10*g10*x12 - 
     7.42369322805527411e-9*A5*g7*x14 + 
     4.37038526225414347e-9*A2*g9*x14 - 
     2.40937437944208411e-9*A4*g8*x16 + 
     5.35568097093309146e-10*A*g10*x16 - 
     4.99603251087911808e-10*A3*g9*x18 + 
     2.64472477748035067e-11*g11*x18 - 
     6.40255800593810452e-11*A2*g10*x20 - 
     4.61829796410311992e-12*A*g11*x22 - 
     1.43368406597132889e-13*g12*x24) + 
  eps22*(2.63381701723029945e-12*A10*g - 
     4.95613474685512438e-11*A7*g3 + 
     7.3461839787322817e-11*A4*g5 - 
     5.80927196941699941e-12*A*g7 - 
     4.68234108487568308e-12*A12*x2 + 
     5.62566165576091132e-10*A9*g2*x2 - 
     3.55029758958278224e-9*A6*g4*x2 + 
     2.01925178972162547e-9*A3*g6*x2 - 
     3.0814593971546122e-11*g8*x2 - 
     1.56527781346397019e-10*A11*g*x4 + 
     8.57069278143073356e-9*A8*g3*x4 - 
     2.64080665694219489e-8*A5*g5*x4 + 
     6.0407259102082057e-9*A2*g7*x4 - 
     1.20889938892283076e-9*A10*g2*x6 + 
     3.69930387182005496e-8*A7*g4*x6 - 
     5.87976309873423814e-8*A4*g6*x6 + 
     4.64691762189073441e-9*A*g8*x6 - 
     3.7731495679189183e-9*A9*g3*x8 + 
     6.81148651466673022e-8*A6*g5*x8 - 
     5.41126426776092471e-8*A3*g7*x8 + 
     9.60423280700958978e-10*g9*x8 - 
     6.06051978329905884e-9*A8*g4*x10 + 
     6.45172101423398301e-8*A5*g6*x10 - 
     2.31853730369969274e-8*A2*g8*x10 - 
     5.69384641167539249e-9*A7*g5*x12 + 
     3.45031778931260666e-8*A4*g7*x12 - 
     4.5856200745095094e-9*A*g9*x12 - 
     3.36446046321516529e-9*A6*g6*x14 + 
     1.08170138123001676e-8*A3*g8*x14 - 
     3.37300366179434001e-10*g10*x14 - 
     1.30060474988550597e-9*A5*g7*x16 + 
     1.9676600421073939e-9*A2*g9*x16 - 
     3.33854146037989048e-10*A4*g8*x18 + 
     1.92027951778477411e-10*A*g10*x18 - 
     5.64147807443152692e-11*A3*g9*x20 + 
     7.76866625886353525e-12*g11*x20 - 
     6.03122771185984168e-12*A2*g10*x22 - 
     3.69809171837544212e-13*A*g11*x24 - 
     9.90994892123906548e-15*g12*x26) + 
  eps25*(4.5617341154295489e-15*A13 - 
     7.65681973581163408e-13*A10*g2 + 
     7.36427533361146046e-12*A7*g4 - 
     7.77915357825993505e-12*A4*g6 + 
     5.01822372498827554e-13*A*g8 + 
     3.39946554308810257e-12*A12*g*x2 - 
     1.32218967001765988e-10*A9*g3*x2 + 
     5.24826694161013285e-10*A6*g5*x2 - 
     2.29911014730304061e-10*A3*g7*x2 + 
     2.97396110366290561e-12*g9*x2 + 
     1.05899009942419973e-10*A11*g2*x4 - 
     2.07888236061736146e-9*A8*g4*x4 + 
     4.2205345488109798e-9*A5*g6*x4 - 
     7.62725505811220135e-10*A2*g8*x4 + 
     8.56030817990639683e-10*A10*g3*x6 - 
     9.69700200555032466e-9*A7*g5*x6 + 
     1.0345307489459437e-8*A4*g7*x6 - 
     6.53391446848804187e-10*A*g9*x6 + 
     2.88536112350769269e-9*A9*g4*x8 - 
     1.95458369290004387e-8*A6*g6*x8 + 
     1.05141608097548792e-8*A3*g8*x8 - 
     1.49985208961406861e-10*g10*x8 + 
     5.0517190817639561e-9*A8*g5*x10 - 
     2.03127428588433698e-8*A5*g7*x10 + 
     4.96479103747145285e-9*A2*g9*x10 + 
     5.18105920734004777e-9*A7*g6*x12 - 
     1.18984582771191454e-8*A4*g8*x12 + 
     1.07801501997213091e-9*A*g10*x12 + 
     3.33667223847150641e-9*A6*g7*x14 - 
     4.07258881748425756e-9*A3*g9*x14 + 
     8.66712686070301579e-11*g11*x14 + 
     1.4017941285304863e-9*A5*g8*x16 - 
     8.05772603894054025e-10*A2*g10*x16 + 
     3.89757092431598696e-10*A4*g9*x18 - 
     8.52041965373136873e-11*A*g11*x18 + 
     7.10964158735397762e-11*A3*g10*x20 - 
     3.72103988693417535e-12*g12*x20 + 
     8.17773394901589543e-12*A2*g11*x22 + 
     5.37775729072728217e-13*A*g12*x24 + 
     1.54097984854059648e-14*g13*x26) + 
  eps24*(-2.89099899565347662e-13*A11*g + 
     7.9759930961059578e-12*A8*g3 - 
     2.00555906593283631e-11*A5*g5 + 
     4.18688595364780991e-12*A2*g7 + 
     4.74420340935259007e-13*A13*x2 - 
     7.92461835979771511e-11*A10*g2*x2 + 
     7.58561702147442218e-10*A7*g4*x2 - 
     7.97991543042322495e-10*A4*g6*x2 + 
     5.12980963092851767e-11*A*g8*x2 + 
     1.99411637693229689e-11*A12*g*x4 - 
     1.54367310321517635e-9*A9*g3*x4 + 
     7.53265555420091332e-9*A6*g5*x4 - 
     3.62648374581728425e-9*A3*g7*x4 + 
     4.93947743563747665e-11*g9*x4 + 
     1.91553592353180707e-10*A11*g2*x6 - 
     8.49094217698978774e-9*A8*g4*x6 + 
     2.26856565220020088e-8*A5*g6*x6 - 
     4.69772329949351813e-9*A2*g8*x6 + 
     7.38610816404395504e-10*A10*g3*x8 - 
     1.99662166333330706e-8*A7*g5*x8 + 
     2.9041859633440226e-8*A4*g7*x8 - 
     2.15327269006722961e-9*A*g9*x8 + 
     1.46232224612947612e-9*A9*g4*x10 - 
     2.43772139379355154e-8*A6*g6*x10 + 
     1.82674355319716322e-8*A3*g8*x10 - 
     3.10752555543901178e-10*g10*x10 + 
     1.69732946496891816e-9*A8*g5*x12 - 
     1.71231822209617444e-8*A5*g7*x12 + 
     5.9144501741718517e-9*A2*g9*x12 + 
     1.24827250807789759e-9*A7*g6*x14 - 
     7.28755328956029511e-9*A4*g8*x14 + 
     9.42570128461049658e-10*A*g10*x14 + 
     6.08812904258686911e-10*A6*g7*x16 - 
     1.90694699932313329e-9*A3*g9*x16 + 
     5.83702428173174224e-11*g11*x16 + 
     2.01600973965553078e-10*A5*g8*x18 - 
     2.99487561260952419e-10*A2*g10*x18 + 
     4.5544937416083891e-11*A4*g9*x20 - 
     2.58715552328237504e-11*A*g11*x20 + 
     6.91310656589337861e-12*A3*g10*x22 - 
     9.44207238480244009e-13*g12*x22 + 
     6.74432494205638096e-13*A2*g11*x24 + 
     3.82104888900742578e-14*A*g12*x26 + 
     9.55678585992729762e-16*g13*x28) + 
  0.00833333333333333333*eps*g*xbar2 + 
  0.166666666666666667*(A + 0.5*g*x2)*xbar2 + 
  eps3*(-0.000793650793650793651*A*g - 
     0.00138888888888888889*g2*x2)*xbar2 + 
  eps2*(-0.00277777777777777778*A2 - 
     0.0111111111111111111*A*g*x2 - 
     0.00208333333333333333*g2*x4)*xbar2 + 
  eps5*(0.0000727513227513227513*A2*g + 
     0.000522486772486772487*A*g2*x2 + 
     0.000162037037037037037*g3*x4)*xbar2 + 
  eps4*(0.0000661375661375661376*A3 - 
     0.0000644841269841269841*g2 + 
     0.0015873015873015873*A2*g*x2 + 
     0.00094246031746031746*A*g2*x4 + 
     0.000115740740740740741*g3*x6)*xbar2 + 
  eps7*(-6.91438191438191438e-6*A3*g + 
     1.41486599819933153e-6*g3 - 
     0.000128066378066378066*A2*g2*x2 - 
     0.000110705266955266955*A*g3*x4 - 
     0.000018647119341563786*g4*x6)*xbar2 + 
  eps6*(-1.65343915343915344e-6*A4 + 
     0.0000179623617123617124*A*g2 - 
     0.00021164021164021164*A3*g*x2 + 
     0.0000485008818342151675*g3*x2 - 
     0.000276951058201058201*A2*g2*x4 - 
     0.0000898368606701940035*A*g3*x6 - 
     8.27867798353909465e-6*g4*x8)*xbar2 + 
  eps9*(6.79829796893288957e-7*A4*g - 
     6.72419695237155555e-7*A*g3 + 
     0.0000254975770848786722*A3*g2*x2 - 
     2.25056258042369153e-6*g4*x2 + 
     0.0000441438108848823135*A2*g3*x4 + 
     0.0000185871013417309714*A*g4*x6 + 
     2.15148764772607365e-6*g5*x8)*xbar2 + 
  eps8*(4.1753513975736198e-8*A5 - 
     3.46221514376276281e-6*A2*g2 + 
     0.0000267222489444711667*A4*g*x2 - 
     0.0000281804101248545693*A*g3*x2 + 
     0.0000649475909892576559*A3*g2*x4 - 
     0.0000122030666735527847*g4*x4 + 
     0.0000403965247715247715*A2*g3*x6 + 
     9.0700810463541945e-6*A*g4*x8 + 
     6.69795953360768176e-7*g5*x10)*xbar2 + 
  eps11*(-6.80612866459427306e-8*A5*g + 
     1.95584655809718057e-7*A2*g3 - 
     4.47269759439071608e-6*A4*g2*x2 + 
     1.75829988748211593e-6*A*g4*x2 - 
     0.0000133314481239415102*A3*g3*x4 + 
     9.71399147418687179e-7*g5*x4 - 
     0.0000103064498801381517*A2*g4*x6 - 
     2.82142523293179157e-6*A*g5*x8 - 
     2.4892365507720446e-7*g6*x10)*xbar2 + 
  eps10*(-1.05683802773749864e-9*A6 + 
     5.67501373552960855e-7*A3*g2 - 
     4.8511255774108832e-8*g4 - 
     3.24660642120959581e-6*A5*g*x2 + 
     9.71126169538867952e-6*A2*g3*x2 - 
     0.0000131832441790279092*A4*g2*x4 + 
     0.0000108846610427711618*A*g4*x4 - 
     0.0000136365860158849577*A3*g3*x6 + 
     2.33168885512635513e-6*g5*x6 - 
     5.4993290386188865e-6*A2*g4*x8 - 
     9.46094479080590192e-7*A*g5*x10 - 
     5.8302302889011994e-8*g6*x12)*xbar2 + 
  eps13*(6.86627585651083939e-9*A6*g - 
     4.47785160224899766e-8*A3*g3 + 
     2.19249275444418889e-9*g5 + 
     7.19946098097358602e-7*A5*g2*x2 - 
     7.80379784965903039e-7*A2*g4*x2 + 
     3.37142842641135708e-6*A4*g3*x4 - 
     1.06398186364605041e-6*A*g5*x4 + 
     4.18165456228327982e-6*A3*g4*x6 - 
     2.76351067919865578e-7*g6*x6 + 
     2.00589567077445504e-6*A2*g5*x8 + 
     4.04753308555164946e-7*A*g6*x10 + 
     2.88571475583667131e-8*g7*x12)*xbar2 + 
  eps12*(2.67650730613693577e-11*A7 - 
     8.46192910475220622e-8*A4*g2 + 
     3.25142589196534057e-8*A*g4 + 
     3.83704087407791111e-7*A6*g*x2 - 
     2.57283359783619147e-6*A3*g3*x2 + 
     1.27951218977907431e-7*g5*x2 + 
     2.41765559329216737e-6*A5*g2*x4 - 
     5.44480881814382923e-6*A2*g4*x4 + 
     3.82233569685344377e-6*A4*g3*x6 - 
     2.81139544164632672e-6*A*g5*x6 + 
     2.42710273474001612e-6*A3*g4*x8 - 
     3.92027350262991887e-7*g6*x8 + 
     7.21984500196305752e-7*A2*g5*x10 + 
     1.007566064009769e-7*A*g6*x12 + 
     5.32759708629371695e-9*g7*x14)*xbar2 + 
  eps15*(-6.94677964495491896e-10*A7*g + 
     8.85485037384606633e-9*A4*g3 - 
     1.89784940868103996e-9*A*g5 - 
     1.08873720111587578e-7*A6*g2*x2 + 
     2.58200627219967634e-7*A3*g4*x2 - 
     8.57415659878293831e-9*g6*x2 - 
     7.52178044272582197e-7*A5*g3*x4 + 
     6.39174172204870162e-7*A2*g5*x4 - 
     1.38311030669262085e-6*A4*g4*x6 + 
     3.89805821462228289e-7*A*g6*x6 - 
     1.02272071613530239e-6*A3*g5*x8 + 
     6.35874554600849527e-8*g7*x8 - 
     3.51191445940869782e-7*A2*g6*x10 - 
     5.59975947545884819e-8*A*g7*x12 - 
     3.35001083013772154e-9*g8*x14)*xbar2 + 
  eps14*(-6.77936059264516573e-13*A8 + 
     1.18453251754498057e-8*A5*g2 - 
     1.26192122113177278e-8*A2*g4 - 
     4.44292175799593582e-8*A7*g*x2 + 
     5.78235471803035281e-7*A4*g3*x2 - 
     1.25465164813262727e-7*A*g5*x2 - 
     4.11093596933471078e-7*A6*g2*x4 + 
     2.00802343589623813e-6*A3*g4*x4 - 
     8.38456228452171631e-8*g6*x4 - 
     9.37962675222683393e-7*A5*g3*x6 + 
     1.84660973293660698e-6*A2*g5*x6 - 
     8.68952732620502728e-7*A4*g4*x8 + 
     5.95974150882540242e-7*A*g6*x8 - 
     3.93789587968658131e-7*A3*g5*x10 + 
     6.11861559616332661e-8*g7*x10 - 
     9.26911580977221589e-8*A2*g6*x12 - 
     1.08851336477984649e-8*A*g7*x14 - 
     5.04016698893419468e-10*g8*x16)*xbar2 + 
  eps17*(7.03519796756268115e-11*A8*g - 
     1.58412622695254907e-9*A5*g3 + 
     9.21824723042734146e-10*A2*g5 + 
     1.57013176618403867e-8*A7*g2*x2 - 
     7.07877152349972815e-8*A4*g4*x2 + 
     1.01145514044440416e-8*A*g6*x2 + 
     1.52755677874009072e-7*A6*g3*x4 - 
     2.78303968964189299e-7*A3*g5*x4 + 
     7.90216106829461597e-9*g7*x4 + 
     3.94839847004885584e-7*A5*g4*x6 - 
     2.95546266642869418e-7*A2*g6*x6 + 
     4.1812888733216445e-7*A4*g5*x8 - 
     1.09749260429676339e-7*A*g7*x8 + 
     2.15692160440115788e-7*A3*g6*x10 - 
     1.28547064754435117e-8*g8*x10 + 
     5.73688513495873601e-8*A2*g7*x12 + 
     7.55383153004710777e-9*A*g8*x14 + 
     3.89293296941875901e-10*g9*x16)*xbar2 + 
  eps16*(1.71721241125556891e-14*A9 - 
     1.58463391176416606e-9*A6*g2 + 
     3.70687203668986364e-9*A3*g4 - 
     1.21950914958299276e-10*g6 + 
     5.06426546628202339e-9*A8*g*x2 - 
     1.15919331839795365e-7*A5*g3*x2 + 
     6.813324046201634e-8*A2*g5*x2 + 
     6.59264102615256734e-8*A7*g2*x4 - 
     6.0783143535697607e-7*A4*g4*x4 + 
     1.08734552181364072e-7*A*g6*x4 + 
     2.08077893379438207e-7*A6*g3*x6 - 
     8.7376194571684116e-7*A3*g5*x6 + 
     3.31435423816449871e-8*g7*x6 + 
     2.67286143174399604e-7*A5*g4*x8 - 
     4.84990273878282454e-7*A2*g6*x8 + 
     1.71677767909550515e-7*A4*g5*x10 - 
     1.12268658721773254e-7*A*g7*x10 + 
     6.02176056859808662e-8*A3*g6*x12 - 
     9.09453722352822717e-9*g8*x12 + 
     1.17208819972660499e-8*A2*g7*x14 + 
     1.18834173730462595e-9*A*g8*x16 + 
     4.8940576382579539e-11*g9*x18)*xbar2 + 
  eps19*(-7.12707337587569786e-12*A9*g + 
     2.63376364359160315e-10*A6*g3 - 
     3.30780046645030994e-10*A3*g5 + 
     8.03679335161609342e-12*g7 - 
     2.18139573549146275e-9*A8*g2*x2 + 
     1.6989863583308778e-8*A5*g4*x2 - 
     6.4969385102430346e-9*A2*g6*x2 - 
     2.88250590711040757e-8*A7*g3*x4 + 
     9.81072496878526138e-8*A4*g5*x4 - 
     1.18346882869724656e-8*A*g7*x4 - 
     1.00731210992033847e-7*A6*g4*x6 + 
     1.59691202088983395e-7*A3*g6*x6 - 
     4.13548363870289057e-9*g8*x6 - 
     1.45496453255537213e-7*A5*g5*x8 + 
     1.00501516554651165e-7*A2*g7*x8 - 
     1.05051610378898918e-7*A4*g6*x10 + 
     2.62399674415998082e-8*A*g8*x10 - 
     4.12244346987175346e-8*A3*g7*x12 + 
     2.38101241880130705e-9*g9*x12 - 
     8.92371773273422321e-9*A2*g8*x14 - 
     1.00013636391153993e-9*A*g9*x16 - 
     4.52724718151082609e-11*g10*x18)*xbar2 + 
  eps18*(-4.34973739711612375e-16*A10 + 
     2.04866596742209561e-10*A7*g2 - 
     9.13337973503563032e-10*A4*g4 + 
     1.29494994082815314e-10*A*g6 - 
     5.70128780114804572e-10*A9*g*x2 + 
     2.13523668994309077e-8*A6*g3*x2 - 
     2.7041278749459319e-8*A3*g5*x2 + 
     6.61136770529593115e-10*g7*x2 - 
     1.00900226220693725e-8*A8*g2*x4 + 
     1.59771473522731497e-7*A5*g4*x4 - 
     7.62149977963186539e-8*A2*g6*x4 - 
     4.26288251723329756e-8*A7*g3*x6 + 
     3.32905368200259132e-7*A4*g5*x6 - 
     5.34789893441100738e-8*A*g7*x6 - 
     7.31666710191171495e-8*A6*g4*x8 + 
     2.80197106079331506e-7*A3*g6*x8 - 
     9.98659790379859243e-9*g8*x8 - 
     6.35106992331774466e-8*A5*g5*x10 + 
     1.08995209478400767e-7*A2*g7*x10 - 
     3.09539659674895079e-8*A4*g6*x12 + 
     1.95483783519714526e-8*A*g8*x12 - 
     8.83724740598401241e-9*A3*g7*x14 + 
     1.30582050443893102e-9*g9*x14 - 
     1.46593717511110234e-9*A2*g8*x16 - 
     1.30772635674859038e-10*A*g9*x18 - 
     4.84955398928857724e-12*g10*x20)*xbar2 + 
  eps21*(7.22090117277105046e-13*A10*g - 
     4.13991085301446953e-11*A7*g3 + 
     9.76589682716262956e-11*A4*g5 - 
     1.01171462635282484e-11*A*g7 + 
     2.94059482872196453e-10*A9*g2*x2 - 
     3.68979054877682005e-9*A6*g4*x2 + 
     3.00808714445394687e-9*A3*g6*x2 - 
     5.76746247671597889e-11*g8*x2 + 
     5.12696720776491515e-9*A8*g3*x4 - 
     2.96928069363177013e-8*A5*g5*x4 + 
     9.47962261651077826e-9*A2*g7*x4 + 
     2.35049540761358863e-8*A7*g4*x6 - 
     6.88556064847354174e-8*A4*g6*x6 + 
     7.5086659172629484e-9*A*g8*x6 + 
     4.47020768444263473e-8*A6*g5*x8 - 
     6.48548347717962229e-8*A3*g7*x8 + 
     1.57872287719044645e-9*g9*x8 + 
     4.31283591778531503e-8*A5*g6*x10 - 
     2.81624636750572854e-8*A2*g8*x10 + 
     2.3304946259676748e-8*A4*g7*x12 - 
     5.6106802334762125e-9*A*g9*x12 + 
     7.34468856466444926e-9*A3*g8*x14 - 
     4.14021761190658312e-10*g10*x14 + 
     1.33841053507869873e-9*A2*g9*x16 + 
     1.30531947930356562e-10*A*g10*x18 + 
     5.26795343697585529e-12*g11*x20)*xbar2 + 
  eps20*(1.1018005656720459e-17*A11 - 
     2.57889246901160178e-11*A8*g2 + 
     1.98990234155769708e-10*A5*g4 - 
     7.55965424361672699e-11*A2*g6 + 
     6.35426896472572163e-11*A10*g*x2 - 
     3.68388963577669912e-9*A7*g3*x2 + 
     8.75177480890399108e-9*A4*g5*x2 - 
     9.11535637885301799e-10*A*g7*x2 + 
     1.48649455332149944e-9*A9*g2*x4 - 
     3.77359746051647268e-8*A6*g4*x4 + 
     3.82594204726996217e-8*A3*g6*x4 - 
     8.13304101172221063e-10*g8*x4 + 
     8.18713369443791778e-9*A8*g3*x6 - 
     1.08366523313337395e-7*A5*g5*x6 + 
     4.5944289943616577e-8*A2*g7*x6 + 
     1.82487684327326814e-8*A7*g4*x8 - 
     1.28729795350649249e-7*A4*g6*x8 + 
     1.92747318307891877e-8*A*g8*x8 + 
     2.06867607666613227e-8*A6*g5*x10 - 
     7.43763204190519753e-8*A3*g7*x10 + 
     2.53626156501045944e-9*g9*x10 + 
     1.33838352059798451e-8*A5*g6*x12 - 
     2.20494122463979174e-8*A2*g8*x12 + 
     5.23330987914141423e-9*A4*g7*x14 - 
     3.21750395058170305e-9*A*g9*x14 + 
     1.25827561244148185e-9*A3*g8*x16 - 
     1.82713361623688652e-10*g10*x16 + 
     1.81827783439828152e-10*A2*g9*x18 + 
     1.44818570824073778e-11*A*g10*x20 + 
     4.88417660313835094e-13*g11*x22)*xbar2 + 
  eps23*(-7.31620058828327886e-14*A11*g + 
     6.2244144715351518e-12*A8*g3 - 
     2.50972722113902645e-11*A5*g5 + 
     6.90195578112387954e-12*A2*g7 - 
     3.86661866535845128e-11*A10*g2*x2 + 
     7.40985528302493753e-10*A7*g4*x2 - 
     1.12263534560497836e-9*A4*g6*x2 + 
     9.10038912793887614e-11*A*g8*x2 - 
     8.68557303415569482e-10*A9*g3*x4 + 
     7.99751265225702085e-9*A6*g5*x4 - 
     5.38995025036586533e-9*A3*g7*x4 + 
     9.11682355767971334e-11*g9*x4 - 
     5.09949189194303306e-9*A8*g4*x6 + 
     2.517151280314285e-8*A5*g6*x6 - 
     7.20688202607308513e-9*A2*g8*x6 - 
     1.24293927810383763e-8*A7*g5*x8 + 
     3.30698321741881119e-8*A4*g7*x8 - 
     3.36777220246894258e-9*A*g9*x8 - 
     1.55006071785928367e-8*A6*g6*x10 + 
     2.11300984088409138e-8*A3*g8*x10 - 
     4.91764411032702861e-10*g10*x10 - 
     1.10270946906705895e-8*A5*g7*x12 + 
     6.90528529828172647e-9*A2*g9*x12 - 
     4.72730487747526667e-9*A4*g8*x14 + 
     1.10602336934435099e-9*A*g10*x14 - 
     1.24144324312375269e-9*A3*g9*x16 + 
     6.86305256373542116e-11*g11*x16 - 
     1.95159691471731057e-10*A2*g10*x18 - 
     1.68433306811216689e-11*A*g11*x20 - 
     6.13262463130406207e-13*g12*x22)*xbar2 + 
  eps22*(-2.79089293716250467e-19*A12 + 
     3.17766604095748225e-12*A9*g2 - 
     3.95577368582764204e-11*A6*g4 + 
     3.2068101326980409e-11*A3*g6 - 
     6.12076747703341304e-13*g8 - 
     7.02351204594746519e-12*A11*g*x2 + 
     6.03214212931090113e-10*A8*g3*x2 - 
     2.44702734746155151e-9*A5*g5*x2 + 
     6.76097426096149884e-10*A2*g7*x2 - 
     2.12157940796992025e-10*A10*g2*x4 + 
     8.1916797369498686e-9*A7*g4*x4 - 
     1.53944612844692757e-8*A4*g6*x4 + 
     1.38109622177934475e-9*A*g8*x4 - 
     1.49038549899160153e-9*A9*g3*x6 + 
     3.12551588277558658e-8*A6*g5*x6 - 
     2.79047223116628872e-8*A3*g7*x6 + 
     5.436847471574281e-10*g9*x6 - 
     4.21695720957640858e-9*A8*g4*x8 + 
     4.99819767239979985e-8*A5*g6*x8 - 
     1.96069567048585921e-8*A2*g8*x8 - 
     6.0820173561110201e-9*A7*g5*x10 + 
     4.00069800775570726e-8*A4*g7*x10 - 
     5.69705873785929584e-9*A*g9*x10 - 
     5.05592156438231298e-9*A6*g6*x12 + 
     1.73541009641709023e-8*A3*g8*x12 - 
     5.72444406380114732e-10*g10*x12 - 
     2.58984982240261447e-9*A5*g7*x14 + 
     4.13461348937075909e-9*A2*g9*x14 - 
     8.43540110516749951e-10*A4*g8*x16 + 
     5.07648285991122299e-10*A*g10*x16 - 
     1.75053485949267209e-10*A3*g9*x18 + 
     2.50585955675889897e-11*g11*x18 - 
     2.24065847218371337e-11*A2*g10*x20 - 
     1.61190422371025444e-12*A*g11*x22 - 
     4.98497255151051565e-14*g12*x24)*xbar2 + 
  eps24*(7.06941407925893494e-21*A13 - 
     3.84741654463843396e-13*A10*g2 + 
     7.32293254814967057e-12*A7*g4 - 
     1.10404290967107504e-11*A4*g6 + 
     8.91430430592888932e-13*A*g8 + 
     7.70933065507593765e-13*A12*g*x2 - 
     9.46392329053276403e-11*A9*g3*x2 + 
     6.12204723118016064e-10*A6*g5*x2 - 
     3.57786436948859923e-10*A3*g7*x2 + 
     5.61900352465916136e-12*g9*x2 + 
     2.94794501076642169e-11*A11*g2*x4 - 
     1.66054285997922112e-9*A8*g4*x4 + 
     5.27270026858442259e-9*A5*g6*x4 - 
     1.24441828714339168e-9*A2*g8*x4 + 
     2.5932143768735243e-10*A10*g3*x6 - 
     8.18440975363309936e-9*A7*g5*x6 + 
     1.34316391603932223e-8*A4*g7*x6 - 
     1.0967577860615365e-9*A*g9*x6 + 
     9.14099216298559597e-10*A9*g4*x8 - 
     1.70303761165690513e-8*A6*g6*x8 + 
     1.39743392988134275e-8*A3*g8*x8 - 
     2.56275349412587196e-10*g10*x8 + 
     1.64295978902062036e-9*A8*g5*x10 - 
     1.80454719563725777e-8*A5*g7*x10 + 
     6.69540001883729058e-9*A2*g9*x10 + 
     1.71211385785801628e-9*A7*g6*x12 - 
     1.06969476032442112e-8*A4*g8*x12 + 
     1.46666897500527102e-9*A*g10*x12 + 
     1.11324562362569516e-9*A6*g7*x14 - 
     3.68698661561997461e-9*A3*g9*x14 + 
     1.18497108911150463e-10*g11*x14 + 
     4.70206598723156244e-10*A5*g8*x16 - 
     7.32089723755050849e-10*A2*g10*x16 + 
     1.31051469702399336e-10*A4*g9*x18 - 
     7.74991097074319971e-11*A*g11*x18 + 
     2.39115858864581722e-11*A3*g10*x20 - 
     3.38215281496470102e-12*g12*x20 + 
     2.74671447656417087e-12*A2*g11*x22 + 
     1.80167001235699906e-13*A*g12*x24 + 
     5.14468471968218436e-15*g13*x26)*xbar2 + 
  0.00833333333333333333*g*xbar4 - 
  0.0000462962962962962963*eps3*g2*xbar4 + 
  eps2*(-0.000396825396825396825*A*g - 
     0.000694444444444444444*g2*x2)*xbar4 + 
  eps5*(9.11896745230078563e-6*A*g2 + 
     0.0000308641975308641975*g3*x2)*xbar4 + 
  eps4*(0.0000198412698412698413*A2*g + 
     0.000195105820105820106*A*g2*x2 + 
     0.0000617283950617283951*g3*x4)*xbar4 + 
  eps7*(-1.31581381581381581e-6*A2*g2 - 
     0.0000151318588818588819*A*g3*x2 - 
     6.8455207344096233e-6*g4*x4)*xbar4 + 
  eps6*(-9.01875901875901876e-7*A3*g + 
     9.90714532381199048e-7*g3 - 
     0.0000389059243225909893*A2*g2*x2 - 
     0.0000351397573619795842*A*g3*x4 - 
     5.9477880658436214e-6*g4*x6)*xbar4 + 
  eps9*(1.71045640622360199e-7*A3*g2 - 
     3.60906857706966639e-8*g4 + 
     4.53245406122390249e-6*A2*g3*x2 + 
     5.38783061931210079e-6*A*g4*x4 + 
     1.17492514772607365e-6*g5*x6)*xbar4 + 
  eps8*(3.77616945077262538e-8*A4*g - 
     3.91505723846993688e-7*A*g3 + 
     6.55938527962337486e-6*A3*g2*x2 - 
     1.61985166325444103e-6*g4*x2 + 
     0.0000121547079219036891*A2*g3*x4 + 
     5.20508405346368309e-6*A*g4*x6 + 
     6.02301130368259998e-7*g5*x8)*xbar4 + 
  eps11*(-2.12135350797297057e-8*A4*g2 + 
     2.14460056215349951e-8*A*g4 - 
     1.06401470496877178e-6*A3*g3*x2 + 
     9.9419658966568008e-8*g5*x2 - 
     2.4228308825712602e-6*A2*g4*x4 - 
     1.28380796826126347e-6*A*g5*x6 - 
     1.80516340332649186e-7*g6*x8)*xbar4 + 
  eps10*(-1.48202033122668043e-9*A5*g + 
     9.77137892841674354e-8*A2*g3 - 
     9.98537198520664129e-7*A4*g2*x2 + 
     1.12096864298613054e-6*A*g4*x2 - 
     3.25929867376075489e-6*A3*g3*x4 + 
     6.52088831782005348e-7*g5*x4 - 
     2.59007734102806854e-6*A2*g4*x6 - 
     7.14333704061713321e-7*A*g5*x8 - 
     6.28878290312510992e-8*g6*x10)*xbar4 + 
  eps13*(2.55551047231023315e-9*A5*g2 - 
     7.48454109323006102e-9*A2*g4 + 
     2.14869723911233424e-7*A4*g3*x2 - 
     8.87037184673700903e-8*A*g5*x2 + 
     8.1367411096167446e-7*A3*g4*x4 - 
     6.24554324051377381e-8*g6*x4 + 
     7.73534185148061632e-7*A2*g5*x6 + 
     2.53114332805174734e-7*A*g6*x8 + 
     2.60907174059342559e-8*g7*x10)*xbar4 + 
  eps12*(5.52620037914155561e-11*A6*g - 
     1.96395897468419557e-8*A3*g3 + 
     1.73105497543500998e-9*g5 + 
     1.41930118072774209e-7*A5*g2*x2 - 
     4.4751871911848506e-7*A2*g4*x2 + 
     7.4329679752095632e-7*A4*g3*x4 - 
     6.48579919839268283e-7*A*g5*x4 + 
     9.56849686940199225e-7*A3*g4*x6 - 
     1.72592309647809413e-7*g6*x6 + 
     4.6549037372399414e-7*A2*g5*x8 + 
     9.4234108977460504e-8*A*g6*x10 + 
     6.6997976279157566e-9*g7*x12)*xbar4 + 
  eps15*(-3.01110179246578381e-10*A6*g2 + 
     1.99854473307210245e-9*A3*g4 - 
     1.0075222178954846e-10*g6 - 
     3.91236879782746971e-8*A5*g3*x2 + 
     4.42468326545839399e-8*A2*g5*x2 - 
     2.26449722207185509e-7*A4*g4*x4 + 
     7.48610321580336637e-8*A*g6*x4 - 
     3.38794481457344831e-7*A3*g5*x6 + 
     2.34467193453680488e-8*g7*x6 - 
     1.91586076465687549e-7*A2*g6*x8 - 
     4.4705147415174641e-8*A*g7*x10 - 
     3.62790374951045814e-9*g8*x12)*xbar4 + 
  eps14*(-1.97753534590218582e-12*A7*g + 
     3.46651613447685113e-9*A4*g3 - 
     1.3675698718070872e-9*A*g5 - 
     1.92080361104674656e-8*A6*g2*x2 + 
     1.34714593349386061e-7*A3*g4*x2 - 
     7.0165116069938331e-9*g6*x2 - 
     1.51234778678998732e-7*A5*g3*x4 + 
     3.57677410764887609e-7*A2*g5*x4 - 
     2.9119323970204683e-7*A4*g4*x6 + 
     2.24757818721415644e-7*A*g6*x6 - 
     2.19654624683123427e-7*A3*g5*x8 + 
     3.71577620957842484e-8*g7*x8 - 
     7.60245440599503551e-8*A2*g6*x10 - 
     1.21363875909823901e-8*A*g7*x12 - 
     7.23898306636066601e-10*g8*x14)*xbar4 + 
  eps17*(3.48460743277465292e-11*A7*g2 - 
     4.51506468378503526e-10*A4*g4 + 
     9.93046484625324211e-11*A*g6 + 
     6.6025042810186813e-9*A6*g3*x2 - 
     1.62520631488663842e-8*A3*g5*x2 + 
     5.61230122018474251e-10*g7*x2 + 
     5.51380920101008308e-8*A5*g4*x4 - 
     4.88479275078761747e-8*A2*g6*x4 + 
     1.20320332856371923e-7*A4*g5*x6 - 
     3.5365653527819202e-8*A*g7*x6 + 
     1.03628614951869648e-7*A3*g6*x8 - 
     6.71263413921269682e-9*g8*x8 + 
     4.07776601703241782e-8*A2*g7*x10 + 
     7.34880420888892836e-9*A*g8*x12 + 
     4.91163816649064884e-10*g9*x14)*xbar4 + 
  eps16*(6.84233044511131468e-14*A8*g - 
     5.60464705059266925e-10*A5*g3 + 
     6.1113506912043867e-10*A2*g5 + 
     2.50582201503812155e-9*A7*g2*x2 - 
     3.39024845059116986e-8*A4*g4*x2 + 
     7.66141086125169516e-9*A*g6*x2 + 
     2.82533097805425257e-8*A6*g3*x4 - 
     1.44153074493338505e-7*A3*g5*x4 + 
     6.29165697711773721e-9*g7*x4 + 
     7.70955531949116842e-8*A5*g4*x6 - 
     1.5856345215569678e-7*A2*g6*x6 + 
     8.37319173204484218e-8*A4*g5*x8 - 
     5.99155536147365961e-8*A*g7*x8 + 
     4.37139891312553985e-8*A3*g6*x10 - 
     7.07392441584795305e-9*g8*x10 + 
     1.16805756794796047e-8*A2*g7*x12 + 
     1.53807088851897092e-9*A*g8*x14 + 
     7.90314013633620188e-11*g9*x16)*xbar4 + 
  eps19*(-3.97340865876564659e-12*A8*g2 + 
     9.08389634660042267e-11*A5*g4 - 
     5.40989729447639056e-11*A2*g6 - 
     1.05114495716806379e-9*A7*g3*x2 + 
     4.89773729086143515e-9*A4*g5*x2 - 
     7.24791876301819899e-10*A*g7*x2 - 
     1.21370267986698838e-8*A6*g4*x4 + 
     2.29597017376750524e-8*A3*g6*x4 - 
     6.7748721115604107e-10*g8*x4 - 
     3.67138156717417151e-8*A5*g5*x6 + 
     2.85584385486008741e-8*A2*g7*x6 - 
     4.48093489348219503e-8*A4*g6*x8 + 
     1.22153837054061484e-8*A*g8*x8 - 
     2.6272947304230525e-8*A3*g7*x10 + 
     1.62436680861277498e-9*g9*x10 - 
     7.84757421369128482e-9*A2*g8*x12 - 
     1.1484952449755475e-9*A*g9*x14 - 
     6.52079226899128072e-11*g10*x16)*xbar4 + 
  eps18*(-2.30220514713186019e-15*A9*g + 
     8.50336672523331952e-11*A6*g3 - 
     2.03099120170330866e-10*A3*g5 + 
     6.86599038065945835e-12*g7 - 
     3.17730510813967685e-10*A8*g2*x2 + 
     7.52334651318304606e-9*A5*g4*x2 - 
     4.58441975864061026e-9*A2*g6*x2 - 
     4.93856631341031329e-9*A7*g3*x4 + 
     4.73460373170155555e-8*A4*g5*x4 - 
     8.81541701496240287e-9*A*g7*x4 - 
     1.83568265106518087e-8*A6*g4*x6 + 
     8.0214964397589886e-8*A3*g6*x6 - 
     3.16831385872351314e-9*g8*x6 - 
     2.73264771648576643e-8*A5*g5*x8 + 
     5.15584868924249984e-8*A2*g7*x8 - 
     2.00422243527645685e-8*A4*g6*x10 + 
     1.36105580520898305e-8*A*g8*x10 - 
     7.92549659107905268e-9*A3*g7*x12 + 
     1.24112226442452554e-9*g9*x12 - 
     1.72024465137340275e-9*A2*g8*x14 - 
     1.92684278620064115e-10*A*g9*x16 - 
     8.69704747258045207e-12*g10*x18)*xbar4 + 
  eps21*(4.47608018566873029e-13*A9*g2 - 
     1.67753308125991472e-11*A6*g4 + 
     2.15143559796472255e-11*A3*g6 - 
     5.36097713439665228e-13*g8 + 
     1.59789748504864926e-10*A8*g3*x2 - 
     1.28169491309084248e-9*A5*g5*x2 + 
     5.05873112365848404e-10*A2*g7*x2 + 
     2.46793239696357667e-9*A7*g4*x4 - 
     8.69126604407042738e-9*A4*g6*x4 + 
     1.08592337487209441e-9*A*g8*x4 + 
     9.97215933211799948e-9*A6*g5*x6 - 
     1.63775632230861457e-8*A3*g7*x6 + 
     4.39638545658591092e-10*g9*x6 + 
     1.6446217893554322e-8*A5*g6*x8 - 
     1.17661894622675905e-8*A2*g8*x8 + 
     1.33981457517207347e-8*A4*g7*x10 - 
     3.46334251627866228e-9*A*g9*x10 + 
     5.87002262267861254e-9*A3*g8*x12 - 
     3.50481841251753294e-10*g10*x12 + 
     1.40564140813720233e-9*A2*g9*x14 + 
     1.72885003376200776e-10*A*g10*x16 + 
     8.52860757101693105e-12*g11*x18)*xbar4 + 
  eps20*(7.56595105695415785e-17*A10*g - 
     1.22932630659041053e-11*A7*g3 + 
     5.58459887241763578e-11*A4*g5 - 
     8.11455810014543089e-12*A*g7 + 
     3.9383320785984906e-11*A9*g2*x2 - 
     1.51976152664836327e-9*A6*g4*x2 + 
     1.98780657022334646e-9*A3*g6*x2 - 
     5.0284224652211995e-11*g8*x2 + 
     8.18366713361052766e-10*A8*g3*x4 - 
     1.34227304693417849e-8*A5*g5*x4 + 
     6.6399136914675485e-9*A2*g7*x4 + 
     4.01847928057574067e-9*A7*g4*x6 - 
     3.25458326731869081e-8*A4*g6*x6 + 
     5.42627614195641677e-9*A*g8*x6 + 
     7.91216320845347941e-9*A6*g5*x8 - 
     3.14137939839749592e-8*A3*g7*x8 + 
     1.16149233526855299e-9*g9*x8 + 
     7.7806358292877523e-9*A5*g6*x10 - 
     1.38304354148956577e-8*A2*g8*x10 + 
     4.24844294383596806e-9*A4*g7*x12 - 
     2.77563538429180564e-9*A*g9*x12 + 
     1.34573608785890679e-9*A3*g8*x14 - 
     2.05451606449403644e-10*g10*x14 + 
     2.45603481008104843e-10*A2*g9*x16 + 
     2.39299395598715992e-11*A*g10*x18 + 
     9.63092387870827136e-13*g11*x20)*xbar4 + 
  eps23*(-4.99202514118831333e-14*A10*g2 + 
     2.89962490735076355e-12*A7*g4 - 
     6.97186084528071566e-12*A4*g6 + 
     7.39113581154999613e-13*A*g8 - 
     2.3394917837884362e-11*A9*g3*x2 + 
     3.01433272680195764e-10*A6*g5*x2 - 
     2.52901008371964216e-10*A3*g7*x2 + 
     4.9975823717035003e-12*g9*x2 - 
     4.70635007764103411e-10*A8*g4*x4 + 
     2.81182652238779472e-9*A5*g6*x4 - 
     9.27102400382163909e-10*A2*g8*x4 - 
     2.46882746644613326e-9*A7*g5*x6 + 
     7.47170357614364372e-9*A4*g7*x6 - 
     8.42342156242855593e-10*A*g9*x6 - 
     5.31658207824290054e-9*A6*g6*x8 + 
     7.96948615558779495e-9*A3*g8*x8 - 
     2.00535355872142721e-10*g10*x8 - 
     5.74925362613453206e-9*A5*g7*x10 + 
     3.87667862850608752e-9*A2*g9*x10 - 
     3.44992473074412105e-9*A4*g8*x12 + 
     8.569346015302056e-10*A*g10*x12 - 
     1.19748784968841458e-9*A3*g9*x14 + 
     6.95772409909226155e-11*g11*x14 - 
     2.38602512157003406e-10*A2*g10*x16 - 
     2.52826017059561289e-11*A*g11*x18 - 
     1.10236531866119468e-12*g12*x20)*xbar4 + 
  eps22*(-2.43710422261727909e-18*A11*g + 
     1.71109183419778529e-12*A8*g3 - 
     1.34309072457408887e-11*A5*g5 + 
     5.2173544345517194e-12*A2*g7 - 
     4.7920869812117813e-12*A10*g2*x2 + 
     2.85329265230758798e-10*A7*g4*x2 - 
     6.97857430562307631e-10*A4*g6*x2 + 
     7.49694255924035744e-11*A*g8*x2 - 
     1.29794915911680679e-10*A9*g3*x4 + 
     3.40176751053615467e-9*A6*g5*x4 - 
     3.56524460909925476e-9*A3*g7*x4 + 
     7.84071353306302568e-11*g9*x4 - 
     8.21445917536130217e-10*A8*g4*x6 + 
     1.12426357550003378e-8*A5*g6*x6 - 
     4.93283496356209241e-9*A2*g8*x6 - 
     2.08160234188537877e-9*A7*g5*x8 + 
     1.51837246414786265e-8*A4*g7*x8 - 
     2.35241679748374184e-9*A*g9*x8 - 
     2.65426623474241136e-9*A6*g6*x10 + 
     9.86143500745746335e-9*A3*g8*x10 - 
     3.47704012872899376e-10*g10*x10 - 
     1.91288185358486004e-9*A5*g7*x12 + 
     3.25348485105233778e-9*A2*g9*x12 - 
     8.26008166150946402e-10*A4*g8*x14 + 
     5.23734714713970356e-10*A*g10*x14 - 
     2.17662681277754724e-10*A3*g9*x16 + 
     3.25604627396838786e-11*g11*x16 - 
     3.42430735395904115e-11*A2*g10*x18 - 
     2.95184625537922171e-12*A*g11*x20 - 
     1.07193479659543963e-13*g12*x22)*xbar4 - 
  0.0000154320987654320988*eps2*g2*xbar6 + 
  3.56125356125356125e-7*eps5*g3*xbar6 + 
  eps4*(1.90396023729357063e-6*A*g2 + 
     7.71604938271604938e-6*g3*x2)*xbar6 + 
  eps7*(-1.06760523427190094e-7*A*g3 - 
     5.83649889205444761e-7*g4*x2)*xbar6 + 
  eps6*(-1.58222876476844731e-7*A2*g2 - 
     3.0990100434544879e-6*A*g3*x2 - 
     1.45170544476100032e-6*g4*x4)*xbar6 + 
  eps9*(2.10474956623416007e-8*A2*g3 + 
     3.52066889376257568e-7*A*g4*x2 + 
     2.15683591284989252e-7*g5*x4)*xbar6 + 
  eps8*(1.0639753805538638e-8*A3*g2 - 
     1.44647796358943781e-8*g4 + 
     7.89019059521705024e-7*A2*g3*x2 + 
     9.93278626380478232e-7*A*g4*x4 + 
     2.19830466744046991e-7*g5*x6)*xbar6 + 
  eps11*(-3.48009271425128996e-9*A3*g3 + 
     7.74456172615070677e-10*g5 - 
     1.24759056081950737e-7*A2*g4*x2 - 
     1.93124743183608916e-7*A*g5*x4 - 
     5.26262283781649553e-8*g6*x6)*xbar6 + 
  eps10*(-6.21784885258793341e-10*A4*g2 + 
     7.35917308458240036e-9*A*g4 - 
     1.61082849737015107e-7*A3*g3*x2 + 
     4.25042008023580282e-8*g5*x2 - 
     3.97181909847740069e-7*A2*g4*x4 - 
     2.15693489113968417e-7*A*g5*x6 - 
     3.05361793587726322e-8*g6*x8)*xbar6 + 
  eps13*(5.22929181665348026e-10*A4*g3 - 
     5.49761548927799316e-10*A*g5 + 
     3.37795673591345898e-8*A3*g4*x2 - 
     3.32362369023656752e-9*g6*x2 + 
     9.70864128827426103e-8*A2*g5*x4 + 
     6.29082935052959515e-8*A*g6*x6 + 
     1.05359214957493409e-8*g7*x8)*xbar6 + 
  eps12*(3.28023733515722384e-11*A5*g2 - 
     2.2483490443839068e-9*A2*g4 + 
     2.87554439944054822e-8*A4*g3*x2 - 
     3.41643318587639607e-8*A*g5*x2 + 
     1.20413081223750724e-7*A3*g4*x4 - 
     2.54382194661358481e-8*g6*x4 + 
     1.18403247344882478e-7*A2*g5*x6 + 
     3.92485363936068314e-8*A*g6*x8 + 
     4.05810532585570662e-9*g7*x10)*xbar6 + 
  eps15*(-7.38610165433134699e-11*A5*g3 + 
     2.23185618064230175e-10*A2*g5 - 
     7.72550467360774725e-9*A4*g4*x2 + 
     3.33675225731002428e-9*A*g6*x2 - 
     3.60024022499056884e-8*A3*g5*x4 + 
     2.89391686340197044e-9*g7*x4 - 
     4.11034234008140627e-8*A2*g6*x6 - 
     1.58061594311664227e-8*A*g7*x8 - 
     1.88044966020543737e-9*g8*x10)*xbar6 + 
  eps14*(-1.59924972891624396e-12*A6*g2 + 
     5.34559467656326695e-10*A3*g4 - 
     4.89531412255654985e-11*g6 - 
     4.68743656687813986e-9*A5*g3*x2 + 
     1.55203340852120435e-8*A2*g5*x2 - 
     3.05848967636635251e-8*A4*g4*x4 + 
     2.80191583068273077e-8*A*g6*x4 - 
     4.77391188802852923e-8*A3*g5*x6 + 
     9.0249644584421326e-9*g7*x6 - 
     2.7500470429085428e-8*A2*g6*x8 - 
     6.46467617732357999e-9*A*g7*x10 - 
     5.25206836466407194e-10*g8*x12)*xbar6 + 
  eps17*(9.97455222947976728e-12*A6*g3 - 
     6.79725936335510667e-11*A3*g5 + 
     3.53973893285757087e-12*g7 + 
     1.57106382527547975e-9*A5*g4*x2 - 
     1.84906281043290629e-9*A2*g6*x2 + 
     1.0959810274248971e-8*A4*g5*x4 - 
     3.77750956813660573e-9*A*g7*x4 + 
     1.93914172243944712e-8*A3*g6*x6 - 
     1.39852236310538808e-9*g8*x6 + 
     1.27378874003962749e-8*A2*g7*x8 + 
     3.39967157316226349e-9*A*g8*x10 + 
     3.11454821672654227e-10*g9*x12)*xbar6 + 
  eps16*(7.32043787188737753e-14*A7*g2 - 
     1.08932623361419343e-10*A4*g4 + 
     4.43882953795228996e-11*A*g6 + 
     7.1553877265847084e-10*A6*g3*x2 - 
     5.23629960443907472e-9*A3*g5*x2 + 
     2.84608830720512483e-10*g7*x2 + 
     6.85430762519816909e-9*A5*g4*x4 - 
     1.69359418456327738e-8*A2*g6*x4 + 
     1.57308771746978335e-8*A4*g5*x6 - 
     1.26738239683828291e-8*A*g7*x6 + 
     1.38726146998630169e-8*A3*g6*x8 - 
     2.44574523622132431e-9*g8*x8 + 
     5.52081375700205184e-9*A2*g7*x10 + 
     9.99298373572599506e-10*A*g8*x12 + 
     6.67917519196695508e-11*g9*x14)*xbar6 + 
  eps19*(-1.30114590146037234e-12*A7*g3 + 
     1.72511713934239417e-11*A4*g5 - 
     3.90436685140620179e-12*A*g7 - 
     2.92867814057581221e-10*A6*g4*x2 + 
     7.46902977877224456e-10*A3*g6*x2 - 
     2.67522864508407854e-11*g8*x2 - 
     2.89699505443225961e-9*A5*g5*x4 + 
     2.66562938868512264e-9*A2*g7*x4 - 
     7.37795565467524207e-9*A4*g6*x6 + 
     2.25247153971908075e-9*A*g8*x6 - 
     7.30651817416318482e-9*A3*g7*x8 + 
     4.91176292870876797e-10*g9*x8 - 
     3.26224960924321828e-9*A2*g8*x10 - 
     6.59449314458554338e-10*A*g9*x12 - 
     4.89514760970749125e-11*g10*x14)*xbar6 + 
  eps18*(-3.18177848990088646e-15*A8*g2 + 
     1.99695443999379049e-11*A5*g4 - 
     2.23943125358944015e-11*A2*g6 - 
     1.03933552034436454e-10*A7*g3*x2 + 
     1.45959832999336206e-9*A4*g5*x2 - 
     3.42631031918890525e-10*A*g7*x2 - 
     1.39812800630481225e-9*A6*g4*x4 + 
     7.42096889844293084e-9*A3*g6*x4 - 
     3.37099552457525213e-10*g8*x4 - 
     4.48155653124553849e-9*A5*g5*x6 + 
     9.58666614025997167e-9*A2*g7*x6 - 
     5.62734416286699799e-9*A4*g6*x8 + 
     4.18363357640745376e-9*A*g8*x8 - 
     3.34880212849529458e-9*A3*g7*x10 + 
     5.62255597605531686e-10*g9*x10 - 
     1.00758346454303337e-9*A2*g8*x12 - 
     1.478403576160079e-10*A*g9*x14 - 
     8.38903736074731077e-12*g10*x16)*xbar6 + 
  eps21*(1.65107570494289514e-13*A8*g3 - 
     3.85243170234057994e-12*A5*g5 + 
     2.35361375548192462e-12*A2*g7 + 
     5.10417794581330247e-11*A7*g4*x2 - 
     2.45495411183393324e-10*A4*g6*x2 + 
     3.75511182588112891e-11*A*g8*x2 + 
     6.87936705237642027e-10*A6*g5*x4 - 
     1.34714877461804848e-9*A3*g7*x4 + 
     4.11758068629525797e-11*g9*x4 + 
     2.400949695111526e-9*A5*g6*x6 - 
     1.93419604503727388e-9*A2*g8*x6 + 
     3.33918824376270404e-9*A4*g7*x8 - 
     9.42270610564786763e-10*A*g9*x8 + 
     2.20558587287283118e-9*A3*g8*x10 - 
     1.41026346318580081e-10*g10*x10 + 
     7.34671001558905886e-10*A2*g9*x12 + 
     1.18846098758935012e-10*A*g10*x14 + 
     7.4012085886463764e-12*g11*x16)*xbar6 + 
  eps20*(1.32423923182168128e-16*A9*g2 - 
     3.38762545168358761e-12*A6*g4 + 
     8.2936742090468515e-12*A3*g6 - 
     2.88553271599458446e-13*g8 + 
     1.45206721816612312e-11*A8*g3*x2 - 
     3.55365267771350475e-10*A5*g5*x2 + 
     2.24067642028217925e-10*A2*g7*x2 + 
     2.64931375976082846e-10*A7*g4*x4 - 
     2.63256077540054192e-9*A4*g6*x4 + 
     5.08380778036583002e-10*A*g8*x4 + 
     1.14232293931335993e-9*A6*g5*x6 - 
     5.17535342835764208e-9*A3*g7*x6 + 
     2.12052573958312186e-10*g9*x6 + 
     1.94686955319541028e-9*A5*g6*x8 - 
     3.80593235862788058e-9*A2*g8*x8 + 
     1.61506335347690598e-9*A4*g7*x10 - 
     1.13519934804077239e-9*A*g9*x10 + 
     7.1467043552215311e-10*A3*g8*x12 - 
     1.15698350133799093e-10*g10*x12 + 
     1.719691436452393e-10*A2*g9*x14 + 
     2.11817828858919301e-11*A*g10*x16 + 
     1.0439296901669795e-12*g11*x18)*xbar6 + 
  eps22*(-5.31170301889157885e-18*A10*g2 + 
     5.41512008345912225e-13*A7*g4 - 
     2.51484843977932421e-12*A4*g6 + 
     3.74997952559516213e-13*A*g8 - 
     1.96622519209470769e-12*A9*g3*x2 + 
     7.81432830846281016e-11*A6*g5*x2 - 
     1.0541243620224235e-10*A3*g7*x2 + 
     2.75343063440850494e-12*g9*x2 - 
     4.73066561901215884e-11*A8*g4*x4 + 
     8.01663669414465443e-10*A5*g6*x4 - 
     4.10061241924541413e-10*A2*g8*x4 - 
     2.66530256112802594e-10*A7*g5*x6 + 
     2.23182456344329143e-9*A4*g7*x6 - 
     3.84966796590767183e-10*A*g9*x6 - 
     5.95626630491287062e-10*A6*g6*x8 + 
     2.44421723666841458e-9*A3*g8*x8 - 
     9.34592147729657581e-11*g10*x8 - 
     6.57899358910793091e-10*A5*g7*x10 + 
     1.20777680989039448e-9*A2*g9*x10 - 
     3.99711629253997661e-10*A4*g8*x12 + 
     2.69443230465710687e-10*A*g10*x12 - 
     1.39709228180795027e-10*A3*g9*x14 + 
     2.19843031752725675e-11*g11*x14 - 
     2.79291327736950798e-11*A2*g10*x16 - 
     2.96151288108938101e-12*A*g11*x18 - 
     1.2897624149994603e-13*g12*x20)*xbar6 + 
  5.93542260208926876e-8*eps4*g3*xbar8 - 
  3.12288574815807931e-9*eps7*g4*xbar8 + 
  eps6*(-1.14340392118169896e-8*A*g3 - 
     9.02678854067742957e-8*g4*x2)*xbar8 + 
  eps9*(1.26121885620031857e-9*A*g4 + 
     1.00859349622512295e-8*g5*x2)*xbar8 + 
  eps8*(1.32727772394750297e-9*A2*g3 + 
     4.65033697944917988e-8*A*g4*x2 + 
     2.99054295797669073e-8*g5*x4)*xbar8 + 
  eps11*(-3.15709843216944468e-10*A2*g4 - 
     7.21099301568180965e-9*A*g5*x2 - 
     5.69746824484251863e-9*g6*x4)*xbar8 + 
  eps10*(-1.18235613578975095e-10*A3*g3 + 
     2.04522364126337295e-10*g5 - 
     1.4372001684607648e-8*A2*g4*x2 - 
     2.38545902650207871e-8*A*g5*x4 - 
     6.6442647298050802e-9*g6*x6)*xbar8 + 
  eps13*(6.34254881618462429e-11*A3*g4 - 
     1.4977795563804726e-11*g6 + 
     2.95036268409924151e-9*A2*g5*x2 + 
     5.72733871097688746e-9*A*g6*x4 + 
     1.89780374932858316e-9*g7*x6)*xbar8 + 
  eps12*(8.85933436332280376e-12*A4*g3 - 
     1.2695043367275619e-10*A*g5 + 
     3.44553148081436095e-9*A3*g4*x2 - 
     9.66117808074637814e-10*g6*x2 + 
     1.08393242236143663e-8*A2*g5*x4 + 
     7.24181767567549532e-9*A*g6*x6 + 
     1.22738677265426237e-9*g7*x8)*xbar8 + 
  eps15*(-1.1209244129052603e-11*A4*g4 + 
     1.23354796462055584e-11*A*g6 - 
     9.05322252904213583e-10*A3*g5*x2 + 
     9.34529456546429641e-11*g7*x2 - 
     3.18804749658072552e-9*A2*g6*x4 - 
     2.46989894878460521e-9*A*g7*x6 - 
     4.84553260391626981e-10*g8*x8)*xbar8 + 
  eps14*(-5.85591473164617337e-13*A5*g3 + 
     4.58152437519766974e-11*A2*g5 - 
     7.06061940978074562e-10*A4*g4*x2 + 
     8.8437067488213914e-10*A*g6*x2 - 
     3.6718459581734819e-9*A3*g5*x4 + 
     8.14572670487090063e-10*g7*x4 - 
     4.35865819040676537e-9*A2*g6*x6 - 
     1.70511399881374369e-9*A*g7*x8 - 
     2.04267683542374506e-10*g8*x10)*xbar8 + 
  eps17*(1.81850832862627129e-12*A5*g4 - 
     5.7018133606605742e-12*A2*g6 + 
     2.31363157692796144e-10*A4*g5*x2 - 
     1.04268313475235866e-10*A*g7*x2 + 
     1.29559671265166405e-9*A3*g6*x4 - 
     1.08608812804810835e-10*g8*x4 + 
     1.74321237740579218e-9*A2*g7*x6 + 
     7.76515634579396129e-10*A*g8*x8 + 
     1.05455124124405657e-10*g9*x10)*xbar8 + 
  eps16*(3.51441987362562031e-14*A6*g3 - 
     1.25669585862967901e-11*A3*g5 + 
     1.19873609386538047e-12*g7 + 
     1.29917477297039227e-10*A5*g4*x2 - 
     4.50505663684441363e-10*A2*g6*x2 + 
     1.0294836459233229e-9*A4*g5*x4 - 
     9.85762364733873057e-10*A*g7*x4 + 
     1.90892686734913978e-9*A3*g6*x6 - 
     3.76480107979462358e-10*g8*x6 + 
     1.28194605951425965e-9*A2*g7*x8 + 
     3.45797358676807567e-10*A*g8*x10 + 
     3.18111454415424726e-11*g9*x12)*xbar8 + 
  eps19*(-2.77181792125363476e-13*A6*g4 + 
     1.94851026920691567e-12*A3*g6 - 
     1.04933332657610013e-13*g8 - 
     5.1992259514176436e-11*A5*g5*x2 + 
     6.35571518081156783e-11*A2*g7*x2 - 
     4.28732342024609978e-10*A4*g6*x4 + 
     1.53545689985903239e-10*A*g8*x4 - 
     8.82875940509388448e-10*A3*g7*x6 + 
     6.61143800669246729e-11*g9*x6 - 
     6.65258660548452332e-10*A2*g8*x8 - 
     2.01099007966251153e-10*A*g9*x10 - 
     2.06386033152073184e-11*g10*x12)*xbar8 + 
  eps18*(-1.95213901631847725e-15*A7*g3 + 
     2.9024042061210064e-12*A4*g5 - 
     1.22464345499091446e-12*A*g7 - 
     2.20948357179324358e-11*A6*g4*x2 + 
     1.68407222784752482e-10*A3*g6*x2 - 
     9.52673617116155421e-12*g8*x2 - 
     2.52285174010719033e-10*A5*g5*x4 + 
     6.48893132761825578e-10*A2*g7*x4 - 
     6.78403369061433162e-10*A4*g6*x6 + 
     5.68290125969521456e-10*A*g8*x6 - 
     6.90033763945661382e-10*A3*g7*x8 + 
     1.26310595431481278e-10*g9*x8 - 
     3.12443265284225916e-10*A2*g8*x10 - 
     6.3597958994265421e-11*A*g9*x12 - 
     4.73255306775791468e-12*g10*x14)*xbar8 + 
  eps21*(4.02698278092183264e-14*A7*g4 - 
     5.48456153392839097e-13*A4*g6 + 
     1.27878322517070527e-13*A*g8 + 
     1.06134424697227182e-11*A6*g5*x2 - 
     2.8004805743707356e-11*A3*g7*x2 + 
     1.03826550082836709e-12*g9*x2 + 
     1.22375351923488345e-10*A5*g6*x4 - 
     1.16626518182467646e-10*A2*g8*x4 + 
     3.58798538233177846e-10*A4*g7*x6 - 
     1.13425693456240496e-10*A*g9*x6 + 
     4.04078829257981979e-10*A3*g8*x8 - 
     2.81051427782846787e-11*g10*x8 + 
     2.02913314961737926e-10*A2*g9*x10 + 
     4.56865113489605372e-11*A*g10*x12 + 
     3.74535590061231334e-12*g11*x14)*xbar8 + 
  eps20*(1.01735256778363072e-16*A8*g3 - 
     5.94748498729256522e-13*A5*g5 + 
     6.8752666515941573e-13*A2*g7 + 
     3.53810789377630122e-12*A7*g4*x2 - 
     5.15152807107229022e-11*A4*g6*x2 + 
     1.25362167426384833e-11*A*g8*x2 + 
     5.5847059374569765e-11*A6*g5*x4 - 
     3.07470180635305607e-10*A3*g7*x4 + 
     1.44903732082026135e-11*g9*x4 + 
     2.07246456352654245e-10*A5*g6*x6 - 
     4.59578840273247801e-10*A2*g8*x6 + 
     2.97340805913634912e-10*A4*g7*x8 - 
     2.2892955313025694e-10*A*g9*x8 + 
     1.99809393100334618e-10*A3*g8*x10 - 
     3.47015927264758897e-11*g10*x10 + 
     6.71900005565290136e-11*A2*g9*x12 + 
     1.09198252656076105e-11*A*g10*x14 + 
     6.80982990694437919e-13*g11*x16)*xbar8 - 
  2.95801289810004407e-10*eps6*g4*xbar10 + 
  2.94346529368315861e-11*eps9*g5*xbar10 + 
  eps8*(7.69281785172546935e-11*A*g4 + 
     1.07490632635875918e-9*g5*x2)*xbar10 + 
  eps11*(-1.49854878334381416e-11*A*g5 - 
     1.64414869918985145e-10*g6*x2)*xbar10 + 
  eps10*(-1.14623038722347948e-11*A2*g4 - 
     6.72527675714427998e-10*A*g5*x2 - 
     5.64942074025452747e-10*g6*x4)*xbar10 + 
  eps13*(4.55203920804202245e-12*A2*g5 + 
     1.35763920347428776e-10*A*g6*x2 + 
     1.33652228562929386e-10*g7*x4)*xbar10 + 
  eps12*(1.27157831390982766e-12*A3*g4 - 
     2.82877994364105943e-12*g6 + 
     2.44160830279527547e-10*A2*g5*x2 + 
     5.14076796669365287e-10*A*g6*x4 + 
     1.75139799425245342e-10*g7*x6)*xbar10 + 
  eps15*(-1.07685636895144654e-12*A3*g5 + 
     2.70026199694243437e-13*g7 - 
     6.29652746661281415e-11*A2*g6*x2 - 
     1.49092240439933003e-10*A*g7*x4 - 
     5.88096054052166419e-11*g8*x6)*xbar10 + 
  eps14*(-1.16205790093287907e-13*A4*g4 + 
     2.06949189356323779e-12*A*g6 - 
     6.72146134669773312e-11*A3*g5*x2 + 
     1.99437288401862085e-11*g7*x2 - 
     2.61681510848862049e-10*A2*g6*x4 - 
     2.10127602166714473e-10*A*g7*x6 - 
     4.18842380479881739e-11*g8*x8)*xbar10 + 
  eps17*(2.18937302179867743e-13*A4*g5 - 
     2.52743776628905178e-13*A*g7 + 
     2.15933914153368247e-11*A3*g6*x2 - 
     2.33174044228357075e-12*g8*x2 + 
     9.10889047339860176e-11*A2*g7*x4 + 
     8.28793584781457544e-11*A*g8*x6 + 
     1.87814134450040901e-11*g9*x8)*xbar10 + 
  eps16*(9.22277143780367963e-15*A5*g4 - 
     8.60637474674818858e-13*A2*g6 + 
     1.55522012194999734e-11*A4*g5*x2 - 
     2.04738873511014663e-11*A*g7*x2 + 
     9.80212032242431517e-11*A3*g6*x4 - 
     2.27433206141358192e-11*g8*x4 + 
     1.3776069368825939e-10*A2*g7*x6 + 
     6.26447221848720574e-11*A*g8*x8 + 
     8.59289553201749293e-12*g9*x10)*xbar10 + 
  eps19*(-4.01386516110057917e-14*A5*g5 + 
     1.3091834712452921e-13*A2*g7 - 
     6.0989736648541878e-12*A4*g6*x2 + 
     2.86173201964551467e-12*A*g8*x2 - 
     4.02840475527683715e-11*A3*g7*x4 + 
     3.510880308676512e-12*g9*x4 - 
     6.29106001544106061e-11*A2*g8*x6 - 
     3.20688619604414165e-11*A*g9*x8 - 
     4.92343192873666106e-12*g10*x10)*xbar10 + 
  eps18*(-6.56399733698215579e-16*A6*g4 + 
     2.67367086954926804e-13*A3*g6 - 
     2.65773724648037072e-14*g8 - 
     3.1891761064266082e-12*A5*g5*x2 + 
     1.1556733294634019e-11*A2*g7*x2 - 
     3.00891865934477623e-11*A4*g6*x4 + 
     3.00144725725027383e-11*A*g8*x4 - 
     6.52019833501791742e-11*A3*g7*x6 + 
     1.33683467827448483e-11*g9*x6 - 
     5.03812647605675579e-11*A2*g8*x8 - 
     1.54328716110212964e-11*A*g9*x10 - 
     1.5943182436056292e-12*g10*x12)*xbar10 + 
  eps20*(4.27976553989265789e-17*A7*g4 - 
     6.89934943139530425e-14*A4*g6 + 
     3.01698740413725238e-14*A*g8 + 
     5.98132658710965791e-13*A6*g5*x2 - 
     4.74116732715012842e-12*A3*g7*x2 + 
     2.78541034399807552e-13*g9*x2 + 
     8.00945275253022047e-12*A5*g6*x4 - 
     2.13863386293836158e-11*A2*g8*x4 + 
     2.48849376049208704e-11*A4*g7*x6 - 
     2.16096622933769274e-11*A*g9*x6 + 
     2.88625342578349044e-11*A3*g8*x8 - 
     5.46942831323172719e-12*g10*x8 + 
     1.47325399109498875e-11*A2*g9*x10 + 
     3.34719700407126729e-12*A*g10*x12 + 
     2.75625052642210253e-13*g11*x14)*xbar10 + 
  1.69722051530330397e-12*eps8*g5*xbar12 - 
  2.90595190793452012e-13*eps11*g6*xbar12 + 
  eps10*(-5.54575148020670988e-13*A*g5 - 
     1.29008964169185665e-11*g6*x2)*xbar12 + 
  eps13*(1.78798720202615632e-13*A*g6 + 
     2.57210159823889116e-12*g7*x2)*xbar12 + 
  eps12*(1.00869657097464141e-13*A2*g5 + 
     9.47632013657176953e-12*A*g6*x2 + 
     1.00368310409322369e-11*g7*x4)*xbar12 + 
  eps15*(-6.39010493062016058e-14*A2*g6 - 
     2.40693363499189255e-12*A*g7*x2 - 
     2.87715768832048683e-12*g8*x4)*xbar12 + 
  eps14*(-1.33953977785016062e-14*A3*g5 + 
     3.84980892713537606e-14*g7 - 
     3.94928486633783273e-12*A2*g6*x2 - 
     1.02511581325767213e-11*A*g7*x4 - 
     4.17899415533904787e-12*g8*x6)*xbar12 + 
  eps17*(1.73998403455957848e-14*A3*g6 - 
     4.62636803886378434e-15*g8 + 
     1.24741423146112554e-12*A2*g7*x2 + 
     3.52693455958173369e-12*A*g8*x4 + 
     1.62821302569789988e-12*g9*x6)*xbar12 + 
  eps16*(1.44440682820300384e-15*A4*g5 - 
     3.24022688540454265e-14*A*g7 + 
     1.22741801273679764e-12*A3*g6*x2 - 
     3.84061473377336244e-13*g8*x2 + 
     5.77793844380739442e-12*A2*g7*x4 + 
     5.47447616200335818e-12*A*g8*x6 + 
     1.26471026695269685e-12*g9*x8)*xbar12 + 
  eps19*(-4.00106875821619636e-15*A4*g6 + 
     4.84590692629411758e-15*A*g8 - 
     4.72763385349764825e-13*A3*g7*x2 + 
     5.32739458894566085e-14*g9*x2 - 
     2.34696797887097322e-12*A2*g8*x4 - 
     2.47171834511294782e-12*A*g9*x6 - 
     6.39422064458918014e-13*g10*x8)*xbar12 + 
  eps18*(-1.33739060725578634e-16*A5*g5 + 
     1.52467406929696226e-14*A2*g7 - 
     3.16506850006518787e-13*A4*g6*x2 + 
     4.36808508700696498e-13*A*g8*x2 - 
     2.37192884056053272e-12*A3*g7*x4 + 
     5.73811638250132219e-13*g9*x4 - 
     3.88549767072102607e-12*A2*g8*x6 - 
     2.02801867312185292e-12*A*g9*x8 - 
     3.15279597165500734e-13*g10*x10)*xbar12 - 
  1.06551186196798794e-14*eps10*g6*xbar14 + 
  2.96371424137457707e-15*eps13*g7*xbar14 + 
  eps12*(4.1883104771160436e-15*A*g6 + 
     1.55454784378046993e-13*g7*x2)*xbar14 + 
  eps15*(-2.14017433818550597e-15*A*g7 - 
     3.90198867402243257e-14*g8*x2)*xbar14 + 
  eps14*(-8.99454744512618591e-16*A2*g6 - 
     1.30968415155813316e-13*A*g7*x2 - 
     1.70308449198607365e-13*g8*x4)*xbar14 + 
  eps17*(8.79886328932693487e-16*A2*g7 + 
     4.07855521267175371e-14*A*g8*x2 + 
     5.8024185244265147e-14*g9*x4)*xbar14 + 
  eps16*(1.39116436986363771e-16*A3*g6 - 
     5.17467765013076258e-16*g8 + 
     6.15890327064823114e-14*A2*g7*x2 + 
     1.92792938842998867e-13*A*g8*x4 + 
     9.24186997248047774e-14*g9*x6)*xbar14 + 
  eps18*(-1.72867499565968957e-17*A4*g6 + 
     4.9217313236453732e-16*A*g8 - 
     2.13260411115595534e-14*A3*g7*x2 + 
     7.01612347492652808e-15*g9*x2 - 
     1.19175537714779419e-13*A2*g8*x4 - 
     1.31262296085466213e-13*A*g9*x6 - 
     3.47201752597269316e-14*g10*x8)*xbar14 + 
  7.1230636127202905e-17*eps12*g7*xbar16 - 
  3.09644400991606704e-17*eps15*g8*xbar16 + 
  eps14*(-3.27091744222075652e-17*A*g7 - 
     1.87737117146802168e-15*g8*x2)*xbar16 + 
  eps17*(2.56820081466394239e-17*A*g8 + 
     5.77970340504678044e-16*g9*x2)*xbar16 + 
  eps16*(8.09908041993038944e-18*A2*g7 + 
     1.78317218006896548e-15*A*g8*x2 + 
     2.78832594974046941e-15*g9*x4)*xbar16 - 
  4.98845119121947873e-19*eps14*g8*xbar18 + 
  eps16*(2.61992075966627237e-19*A*g8 + 
     2.27018895731900669e-17*g9*x2)*xbar18;
}
#endif

#ifdef p27
double Wp(void)
{
   return 0.5*A*x2 + 0.0416666666666666667*g*x4 + 
  eps*(0.0833333333333333333*A + 0.0416666666666666667*g*x2) + 
  eps3*(-0.00277777777777777778*A2 - 
     0.0111111111111111111*A*g*x2 - 
     0.00208333333333333333*g2*x4) + 
  eps2*(0.00416666666666666667*g - 
     0.0416666666666666667*A2*x2 - 
     0.0138888888888888889*A*g*x4 - 
     0.00115740740740740741*g2*x6) + 
  eps5*(0.0001763668430335097*A3 - 
     0.0000388558201058201058*g2 + 
     0.00214947089947089947*A2*g*x2 + 
     0.00124007936507936508*A*g2*x4 + 
     0.000154320987654320988*g3*x6) + 
  eps4*(-0.000595238095238095238*A*g + 
     0.00416666666666666667*A3*x2 - 
     0.000868055555555555556*g2*x2 + 
     0.00347222222222222222*A2*g*x4 + 
     0.000810185185185185185*A*g2*x6 + 
     0.0000578703703703703704*g3*x8) + 
  eps7*(-0.0000132275132275132275*A4 + 
     0.000013452982202982203*A*g2 - 
     0.000353835978835978836*A3*g*x2 + 
     0.0000292107583774250441*g3*x2 - 
     0.000438161375661375661*A2*g2*x4 - 
     0.000141369047619047619*A*g3*x6 - 
     0.0000131815843621399177*g4*x8) + 
  eps6*(0.0000793650793650793651*A2*g - 
     0.000421626984126984127*A4*x2 + 
     0.000412533068783068783*A*g2*x2 - 
     0.000710978835978835979*A3*g*x4 + 
     0.00012359457671957672*g3*x4 - 
     0.000332065696649029982*A2*g2*x6 - 
     0.0000592482363315696649*A*g3*x8 - 
     3.61689814814814815e-6*g4*x10) + 
  eps9*(1.06888995777884667e-6*A5 - 
     3.09484386865339246e-6*A2*g2 + 
     0.000052889176153065042*A4*g*x2 - 
     0.0000196739667225778337*A*g3*x2 + 
     0.000118621733205066538*A3*g2*x4 - 
     8.12834124466068911e-6*g4*x4 + 
     0.0000723776288012399124*A2*g3*x6 + 
     0.0000162595142340512711*A*g4*x8 + 
     1.2123306755829904e-6*g5*x10) + 
  eps8*(-0.0000100208433541766875*A3*g + 
     8.50711788211788212e-7*g3 + 
     0.0000427138447971781305*A5*x2 - 
     0.000120331539602372936*A2*g2*x2 + 
     0.000127911890064667842*A4*g*x4 - 
     0.000098836830607663941*A*g3*x4 + 
     0.000102804110327258475*A3*g2*x6 - 
     0.0000165018585880854399*g4*x6 + 
     0.0000336428938859494415*A2*g3*x8 + 
     4.8512364050558495e-6*A*g4*x10 + 
     2.56755115454961134e-7*g5*x12) + 
  eps11*(-9.01835117002665504e-8*A6 + 
     5.87400058299529199e-7*A3*g2 - 
     2.81868399275952575e-8*g4 - 
     7.41416841780598394e-6*A5*g*x2 + 
     7.67116473755031956e-6*A2*g3*x2 - 
     0.000027147462601331649*A4*g2*x4 + 
     8.12031936990601012e-6*A*g4*x4 - 
     0.0000272310450812986086*A3*g3*x6 + 
     1.70667153812408442e-6*g5*x6 - 
     0.0000108933015093453806*A2*g4*x8 - 
     1.87850642976993286e-6*A*g5*x10 - 
     1.16690477054095881e-7*g6*x12) + 
  eps10*(1.21747740795359843e-6*A4*g - 
     4.62417873132158846e-7*A*g3 - 
     4.32775172358505692e-6*A6*x2 + 
     0.0000276277014248244407*A3*g2*x2 - 
     1.30445706075046353e-6*g4*x2 - 
     0.0000210333326652771097*A5*g*x4 + 
     0.0000447391253752860896*A2*g3*x4 - 
     0.0000265668910778864483*A4*g2*x6 + 
     0.0000184769777868736202*A*g4*x6 - 
     0.0000139376709110505407*A3*g3*x8 + 
     2.13520310814871e-6*g5*x8 - 
     3.5181249916492972e-6*A2*g4*x10 - 
     4.25407416871537242e-7*A*g5*x12 - 
     1.98147969535893919e-8*g6*x14) + 
  eps13*(7.83069566138349207e-9*A7 - 
     9.93094869534334209e-8*A4*g2 + 
     2.08755249185163841e-8*A*g4 + 
     9.92791119692574719e-7*A6*g*x2 - 
     2.26246788359770127e-6*A3*g3*x2 + 
     7.19774046753493046e-8*g5*x2 + 
     5.52538741816188906e-6*A5*g2*x4 - 
     4.47883727161149936e-6*A2*g4*x4 + 
     8.38601213983571788e-6*A4*g3*x6 - 
     2.25348627386308778e-6*A*g5*x6 + 
     5.24445855604457162e-6*A3*g4*x8 - 
     3.11392974798759566e-7*g6*x8 + 
     1.55465050346795001e-6*A2*g5*x10 + 
     2.17600880397466046e-7*A*g6*x12 + 
     1.15841884836628278e-8*g7*x14) + 
  eps12*(-1.43889032777921667e-7*A5*g + 
     1.51283642180000723e-7*A2*g3 + 
     4.38492191964414187e-7*A7*x2 - 
     5.47671197834474951e-6*A4*g2*x2 + 
     1.1365151365172641e-6*A*g4*x2 + 
     3.23789133106262736e-6*A6*g*x4 - 
     0.0000150481673660823793*A3*g3*x4 + 
     5.97324614725086198e-7*g5*x4 + 
     6.03932684613625972e-6*A5*g2*x6 - 
     0.0000113106765525436987*A2*g4*x6 + 
     4.69528859165240338e-6*A4*g3*x8 - 
     3.0694501391598228e-6*A*g5*x8 + 
     1.82557370238215146e-6*A3*g4*x10 - 
     2.71046144994230449e-7*g6*x10 + 
     3.7535031778135559e-7*A2*g5*x12 + 
     3.90681314457195373e-8*A*g6*x14 + 
     1.62260932077515154e-9*g7*x16) + 
  eps15*(-6.94206524686864971e-10*A8 + 
     1.55258266251201437e-8*A5*g2 - 
     8.87063997906019346e-9*A2*g4 - 
     1.28444091425696105e-7*A7*g*x2 + 
     5.59355511978255916e-7*A4*g3*x2 - 
     7.69591961687451275e-8*A*g5*x2 - 
     1.03084425773136674e-6*A6*g2*x4 + 
     1.80099658500984157e-6*A3*g4*x4 - 
     4.89852640150590245e-8*g6*x4 - 
     2.23744987275327073e-6*A5*g3*x6 + 
     1.60416803829389571e-6*A2*g5*x6 - 
     2.02887475090349778e-6*A4*g4*x8 + 
     5.10536772376168298e-7*A*g6*x8 - 
     9.11746562790846727e-7*A3*g5*x10 + 
     5.21769349658492833e-8*g7*x10 - 
     2.14341780318485671e-7*A2*g6*x12 - 
     2.52490551976121104e-8*A*g7*x14 - 
     1.17600420262660865e-9*g8*x16) + 
  eps14*(1.66609565924847593e-8*A6*g - 
     3.84541066603365207e-8*A3*g3 + 
     1.23616495716322489e-9*g5 - 
     4.44285396439000936e-8*A8*x2 + 
     9.81807578832239391e-7*A5*g2*x2 - 
     5.55101746448534654e-7*A2*g4*x2 - 
     4.73967830600877338e-7*A7*g*x4 + 
     4.18284859452059839e-6*A4*g3*x4 - 
     7.15343253702736788e-7*A*g5*x4 - 
     1.24663165145441196e-6*A6*g2*x6 + 
     5.00514675879205854e-6*A3*g4*x6 - 
     1.81402700349001079e-7*g6*x6 - 
     1.36226318220021373e-6*A5*g3*x8 + 
     2.36606032230627314e-6*A2*g5*x8 - 
     7.58172593612770117e-7*A4*g4*x10 + 
     4.75471890972483691e-7*A*g6*x10 - 
     2.34027522244261325e-7*A3*g5*x12 + 
     3.3963539821117207e-8*g7*x12 - 
     4.06050820222736176e-8*A2*g6*x14 - 
     3.70938742929349711e-9*A*g7*x16 - 
     1.38898528337180163e-10*g8*x18) + 
  eps17*(6.25217958800249802e-11*A9 - 
     2.29312206278746533e-9*A6*g2 + 
     2.8310089717477044e-9*A3*g4 - 
     6.71998649148490015e-11*g6 + 
     1.61783182535963035e-8*A8*g*x2 - 
     1.222198282975496e-7*A5*g3*x2 + 
     4.51903487294323094e-8*A2*g5*x2 + 
     1.79787422789127715e-7*A7*g2*x4 - 
     5.89386352242391962e-7*A4*g4*x4 + 
     6.83924293854497039e-8*A*g6*x4 + 
     5.35385253592035249e-7*A6*g3*x6 - 
     8.16161936426993263e-7*A3*g5*x6 + 
     2.03110694856709656e-8*g7*x6 + 
     6.69429955495357485e-7*A5*g4*x8 - 
     4.44812062546498445e-7*A2*g6*x8 + 
     4.24544759374608395e-7*A4*g5*x10 - 
     1.02125278182278717e-7*A*g7*x10 + 
     1.48190757087105866e-7*A3*g6*x12 - 
     8.25465653164429909e-9*g8*x12 + 
     2.8842218900714868e-8*A2*g7*x14 + 
     2.93316966296752154e-9*A*g8*x16 + 
     1.21426224678902097e-10*g9*x18) + 
  eps16*(-1.89909954985575877e-9*A7*g + 
     8.35603474047208798e-9*A4*g3 - 
     1.15966243496214952e-9*A*g5 + 
     4.50155213123768602e-9*A9*x2 - 
     1.63520154608933337e-7*A6*g2*x2 + 
     2.00125773929144853e-7*A3*g4*x2 - 
     4.71643935891082883e-9*g6*x2 + 
     6.66827009985439445e-8*A8*g*x4 - 
     1.01569722853466271e-6*A5*g3*x4 + 
     4.653753986331283e-7*A2*g5*x4 + 
     2.38609112997144637e-7*A7*g2*x6 - 
     1.78931879078472604e-6*A4*g4*x6 + 
     2.75782412054904595e-7*A*g6*x6 + 
     3.5257503626825941e-7*A6*g3*x8 - 
     1.29719583644083582e-6*A3*g5*x8 + 
     4.43904638337799842e-8*g7*x8 + 
     2.67563783428073661e-7*A5*g4*x10 - 
     4.41739629456479988e-7*A2*g6*x10 + 
     1.15544405881940575e-7*A4*g5*x12 - 
     7.03094817586759951e-8*A*g7*x12 + 
     2.95627516533174602e-8*A3*g6*x14 - 
     4.21593686904484474e-9*g8*x14 + 
     4.43746780874914946e-9*A2*g7*x16 + 
     3.61167459558351774e-10*A*g8*x18 + 
     1.23066706066192904e-11*g9*x20) + 
  eps19*(-5.70128780114804572e-12*A10 + 
     3.24325759393455769e-10*A7*g2 - 
     7.52920392642037898e-10*A4*g4 + 
     7.63432039813829238e-11*A*g6 - 
     1.99446765051272661e-9*A9*g*x2 + 
     2.43560018179573397e-8*A6*g3*x2 - 
     1.92651473964731419e-8*A3*g5*x2 + 
     3.57664504054283011e-10*g7*x2 - 
     2.97138844105769473e-8*A8*g2*x4 + 
     1.66367899286352586e-7*A5*g4*x4 - 
     5.12763843043703477e-8*A2*g6*x4 - 
     1.17558487781038256e-7*A7*g3*x6 + 
     3.32274083849900958e-7*A4*g5*x6 - 
     3.49339293457975036e-8*A*g7*x6 - 
     1.95421595481198395e-7*A6*g4*x8 + 
     2.73546099832218964e-7*A3*g6*x8 - 
     6.42119893976624269e-9*g8*x8 - 
     1.66845932629322826e-7*A5*g5*x10 + 
     1.05196992302604677e-7*A2*g7*x10 - 
     8.06653736383214643e-8*A4*g6*x12 + 
     1.87723844343482559e-8*A*g8*x12 - 
     2.29644918467110207e-8*A3*g7*x14 + 
     1.25288025697957571e-9*g9*x14 - 
     3.81165485194947533e-9*A2*g8*x16 - 
     3.41033212304414905e-10*A*g9*x18 - 
     1.27053709821831841e-11*g10*x20) + 
  eps18*(2.13798292543051714e-10*A8*g - 
     1.62899940163818617e-9*A5*g3 + 
     6.06739124374671626e-10*A2*g5 - 
     4.56102589118103946e-10*A10*x2 + 
     2.5741194154734252e-8*A7*g2*x2 - 
     5.93202934378594688e-8*A4*g4*x2 + 
     5.97796132442781859e-9*A*g6*x2 - 
     9.086017175115798e-9*A9*g*x4 + 
     2.22788546277779156e-7*A6*g3*x4 - 
     2.17818061292066124e-7*A3*g5*x4 + 
     4.46060201054250811e-9*g7*x4 - 
     4.29736286745591606e-8*A8*g2*x6 + 
     5.48218484132244335e-7*A5*g4*x6 - 
     2.23798601959230444e-7*A2*g6*x6 - 
     8.3334504765293729e-8*A7*g3*x8 + 
     5.66588387939462102e-7*A4*g5*x8 - 
     8.17078651256326395e-8*A*g7*x8 - 
     8.32572408053676287e-8*A6*g4*x10 + 
     2.88769211893932833e-7*A3*g6*x10 - 
     9.49367158787967084e-9*g8*x10 - 
     4.80270155903927102e-8*A5*g5*x12 + 
     7.64234973061525259e-8*A2*g7*x12 - 
     1.69136821548003748e-8*A4*g6*x14 + 
     1.00575293092506873e-8*A*g8*x14 - 
     3.69466622059472975e-9*A3*g7*x16 + 
     5.19597646877020836e-10*g9*x16 - 
     4.88723854749631574e-10*A2*g8*x18 - 
     3.58645537045585288e-11*A*g9*x20 - 
     1.12084057456710382e-12*g10*x22) + 
  eps21*(5.2514619543187782e-13*A11 - 
     4.43285954755604869e-11*A8*g2 + 
     1.76083788279021689e-10*A5*g4 - 
     4.74728753998211342e-11*A2*g6 + 
     2.41589075467910444e-10*A10*g*x2 - 
     4.51824485857656974e-9*A7*g3*x2 + 
     6.66083029216207287e-9*A4*g5*x2 - 
     5.24335874922835697e-10*A*g7*x2 + 
     4.69949475640663485e-9*A9*g2*x4 - 
     4.19656758646856316e-8*A6*g4*x4 + 
     2.73885212294566607e-8*A3*g6*x4 - 
     4.48244578272414887e-10*g8*x4 + 
     2.40727904510809782e-8*A8*g3*x6 - 
     1.14987302708287038e-7*A5*g5*x6 + 
     3.18314156293579248e-8*A2*g7*x6 + 
     5.1729556293745067e-8*A7*g4*x8 - 
     1.33139310440523761e-7*A4*g6*x8 + 
     1.31084047358048264e-8*A*g8*x8 + 
     5.74763592331078553e-8*A6*g5*x10 - 
     7.58285646214704478e-8*A3*g7*x10 + 
     1.70719938146989968e-9*g9*x10 + 
     3.67818305341475603e-8*A5*g6*x12 - 
     2.23107719453182269e-8*A2*g8*x12 + 
     1.43062528484956471e-8*A4*g7*x14 - 
     3.24546888412113238e-9*A*g9*x14 + 
     3.43426667042232431e-9*A3*g8*x16 - 
     1.84284319077257175e-10*g10*x16 + 
     4.96756814596081739e-10*A2*g9*x18 + 
     3.96764099826891058e-11*A*g10*x20 + 
     1.34372144042558418e-12*g11*x22) + 
  eps20*(-2.38285086177214561e-11*A9*g + 
     2.93087835503767857e-10*A6*g3 - 
     2.33284850513311582e-10*A3*g5 + 
     4.35358687387975124e-12*g7 + 
     4.62128541799995915e-11*A11*x2 - 
     3.87512747715920683e-9*A8*g2*x2 + 
     1.52963831343981389e-8*A5*g4*x2 - 
     4.10201649274809254e-9*A2*g6*x2 + 
     1.2058131859727143e-9*A10*g*x4 - 
     4.51251014708823542e-8*A7*g3*x4 + 
     8.20524658045556169e-8*A4*g5*x4 - 
     7.11455083461241557e-9*A*g7*x4 + 
     7.36094104464716057e-9*A9*g2*x6 - 
     1.49255884116928141e-7*A6*g4*x6 + 
     1.28707565844365563e-7*A3*g6*x6 - 
     2.42078453530071715e-9*g8*x6 + 
     1.82893288628610935e-8*A8*g3*x8 - 
     2.09524543137285467e-7*A5*g5*x8 + 
     7.93810679543179244e-8*A2*g7*x8 + 
     2.34179153309909358e-8*A7*g4*x10 - 
     1.48969846228119514e-7*A4*g6*x10 + 
     2.05019199855671562e-8*A*g8*x10 + 
     1.74575105847696841e-8*A6*g5*x12 - 
     5.80036979689224998e-8*A3*g7*x12 + 
     1.8510046912641176e-9*g9*x12 + 
     8.09148869608194122e-9*A5*g6*x14 - 
     1.251808839252206e-8*A2*g8*x14 + 
     2.40348962003249252e-9*A4*g7*x16 - 
     1.40328230011170153e-9*A*g9*x16 + 
     4.58007384146693616e-10*A3*g8*x18 - 
     6.36787892934133022e-11*g10*x18 + 
     5.41571641768509377e-11*A2*g9*x20 + 
     3.61823810155023661e-12*A*g10*x22 + 
     1.04407319287969897e-13*g11*x24) + 
  eps23*(-4.87743892079685082e-14*A12 + 
     5.89316491267758974e-12*A9*g2 - 
     3.73943263170943611e-11*A6*g4 + 
     2.13679155317563112e-11*A3*g6 - 
     3.27361153325515243e-13*g8 - 
     2.88368279506519334e-11*A11*g*x2 + 
     7.91374895139060628e-10*A8*g3*x2 - 
     1.98046179372144604e-9*A5*g5*x2 + 
     4.11786639583657111e-10*A2*g7*x2 - 
     7.16497851551313523e-10*A10*g2*x4 + 
     9.68464471525289276e-9*A7*g4*x4 - 
     1.16748393728030986e-8*A4*g6*x4 + 
     8.04127478183736051e-10*A*g8*x4 - 
     4.65194608412246558e-9*A9*g3*x6 + 
     3.51082372037893695e-8*A6*g5*x6 - 
     2.04201982013264592e-8*A3*g7*x6 + 
     3.08310721156552306e-10*g9*x6 - 
     1.26357673284535273e-8*A8*g4*x8 + 
     5.45476416156654204e-8*A5*g6*x8 - 
     1.40486405551536498e-8*A2*g8*x8 - 
     1.7805212696568686e-8*A7*g5*x10 + 
     4.2926305860153371e-8*A4*g7*x10 - 
     4.0312366550615087e-9*A*g9*x10 - 
     1.46022546131613235e-8*A6*g6*x12 + 
     1.843836447337074e-8*A3*g8*x12 - 
     4.02235197734030437e-10*g10*x12 - 
     7.42369322805527411e-9*A5*g7*x14 + 
     4.37038526225414347e-9*A2*g9*x14 - 
     2.40937437944208411e-9*A4*g8*x16 + 
     5.35568097093309146e-10*A*g10*x16 - 
     4.99603251087911808e-10*A3*g9*x18 + 
     2.64472477748035067e-11*g11*x18 - 
     6.40255800593810452e-11*A2*g10*x20 - 
     4.61829796410311992e-12*A*g11*x22 - 
     1.43368406597132889e-13*g12*x24) + 
  eps22*(2.63381701723029945e-12*A10*g - 
     4.95613474685512438e-11*A7*g3 + 
     7.3461839787322817e-11*A4*g5 - 
     5.80927196941699941e-12*A*g7 - 
     4.68234108487568308e-12*A12*x2 + 
     5.62566165576091132e-10*A9*g2*x2 - 
     3.55029758958278224e-9*A6*g4*x2 + 
     2.01925178972162547e-9*A3*g6*x2 - 
     3.0814593971546122e-11*g8*x2 - 
     1.56527781346397019e-10*A11*g*x4 + 
     8.57069278143073356e-9*A8*g3*x4 - 
     2.64080665694219489e-8*A5*g5*x4 + 
     6.0407259102082057e-9*A2*g7*x4 - 
     1.20889938892283076e-9*A10*g2*x6 + 
     3.69930387182005496e-8*A7*g4*x6 - 
     5.87976309873423814e-8*A4*g6*x6 + 
     4.64691762189073441e-9*A*g8*x6 - 
     3.7731495679189183e-9*A9*g3*x8 + 
     6.81148651466673022e-8*A6*g5*x8 - 
     5.41126426776092471e-8*A3*g7*x8 + 
     9.60423280700958978e-10*g9*x8 - 
     6.06051978329905884e-9*A8*g4*x10 + 
     6.45172101423398301e-8*A5*g6*x10 - 
     2.31853730369969274e-8*A2*g8*x10 - 
     5.69384641167539249e-9*A7*g5*x12 + 
     3.45031778931260666e-8*A4*g7*x12 - 
     4.5856200745095094e-9*A*g9*x12 - 
     3.36446046321516529e-9*A6*g6*x14 + 
     1.08170138123001676e-8*A3*g8*x14 - 
     3.37300366179434001e-10*g10*x14 - 
     1.30060474988550597e-9*A5*g7*x16 + 
     1.9676600421073939e-9*A2*g9*x16 - 
     3.33854146037989048e-10*A4*g8*x18 + 
     1.92027951778477411e-10*A*g10*x18 - 
     5.64147807443152692e-11*A3*g9*x20 + 
     7.76866625886353525e-12*g11*x20 - 
     6.03122771185984168e-12*A2*g10*x22 - 
     3.69809171837544212e-13*A*g11*x24 - 
     9.90994892123906548e-15*g12*x26) + 
  eps25*(4.5617341154295489e-15*A13 - 
     7.65681973581163408e-13*A10*g2 + 
     7.36427533361146046e-12*A7*g4 - 
     7.77915357825993505e-12*A4*g6 + 
     5.01822372498827554e-13*A*g8 + 
     3.39946554308810257e-12*A12*g*x2 - 
     1.32218967001765988e-10*A9*g3*x2 + 
     5.24826694161013285e-10*A6*g5*x2 - 
     2.29911014730304061e-10*A3*g7*x2 + 
     2.97396110366290561e-12*g9*x2 + 
     1.05899009942419973e-10*A11*g2*x4 - 
     2.07888236061736146e-9*A8*g4*x4 + 
     4.2205345488109798e-9*A5*g6*x4 - 
     7.62725505811220135e-10*A2*g8*x4 + 
     8.56030817990639683e-10*A10*g3*x6 - 
     9.69700200555032466e-9*A7*g5*x6 + 
     1.0345307489459437e-8*A4*g7*x6 - 
     6.53391446848804187e-10*A*g9*x6 + 
     2.88536112350769269e-9*A9*g4*x8 - 
     1.95458369290004387e-8*A6*g6*x8 + 
     1.05141608097548792e-8*A3*g8*x8 - 
     1.49985208961406861e-10*g10*x8 + 
     5.0517190817639561e-9*A8*g5*x10 - 
     2.03127428588433698e-8*A5*g7*x10 + 
     4.96479103747145285e-9*A2*g9*x10 + 
     5.18105920734004777e-9*A7*g6*x12 - 
     1.18984582771191454e-8*A4*g8*x12 + 
     1.07801501997213091e-9*A*g10*x12 + 
     3.33667223847150641e-9*A6*g7*x14 - 
     4.07258881748425756e-9*A3*g9*x14 + 
     8.66712686070301579e-11*g11*x14 + 
     1.4017941285304863e-9*A5*g8*x16 - 
     8.05772603894054025e-10*A2*g10*x16 + 
     3.89757092431598696e-10*A4*g9*x18 - 
     8.52041965373136873e-11*A*g11*x18 + 
     7.10964158735397762e-11*A3*g10*x20 - 
     3.72103988693417535e-12*g12*x20 + 
     8.17773394901589543e-12*A2*g11*x22 + 
     5.37775729072728217e-13*A*g12*x24 + 
     1.54097984854059648e-14*g13*x26) + 
  eps24*(-2.89099899565347662e-13*A11*g + 
     7.9759930961059578e-12*A8*g3 - 
     2.00555906593283631e-11*A5*g5 + 
     4.18688595364780991e-12*A2*g7 + 
     4.74420340935259007e-13*A13*x2 - 
     7.92461835979771511e-11*A10*g2*x2 + 
     7.58561702147442218e-10*A7*g4*x2 - 
     7.97991543042322495e-10*A4*g6*x2 + 
     5.12980963092851767e-11*A*g8*x2 + 
     1.99411637693229689e-11*A12*g*x4 - 
     1.54367310321517635e-9*A9*g3*x4 + 
     7.53265555420091332e-9*A6*g5*x4 - 
     3.62648374581728425e-9*A3*g7*x4 + 
     4.93947743563747665e-11*g9*x4 + 
     1.91553592353180707e-10*A11*g2*x6 - 
     8.49094217698978774e-9*A8*g4*x6 + 
     2.26856565220020088e-8*A5*g6*x6 - 
     4.69772329949351813e-9*A2*g8*x6 + 
     7.38610816404395504e-10*A10*g3*x8 - 
     1.99662166333330706e-8*A7*g5*x8 + 
     2.9041859633440226e-8*A4*g7*x8 - 
     2.15327269006722961e-9*A*g9*x8 + 
     1.46232224612947612e-9*A9*g4*x10 - 
     2.43772139379355154e-8*A6*g6*x10 + 
     1.82674355319716322e-8*A3*g8*x10 - 
     3.10752555543901178e-10*g10*x10 + 
     1.69732946496891816e-9*A8*g5*x12 - 
     1.71231822209617444e-8*A5*g7*x12 + 
     5.9144501741718517e-9*A2*g9*x12 + 
     1.24827250807789759e-9*A7*g6*x14 - 
     7.28755328956029511e-9*A4*g8*x14 + 
     9.42570128461049658e-10*A*g10*x14 + 
     6.08812904258686911e-10*A6*g7*x16 - 
     1.90694699932313329e-9*A3*g9*x16 + 
     5.83702428173174224e-11*g11*x16 + 
     2.01600973965553078e-10*A5*g8*x18 - 
     2.99487561260952419e-10*A2*g10*x18 + 
     4.5544937416083891e-11*A4*g9*x20 - 
     2.58715552328237504e-11*A*g11*x20 + 
     6.91310656589337861e-12*A3*g10*x22 - 
     9.44207238480244009e-13*g12*x22 + 
     6.74432494205638096e-13*A2*g11*x24 + 
     3.82104888900742578e-14*A*g12*x26 + 
     9.55678585992729762e-16*g13*x28) + 
  eps26*(3.15451701249663644e-14*A12*g - 
     1.23260743380846408e-12*A9*g3 + 
     4.91328598966957483e-12*A6*g5 - 
     2.16010730561106487e-12*A3*g7 + 
     2.80265846575244876e-14*g9 - 
     4.80688304875450638e-14*A14*x2 + 
     1.0882967128577594e-11*A11*g2*x2 - 
     1.51564449755526941e-10*A8*g4*x2 + 
     2.68832690023484167e-10*A5*g6*x2 - 
     4.53800665535698655e-11*A2*g8*x2 - 
     2.49976348277787481e-12*A13*g*x4 + 
     2.65894282403365961e-10*A10*g3*x4 - 
     1.95152833009846442e-9*A7*g5*x4 + 
     1.72592503214026419e-9*A4*g7*x4 - 
     9.84468564911047601e-11*A*g9*x4 - 
     2.9429564195639701e-11*A12*g2*x6 + 
     1.82782910902163964e-9*A9*g4*x6 - 
     7.67829334489098475e-9*A6*g6*x6 + 
     3.32590234296463859e-9*A3*g8*x6 - 
     4.19820646804651369e-11*g10*x6 - 
     1.38204464610680452e-10*A11*g3*x8 + 
     5.37351949422549083e-9*A8*g5*x8 - 
     1.30589400763732115e-8*A5*g7*x8 + 
     2.52344638346505715e-9*A2*g9*x8 - 
     3.32321907447622297e-10*A10*g4*x10 + 
     8.24783952385426657e-9*A7*g6*x10 - 
     1.1258556884547882e-8*A4*g8*x10 + 
     7.96395396558461894e-10*A*g10*x10 - 
     4.68876173390562072e-10*A9*g5*x12 + 
     7.37174695327914701e-9*A6*g7*x12 - 
     5.2863782907904963e-9*A3*g9*x12 + 
     8.70473987527200665e-11*g11*x12 - 
     4.21139769024652842e-10*A8*g6*x14 + 
     4.07659424674585697e-9*A5*g8*x14 - 
     1.36514999589867453e-9*A2*g10*x14 - 
     2.53184281042569276e-10*A7*g7*x16 + 
     1.43498819528840929e-9*A4*g9*x16 - 
     1.81588742992582398e-10*A*g11*x16 - 
     1.04910984884796622e-10*A6*g8*x18 + 
     3.21680373413064642e-10*A3*g10*x18 - 
     9.69728250369714944e-12*g12*x18 - 
     3.03594939414036236e-11*A5*g9*x20 + 
     4.44197711547649947e-11*A2*g11*x20 - 
     6.12305100850786679e-12*A4*g10*x22 + 
     3.44141679543564567e-12*A*g12*x22 - 
     8.43545071546764867e-13*A3*g11*x24 + 
     1.14398078813312878e-13*g13*x24 - 
     7.56779797267724648e-14*A2*g12*x26 - 
     3.98471719227870099e-15*A*g13*x28 - 
     9.34260000972918927e-17*g14*x30) + 
  0.00833333333333333333*eps*g*xbar2 + 
  0.166666666666666667*(A + 0.5*g*x2)*xbar2 + 
  eps3*(-0.000793650793650793651*A*g - 
     0.00138888888888888889*g2*x2)*xbar2 + 
  eps2*(-0.00277777777777777778*A2 - 
     0.0111111111111111111*A*g*x2 - 
     0.00208333333333333333*g2*x4)*xbar2 + 
  eps5*(0.0000727513227513227513*A2*g + 
     0.000522486772486772487*A*g2*x2 + 
     0.000162037037037037037*g3*x4)*xbar2 + 
  eps4*(0.0000661375661375661376*A3 - 
     0.0000644841269841269841*g2 + 
     0.0015873015873015873*A2*g*x2 + 
     0.00094246031746031746*A*g2*x4 + 
     0.000115740740740740741*g3*x6)*xbar2 + 
  eps7*(-6.91438191438191438e-6*A3*g + 
     1.41486599819933153e-6*g3 - 
     0.000128066378066378066*A2*g2*x2 - 
     0.000110705266955266955*A*g3*x4 - 
     0.000018647119341563786*g4*x6)*xbar2 + 
  eps6*(-1.65343915343915344e-6*A4 + 
     0.0000179623617123617124*A*g2 - 
     0.00021164021164021164*A3*g*x2 + 
     0.0000485008818342151675*g3*x2 - 
     0.000276951058201058201*A2*g2*x4 - 
     0.0000898368606701940035*A*g3*x6 - 
     8.27867798353909465e-6*g4*x8)*xbar2 + 
  eps9*(6.79829796893288957e-7*A4*g - 
     6.72419695237155555e-7*A*g3 + 
     0.0000254975770848786722*A3*g2*x2 - 
     2.25056258042369153e-6*g4*x2 + 
     0.0000441438108848823135*A2*g3*x4 + 
     0.0000185871013417309714*A*g4*x6 + 
     2.15148764772607365e-6*g5*x8)*xbar2 + 
  eps8*(4.1753513975736198e-8*A5 - 
     3.46221514376276281e-6*A2*g2 + 
     0.0000267222489444711667*A4*g*x2 - 
     0.0000281804101248545693*A*g3*x2 + 
     0.0000649475909892576559*A3*g2*x4 - 
     0.0000122030666735527847*g4*x4 + 
     0.0000403965247715247715*A2*g3*x6 + 
     9.0700810463541945e-6*A*g4*x8 + 
     6.69795953360768176e-7*g5*x10)*xbar2 + 
  eps11*(-6.80612866459427306e-8*A5*g + 
     1.95584655809718057e-7*A2*g3 - 
     4.47269759439071608e-6*A4*g2*x2 + 
     1.75829988748211593e-6*A*g4*x2 - 
     0.0000133314481239415102*A3*g3*x4 + 
     9.71399147418687179e-7*g5*x4 - 
     0.0000103064498801381517*A2*g4*x6 - 
     2.82142523293179157e-6*A*g5*x8 - 
     2.4892365507720446e-7*g6*x10)*xbar2 + 
  eps10*(-1.05683802773749864e-9*A6 + 
     5.67501373552960855e-7*A3*g2 - 
     4.8511255774108832e-8*g4 - 
     3.24660642120959581e-6*A5*g*x2 + 
     9.71126169538867952e-6*A2*g3*x2 - 
     0.0000131832441790279092*A4*g2*x4 + 
     0.0000108846610427711618*A*g4*x4 - 
     0.0000136365860158849577*A3*g3*x6 + 
     2.33168885512635513e-6*g5*x6 - 
     5.4993290386188865e-6*A2*g4*x8 - 
     9.46094479080590192e-7*A*g5*x10 - 
     5.8302302889011994e-8*g6*x12)*xbar2 + 
  eps13*(6.86627585651083939e-9*A6*g - 
     4.47785160224899766e-8*A3*g3 + 
     2.19249275444418889e-9*g5 + 
     7.19946098097358602e-7*A5*g2*x2 - 
     7.80379784965903039e-7*A2*g4*x2 + 
     3.37142842641135708e-6*A4*g3*x4 - 
     1.06398186364605041e-6*A*g5*x4 + 
     4.18165456228327982e-6*A3*g4*x6 - 
     2.76351067919865578e-7*g6*x6 + 
     2.00589567077445504e-6*A2*g5*x8 + 
     4.04753308555164946e-7*A*g6*x10 + 
     2.88571475583667131e-8*g7*x12)*xbar2 + 
  eps12*(2.67650730613693577e-11*A7 - 
     8.46192910475220622e-8*A4*g2 + 
     3.25142589196534057e-8*A*g4 + 
     3.83704087407791111e-7*A6*g*x2 - 
     2.57283359783619147e-6*A3*g3*x2 + 
     1.27951218977907431e-7*g5*x2 + 
     2.41765559329216737e-6*A5*g2*x4 - 
     5.44480881814382923e-6*A2*g4*x4 + 
     3.82233569685344377e-6*A4*g3*x6 - 
     2.81139544164632672e-6*A*g5*x6 + 
     2.42710273474001612e-6*A3*g4*x8 - 
     3.92027350262991887e-7*g6*x8 + 
     7.21984500196305752e-7*A2*g5*x10 + 
     1.007566064009769e-7*A*g6*x12 + 
     5.32759708629371695e-9*g7*x14)*xbar2 + 
  eps15*(-6.94677964495491896e-10*A7*g + 
     8.85485037384606633e-9*A4*g3 - 
     1.89784940868103996e-9*A*g5 - 
     1.08873720111587578e-7*A6*g2*x2 + 
     2.58200627219967634e-7*A3*g4*x2 - 
     8.57415659878293831e-9*g6*x2 - 
     7.52178044272582197e-7*A5*g3*x4 + 
     6.39174172204870162e-7*A2*g5*x4 - 
     1.38311030669262085e-6*A4*g4*x6 + 
     3.89805821462228289e-7*A*g6*x6 - 
     1.02272071613530239e-6*A3*g5*x8 + 
     6.35874554600849527e-8*g7*x8 - 
     3.51191445940869782e-7*A2*g6*x10 - 
     5.59975947545884819e-8*A*g7*x12 - 
     3.35001083013772154e-9*g8*x14)*xbar2 + 
  eps14*(-6.77936059264516573e-13*A8 + 
     1.18453251754498057e-8*A5*g2 - 
     1.26192122113177278e-8*A2*g4 - 
     4.44292175799593582e-8*A7*g*x2 + 
     5.78235471803035281e-7*A4*g3*x2 - 
     1.25465164813262727e-7*A*g5*x2 - 
     4.11093596933471078e-7*A6*g2*x4 + 
     2.00802343589623813e-6*A3*g4*x4 - 
     8.38456228452171631e-8*g6*x4 - 
     9.37962675222683393e-7*A5*g3*x6 + 
     1.84660973293660698e-6*A2*g5*x6 - 
     8.68952732620502728e-7*A4*g4*x8 + 
     5.95974150882540242e-7*A*g6*x8 - 
     3.93789587968658131e-7*A3*g5*x10 + 
     6.11861559616332661e-8*g7*x10 - 
     9.26911580977221589e-8*A2*g6*x12 - 
     1.08851336477984649e-8*A*g7*x14 - 
     5.04016698893419468e-10*g8*x16)*xbar2 + 
  eps17*(7.03519796756268115e-11*A8*g - 
     1.58412622695254907e-9*A5*g3 + 
     9.21824723042734146e-10*A2*g5 + 
     1.57013176618403867e-8*A7*g2*x2 - 
     7.07877152349972815e-8*A4*g4*x2 + 
     1.01145514044440416e-8*A*g6*x2 + 
     1.52755677874009072e-7*A6*g3*x4 - 
     2.78303968964189299e-7*A3*g5*x4 + 
     7.90216106829461597e-9*g7*x4 + 
     3.94839847004885584e-7*A5*g4*x6 - 
     2.95546266642869418e-7*A2*g6*x6 + 
     4.1812888733216445e-7*A4*g5*x8 - 
     1.09749260429676339e-7*A*g7*x8 + 
     2.15692160440115788e-7*A3*g6*x10 - 
     1.28547064754435117e-8*g8*x10 + 
     5.73688513495873601e-8*A2*g7*x12 + 
     7.55383153004710777e-9*A*g8*x14 + 
     3.89293296941875901e-10*g9*x16)*xbar2 + 
  eps16*(1.71721241125556891e-14*A9 - 
     1.58463391176416606e-9*A6*g2 + 
     3.70687203668986364e-9*A3*g4 - 
     1.21950914958299276e-10*g6 + 
     5.06426546628202339e-9*A8*g*x2 - 
     1.15919331839795365e-7*A5*g3*x2 + 
     6.813324046201634e-8*A2*g5*x2 + 
     6.59264102615256734e-8*A7*g2*x4 - 
     6.0783143535697607e-7*A4*g4*x4 + 
     1.08734552181364072e-7*A*g6*x4 + 
     2.08077893379438207e-7*A6*g3*x6 - 
     8.7376194571684116e-7*A3*g5*x6 + 
     3.31435423816449871e-8*g7*x6 + 
     2.67286143174399604e-7*A5*g4*x8 - 
     4.84990273878282454e-7*A2*g6*x8 + 
     1.71677767909550515e-7*A4*g5*x10 - 
     1.12268658721773254e-7*A*g7*x10 + 
     6.02176056859808662e-8*A3*g6*x12 - 
     9.09453722352822717e-9*g8*x12 + 
     1.17208819972660499e-8*A2*g7*x14 + 
     1.18834173730462595e-9*A*g8*x16 + 
     4.8940576382579539e-11*g9*x18)*xbar2 + 
  eps19*(-7.12707337587569786e-12*A9*g + 
     2.63376364359160315e-10*A6*g3 - 
     3.30780046645030994e-10*A3*g5 + 
     8.03679335161609342e-12*g7 - 
     2.18139573549146275e-9*A8*g2*x2 + 
     1.6989863583308778e-8*A5*g4*x2 - 
     6.4969385102430346e-9*A2*g6*x2 - 
     2.88250590711040757e-8*A7*g3*x4 + 
     9.81072496878526138e-8*A4*g5*x4 - 
     1.18346882869724656e-8*A*g7*x4 - 
     1.00731210992033847e-7*A6*g4*x6 + 
     1.59691202088983395e-7*A3*g6*x6 - 
     4.13548363870289057e-9*g8*x6 - 
     1.45496453255537213e-7*A5*g5*x8 + 
     1.00501516554651165e-7*A2*g7*x8 - 
     1.05051610378898918e-7*A4*g6*x10 + 
     2.62399674415998082e-8*A*g8*x10 - 
     4.12244346987175346e-8*A3*g7*x12 + 
     2.38101241880130705e-9*g9*x12 - 
     8.92371773273422321e-9*A2*g8*x14 - 
     1.00013636391153993e-9*A*g9*x16 - 
     4.52724718151082609e-11*g10*x18)*xbar2 + 
  eps18*(-4.34973739711612375e-16*A10 + 
     2.04866596742209561e-10*A7*g2 - 
     9.13337973503563032e-10*A4*g4 + 
     1.29494994082815314e-10*A*g6 - 
     5.70128780114804572e-10*A9*g*x2 + 
     2.13523668994309077e-8*A6*g3*x2 - 
     2.7041278749459319e-8*A3*g5*x2 + 
     6.61136770529593115e-10*g7*x2 - 
     1.00900226220693725e-8*A8*g2*x4 + 
     1.59771473522731497e-7*A5*g4*x4 - 
     7.62149977963186539e-8*A2*g6*x4 - 
     4.26288251723329756e-8*A7*g3*x6 + 
     3.32905368200259132e-7*A4*g5*x6 - 
     5.34789893441100738e-8*A*g7*x6 - 
     7.31666710191171495e-8*A6*g4*x8 + 
     2.80197106079331506e-7*A3*g6*x8 - 
     9.98659790379859243e-9*g8*x8 - 
     6.35106992331774466e-8*A5*g5*x10 + 
     1.08995209478400767e-7*A2*g7*x10 - 
     3.09539659674895079e-8*A4*g6*x12 + 
     1.95483783519714526e-8*A*g8*x12 - 
     8.83724740598401241e-9*A3*g7*x14 + 
     1.30582050443893102e-9*g9*x14 - 
     1.46593717511110234e-9*A2*g8*x16 - 
     1.30772635674859038e-10*A*g9*x18 - 
     4.84955398928857724e-12*g10*x20)*xbar2 + 
  eps21*(7.22090117277105046e-13*A10*g - 
     4.13991085301446953e-11*A7*g3 + 
     9.76589682716262956e-11*A4*g5 - 
     1.01171462635282484e-11*A*g7 + 
     2.94059482872196453e-10*A9*g2*x2 - 
     3.68979054877682005e-9*A6*g4*x2 + 
     3.00808714445394687e-9*A3*g6*x2 - 
     5.76746247671597889e-11*g8*x2 + 
     5.12696720776491515e-9*A8*g3*x4 - 
     2.96928069363177013e-8*A5*g5*x4 + 
     9.47962261651077826e-9*A2*g7*x4 + 
     2.35049540761358863e-8*A7*g4*x6 - 
     6.88556064847354174e-8*A4*g6*x6 + 
     7.5086659172629484e-9*A*g8*x6 + 
     4.47020768444263473e-8*A6*g5*x8 - 
     6.48548347717962229e-8*A3*g7*x8 + 
     1.57872287719044645e-9*g9*x8 + 
     4.31283591778531503e-8*A5*g6*x10 - 
     2.81624636750572854e-8*A2*g8*x10 + 
     2.3304946259676748e-8*A4*g7*x12 - 
     5.6106802334762125e-9*A*g9*x12 + 
     7.34468856466444926e-9*A3*g8*x14 - 
     4.14021761190658312e-10*g10*x14 + 
     1.33841053507869873e-9*A2*g9*x16 + 
     1.30531947930356562e-10*A*g10*x18 + 
     5.26795343697585529e-12*g11*x20)*xbar2 + 
  eps20*(1.1018005656720459e-17*A11 - 
     2.57889246901160178e-11*A8*g2 + 
     1.98990234155769708e-10*A5*g4 - 
     7.55965424361672699e-11*A2*g6 + 
     6.35426896472572163e-11*A10*g*x2 - 
     3.68388963577669912e-9*A7*g3*x2 + 
     8.75177480890399108e-9*A4*g5*x2 - 
     9.11535637885301799e-10*A*g7*x2 + 
     1.48649455332149944e-9*A9*g2*x4 - 
     3.77359746051647268e-8*A6*g4*x4 + 
     3.82594204726996217e-8*A3*g6*x4 - 
     8.13304101172221063e-10*g8*x4 + 
     8.18713369443791778e-9*A8*g3*x6 - 
     1.08366523313337395e-7*A5*g5*x6 + 
     4.5944289943616577e-8*A2*g7*x6 + 
     1.82487684327326814e-8*A7*g4*x8 - 
     1.28729795350649249e-7*A4*g6*x8 + 
     1.92747318307891877e-8*A*g8*x8 + 
     2.06867607666613227e-8*A6*g5*x10 - 
     7.43763204190519753e-8*A3*g7*x10 + 
     2.53626156501045944e-9*g9*x10 + 
     1.33838352059798451e-8*A5*g6*x12 - 
     2.20494122463979174e-8*A2*g8*x12 + 
     5.23330987914141423e-9*A4*g7*x14 - 
     3.21750395058170305e-9*A*g9*x14 + 
     1.25827561244148185e-9*A3*g8*x16 - 
     1.82713361623688652e-10*g10*x16 + 
     1.81827783439828152e-10*A2*g9*x18 + 
     1.44818570824073778e-11*A*g10*x20 + 
     4.88417660313835094e-13*g11*x22)*xbar2 + 
  eps23*(-7.31620058828327886e-14*A11*g + 
     6.2244144715351518e-12*A8*g3 - 
     2.50972722113902645e-11*A5*g5 + 
     6.90195578112387954e-12*A2*g7 - 
     3.86661866535845128e-11*A10*g2*x2 + 
     7.40985528302493753e-10*A7*g4*x2 - 
     1.12263534560497836e-9*A4*g6*x2 + 
     9.10038912793887614e-11*A*g8*x2 - 
     8.68557303415569482e-10*A9*g3*x4 + 
     7.99751265225702085e-9*A6*g5*x4 - 
     5.38995025036586533e-9*A3*g7*x4 + 
     9.11682355767971334e-11*g9*x4 - 
     5.09949189194303306e-9*A8*g4*x6 + 
     2.517151280314285e-8*A5*g6*x6 - 
     7.20688202607308513e-9*A2*g8*x6 - 
     1.24293927810383763e-8*A7*g5*x8 + 
     3.30698321741881119e-8*A4*g7*x8 - 
     3.36777220246894258e-9*A*g9*x8 - 
     1.55006071785928367e-8*A6*g6*x10 + 
     2.11300984088409138e-8*A3*g8*x10 - 
     4.91764411032702861e-10*g10*x10 - 
     1.10270946906705895e-8*A5*g7*x12 + 
     6.90528529828172647e-9*A2*g9*x12 - 
     4.72730487747526667e-9*A4*g8*x14 + 
     1.10602336934435099e-9*A*g10*x14 - 
     1.24144324312375269e-9*A3*g9*x16 + 
     6.86305256373542116e-11*g11*x16 - 
     1.95159691471731057e-10*A2*g10*x18 - 
     1.68433306811216689e-11*A*g11*x20 - 
     6.13262463130406207e-13*g12*x22)*xbar2 + 
  eps22*(-2.79089293716250467e-19*A12 + 
     3.17766604095748225e-12*A9*g2 - 
     3.95577368582764204e-11*A6*g4 + 
     3.2068101326980409e-11*A3*g6 - 
     6.12076747703341304e-13*g8 - 
     7.02351204594746519e-12*A11*g*x2 + 
     6.03214212931090113e-10*A8*g3*x2 - 
     2.44702734746155151e-9*A5*g5*x2 + 
     6.76097426096149884e-10*A2*g7*x2 - 
     2.12157940796992025e-10*A10*g2*x4 + 
     8.1916797369498686e-9*A7*g4*x4 - 
     1.53944612844692757e-8*A4*g6*x4 + 
     1.38109622177934475e-9*A*g8*x4 - 
     1.49038549899160153e-9*A9*g3*x6 + 
     3.12551588277558658e-8*A6*g5*x6 - 
     2.79047223116628872e-8*A3*g7*x6 + 
     5.436847471574281e-10*g9*x6 - 
     4.21695720957640858e-9*A8*g4*x8 + 
     4.99819767239979985e-8*A5*g6*x8 - 
     1.96069567048585921e-8*A2*g8*x8 - 
     6.0820173561110201e-9*A7*g5*x10 + 
     4.00069800775570726e-8*A4*g7*x10 - 
     5.69705873785929584e-9*A*g9*x10 - 
     5.05592156438231298e-9*A6*g6*x12 + 
     1.73541009641709023e-8*A3*g8*x12 - 
     5.72444406380114732e-10*g10*x12 - 
     2.58984982240261447e-9*A5*g7*x14 + 
     4.13461348937075909e-9*A2*g9*x14 - 
     8.43540110516749951e-10*A4*g8*x16 + 
     5.07648285991122299e-10*A*g10*x16 - 
     1.75053485949267209e-10*A3*g9*x18 + 
     2.50585955675889897e-11*g11*x18 - 
     2.24065847218371337e-11*A2*g10*x20 - 
     1.61190422371025444e-12*A*g11*x22 - 
     4.98497255151051565e-14*g12*x24)*xbar2 + 
  eps25*(7.41283040826477982e-15*A12*g - 
     9.02635849548132915e-13*A9*g3 + 
     5.808192723300797e-12*A6*g5 - 
     3.38057427569094457e-12*A3*g7 + 
     5.29100393497390523e-14*g9 + 
     4.97920609040144658e-12*A11*g2*x2 - 
     1.39694069095383245e-10*A8*g4*x2 + 
     3.58402228305301032e-10*A5*g6*x2 - 
     7.65495191386971796e-11*A2*g8*x2 + 
     1.4125212696675559e-10*A10*g3*x4 - 
     1.96338748728595609e-9*A7*g5*x4 + 
     2.43765341823600507e-9*A4*g7*x4 - 
     1.73076565727920605e-10*A*g9*x4 + 
     1.04116644719005016e-9*A9*g4*x6 - 
     8.09905476228113474e-9*A6*g6*x6 + 
     4.85986711480587249e-9*A3*g8*x6 - 
     7.57303676890670029e-11*g10*x6 + 
     3.18313608725054007e-9*A8*g5*x8 - 
     1.41719309600437594e-8*A5*g7*x8 + 
     3.76671783453056944e-9*A2*g9*x8 + 
     5.00343186081653831e-9*A7*g6*x10 - 
     1.24378552441987574e-8*A4*g8*x10 + 
     1.20496661429663104e-9*A*g10*x10 + 
     4.53880717317622481e-9*A6*g7*x12 - 
     5.90571016995380991e-9*A3*g9*x12 + 
     1.32811990726503565e-10*g11*x12 + 
     2.53296660339142496e-9*A5*g8*x14 - 
     1.53532762899011833e-9*A2*g10*x14 + 
     8.96296897032458165e-10*A4*g9*x16 - 
     2.04947909641080151e-10*A*g11*x16 + 
     2.01417828995844438e-10*A3*g10*x18 - 
     1.09580840956783665e-11*g12*x18 + 
     2.78250438436826e-11*A2*g11*x20 + 
     2.15336350583630878e-12*A*g12*x22 + 
     7.14181481885948442e-14*g13*x24)*xbar2 + 
  eps24*(7.06941407925893494e-21*A13 - 
     3.84741654463843396e-13*A10*g2 + 
     7.32293254814967057e-12*A7*g4 - 
     1.10404290967107504e-11*A4*g6 + 
     8.91430430592888932e-13*A*g8 + 
     7.70933065507593765e-13*A12*g*x2 - 
     9.46392329053276403e-11*A9*g3*x2 + 
     6.12204723118016064e-10*A6*g5*x2 - 
     3.57786436948859923e-10*A3*g7*x2 + 
     5.61900352465916136e-12*g9*x2 + 
     2.94794501076642169e-11*A11*g2*x4 - 
     1.66054285997922112e-9*A8*g4*x4 + 
     5.27270026858442259e-9*A5*g6*x4 - 
     1.24441828714339168e-9*A2*g8*x4 + 
     2.5932143768735243e-10*A10*g3*x6 - 
     8.18440975363309936e-9*A7*g5*x6 + 
     1.34316391603932223e-8*A4*g7*x6 - 
     1.0967577860615365e-9*A*g9*x6 + 
     9.14099216298559597e-10*A9*g4*x8 - 
     1.70303761165690513e-8*A6*g6*x8 + 
     1.39743392988134275e-8*A3*g8*x8 - 
     2.56275349412587196e-10*g10*x8 + 
     1.64295978902062036e-9*A8*g5*x10 - 
     1.80454719563725777e-8*A5*g7*x10 + 
     6.69540001883729058e-9*A2*g9*x10 + 
     1.71211385785801628e-9*A7*g6*x12 - 
     1.06969476032442112e-8*A4*g8*x12 + 
     1.46666897500527102e-9*A*g10*x12 + 
     1.11324562362569516e-9*A6*g7*x14 - 
     3.68698661561997461e-9*A3*g9*x14 + 
     1.18497108911150463e-10*g11*x14 + 
     4.70206598723156244e-10*A5*g8*x16 - 
     7.32089723755050849e-10*A2*g10*x16 + 
     1.31051469702399336e-10*A4*g9*x18 - 
     7.74991097074319971e-11*A*g11*x18 + 
     2.39115858864581722e-11*A3*g10*x20 - 
     3.38215281496470102e-12*g12*x20 + 
     2.74671447656417087e-12*A2*g11*x22 + 
     1.80167001235699906e-13*A*g12*x24 + 
     5.14468471968218436e-15*g13*x26)*xbar2 + 
  0.00833333333333333333*g*xbar4 - 
  0.0000462962962962962963*eps3*g2*xbar4 + 
  eps2*(-0.000396825396825396825*A*g - 
     0.000694444444444444444*g2*x2)*xbar4 + 
  eps5*(9.11896745230078563e-6*A*g2 + 
     0.0000308641975308641975*g3*x2)*xbar4 + 
  eps4*(0.0000198412698412698413*A2*g + 
     0.000195105820105820106*A*g2*x2 + 
     0.0000617283950617283951*g3*x4)*xbar4 + 
  eps7*(-1.31581381581381581e-6*A2*g2 - 
     0.0000151318588818588819*A*g3*x2 - 
     6.8455207344096233e-6*g4*x4)*xbar4 + 
  eps6*(-9.01875901875901876e-7*A3*g + 
     9.90714532381199048e-7*g3 - 
     0.0000389059243225909893*A2*g2*x2 - 
     0.0000351397573619795842*A*g3*x4 - 
     5.9477880658436214e-6*g4*x6)*xbar4 + 
  eps9*(1.71045640622360199e-7*A3*g2 - 
     3.60906857706966639e-8*g4 + 
     4.53245406122390249e-6*A2*g3*x2 + 
     5.38783061931210079e-6*A*g4*x4 + 
     1.17492514772607365e-6*g5*x6)*xbar4 + 
  eps8*(3.77616945077262538e-8*A4*g - 
     3.91505723846993688e-7*A*g3 + 
     6.55938527962337486e-6*A3*g2*x2 - 
     1.61985166325444103e-6*g4*x2 + 
     0.0000121547079219036891*A2*g3*x4 + 
     5.20508405346368309e-6*A*g4*x6 + 
     6.02301130368259998e-7*g5*x8)*xbar4 + 
  eps11*(-2.12135350797297057e-8*A4*g2 + 
     2.14460056215349951e-8*A*g4 - 
     1.06401470496877178e-6*A3*g3*x2 + 
     9.9419658966568008e-8*g5*x2 - 
     2.4228308825712602e-6*A2*g4*x4 - 
     1.28380796826126347e-6*A*g5*x6 - 
     1.80516340332649186e-7*g6*x8)*xbar4 + 
  eps10*(-1.48202033122668043e-9*A5*g + 
     9.77137892841674354e-8*A2*g3 - 
     9.98537198520664129e-7*A4*g2*x2 + 
     1.12096864298613054e-6*A*g4*x2 - 
     3.25929867376075489e-6*A3*g3*x4 + 
     6.52088831782005348e-7*g5*x4 - 
     2.59007734102806854e-6*A2*g4*x6 - 
     7.14333704061713321e-7*A*g5*x8 - 
     6.28878290312510992e-8*g6*x10)*xbar4 + 
  eps13*(2.55551047231023315e-9*A5*g2 - 
     7.48454109323006102e-9*A2*g4 + 
     2.14869723911233424e-7*A4*g3*x2 - 
     8.87037184673700903e-8*A*g5*x2 + 
     8.1367411096167446e-7*A3*g4*x4 - 
     6.24554324051377381e-8*g6*x4 + 
     7.73534185148061632e-7*A2*g5*x6 + 
     2.53114332805174734e-7*A*g6*x8 + 
     2.60907174059342559e-8*g7*x10)*xbar4 + 
  eps12*(5.52620037914155561e-11*A6*g - 
     1.96395897468419557e-8*A3*g3 + 
     1.73105497543500998e-9*g5 + 
     1.41930118072774209e-7*A5*g2*x2 - 
     4.4751871911848506e-7*A2*g4*x2 + 
     7.4329679752095632e-7*A4*g3*x4 - 
     6.48579919839268283e-7*A*g5*x4 + 
     9.56849686940199225e-7*A3*g4*x6 - 
     1.72592309647809413e-7*g6*x6 + 
     4.6549037372399414e-7*A2*g5*x8 + 
     9.4234108977460504e-8*A*g6*x10 + 
     6.6997976279157566e-9*g7*x12)*xbar4 + 
  eps15*(-3.01110179246578381e-10*A6*g2 + 
     1.99854473307210245e-9*A3*g4 - 
     1.0075222178954846e-10*g6 - 
     3.91236879782746971e-8*A5*g3*x2 + 
     4.42468326545839399e-8*A2*g5*x2 - 
     2.26449722207185509e-7*A4*g4*x4 + 
     7.48610321580336637e-8*A*g6*x4 - 
     3.38794481457344831e-7*A3*g5*x6 + 
     2.34467193453680488e-8*g7*x6 - 
     1.91586076465687549e-7*A2*g6*x8 - 
     4.4705147415174641e-8*A*g7*x10 - 
     3.62790374951045814e-9*g8*x12)*xbar4 + 
  eps14*(-1.97753534590218582e-12*A7*g + 
     3.46651613447685113e-9*A4*g3 - 
     1.3675698718070872e-9*A*g5 - 
     1.92080361104674656e-8*A6*g2*x2 + 
     1.34714593349386061e-7*A3*g4*x2 - 
     7.0165116069938331e-9*g6*x2 - 
     1.51234778678998732e-7*A5*g3*x4 + 
     3.57677410764887609e-7*A2*g5*x4 - 
     2.9119323970204683e-7*A4*g4*x6 + 
     2.24757818721415644e-7*A*g6*x6 - 
     2.19654624683123427e-7*A3*g5*x8 + 
     3.71577620957842484e-8*g7*x8 - 
     7.60245440599503551e-8*A2*g6*x10 - 
     1.21363875909823901e-8*A*g7*x12 - 
     7.23898306636066601e-10*g8*x14)*xbar4 + 
  eps17*(3.48460743277465292e-11*A7*g2 - 
     4.51506468378503526e-10*A4*g4 + 
     9.93046484625324211e-11*A*g6 + 
     6.6025042810186813e-9*A6*g3*x2 - 
     1.62520631488663842e-8*A3*g5*x2 + 
     5.61230122018474251e-10*g7*x2 + 
     5.51380920101008308e-8*A5*g4*x4 - 
     4.88479275078761747e-8*A2*g6*x4 + 
     1.20320332856371923e-7*A4*g5*x6 - 
     3.5365653527819202e-8*A*g7*x6 + 
     1.03628614951869648e-7*A3*g6*x8 - 
     6.71263413921269682e-9*g8*x8 + 
     4.07776601703241782e-8*A2*g7*x10 + 
     7.34880420888892836e-9*A*g8*x12 + 
     4.91163816649064884e-10*g9*x14)*xbar4 + 
  eps16*(6.84233044511131468e-14*A8*g - 
     5.60464705059266925e-10*A5*g3 + 
     6.1113506912043867e-10*A2*g5 + 
     2.50582201503812155e-9*A7*g2*x2 - 
     3.39024845059116986e-8*A4*g4*x2 + 
     7.66141086125169516e-9*A*g6*x2 + 
     2.82533097805425257e-8*A6*g3*x4 - 
     1.44153074493338505e-7*A3*g5*x4 + 
     6.29165697711773721e-9*g7*x4 + 
     7.70955531949116842e-8*A5*g4*x6 - 
     1.5856345215569678e-7*A2*g6*x6 + 
     8.37319173204484218e-8*A4*g5*x8 - 
     5.99155536147365961e-8*A*g7*x8 + 
     4.37139891312553985e-8*A3*g6*x10 - 
     7.07392441584795305e-9*g8*x10 + 
     1.16805756794796047e-8*A2*g7*x12 + 
     1.53807088851897092e-9*A*g8*x14 + 
     7.90314013633620188e-11*g9*x16)*xbar4 + 
  eps19*(-3.97340865876564659e-12*A8*g2 + 
     9.08389634660042267e-11*A5*g4 - 
     5.40989729447639056e-11*A2*g6 - 
     1.05114495716806379e-9*A7*g3*x2 + 
     4.89773729086143515e-9*A4*g5*x2 - 
     7.24791876301819899e-10*A*g7*x2 - 
     1.21370267986698838e-8*A6*g4*x4 + 
     2.29597017376750524e-8*A3*g6*x4 - 
     6.7748721115604107e-10*g8*x4 - 
     3.67138156717417151e-8*A5*g5*x6 + 
     2.85584385486008741e-8*A2*g7*x6 - 
     4.48093489348219503e-8*A4*g6*x8 + 
     1.22153837054061484e-8*A*g8*x8 - 
     2.6272947304230525e-8*A3*g7*x10 + 
     1.62436680861277498e-9*g9*x10 - 
     7.84757421369128482e-9*A2*g8*x12 - 
     1.1484952449755475e-9*A*g9*x14 - 
     6.52079226899128072e-11*g10*x16)*xbar4 + 
  eps18*(-2.30220514713186019e-15*A9*g + 
     8.50336672523331952e-11*A6*g3 - 
     2.03099120170330866e-10*A3*g5 + 
     6.86599038065945835e-12*g7 - 
     3.17730510813967685e-10*A8*g2*x2 + 
     7.52334651318304606e-9*A5*g4*x2 - 
     4.58441975864061026e-9*A2*g6*x2 - 
     4.93856631341031329e-9*A7*g3*x4 + 
     4.73460373170155555e-8*A4*g5*x4 - 
     8.81541701496240287e-9*A*g7*x4 - 
     1.83568265106518087e-8*A6*g4*x6 + 
     8.0214964397589886e-8*A3*g6*x6 - 
     3.16831385872351314e-9*g8*x6 - 
     2.73264771648576643e-8*A5*g5*x8 + 
     5.15584868924249984e-8*A2*g7*x8 - 
     2.00422243527645685e-8*A4*g6*x10 + 
     1.36105580520898305e-8*A*g8*x10 - 
     7.92549659107905268e-9*A3*g7*x12 + 
     1.24112226442452554e-9*g9*x12 - 
     1.72024465137340275e-9*A2*g8*x14 - 
     1.92684278620064115e-10*A*g9*x16 - 
     8.69704747258045207e-12*g10*x18)*xbar4 + 
  eps21*(4.47608018566873029e-13*A9*g2 - 
     1.67753308125991472e-11*A6*g4 + 
     2.15143559796472255e-11*A3*g6 - 
     5.36097713439665228e-13*g8 + 
     1.59789748504864926e-10*A8*g3*x2 - 
     1.28169491309084248e-9*A5*g5*x2 + 
     5.05873112365848404e-10*A2*g7*x2 + 
     2.46793239696357667e-9*A7*g4*x4 - 
     8.69126604407042738e-9*A4*g6*x4 + 
     1.08592337487209441e-9*A*g8*x4 + 
     9.97215933211799948e-9*A6*g5*x6 - 
     1.63775632230861457e-8*A3*g7*x6 + 
     4.39638545658591092e-10*g9*x6 + 
     1.6446217893554322e-8*A5*g6*x8 - 
     1.17661894622675905e-8*A2*g8*x8 + 
     1.33981457517207347e-8*A4*g7*x10 - 
     3.46334251627866228e-9*A*g9*x10 + 
     5.87002262267861254e-9*A3*g8*x12 - 
     3.50481841251753294e-10*g10*x12 + 
     1.40564140813720233e-9*A2*g9*x14 + 
     1.72885003376200776e-10*A*g10*x16 + 
     8.52860757101693105e-12*g11*x18)*xbar4 + 
  eps20*(7.56595105695415785e-17*A10*g - 
     1.22932630659041053e-11*A7*g3 + 
     5.58459887241763578e-11*A4*g5 - 
     8.11455810014543089e-12*A*g7 + 
     3.9383320785984906e-11*A9*g2*x2 - 
     1.51976152664836327e-9*A6*g4*x2 + 
     1.98780657022334646e-9*A3*g6*x2 - 
     5.0284224652211995e-11*g8*x2 + 
     8.18366713361052766e-10*A8*g3*x4 - 
     1.34227304693417849e-8*A5*g5*x4 + 
     6.6399136914675485e-9*A2*g7*x4 + 
     4.01847928057574067e-9*A7*g4*x6 - 
     3.25458326731869081e-8*A4*g6*x6 + 
     5.42627614195641677e-9*A*g8*x6 + 
     7.91216320845347941e-9*A6*g5*x8 - 
     3.14137939839749592e-8*A3*g7*x8 + 
     1.16149233526855299e-9*g9*x8 + 
     7.7806358292877523e-9*A5*g6*x10 - 
     1.38304354148956577e-8*A2*g8*x10 + 
     4.24844294383596806e-9*A4*g7*x12 - 
     2.77563538429180564e-9*A*g9*x12 + 
     1.34573608785890679e-9*A3*g8*x14 - 
     2.05451606449403644e-10*g10*x14 + 
     2.45603481008104843e-10*A2*g9*x16 + 
     2.39299395598715992e-11*A*g10*x18 + 
     9.63092387870827136e-13*g11*x20)*xbar4 + 
  eps23*(-4.99202514118831333e-14*A10*g2 + 
     2.89962490735076355e-12*A7*g4 - 
     6.97186084528071566e-12*A4*g6 + 
     7.39113581154999613e-13*A*g8 - 
     2.3394917837884362e-11*A9*g3*x2 + 
     3.01433272680195764e-10*A6*g5*x2 - 
     2.52901008371964216e-10*A3*g7*x2 + 
     4.9975823717035003e-12*g9*x2 - 
     4.70635007764103411e-10*A8*g4*x4 + 
     2.81182652238779472e-9*A5*g6*x4 - 
     9.27102400382163909e-10*A2*g8*x4 - 
     2.46882746644613326e-9*A7*g5*x6 + 
     7.47170357614364372e-9*A4*g7*x6 - 
     8.42342156242855593e-10*A*g9*x6 - 
     5.31658207824290054e-9*A6*g6*x8 + 
     7.96948615558779495e-9*A3*g8*x8 - 
     2.00535355872142721e-10*g10*x8 - 
     5.74925362613453206e-9*A5*g7*x10 + 
     3.87667862850608752e-9*A2*g9*x10 - 
     3.44992473074412105e-9*A4*g8*x12 + 
     8.569346015302056e-10*A*g10*x12 - 
     1.19748784968841458e-9*A3*g9*x14 + 
     6.95772409909226155e-11*g11*x14 - 
     2.38602512157003406e-10*A2*g10*x16 - 
     2.52826017059561289e-11*A*g11*x18 - 
     1.10236531866119468e-12*g12*x20)*xbar4 + 
  eps22*(-2.43710422261727909e-18*A11*g + 
     1.71109183419778529e-12*A8*g3 - 
     1.34309072457408887e-11*A5*g5 + 
     5.2173544345517194e-12*A2*g7 - 
     4.7920869812117813e-12*A10*g2*x2 + 
     2.85329265230758798e-10*A7*g4*x2 - 
     6.97857430562307631e-10*A4*g6*x2 + 
     7.49694255924035744e-11*A*g8*x2 - 
     1.29794915911680679e-10*A9*g3*x4 + 
     3.40176751053615467e-9*A6*g5*x4 - 
     3.56524460909925476e-9*A3*g7*x4 + 
     7.84071353306302568e-11*g9*x4 - 
     8.21445917536130217e-10*A8*g4*x6 + 
     1.12426357550003378e-8*A5*g6*x6 - 
     4.93283496356209241e-9*A2*g8*x6 - 
     2.08160234188537877e-9*A7*g5*x8 + 
     1.51837246414786265e-8*A4*g7*x8 - 
     2.35241679748374184e-9*A*g9*x8 - 
     2.65426623474241136e-9*A6*g6*x10 + 
     9.86143500745746335e-9*A3*g8*x10 - 
     3.47704012872899376e-10*g10*x10 - 
     1.91288185358486004e-9*A5*g7*x12 + 
     3.25348485105233778e-9*A2*g9*x12 - 
     8.26008166150946402e-10*A4*g8*x14 + 
     5.23734714713970356e-10*A*g10*x14 - 
     2.17662681277754724e-10*A3*g9*x16 + 
     3.25604627396838786e-11*g11*x16 - 
     3.42430735395904115e-11*A2*g10*x18 - 
     2.95184625537922171e-12*A*g11*x20 - 
     1.07193479659543963e-13*g12*x22)*xbar4 + 
  eps24*(7.71585736870360985e-20*A12*g - 
     2.30992258376006814e-13*A9*g3 + 
     2.92102366881800346e-12*A6*g5 - 
     2.41669954412293445e-12*A3*g7 + 
     4.72216204539068631e-14*g9 + 
     5.74184634945686335e-13*A11*g2*x2 - 
     5.05105154346589262e-11*A8*g4*x2 + 
     2.10380593488870381e-10*A5*g6*x2 - 
     5.97933596683359805e-11*A2*g8*x2 + 
     1.98448558495321466e-11*A10*g3*x4 - 
     7.88832679162696204e-10*A7*g5*x4 + 
     1.52819851860648456e-9*A4*g7*x4 - 
     1.41460420089467831e-10*A*g9*x4 + 
     1.58609533764471402e-10*A9*g4*x6 - 
     3.43038983424224915e-9*A6*g6*x6 + 
     3.16143488249608422e-9*A3*g8*x6 - 
     6.36135955205512617e-11*g10*x6 + 
     5.0613788167530953e-10*A8*g5*x8 - 
     6.18873950256648937e-9*A5*g7*x8 + 
     2.5062720440597051e-9*A2*g9*x8 + 
     8.15831547687990564e-10*A7*g6*x10 - 
     5.53396691054777854e-9*A4*g8*x10 + 
     8.13144274490680289e-10*A*g10*x10 + 
     7.51495225003727191e-10*A6*g7*x12 - 
     2.65804849164409833e-9*A3*g9*x12 + 
     9.04010499952531028e-11*g11*x12 + 
     4.23273801532746854e-10*A5*g8*x14 - 
     6.95727565670343238e-10*A2*g10*x14 + 
     1.50552227564369774e-10*A4*g9*x16 - 
     9.31966125875092865e-11*A*g11*x16 + 
     3.39107891271974624e-11*A3*g10*x18 - 
     4.98855443293551953e-12*g12*x18 + 
     4.68573921494252176e-12*A2*g11*x20 + 
     3.62148289824228147e-13*A*g12*x22 + 
     1.1980881282823611e-14*g13*x24)*xbar4 - 
  0.0000154320987654320988*eps2*g2*xbar6 + 
  3.56125356125356125e-7*eps5*g3*xbar6 + 
  eps4*(1.90396023729357063e-6*A*g2 + 
     7.71604938271604938e-6*g3*x2)*xbar6 + 
  eps7*(-1.06760523427190094e-7*A*g3 - 
     5.83649889205444761e-7*g4*x2)*xbar6 + 
  eps6*(-1.58222876476844731e-7*A2*g2 - 
     3.0990100434544879e-6*A*g3*x2 - 
     1.45170544476100032e-6*g4*x4)*xbar6 + 
  eps9*(2.10474956623416007e-8*A2*g3 + 
     3.52066889376257568e-7*A*g4*x2 + 
     2.15683591284989252e-7*g5*x4)*xbar6 + 
  eps8*(1.0639753805538638e-8*A3*g2 - 
     1.44647796358943781e-8*g4 + 
     7.89019059521705024e-7*A2*g3*x2 + 
     9.93278626380478232e-7*A*g4*x4 + 
     2.19830466744046991e-7*g5*x6)*xbar6 + 
  eps11*(-3.48009271425128996e-9*A3*g3 + 
     7.74456172615070677e-10*g5 - 
     1.24759056081950737e-7*A2*g4*x2 - 
     1.93124743183608916e-7*A*g5*x4 - 
     5.26262283781649553e-8*g6*x6)*xbar6 + 
  eps10*(-6.21784885258793341e-10*A4*g2 + 
     7.35917308458240036e-9*A*g4 - 
     1.61082849737015107e-7*A3*g3*x2 + 
     4.25042008023580282e-8*g5*x2 - 
     3.97181909847740069e-7*A2*g4*x4 - 
     2.15693489113968417e-7*A*g5*x6 - 
     3.05361793587726322e-8*g6*x8)*xbar6 + 
  eps13*(5.22929181665348026e-10*A4*g3 - 
     5.49761548927799316e-10*A*g5 + 
     3.37795673591345898e-8*A3*g4*x2 - 
     3.32362369023656752e-9*g6*x2 + 
     9.70864128827426103e-8*A2*g5*x4 + 
     6.29082935052959515e-8*A*g6*x6 + 
     1.05359214957493409e-8*g7*x8)*xbar6 + 
  eps12*(3.28023733515722384e-11*A5*g2 - 
     2.2483490443839068e-9*A2*g4 + 
     2.87554439944054822e-8*A4*g3*x2 - 
     3.41643318587639607e-8*A*g5*x2 + 
     1.20413081223750724e-7*A3*g4*x4 - 
     2.54382194661358481e-8*g6*x4 + 
     1.18403247344882478e-7*A2*g5*x6 + 
     3.92485363936068314e-8*A*g6*x8 + 
     4.05810532585570662e-9*g7*x10)*xbar6 + 
  eps15*(-7.38610165433134699e-11*A5*g3 + 
     2.23185618064230175e-10*A2*g5 - 
     7.72550467360774725e-9*A4*g4*x2 + 
     3.33675225731002428e-9*A*g6*x2 - 
     3.60024022499056884e-8*A3*g5*x4 + 
     2.89391686340197044e-9*g7*x4 - 
     4.11034234008140627e-8*A2*g6*x6 - 
     1.58061594311664227e-8*A*g7*x8 - 
     1.88044966020543737e-9*g8*x10)*xbar6 + 
  eps14*(-1.59924972891624396e-12*A6*g2 + 
     5.34559467656326695e-10*A3*g4 - 
     4.89531412255654985e-11*g6 - 
     4.68743656687813986e-9*A5*g3*x2 + 
     1.55203340852120435e-8*A2*g5*x2 - 
     3.05848967636635251e-8*A4*g4*x4 + 
     2.80191583068273077e-8*A*g6*x4 - 
     4.77391188802852923e-8*A3*g5*x6 + 
     9.0249644584421326e-9*g7*x6 - 
     2.7500470429085428e-8*A2*g6*x8 - 
     6.46467617732357999e-9*A*g7*x10 - 
     5.25206836466407194e-10*g8*x12)*xbar6 + 
  eps17*(9.97455222947976728e-12*A6*g3 - 
     6.79725936335510667e-11*A3*g5 + 
     3.53973893285757087e-12*g7 + 
     1.57106382527547975e-9*A5*g4*x2 - 
     1.84906281043290629e-9*A2*g6*x2 + 
     1.0959810274248971e-8*A4*g5*x4 - 
     3.77750956813660573e-9*A*g7*x4 + 
     1.93914172243944712e-8*A3*g6*x6 - 
     1.39852236310538808e-9*g8*x6 + 
     1.27378874003962749e-8*A2*g7*x8 + 
     3.39967157316226349e-9*A*g8*x10 + 
     3.11454821672654227e-10*g9*x12)*xbar6 + 
  eps16*(7.32043787188737753e-14*A7*g2 - 
     1.08932623361419343e-10*A4*g4 + 
     4.43882953795228996e-11*A*g6 + 
     7.1553877265847084e-10*A6*g3*x2 - 
     5.23629960443907472e-9*A3*g5*x2 + 
     2.84608830720512483e-10*g7*x2 + 
     6.85430762519816909e-9*A5*g4*x4 - 
     1.69359418456327738e-8*A2*g6*x4 + 
     1.57308771746978335e-8*A4*g5*x6 - 
     1.26738239683828291e-8*A*g7*x6 + 
     1.38726146998630169e-8*A3*g6*x8 - 
     2.44574523622132431e-9*g8*x8 + 
     5.52081375700205184e-9*A2*g7*x10 + 
     9.99298373572599506e-10*A*g8*x12 + 
     6.67917519196695508e-11*g9*x14)*xbar6 + 
  eps19*(-1.30114590146037234e-12*A7*g3 + 
     1.72511713934239417e-11*A4*g5 - 
     3.90436685140620179e-12*A*g7 - 
     2.92867814057581221e-10*A6*g4*x2 + 
     7.46902977877224456e-10*A3*g6*x2 - 
     2.67522864508407854e-11*g8*x2 - 
     2.89699505443225961e-9*A5*g5*x4 + 
     2.66562938868512264e-9*A2*g7*x4 - 
     7.37795565467524207e-9*A4*g6*x6 + 
     2.25247153971908075e-9*A*g8*x6 - 
     7.30651817416318482e-9*A3*g7*x8 + 
     4.91176292870876797e-10*g9*x8 - 
     3.26224960924321828e-9*A2*g8*x10 - 
     6.59449314458554338e-10*A*g9*x12 - 
     4.89514760970749125e-11*g10*x14)*xbar6 + 
  eps18*(-3.18177848990088646e-15*A8*g2 + 
     1.99695443999379049e-11*A5*g4 - 
     2.23943125358944015e-11*A2*g6 - 
     1.03933552034436454e-10*A7*g3*x2 + 
     1.45959832999336206e-9*A4*g5*x2 - 
     3.42631031918890525e-10*A*g7*x2 - 
     1.39812800630481225e-9*A6*g4*x4 + 
     7.42096889844293084e-9*A3*g6*x4 - 
     3.37099552457525213e-10*g8*x4 - 
     4.48155653124553849e-9*A5*g5*x6 + 
     9.58666614025997167e-9*A2*g7*x6 - 
     5.62734416286699799e-9*A4*g6*x8 + 
     4.18363357640745376e-9*A*g8*x8 - 
     3.34880212849529458e-9*A3*g7*x10 + 
     5.62255597605531686e-10*g9*x10 - 
     1.00758346454303337e-9*A2*g8*x12 - 
     1.478403576160079e-10*A*g9*x14 - 
     8.38903736074731077e-12*g10*x16)*xbar6 + 
  eps21*(1.65107570494289514e-13*A8*g3 - 
     3.85243170234057994e-12*A5*g5 + 
     2.35361375548192462e-12*A2*g7 + 
     5.10417794581330247e-11*A7*g4*x2 - 
     2.45495411183393324e-10*A4*g6*x2 + 
     3.75511182588112891e-11*A*g8*x2 + 
     6.87936705237642027e-10*A6*g5*x4 - 
     1.34714877461804848e-9*A3*g7*x4 + 
     4.11758068629525797e-11*g9*x4 + 
     2.400949695111526e-9*A5*g6*x6 - 
     1.93419604503727388e-9*A2*g8*x6 + 
     3.33918824376270404e-9*A4*g7*x8 - 
     9.42270610564786763e-10*A*g9*x8 + 
     2.20558587287283118e-9*A3*g8*x10 - 
     1.41026346318580081e-10*g10*x10 + 
     7.34671001558905886e-10*A2*g9*x12 + 
     1.18846098758935012e-10*A*g10*x14 + 
     7.4012085886463764e-12*g11*x16)*xbar6 + 
  eps20*(1.32423923182168128e-16*A9*g2 - 
     3.38762545168358761e-12*A6*g4 + 
     8.2936742090468515e-12*A3*g6 - 
     2.88553271599458446e-13*g8 + 
     1.45206721816612312e-11*A8*g3*x2 - 
     3.55365267771350475e-10*A5*g5*x2 + 
     2.24067642028217925e-10*A2*g7*x2 + 
     2.64931375976082846e-10*A7*g4*x4 - 
     2.63256077540054192e-9*A4*g6*x4 + 
     5.08380778036583002e-10*A*g8*x4 + 
     1.14232293931335993e-9*A6*g5*x6 - 
     5.17535342835764208e-9*A3*g7*x6 + 
     2.12052573958312186e-10*g9*x6 + 
     1.94686955319541028e-9*A5*g6*x8 - 
     3.80593235862788058e-9*A2*g8*x8 + 
     1.61506335347690598e-9*A4*g7*x10 - 
     1.13519934804077239e-9*A*g9*x10 + 
     7.1467043552215311e-10*A3*g8*x12 - 
     1.15698350133799093e-10*g10*x12 + 
     1.719691436452393e-10*A2*g9*x14 + 
     2.11817828858919301e-11*A*g10*x16 + 
     1.0439296901669795e-12*g11*x18)*xbar6 + 
  eps23*(-2.04862878355181306e-14*A9*g3 + 
     7.81972174797918537e-13*A6*g5 - 
     1.02619259166044427e-12*A3*g7 + 
     2.62433518896336934e-14*g9 - 
     8.43060024092694187e-12*A8*g4*x2 + 
     6.95862769500813447e-11*A5*g6*x2 - 
     2.83043426411699199e-11*A2*g8*x2 - 
     1.50105719428983393e-10*A7*g5*x4 + 
     5.45631016826002967e-10*A4*g7*x4 - 
     7.04209555461881305e-11*A*g9*x4 - 
     6.92804131934363177e-10*A6*g6*x6 + 
     1.17532183940399869e-9*A3*g8*x6 - 
     3.2607052539653876e-11*g10*x6 - 
     1.29157220680419803e-9*A5*g7*x8 + 
     9.54295239973687871e-10*A2*g9*x8 - 
     1.17766893656649956e-9*A4*g8*x10 + 
     3.14180951036205697e-10*A*g10*x10 - 
     5.72342109737974456e-10*A3*g9*x12 + 
     3.52378082126753302e-11*g11*x12 - 
     1.50826983016266947e-10*A2*g10*x14 - 
     2.0272522360825874e-11*A*g11*x16 - 
     1.08615017352219442e-12*g12*x18)*xbar6 + 
  eps22*(-5.31170301889157885e-18*A10*g2 + 
     5.41512008345912225e-13*A7*g4 - 
     2.51484843977932421e-12*A4*g6 + 
     3.74997952559516213e-13*A*g8 - 
     1.96622519209470769e-12*A9*g3*x2 + 
     7.81432830846281016e-11*A6*g5*x2 - 
     1.0541243620224235e-10*A3*g7*x2 + 
     2.75343063440850494e-12*g9*x2 - 
     4.73066561901215884e-11*A8*g4*x4 + 
     8.01663669414465443e-10*A5*g6*x4 - 
     4.10061241924541413e-10*A2*g8*x4 - 
     2.66530256112802594e-10*A7*g5*x6 + 
     2.23182456344329143e-9*A4*g7*x6 - 
     3.84966796590767183e-10*A*g9*x6 - 
     5.95626630491287062e-10*A6*g6*x8 + 
     2.44421723666841458e-9*A3*g8*x8 - 
     9.34592147729657581e-11*g10*x8 - 
     6.57899358910793091e-10*A5*g7*x10 + 
     1.20777680989039448e-9*A2*g9*x10 - 
     3.99711629253997661e-10*A4*g8*x12 + 
     2.69443230465710687e-10*A*g10*x12 - 
     1.39709228180795027e-10*A3*g9*x14 + 
     2.19843031752725675e-11*g11*x14 - 
     2.79291327736950798e-11*A2*g10*x16 - 
     2.96151288108938101e-12*A*g11*x18 - 
     1.2897624149994603e-13*g12*x20)*xbar6 + 
  5.93542260208926876e-8*eps4*g3*xbar8 - 
  3.12288574815807931e-9*eps7*g4*xbar8 + 
  eps6*(-1.14340392118169896e-8*A*g3 - 
     9.02678854067742957e-8*g4*x2)*xbar8 + 
  eps9*(1.26121885620031857e-9*A*g4 + 
     1.00859349622512295e-8*g5*x2)*xbar8 + 
  eps8*(1.32727772394750297e-9*A2*g3 + 
     4.65033697944917988e-8*A*g4*x2 + 
     2.99054295797669073e-8*g5*x4)*xbar8 + 
  eps11*(-3.15709843216944468e-10*A2*g4 - 
     7.21099301568180965e-9*A*g5*x2 - 
     5.69746824484251863e-9*g6*x4)*xbar8 + 
  eps10*(-1.18235613578975095e-10*A3*g3 + 
     2.04522364126337295e-10*g5 - 
     1.4372001684607648e-8*A2*g4*x2 - 
     2.38545902650207871e-8*A*g5*x4 - 
     6.6442647298050802e-9*g6*x6)*xbar8 + 
  eps13*(6.34254881618462429e-11*A3*g4 - 
     1.4977795563804726e-11*g6 + 
     2.95036268409924151e-9*A2*g5*x2 + 
     5.72733871097688746e-9*A*g6*x4 + 
     1.89780374932858316e-9*g7*x6)*xbar8 + 
  eps12*(8.85933436332280376e-12*A4*g3 - 
     1.2695043367275619e-10*A*g5 + 
     3.44553148081436095e-9*A3*g4*x2 - 
     9.66117808074637814e-10*g6*x2 + 
     1.08393242236143663e-8*A2*g5*x4 + 
     7.24181767567549532e-9*A*g6*x6 + 
     1.22738677265426237e-9*g7*x8)*xbar8 + 
  eps15*(-1.1209244129052603e-11*A4*g4 + 
     1.23354796462055584e-11*A*g6 - 
     9.05322252904213583e-10*A3*g5*x2 + 
     9.34529456546429641e-11*g7*x2 - 
     3.18804749658072552e-9*A2*g6*x4 - 
     2.46989894878460521e-9*A*g7*x6 - 
     4.84553260391626981e-10*g8*x8)*xbar8 + 
  eps14*(-5.85591473164617337e-13*A5*g3 + 
     4.58152437519766974e-11*A2*g5 - 
     7.06061940978074562e-10*A4*g4*x2 + 
     8.8437067488213914e-10*A*g6*x2 - 
     3.6718459581734819e-9*A3*g5*x4 + 
     8.14572670487090063e-10*g7*x4 - 
     4.35865819040676537e-9*A2*g6*x6 - 
     1.70511399881374369e-9*A*g7*x8 - 
     2.04267683542374506e-10*g8*x10)*xbar8 + 
  eps17*(1.81850832862627129e-12*A5*g4 - 
     5.7018133606605742e-12*A2*g6 + 
     2.31363157692796144e-10*A4*g5*x2 - 
     1.04268313475235866e-10*A*g7*x2 + 
     1.29559671265166405e-9*A3*g6*x4 - 
     1.08608812804810835e-10*g8*x4 + 
     1.74321237740579218e-9*A2*g7*x6 + 
     7.76515634579396129e-10*A*g8*x8 + 
     1.05455124124405657e-10*g9*x10)*xbar8 + 
  eps16*(3.51441987362562031e-14*A6*g3 - 
     1.25669585862967901e-11*A3*g5 + 
     1.19873609386538047e-12*g7 + 
     1.29917477297039227e-10*A5*g4*x2 - 
     4.50505663684441363e-10*A2*g6*x2 + 
     1.0294836459233229e-9*A4*g5*x4 - 
     9.85762364733873057e-10*A*g7*x4 + 
     1.90892686734913978e-9*A3*g6*x6 - 
     3.76480107979462358e-10*g8*x6 + 
     1.28194605951425965e-9*A2*g7*x8 + 
     3.45797358676807567e-10*A*g8*x10 + 
     3.18111454415424726e-11*g9*x12)*xbar8 + 
  eps19*(-2.77181792125363476e-13*A6*g4 + 
     1.94851026920691567e-12*A3*g6 - 
     1.04933332657610013e-13*g8 - 
     5.1992259514176436e-11*A5*g5*x2 + 
     6.35571518081156783e-11*A2*g7*x2 - 
     4.28732342024609978e-10*A4*g6*x4 + 
     1.53545689985903239e-10*A*g8*x4 - 
     8.82875940509388448e-10*A3*g7*x6 + 
     6.61143800669246729e-11*g9*x6 - 
     6.65258660548452332e-10*A2*g8*x8 - 
     2.01099007966251153e-10*A*g9*x10 - 
     2.06386033152073184e-11*g10*x12)*xbar8 + 
  eps18*(-1.95213901631847725e-15*A7*g3 + 
     2.9024042061210064e-12*A4*g5 - 
     1.22464345499091446e-12*A*g7 - 
     2.20948357179324358e-11*A6*g4*x2 + 
     1.68407222784752482e-10*A3*g6*x2 - 
     9.52673617116155421e-12*g8*x2 - 
     2.52285174010719033e-10*A5*g5*x4 + 
     6.48893132761825578e-10*A2*g7*x4 - 
     6.78403369061433162e-10*A4*g6*x6 + 
     5.68290125969521456e-10*A*g8*x6 - 
     6.90033763945661382e-10*A3*g7*x8 + 
     1.26310595431481278e-10*g9*x8 - 
     3.12443265284225916e-10*A2*g8*x10 - 
     6.3597958994265421e-11*A*g9*x12 - 
     4.73255306775791468e-12*g10*x14)*xbar8 + 
  eps21*(4.02698278092183264e-14*A7*g4 - 
     5.48456153392839097e-13*A4*g6 + 
     1.27878322517070527e-13*A*g8 + 
     1.06134424697227182e-11*A6*g5*x2 - 
     2.8004805743707356e-11*A3*g7*x2 + 
     1.03826550082836709e-12*g9*x2 + 
     1.22375351923488345e-10*A5*g6*x4 - 
     1.16626518182467646e-10*A2*g8*x4 + 
     3.58798538233177846e-10*A4*g7*x6 - 
     1.13425693456240496e-10*A*g9*x6 + 
     4.04078829257981979e-10*A3*g8*x8 - 
     2.81051427782846787e-11*g10*x8 + 
     2.02913314961737926e-10*A2*g9*x10 + 
     4.56865113489605372e-11*A*g10*x12 + 
     3.74535590061231334e-12*g11*x14)*xbar8 + 
  eps20*(1.01735256778363072e-16*A8*g3 - 
     5.94748498729256522e-13*A5*g5 + 
     6.8752666515941573e-13*A2*g7 + 
     3.53810789377630122e-12*A7*g4*x2 - 
     5.15152807107229022e-11*A4*g6*x2 + 
     1.25362167426384833e-11*A*g8*x2 + 
     5.5847059374569765e-11*A6*g5*x4 - 
     3.07470180635305607e-10*A3*g7*x4 + 
     1.44903732082026135e-11*g9*x4 + 
     2.07246456352654245e-10*A5*g6*x6 - 
     4.59578840273247801e-10*A2*g8*x6 + 
     2.97340805913634912e-10*A4*g7*x8 - 
     2.2892955313025694e-10*A*g9*x8 + 
     1.99809393100334618e-10*A3*g8*x10 - 
     3.47015927264758897e-11*g10*x10 + 
     6.71900005565290136e-11*A2*g9*x12 + 
     1.09198252656076105e-11*A*g10*x14 + 
     6.80982990694437919e-13*g11*x16)*xbar8 + 
  eps22*(-5.02476115994067526e-18*A9*g3 + 
     1.11539174575339278e-13*A6*g5 - 
     2.80495886362028979e-13*A3*g7 + 
     1.00479606252282625e-14*g9 - 
     5.40259809426922891e-13*A8*g4*x2 + 
     1.3655596937180689e-11*A5*g6*x2 - 
     8.89567598025371328e-12*A2*g8*x2 - 
     1.14125112021298833e-11*A7*g5*x4 + 
     1.17262639629103968e-10*A4*g7*x4 - 
     2.34248563243440911e-11*A*g9*x4 - 
     5.63758532628371665e-11*A6*g6*x6 + 
     2.64073536988736149e-10*A3*g8*x6 - 
     1.11917659757112919e-11*g10*x6 - 
     1.08869701145208113e-10*A5*g7*x8 + 
     2.19898065169051477e-10*A2*g9*x8 - 
     1.01295754866412102e-10*A4*g8*x10 + 
     7.34969922028006648e-11*A*g10*x10 - 
     4.98170652624686903e-11*A3*g9*x12 + 
     8.31685179548676633e-12*g11*x12 - 
     1.3215860235187506e-11*A2*g10*x14 - 
     1.78195799356499145e-12*A*g11*x16 - 
     9.55378197871579756e-14*g12*x18)*xbar8 - 
  2.95801289810004407e-10*eps6*g4*xbar10 + 
  2.94346529368315861e-11*eps9*g5*xbar10 + 
  eps8*(7.69281785172546935e-11*A*g4 + 
     1.07490632635875918e-9*g5*x2)*xbar10 + 
  eps11*(-1.49854878334381416e-11*A*g5 - 
     1.64414869918985145e-10*g6*x2)*xbar10 + 
  eps10*(-1.14623038722347948e-11*A2*g4 - 
     6.72527675714427998e-10*A*g5*x2 - 
     5.64942074025452747e-10*g6*x4)*xbar10 + 
  eps13*(4.55203920804202245e-12*A2*g5 + 
     1.35763920347428776e-10*A*g6*x2 + 
     1.33652228562929386e-10*g7*x4)*xbar10 + 
  eps12*(1.27157831390982766e-12*A3*g4 - 
     2.82877994364105943e-12*g6 + 
     2.44160830279527547e-10*A2*g5*x2 + 
     5.14076796669365287e-10*A*g6*x4 + 
     1.75139799425245342e-10*g7*x6)*xbar10 + 
  eps15*(-1.07685636895144654e-12*A3*g5 + 
     2.70026199694243437e-13*g7 - 
     6.29652746661281415e-11*A2*g6*x2 - 
     1.49092240439933003e-10*A*g7*x4 - 
     5.88096054052166419e-11*g8*x6)*xbar10 + 
  eps14*(-1.16205790093287907e-13*A4*g4 + 
     2.06949189356323779e-12*A*g6 - 
     6.72146134669773312e-11*A3*g5*x2 + 
     1.99437288401862085e-11*g7*x2 - 
     2.61681510848862049e-10*A2*g6*x4 - 
     2.10127602166714473e-10*A*g7*x6 - 
     4.18842380479881739e-11*g8*x8)*xbar10 + 
  eps17*(2.18937302179867743e-13*A4*g5 - 
     2.52743776628905178e-13*A*g7 + 
     2.15933914153368247e-11*A3*g6*x2 - 
     2.33174044228357075e-12*g8*x2 + 
     9.10889047339860176e-11*A2*g7*x4 + 
     8.28793584781457544e-11*A*g8*x6 + 
     1.87814134450040901e-11*g9*x8)*xbar10 + 
  eps16*(9.22277143780367963e-15*A5*g4 - 
     8.60637474674818858e-13*A2*g6 + 
     1.55522012194999734e-11*A4*g5*x2 - 
     2.04738873511014663e-11*A*g7*x2 + 
     9.80212032242431517e-11*A3*g6*x4 - 
     2.27433206141358192e-11*g8*x4 + 
     1.3776069368825939e-10*A2*g7*x6 + 
     6.26447221848720574e-11*A*g8*x8 + 
     8.59289553201749293e-12*g9*x10)*xbar10 + 
  eps19*(-4.01386516110057917e-14*A5*g5 + 
     1.3091834712452921e-13*A2*g7 - 
     6.0989736648541878e-12*A4*g6*x2 + 
     2.86173201964551467e-12*A*g8*x2 - 
     4.02840475527683715e-11*A3*g7*x4 + 
     3.510880308676512e-12*g9*x4 - 
     6.29106001544106061e-11*A2*g8*x6 - 
     3.20688619604414165e-11*A*g9*x8 - 
     4.92343192873666106e-12*g10*x10)*xbar10 + 
  eps18*(-6.56399733698215579e-16*A6*g4 + 
     2.67367086954926804e-13*A3*g6 - 
     2.65773724648037072e-14*g8 - 
     3.1891761064266082e-12*A5*g5*x2 + 
     1.1556733294634019e-11*A2*g7*x2 - 
     3.00891865934477623e-11*A4*g6*x4 + 
     3.00144725725027383e-11*A*g8*x4 - 
     6.52019833501791742e-11*A3*g7*x6 + 
     1.33683467827448483e-11*g9*x6 - 
     5.03812647605675579e-11*A2*g8*x8 - 
     1.54328716110212964e-11*A*g9*x10 - 
     1.5943182436056292e-12*g10*x12)*xbar10 + 
  eps21*(6.81948054057362119e-15*A6*g5 - 
     4.95730577363766302e-14*A3*g7 + 
     2.76104504451824809e-15*g9 + 
     1.50108691344008234e-12*A5*g6*x2 - 
     1.90279881030008194e-12*A2*g8*x2 + 
     1.44066974529341e-11*A4*g7*x4 - 
     5.34733489141200454e-12*A*g9*x4 + 
     3.40794085764526502e-11*A3*g8*x6 - 
     2.64239721989513932e-12*g10*x6 + 
     2.91433177396476386e-11*A2*g9*x8 + 
     9.89175324887470848e-12*A*g10*x10 + 
     1.1292802715742771e-12*g11*x12)*xbar10 + 
  eps20*(4.27976553989265789e-17*A7*g4 - 
     6.89934943139530425e-14*A4*g6 + 
     3.01698740413725238e-14*A*g8 + 
     5.98132658710965791e-13*A6*g5*x2 - 
     4.74116732715012842e-12*A3*g7*x2 + 
     2.78541034399807552e-13*g9*x2 + 
     8.00945275253022047e-12*A5*g6*x4 - 
     2.13863386293836158e-11*A2*g8*x4 + 
     2.48849376049208704e-11*A4*g7*x6 - 
     2.16096622933769274e-11*A*g9*x6 + 
     2.88625342578349044e-11*A3*g8*x8 - 
     5.46942831323172719e-12*g10*x8 + 
     1.47325399109498875e-11*A2*g9*x10 + 
     3.34719700407126729e-12*A*g10*x12 + 
     2.75625052642210253e-13*g11*x14)*xbar10 + 
  1.69722051530330397e-12*eps8*g5*xbar12 - 
  2.90595190793452012e-13*eps11*g6*xbar12 + 
  eps10*(-5.54575148020670988e-13*A*g5 - 
     1.29008964169185665e-11*g6*x2)*xbar12 + 
  eps13*(1.78798720202615632e-13*A*g6 + 
     2.57210159823889116e-12*g7*x2)*xbar12 + 
  eps12*(1.00869657097464141e-13*A2*g5 + 
     9.47632013657176953e-12*A*g6*x2 + 
     1.00368310409322369e-11*g7*x4)*xbar12 + 
  eps15*(-6.39010493062016058e-14*A2*g6 - 
     2.40693363499189255e-12*A*g7*x2 - 
     2.87715768832048683e-12*g8*x4)*xbar12 + 
  eps14*(-1.33953977785016062e-14*A3*g5 + 
     3.84980892713537606e-14*g7 - 
     3.94928486633783273e-12*A2*g6*x2 - 
     1.02511581325767213e-11*A*g7*x4 - 
     4.17899415533904787e-12*g8*x6)*xbar12 + 
  eps17*(1.73998403455957848e-14*A3*g6 - 
     4.62636803886378434e-15*g8 + 
     1.24741423146112554e-12*A2*g7*x2 + 
     3.52693455958173369e-12*A*g8*x4 + 
     1.62821302569789988e-12*g9*x6)*xbar12 + 
  eps16*(1.44440682820300384e-15*A4*g5 - 
     3.24022688540454265e-14*A*g7 + 
     1.22741801273679764e-12*A3*g6*x2 - 
     3.84061473377336244e-13*g8*x2 + 
     5.77793844380739442e-12*A2*g7*x4 + 
     5.47447616200335818e-12*A*g8*x6 + 
     1.26471026695269685e-12*g9*x8)*xbar12 + 
  eps19*(-4.00106875821619636e-15*A4*g6 + 
     4.84590692629411758e-15*A*g8 - 
     4.72763385349764825e-13*A3*g7*x2 + 
     5.32739458894566085e-14*g9*x2 - 
     2.34696797887097322e-12*A2*g8*x4 - 
     2.47171834511294782e-12*A*g9*x6 - 
     6.39422064458918014e-13*g10*x8)*xbar12 + 
  eps18*(-1.33739060725578634e-16*A5*g5 + 
     1.52467406929696226e-14*A2*g7 - 
     3.16506850006518787e-13*A4*g6*x2 + 
     4.36808508700696498e-13*A*g8*x2 - 
     2.37192884056053272e-12*A3*g7*x4 + 
     5.73811638250132219e-13*g9*x4 - 
     3.88549767072102607e-12*A2*g8*x6 - 
     2.02801867312185292e-12*A*g9*x8 - 
     3.15279597165500734e-13*g10*x10)*xbar12 + 
  eps20*(1.10024592611551253e-17*A6*g5 - 
     5.28888834827941102e-15*A3*g7 + 
     5.47612344010328206e-16*g9 + 
     7.15818767506558215e-14*A5*g6*x2 - 
     2.70559177977642949e-13*A2*g8*x2 + 
     7.91459587667159745e-13*A4*g7*x4 - 
     8.20326742698849044e-13*A*g9*x4 + 
     1.97757621860341566e-12*A3*g8*x6 - 
     4.20357694313370931e-13*g10*x6 + 
     1.73888738668498436e-12*A2*g9*x8 + 
     5.99434847996843799e-13*A*g10*x10 + 
     6.90257861666477261e-14*g11*x12)*xbar12 - 
  1.06551186196798794e-14*eps10*g6*xbar14 + 
  2.96371424137457707e-15*eps13*g7*xbar14 + 
  eps12*(4.1883104771160436e-15*A*g6 + 
     1.55454784378046993e-13*g7*x2)*xbar14 + 
  eps15*(-2.14017433818550597e-15*A*g7 - 
     3.90198867402243257e-14*g8*x2)*xbar14 + 
  eps14*(-8.99454744512618591e-16*A2*g6 - 
     1.30968415155813316e-13*A*g7*x2 - 
     1.70308449198607365e-13*g8*x4)*xbar14 + 
  eps17*(8.79886328932693487e-16*A2*g7 + 
     4.07855521267175371e-14*A*g8*x2 + 
     5.8024185244265147e-14*g9*x4)*xbar14 + 
  eps16*(1.39116436986363771e-16*A3*g6 - 
     5.17467765013076258e-16*g8 + 
     6.15890327064823114e-14*A2*g7*x2 + 
     1.92792938842998867e-13*A*g8*x4 + 
     9.24186997248047774e-14*g9*x6)*xbar14 + 
  eps19*(-2.71043966692226229e-16*A3*g7 + 
     7.62461032065408102e-17*g9 - 
     2.33529672481396755e-14*A2*g8*x2 - 
     7.75214641947405959e-14*A*g9*x4 - 
     4.13090807033447583e-14*g10*x6)*xbar14 + 
  eps18*(-1.72867499565968957e-17*A4*g6 + 
     4.9217313236453732e-16*A*g8 - 
     2.13260411115595534e-14*A3*g7*x2 + 
     7.01612347492652808e-15*g9*x2 - 
     1.19175537714779419e-13*A2*g8*x4 - 
     1.31262296085466213e-13*A*g9*x6 - 
     3.47201752597269316e-14*g10*x8)*xbar14 + 
  7.1230636127202905e-17*eps12*g7*xbar16 - 
  3.09644400991606704e-17*eps15*g8*xbar16 + 
  eps14*(-3.27091744222075652e-17*A*g7 - 
     1.87737117146802168e-15*g8*x2)*xbar16 + 
  eps17*(2.56820081466394239e-17*A*g8 + 
     5.77970340504678044e-16*g9*x2)*xbar16 + 
  eps16*(8.09908041993038944e-18*A2*g7 + 
     1.78317218006896548e-15*A*g8*x2 + 
     2.78832594974046941e-15*g9*x4)*xbar16 + 
  eps18*(-1.42980374801906325e-18*A3*g7 + 
     6.88701015696998715e-18*g9 - 
     9.33716646729179203e-16*A2*g8*x2 - 
     3.46339329805719736e-15*A*g9*x4 - 
     1.92478458861582261e-15*g10*x6)*xbar16 - 
  4.98845119121947873e-19*eps14*g8*xbar18 + 
  3.29589363262920182e-19*eps17*g9*xbar18 + 
  eps16*(2.61992075966627237e-19*A*g8 + 
     2.27018895731900669e-17*g9*x2)*xbar18 + 
  3.62101682176476165e-21*eps16*g9*xbar20;
}
#endif

#ifdef p28
double Wp(void)
{
   return 0.5*A*x2 + 0.0416666666666666667*g*x4 + 
  eps*(0.0833333333333333333*A + 0.0416666666666666667*g*x2) + 
  eps3*(-0.00277777777777777778*A2 - 
     0.0111111111111111111*A*g*x2 - 
     0.00208333333333333333*g2*x4) + 
  eps2*(0.00416666666666666667*g - 
     0.0416666666666666667*A2*x2 - 
     0.0138888888888888889*A*g*x4 - 
     0.00115740740740740741*g2*x6) + 
  eps5*(0.0001763668430335097*A3 - 
     0.0000388558201058201058*g2 + 
     0.00214947089947089947*A2*g*x2 + 
     0.00124007936507936508*A*g2*x4 + 
     0.000154320987654320988*g3*x6) + 
  eps4*(-0.000595238095238095238*A*g + 
     0.00416666666666666667*A3*x2 - 
     0.000868055555555555556*g2*x2 + 
     0.00347222222222222222*A2*g*x4 + 
     0.000810185185185185185*A*g2*x6 + 
     0.0000578703703703703704*g3*x8) + 
  eps7*(-0.0000132275132275132275*A4 + 
     0.000013452982202982203*A*g2 - 
     0.000353835978835978836*A3*g*x2 + 
     0.0000292107583774250441*g3*x2 - 
     0.000438161375661375661*A2*g2*x4 - 
     0.000141369047619047619*A*g3*x6 - 
     0.0000131815843621399177*g4*x8) + 
  eps6*(0.0000793650793650793651*A2*g - 
     0.000421626984126984127*A4*x2 + 
     0.000412533068783068783*A*g2*x2 - 
     0.000710978835978835979*A3*g*x4 + 
     0.00012359457671957672*g3*x4 - 
     0.000332065696649029982*A2*g2*x6 - 
     0.0000592482363315696649*A*g3*x8 - 
     3.61689814814814815e-6*g4*x10) + 
  eps9*(1.06888995777884667e-6*A5 - 
     3.09484386865339246e-6*A2*g2 + 
     0.000052889176153065042*A4*g*x2 - 
     0.0000196739667225778337*A*g3*x2 + 
     0.000118621733205066538*A3*g2*x4 - 
     8.12834124466068911e-6*g4*x4 + 
     0.0000723776288012399124*A2*g3*x6 + 
     0.0000162595142340512711*A*g4*x8 + 
     1.2123306755829904e-6*g5*x10) + 
  eps8*(-0.0000100208433541766875*A3*g + 
     8.50711788211788212e-7*g3 + 
     0.0000427138447971781305*A5*x2 - 
     0.000120331539602372936*A2*g2*x2 + 
     0.000127911890064667842*A4*g*x4 - 
     0.000098836830607663941*A*g3*x4 + 
     0.000102804110327258475*A3*g2*x6 - 
     0.0000165018585880854399*g4*x6 + 
     0.0000336428938859494415*A2*g3*x8 + 
     4.8512364050558495e-6*A*g4*x10 + 
     2.56755115454961134e-7*g5*x12) + 
  eps11*(-9.01835117002665504e-8*A6 + 
     5.87400058299529199e-7*A3*g2 - 
     2.81868399275952575e-8*g4 - 
     7.41416841780598394e-6*A5*g*x2 + 
     7.67116473755031956e-6*A2*g3*x2 - 
     0.000027147462601331649*A4*g2*x4 + 
     8.12031936990601012e-6*A*g4*x4 - 
     0.0000272310450812986086*A3*g3*x6 + 
     1.70667153812408442e-6*g5*x6 - 
     0.0000108933015093453806*A2*g4*x8 - 
     1.87850642976993286e-6*A*g5*x10 - 
     1.16690477054095881e-7*g6*x12) + 
  eps10*(1.21747740795359843e-6*A4*g - 
     4.62417873132158846e-7*A*g3 - 
     4.32775172358505692e-6*A6*x2 + 
     0.0000276277014248244407*A3*g2*x2 - 
     1.30445706075046353e-6*g4*x2 - 
     0.0000210333326652771097*A5*g*x4 + 
     0.0000447391253752860896*A2*g3*x4 - 
     0.0000265668910778864483*A4*g2*x6 + 
     0.0000184769777868736202*A*g4*x6 - 
     0.0000139376709110505407*A3*g3*x8 + 
     2.13520310814871e-6*g5*x8 - 
     3.5181249916492972e-6*A2*g4*x10 - 
     4.25407416871537242e-7*A*g5*x12 - 
     1.98147969535893919e-8*g6*x14) + 
  eps13*(7.83069566138349207e-9*A7 - 
     9.93094869534334209e-8*A4*g2 + 
     2.08755249185163841e-8*A*g4 + 
     9.92791119692574719e-7*A6*g*x2 - 
     2.26246788359770127e-6*A3*g3*x2 + 
     7.19774046753493046e-8*g5*x2 + 
     5.52538741816188906e-6*A5*g2*x4 - 
     4.47883727161149936e-6*A2*g4*x4 + 
     8.38601213983571788e-6*A4*g3*x6 - 
     2.25348627386308778e-6*A*g5*x6 + 
     5.24445855604457162e-6*A3*g4*x8 - 
     3.11392974798759566e-7*g6*x8 + 
     1.55465050346795001e-6*A2*g5*x10 + 
     2.17600880397466046e-7*A*g6*x12 + 
     1.15841884836628278e-8*g7*x14) + 
  eps12*(-1.43889032777921667e-7*A5*g + 
     1.51283642180000723e-7*A2*g3 + 
     4.38492191964414187e-7*A7*x2 - 
     5.47671197834474951e-6*A4*g2*x2 + 
     1.1365151365172641e-6*A*g4*x2 + 
     3.23789133106262736e-6*A6*g*x4 - 
     0.0000150481673660823793*A3*g3*x4 + 
     5.97324614725086198e-7*g5*x4 + 
     6.03932684613625972e-6*A5*g2*x6 - 
     0.0000113106765525436987*A2*g4*x6 + 
     4.69528859165240338e-6*A4*g3*x8 - 
     3.0694501391598228e-6*A*g5*x8 + 
     1.82557370238215146e-6*A3*g4*x10 - 
     2.71046144994230449e-7*g6*x10 + 
     3.7535031778135559e-7*A2*g5*x12 + 
     3.90681314457195373e-8*A*g6*x14 + 
     1.62260932077515154e-9*g7*x16) + 
  eps15*(-6.94206524686864971e-10*A8 + 
     1.55258266251201437e-8*A5*g2 - 
     8.87063997906019346e-9*A2*g4 - 
     1.28444091425696105e-7*A7*g*x2 + 
     5.59355511978255916e-7*A4*g3*x2 - 
     7.69591961687451275e-8*A*g5*x2 - 
     1.03084425773136674e-6*A6*g2*x4 + 
     1.80099658500984157e-6*A3*g4*x4 - 
     4.89852640150590245e-8*g6*x4 - 
     2.23744987275327073e-6*A5*g3*x6 + 
     1.60416803829389571e-6*A2*g5*x6 - 
     2.02887475090349778e-6*A4*g4*x8 + 
     5.10536772376168298e-7*A*g6*x8 - 
     9.11746562790846727e-7*A3*g5*x10 + 
     5.21769349658492833e-8*g7*x10 - 
     2.14341780318485671e-7*A2*g6*x12 - 
     2.52490551976121104e-8*A*g7*x14 - 
     1.17600420262660865e-9*g8*x16) + 
  eps14*(1.66609565924847593e-8*A6*g - 
     3.84541066603365207e-8*A3*g3 + 
     1.23616495716322489e-9*g5 - 
     4.44285396439000936e-8*A8*x2 + 
     9.81807578832239391e-7*A5*g2*x2 - 
     5.55101746448534654e-7*A2*g4*x2 - 
     4.73967830600877338e-7*A7*g*x4 + 
     4.18284859452059839e-6*A4*g3*x4 - 
     7.15343253702736788e-7*A*g5*x4 - 
     1.24663165145441196e-6*A6*g2*x6 + 
     5.00514675879205854e-6*A3*g4*x6 - 
     1.81402700349001079e-7*g6*x6 - 
     1.36226318220021373e-6*A5*g3*x8 + 
     2.36606032230627314e-6*A2*g5*x8 - 
     7.58172593612770117e-7*A4*g4*x10 + 
     4.75471890972483691e-7*A*g6*x10 - 
     2.34027522244261325e-7*A3*g5*x12 + 
     3.3963539821117207e-8*g7*x12 - 
     4.06050820222736176e-8*A2*g6*x14 - 
     3.70938742929349711e-9*A*g7*x16 - 
     1.38898528337180163e-10*g8*x18) + 
  eps17*(6.25217958800249802e-11*A9 - 
     2.29312206278746533e-9*A6*g2 + 
     2.8310089717477044e-9*A3*g4 - 
     6.71998649148490015e-11*g6 + 
     1.61783182535963035e-8*A8*g*x2 - 
     1.222198282975496e-7*A5*g3*x2 + 
     4.51903487294323094e-8*A2*g5*x2 + 
     1.79787422789127715e-7*A7*g2*x4 - 
     5.89386352242391962e-7*A4*g4*x4 + 
     6.83924293854497039e-8*A*g6*x4 + 
     5.35385253592035249e-7*A6*g3*x6 - 
     8.16161936426993263e-7*A3*g5*x6 + 
     2.03110694856709656e-8*g7*x6 + 
     6.69429955495357485e-7*A5*g4*x8 - 
     4.44812062546498445e-7*A2*g6*x8 + 
     4.24544759374608395e-7*A4*g5*x10 - 
     1.02125278182278717e-7*A*g7*x10 + 
     1.48190757087105866e-7*A3*g6*x12 - 
     8.25465653164429909e-9*g8*x12 + 
     2.8842218900714868e-8*A2*g7*x14 + 
     2.93316966296752154e-9*A*g8*x16 + 
     1.21426224678902097e-10*g9*x18) + 
  eps16*(-1.89909954985575877e-9*A7*g + 
     8.35603474047208798e-9*A4*g3 - 
     1.15966243496214952e-9*A*g5 + 
     4.50155213123768602e-9*A9*x2 - 
     1.63520154608933337e-7*A6*g2*x2 + 
     2.00125773929144853e-7*A3*g4*x2 - 
     4.71643935891082883e-9*g6*x2 + 
     6.66827009985439445e-8*A8*g*x4 - 
     1.01569722853466271e-6*A5*g3*x4 + 
     4.653753986331283e-7*A2*g5*x4 + 
     2.38609112997144637e-7*A7*g2*x6 - 
     1.78931879078472604e-6*A4*g4*x6 + 
     2.75782412054904595e-7*A*g6*x6 + 
     3.5257503626825941e-7*A6*g3*x8 - 
     1.29719583644083582e-6*A3*g5*x8 + 
     4.43904638337799842e-8*g7*x8 + 
     2.67563783428073661e-7*A5*g4*x10 - 
     4.41739629456479988e-7*A2*g6*x10 + 
     1.15544405881940575e-7*A4*g5*x12 - 
     7.03094817586759951e-8*A*g7*x12 + 
     2.95627516533174602e-8*A3*g6*x14 - 
     4.21593686904484474e-9*g8*x14 + 
     4.43746780874914946e-9*A2*g7*x16 + 
     3.61167459558351774e-10*A*g8*x18 + 
     1.23066706066192904e-11*g9*x20) + 
  eps19*(-5.70128780114804572e-12*A10 + 
     3.24325759393455769e-10*A7*g2 - 
     7.52920392642037898e-10*A4*g4 + 
     7.63432039813829238e-11*A*g6 - 
     1.99446765051272661e-9*A9*g*x2 + 
     2.43560018179573397e-8*A6*g3*x2 - 
     1.92651473964731419e-8*A3*g5*x2 + 
     3.57664504054283011e-10*g7*x2 - 
     2.97138844105769473e-8*A8*g2*x4 + 
     1.66367899286352586e-7*A5*g4*x4 - 
     5.12763843043703477e-8*A2*g6*x4 - 
     1.17558487781038256e-7*A7*g3*x6 + 
     3.32274083849900958e-7*A4*g5*x6 - 
     3.49339293457975036e-8*A*g7*x6 - 
     1.95421595481198395e-7*A6*g4*x8 + 
     2.73546099832218964e-7*A3*g6*x8 - 
     6.42119893976624269e-9*g8*x8 - 
     1.66845932629322826e-7*A5*g5*x10 + 
     1.05196992302604677e-7*A2*g7*x10 - 
     8.06653736383214643e-8*A4*g6*x12 + 
     1.87723844343482559e-8*A*g8*x12 - 
     2.29644918467110207e-8*A3*g7*x14 + 
     1.25288025697957571e-9*g9*x14 - 
     3.81165485194947533e-9*A2*g8*x16 - 
     3.41033212304414905e-10*A*g9*x18 - 
     1.27053709821831841e-11*g10*x20) + 
  eps18*(2.13798292543051714e-10*A8*g - 
     1.62899940163818617e-9*A5*g3 + 
     6.06739124374671626e-10*A2*g5 - 
     4.56102589118103946e-10*A10*x2 + 
     2.5741194154734252e-8*A7*g2*x2 - 
     5.93202934378594688e-8*A4*g4*x2 + 
     5.97796132442781859e-9*A*g6*x2 - 
     9.086017175115798e-9*A9*g*x4 + 
     2.22788546277779156e-7*A6*g3*x4 - 
     2.17818061292066124e-7*A3*g5*x4 + 
     4.46060201054250811e-9*g7*x4 - 
     4.29736286745591606e-8*A8*g2*x6 + 
     5.48218484132244335e-7*A5*g4*x6 - 
     2.23798601959230444e-7*A2*g6*x6 - 
     8.3334504765293729e-8*A7*g3*x8 + 
     5.66588387939462102e-7*A4*g5*x8 - 
     8.17078651256326395e-8*A*g7*x8 - 
     8.32572408053676287e-8*A6*g4*x10 + 
     2.88769211893932833e-7*A3*g6*x10 - 
     9.49367158787967084e-9*g8*x10 - 
     4.80270155903927102e-8*A5*g5*x12 + 
     7.64234973061525259e-8*A2*g7*x12 - 
     1.69136821548003748e-8*A4*g6*x14 + 
     1.00575293092506873e-8*A*g8*x14 - 
     3.69466622059472975e-9*A3*g7*x16 + 
     5.19597646877020836e-10*g9*x16 - 
     4.88723854749631574e-10*A2*g8*x18 - 
     3.58645537045585288e-11*A*g9*x20 - 
     1.12084057456710382e-12*g10*x22) + 
  eps21*(5.2514619543187782e-13*A11 - 
     4.43285954755604869e-11*A8*g2 + 
     1.76083788279021689e-10*A5*g4 - 
     4.74728753998211342e-11*A2*g6 + 
     2.41589075467910444e-10*A10*g*x2 - 
     4.51824485857656974e-9*A7*g3*x2 + 
     6.66083029216207287e-9*A4*g5*x2 - 
     5.24335874922835697e-10*A*g7*x2 + 
     4.69949475640663485e-9*A9*g2*x4 - 
     4.19656758646856316e-8*A6*g4*x4 + 
     2.73885212294566607e-8*A3*g6*x4 - 
     4.48244578272414887e-10*g8*x4 + 
     2.40727904510809782e-8*A8*g3*x6 - 
     1.14987302708287038e-7*A5*g5*x6 + 
     3.18314156293579248e-8*A2*g7*x6 + 
     5.1729556293745067e-8*A7*g4*x8 - 
     1.33139310440523761e-7*A4*g6*x8 + 
     1.31084047358048264e-8*A*g8*x8 + 
     5.74763592331078553e-8*A6*g5*x10 - 
     7.58285646214704478e-8*A3*g7*x10 + 
     1.70719938146989968e-9*g9*x10 + 
     3.67818305341475603e-8*A5*g6*x12 - 
     2.23107719453182269e-8*A2*g8*x12 + 
     1.43062528484956471e-8*A4*g7*x14 - 
     3.24546888412113238e-9*A*g9*x14 + 
     3.43426667042232431e-9*A3*g8*x16 - 
     1.84284319077257175e-10*g10*x16 + 
     4.96756814596081739e-10*A2*g9*x18 + 
     3.96764099826891058e-11*A*g10*x20 + 
     1.34372144042558418e-12*g11*x22) + 
  eps20*(-2.38285086177214561e-11*A9*g + 
     2.93087835503767857e-10*A6*g3 - 
     2.33284850513311582e-10*A3*g5 + 
     4.35358687387975124e-12*g7 + 
     4.62128541799995915e-11*A11*x2 - 
     3.87512747715920683e-9*A8*g2*x2 + 
     1.52963831343981389e-8*A5*g4*x2 - 
     4.10201649274809254e-9*A2*g6*x2 + 
     1.2058131859727143e-9*A10*g*x4 - 
     4.51251014708823542e-8*A7*g3*x4 + 
     8.20524658045556169e-8*A4*g5*x4 - 
     7.11455083461241557e-9*A*g7*x4 + 
     7.36094104464716057e-9*A9*g2*x6 - 
     1.49255884116928141e-7*A6*g4*x6 + 
     1.28707565844365563e-7*A3*g6*x6 - 
     2.42078453530071715e-9*g8*x6 + 
     1.82893288628610935e-8*A8*g3*x8 - 
     2.09524543137285467e-7*A5*g5*x8 + 
     7.93810679543179244e-8*A2*g7*x8 + 
     2.34179153309909358e-8*A7*g4*x10 - 
     1.48969846228119514e-7*A4*g6*x10 + 
     2.05019199855671562e-8*A*g8*x10 + 
     1.74575105847696841e-8*A6*g5*x12 - 
     5.80036979689224998e-8*A3*g7*x12 + 
     1.8510046912641176e-9*g9*x12 + 
     8.09148869608194122e-9*A5*g6*x14 - 
     1.251808839252206e-8*A2*g8*x14 + 
     2.40348962003249252e-9*A4*g7*x16 - 
     1.40328230011170153e-9*A*g9*x16 + 
     4.58007384146693616e-10*A3*g8*x18 - 
     6.36787892934133022e-11*g10*x18 + 
     5.41571641768509377e-11*A2*g9*x20 + 
     3.61823810155023661e-12*A*g10*x22 + 
     1.04407319287969897e-13*g11*x24) + 
  eps23*(-4.87743892079685082e-14*A12 + 
     5.89316491267758974e-12*A9*g2 - 
     3.73943263170943611e-11*A6*g4 + 
     2.13679155317563112e-11*A3*g6 - 
     3.27361153325515243e-13*g8 - 
     2.88368279506519334e-11*A11*g*x2 + 
     7.91374895139060628e-10*A8*g3*x2 - 
     1.98046179372144604e-9*A5*g5*x2 + 
     4.11786639583657111e-10*A2*g7*x2 - 
     7.16497851551313523e-10*A10*g2*x4 + 
     9.68464471525289276e-9*A7*g4*x4 - 
     1.16748393728030986e-8*A4*g6*x4 + 
     8.04127478183736051e-10*A*g8*x4 - 
     4.65194608412246558e-9*A9*g3*x6 + 
     3.51082372037893695e-8*A6*g5*x6 - 
     2.04201982013264592e-8*A3*g7*x6 + 
     3.08310721156552306e-10*g9*x6 - 
     1.26357673284535273e-8*A8*g4*x8 + 
     5.45476416156654204e-8*A5*g6*x8 - 
     1.40486405551536498e-8*A2*g8*x8 - 
     1.7805212696568686e-8*A7*g5*x10 + 
     4.2926305860153371e-8*A4*g7*x10 - 
     4.0312366550615087e-9*A*g9*x10 - 
     1.46022546131613235e-8*A6*g6*x12 + 
     1.843836447337074e-8*A3*g8*x12 - 
     4.02235197734030437e-10*g10*x12 - 
     7.42369322805527411e-9*A5*g7*x14 + 
     4.37038526225414347e-9*A2*g9*x14 - 
     2.40937437944208411e-9*A4*g8*x16 + 
     5.35568097093309146e-10*A*g10*x16 - 
     4.99603251087911808e-10*A3*g9*x18 + 
     2.64472477748035067e-11*g11*x18 - 
     6.40255800593810452e-11*A2*g10*x20 - 
     4.61829796410311992e-12*A*g11*x22 - 
     1.43368406597132889e-13*g12*x24) + 
  eps22*(2.63381701723029945e-12*A10*g - 
     4.95613474685512438e-11*A7*g3 + 
     7.3461839787322817e-11*A4*g5 - 
     5.80927196941699941e-12*A*g7 - 
     4.68234108487568308e-12*A12*x2 + 
     5.62566165576091132e-10*A9*g2*x2 - 
     3.55029758958278224e-9*A6*g4*x2 + 
     2.01925178972162547e-9*A3*g6*x2 - 
     3.0814593971546122e-11*g8*x2 - 
     1.56527781346397019e-10*A11*g*x4 + 
     8.57069278143073356e-9*A8*g3*x4 - 
     2.64080665694219489e-8*A5*g5*x4 + 
     6.0407259102082057e-9*A2*g7*x4 - 
     1.20889938892283076e-9*A10*g2*x6 + 
     3.69930387182005496e-8*A7*g4*x6 - 
     5.87976309873423814e-8*A4*g6*x6 + 
     4.64691762189073441e-9*A*g8*x6 - 
     3.7731495679189183e-9*A9*g3*x8 + 
     6.81148651466673022e-8*A6*g5*x8 - 
     5.41126426776092471e-8*A3*g7*x8 + 
     9.60423280700958978e-10*g9*x8 - 
     6.06051978329905884e-9*A8*g4*x10 + 
     6.45172101423398301e-8*A5*g6*x10 - 
     2.31853730369969274e-8*A2*g8*x10 - 
     5.69384641167539249e-9*A7*g5*x12 + 
     3.45031778931260666e-8*A4*g7*x12 - 
     4.5856200745095094e-9*A*g9*x12 - 
     3.36446046321516529e-9*A6*g6*x14 + 
     1.08170138123001676e-8*A3*g8*x14 - 
     3.37300366179434001e-10*g10*x14 - 
     1.30060474988550597e-9*A5*g7*x16 + 
     1.9676600421073939e-9*A2*g9*x16 - 
     3.33854146037989048e-10*A4*g8*x18 + 
     1.92027951778477411e-10*A*g10*x18 - 
     5.64147807443152692e-11*A3*g9*x20 + 
     7.76866625886353525e-12*g11*x20 - 
     6.03122771185984168e-12*A2*g10*x22 - 
     3.69809171837544212e-13*A*g11*x24 - 
     9.90994892123906548e-15*g12*x26) + 
  eps25*(4.5617341154295489e-15*A13 - 
     7.65681973581163408e-13*A10*g2 + 
     7.36427533361146046e-12*A7*g4 - 
     7.77915357825993505e-12*A4*g6 + 
     5.01822372498827554e-13*A*g8 + 
     3.39946554308810257e-12*A12*g*x2 - 
     1.32218967001765988e-10*A9*g3*x2 + 
     5.24826694161013285e-10*A6*g5*x2 - 
     2.29911014730304061e-10*A3*g7*x2 + 
     2.97396110366290561e-12*g9*x2 + 
     1.05899009942419973e-10*A11*g2*x4 - 
     2.07888236061736146e-9*A8*g4*x4 + 
     4.2205345488109798e-9*A5*g6*x4 - 
     7.62725505811220135e-10*A2*g8*x4 + 
     8.56030817990639683e-10*A10*g3*x6 - 
     9.69700200555032466e-9*A7*g5*x6 + 
     1.0345307489459437e-8*A4*g7*x6 - 
     6.53391446848804187e-10*A*g9*x6 + 
     2.88536112350769269e-9*A9*g4*x8 - 
     1.95458369290004387e-8*A6*g6*x8 + 
     1.05141608097548792e-8*A3*g8*x8 - 
     1.49985208961406861e-10*g10*x8 + 
     5.0517190817639561e-9*A8*g5*x10 - 
     2.03127428588433698e-8*A5*g7*x10 + 
     4.96479103747145285e-9*A2*g9*x10 + 
     5.18105920734004777e-9*A7*g6*x12 - 
     1.18984582771191454e-8*A4*g8*x12 + 
     1.07801501997213091e-9*A*g10*x12 + 
     3.33667223847150641e-9*A6*g7*x14 - 
     4.07258881748425756e-9*A3*g9*x14 + 
     8.66712686070301579e-11*g11*x14 + 
     1.4017941285304863e-9*A5*g8*x16 - 
     8.05772603894054025e-10*A2*g10*x16 + 
     3.89757092431598696e-10*A4*g9*x18 - 
     8.52041965373136873e-11*A*g11*x18 + 
     7.10964158735397762e-11*A3*g10*x20 - 
     3.72103988693417535e-12*g12*x20 + 
     8.17773394901589543e-12*A2*g11*x22 + 
     5.37775729072728217e-13*A*g12*x24 + 
     1.54097984854059648e-14*g13*x26) + 
  eps24*(-2.89099899565347662e-13*A11*g + 
     7.9759930961059578e-12*A8*g3 - 
     2.00555906593283631e-11*A5*g5 + 
     4.18688595364780991e-12*A2*g7 + 
     4.74420340935259007e-13*A13*x2 - 
     7.92461835979771511e-11*A10*g2*x2 + 
     7.58561702147442218e-10*A7*g4*x2 - 
     7.97991543042322495e-10*A4*g6*x2 + 
     5.12980963092851767e-11*A*g8*x2 + 
     1.99411637693229689e-11*A12*g*x4 - 
     1.54367310321517635e-9*A9*g3*x4 + 
     7.53265555420091332e-9*A6*g5*x4 - 
     3.62648374581728425e-9*A3*g7*x4 + 
     4.93947743563747665e-11*g9*x4 + 
     1.91553592353180707e-10*A11*g2*x6 - 
     8.49094217698978774e-9*A8*g4*x6 + 
     2.26856565220020088e-8*A5*g6*x6 - 
     4.69772329949351813e-9*A2*g8*x6 + 
     7.38610816404395504e-10*A10*g3*x8 - 
     1.99662166333330706e-8*A7*g5*x8 + 
     2.9041859633440226e-8*A4*g7*x8 - 
     2.15327269006722961e-9*A*g9*x8 + 
     1.46232224612947612e-9*A9*g4*x10 - 
     2.43772139379355154e-8*A6*g6*x10 + 
     1.82674355319716322e-8*A3*g8*x10 - 
     3.10752555543901178e-10*g10*x10 + 
     1.69732946496891816e-9*A8*g5*x12 - 
     1.71231822209617444e-8*A5*g7*x12 + 
     5.9144501741718517e-9*A2*g9*x12 + 
     1.24827250807789759e-9*A7*g6*x14 - 
     7.28755328956029511e-9*A4*g8*x14 + 
     9.42570128461049658e-10*A*g10*x14 + 
     6.08812904258686911e-10*A6*g7*x16 - 
     1.90694699932313329e-9*A3*g9*x16 + 
     5.83702428173174224e-11*g11*x16 + 
     2.01600973965553078e-10*A5*g8*x18 - 
     2.99487561260952419e-10*A2*g10*x18 + 
     4.5544937416083891e-11*A4*g9*x20 - 
     2.58715552328237504e-11*A*g11*x20 + 
     6.91310656589337861e-12*A3*g10*x22 - 
     9.44207238480244009e-13*g12*x22 + 
     6.74432494205638096e-13*A2*g11*x24 + 
     3.82104888900742578e-14*A*g12*x26 + 
     9.55678585992729762e-16*g13*x28) + 
  eps27*(-4.29185988094780467e-16*A14 + 
     9.75792282712677276e-14*A11*g2 - 
     1.3646853162570345e-12*A8*g4 + 
     2.42949425613405441e-12*A5*g6 - 
     4.11394545518213554e-13*A2*g8 - 
     3.96490174257524041e-13*A13*g*x2 + 
     2.12343279256552213e-11*A10*g3*x2 - 
     1.26943061490106314e-10*A7*g5*x2 + 
     1.02247921943695124e-10*A4*g7*x2 - 
     5.5423483777730116e-12*A*g9*x2 - 
     1.52404782309247872e-11*A12*g2*x4 + 
     4.20166632359481189e-10*A9*g4*x4 - 
     1.34342557916077234e-9*A6*g6*x4 + 
     5.08454526341145697e-10*A3*g8*x4 - 
     5.93267483507724836e-12*g10*x4 - 
     1.5105589569086578e-10*A11*g3*x6 + 
     2.46644028677531692e-9*A8*g5*x6 - 
     4.40356140879596708e-9*A5*g7*x6 + 
     7.2573930556411028e-10*A2*g9*x6 - 
     6.22095324902653748e-10*A10*g4*x8 + 
     6.28605537544467192e-9*A7*g6*x8 - 
     6.16872976090627993e-9*A4*g8*x8 + 
     3.66333923503317899e-10*A*g10*x8 - 
     1.3307708807396243e-9*A9*g5*x10 + 
     8.35325491249095651e-9*A6*g7*x10 - 
     4.24450814830156289e-9*A3*g9*x10 + 
     5.80327450488696854e-11*g11*x10 - 
     1.6742025695565531e-9*A8*g6*x12 + 
     6.38443699559690024e-9*A5*g8*x12 - 
     1.49942990889307018e-9*A2*g10*x12 - 
     1.33401488172649674e-9*A7*g7*x14 + 
     2.95015965374919579e-9*A4*g9*x14 - 
     2.59836904724562695e-10*A*g11*x14 - 
     7.03555104941829487e-10*A6*g8*x16 + 
     8.35706570206888892e-10*A3*g10*x16 - 
     1.74326212154086689e-11*g12*x16 - 
     2.51267260438286454e-10*A5*g9*x18 + 
     1.41631829044548074e-10*A2*g11*x18 - 
     6.10485807554465637e-11*A4*g10*x20 + 
     1.31608120750337335e-11*A*g12*x20 - 
     9.93693264312864106e-12*A3*g11*x22 + 
     5.15065776106236279e-13*g13*x22 - 
     1.03668290285869099e-12*A2*g12*x24 - 
     6.26408647094493891e-14*A*g13*x26 - 
     1.66670051667820424e-15*g14*x28) + 
  eps26*(3.15451701249663644e-14*A12*g - 
     1.23260743380846408e-12*A9*g3 + 
     4.91328598966957483e-12*A6*g5 - 
     2.16010730561106487e-12*A3*g7 + 
     2.80265846575244876e-14*g9 - 
     4.80688304875450638e-14*A14*x2 + 
     1.0882967128577594e-11*A11*g2*x2 - 
     1.51564449755526941e-10*A8*g4*x2 + 
     2.68832690023484167e-10*A5*g6*x2 - 
     4.53800665535698655e-11*A2*g8*x2 - 
     2.49976348277787481e-12*A13*g*x4 + 
     2.65894282403365961e-10*A10*g3*x4 - 
     1.95152833009846442e-9*A7*g5*x4 + 
     1.72592503214026419e-9*A4*g7*x4 - 
     9.84468564911047601e-11*A*g9*x4 - 
     2.9429564195639701e-11*A12*g2*x6 + 
     1.82782910902163964e-9*A9*g4*x6 - 
     7.67829334489098475e-9*A6*g6*x6 + 
     3.32590234296463859e-9*A3*g8*x6 - 
     4.19820646804651369e-11*g10*x6 - 
     1.38204464610680452e-10*A11*g3*x8 + 
     5.37351949422549083e-9*A8*g5*x8 - 
     1.30589400763732115e-8*A5*g7*x8 + 
     2.52344638346505715e-9*A2*g9*x8 - 
     3.32321907447622297e-10*A10*g4*x10 + 
     8.24783952385426657e-9*A7*g6*x10 - 
     1.1258556884547882e-8*A4*g8*x10 + 
     7.96395396558461894e-10*A*g10*x10 - 
     4.68876173390562072e-10*A9*g5*x12 + 
     7.37174695327914701e-9*A6*g7*x12 - 
     5.2863782907904963e-9*A3*g9*x12 + 
     8.70473987527200665e-11*g11*x12 - 
     4.21139769024652842e-10*A8*g6*x14 + 
     4.07659424674585697e-9*A5*g8*x14 - 
     1.36514999589867453e-9*A2*g10*x14 - 
     2.53184281042569276e-10*A7*g7*x16 + 
     1.43498819528840929e-9*A4*g9*x16 - 
     1.81588742992582398e-10*A*g11*x16 - 
     1.04910984884796622e-10*A6*g8*x18 + 
     3.21680373413064642e-10*A3*g10*x18 - 
     9.69728250369714944e-12*g12*x18 - 
     3.03594939414036236e-11*A5*g9*x20 + 
     4.44197711547649947e-11*A2*g11*x20 - 
     6.12305100850786679e-12*A4*g10*x22 + 
     3.44141679543564567e-12*A*g12*x22 - 
     8.43545071546764867e-13*A3*g11*x24 + 
     1.14398078813312878e-13*g13*x24 - 
     7.56779797267724648e-14*A2*g12*x26 - 
     3.98471719227870099e-15*A*g13*x28 - 
     9.34260000972918927e-17*g14*x30) + 
  0.00833333333333333333*eps*g*xbar2 + 
  0.166666666666666667*(A + 0.5*g*x2)*xbar2 + 
  eps3*(-0.000793650793650793651*A*g - 
     0.00138888888888888889*g2*x2)*xbar2 + 
  eps2*(-0.00277777777777777778*A2 - 
     0.0111111111111111111*A*g*x2 - 
     0.00208333333333333333*g2*x4)*xbar2 + 
  eps5*(0.0000727513227513227513*A2*g + 
     0.000522486772486772487*A*g2*x2 + 
     0.000162037037037037037*g3*x4)*xbar2 + 
  eps4*(0.0000661375661375661376*A3 - 
     0.0000644841269841269841*g2 + 
     0.0015873015873015873*A2*g*x2 + 
     0.00094246031746031746*A*g2*x4 + 
     0.000115740740740740741*g3*x6)*xbar2 + 
  eps7*(-6.91438191438191438e-6*A3*g + 
     1.41486599819933153e-6*g3 - 
     0.000128066378066378066*A2*g2*x2 - 
     0.000110705266955266955*A*g3*x4 - 
     0.000018647119341563786*g4*x6)*xbar2 + 
  eps6*(-1.65343915343915344e-6*A4 + 
     0.0000179623617123617124*A*g2 - 
     0.00021164021164021164*A3*g*x2 + 
     0.0000485008818342151675*g3*x2 - 
     0.000276951058201058201*A2*g2*x4 - 
     0.0000898368606701940035*A*g3*x6 - 
     8.27867798353909465e-6*g4*x8)*xbar2 + 
  eps9*(6.79829796893288957e-7*A4*g - 
     6.72419695237155555e-7*A*g3 + 
     0.0000254975770848786722*A3*g2*x2 - 
     2.25056258042369153e-6*g4*x2 + 
     0.0000441438108848823135*A2*g3*x4 + 
     0.0000185871013417309714*A*g4*x6 + 
     2.15148764772607365e-6*g5*x8)*xbar2 + 
  eps8*(4.1753513975736198e-8*A5 - 
     3.46221514376276281e-6*A2*g2 + 
     0.0000267222489444711667*A4*g*x2 - 
     0.0000281804101248545693*A*g3*x2 + 
     0.0000649475909892576559*A3*g2*x4 - 
     0.0000122030666735527847*g4*x4 + 
     0.0000403965247715247715*A2*g3*x6 + 
     9.0700810463541945e-6*A*g4*x8 + 
     6.69795953360768176e-7*g5*x10)*xbar2 + 
  eps11*(-6.80612866459427306e-8*A5*g + 
     1.95584655809718057e-7*A2*g3 - 
     4.47269759439071608e-6*A4*g2*x2 + 
     1.75829988748211593e-6*A*g4*x2 - 
     0.0000133314481239415102*A3*g3*x4 + 
     9.71399147418687179e-7*g5*x4 - 
     0.0000103064498801381517*A2*g4*x6 - 
     2.82142523293179157e-6*A*g5*x8 - 
     2.4892365507720446e-7*g6*x10)*xbar2 + 
  eps10*(-1.05683802773749864e-9*A6 + 
     5.67501373552960855e-7*A3*g2 - 
     4.8511255774108832e-8*g4 - 
     3.24660642120959581e-6*A5*g*x2 + 
     9.71126169538867952e-6*A2*g3*x2 - 
     0.0000131832441790279092*A4*g2*x4 + 
     0.0000108846610427711618*A*g4*x4 - 
     0.0000136365860158849577*A3*g3*x6 + 
     2.33168885512635513e-6*g5*x6 - 
     5.4993290386188865e-6*A2*g4*x8 - 
     9.46094479080590192e-7*A*g5*x10 - 
     5.8302302889011994e-8*g6*x12)*xbar2 + 
  eps13*(6.86627585651083939e-9*A6*g - 
     4.47785160224899766e-8*A3*g3 + 
     2.19249275444418889e-9*g5 + 
     7.19946098097358602e-7*A5*g2*x2 - 
     7.80379784965903039e-7*A2*g4*x2 + 
     3.37142842641135708e-6*A4*g3*x4 - 
     1.06398186364605041e-6*A*g5*x4 + 
     4.18165456228327982e-6*A3*g4*x6 - 
     2.76351067919865578e-7*g6*x6 + 
     2.00589567077445504e-6*A2*g5*x8 + 
     4.04753308555164946e-7*A*g6*x10 + 
     2.88571475583667131e-8*g7*x12)*xbar2 + 
  eps12*(2.67650730613693577e-11*A7 - 
     8.46192910475220622e-8*A4*g2 + 
     3.25142589196534057e-8*A*g4 + 
     3.83704087407791111e-7*A6*g*x2 - 
     2.57283359783619147e-6*A3*g3*x2 + 
     1.27951218977907431e-7*g5*x2 + 
     2.41765559329216737e-6*A5*g2*x4 - 
     5.44480881814382923e-6*A2*g4*x4 + 
     3.82233569685344377e-6*A4*g3*x6 - 
     2.81139544164632672e-6*A*g5*x6 + 
     2.42710273474001612e-6*A3*g4*x8 - 
     3.92027350262991887e-7*g6*x8 + 
     7.21984500196305752e-7*A2*g5*x10 + 
     1.007566064009769e-7*A*g6*x12 + 
     5.32759708629371695e-9*g7*x14)*xbar2 + 
  eps15*(-6.94677964495491896e-10*A7*g + 
     8.85485037384606633e-9*A4*g3 - 
     1.89784940868103996e-9*A*g5 - 
     1.08873720111587578e-7*A6*g2*x2 + 
     2.58200627219967634e-7*A3*g4*x2 - 
     8.57415659878293831e-9*g6*x2 - 
     7.52178044272582197e-7*A5*g3*x4 + 
     6.39174172204870162e-7*A2*g5*x4 - 
     1.38311030669262085e-6*A4*g4*x6 + 
     3.89805821462228289e-7*A*g6*x6 - 
     1.02272071613530239e-6*A3*g5*x8 + 
     6.35874554600849527e-8*g7*x8 - 
     3.51191445940869782e-7*A2*g6*x10 - 
     5.59975947545884819e-8*A*g7*x12 - 
     3.35001083013772154e-9*g8*x14)*xbar2 + 
  eps14*(-6.77936059264516573e-13*A8 + 
     1.18453251754498057e-8*A5*g2 - 
     1.26192122113177278e-8*A2*g4 - 
     4.44292175799593582e-8*A7*g*x2 + 
     5.78235471803035281e-7*A4*g3*x2 - 
     1.25465164813262727e-7*A*g5*x2 - 
     4.11093596933471078e-7*A6*g2*x4 + 
     2.00802343589623813e-6*A3*g4*x4 - 
     8.38456228452171631e-8*g6*x4 - 
     9.37962675222683393e-7*A5*g3*x6 + 
     1.84660973293660698e-6*A2*g5*x6 - 
     8.68952732620502728e-7*A4*g4*x8 + 
     5.95974150882540242e-7*A*g6*x8 - 
     3.93789587968658131e-7*A3*g5*x10 + 
     6.11861559616332661e-8*g7*x10 - 
     9.26911580977221589e-8*A2*g6*x12 - 
     1.08851336477984649e-8*A*g7*x14 - 
     5.04016698893419468e-10*g8*x16)*xbar2 + 
  eps17*(7.03519796756268115e-11*A8*g - 
     1.58412622695254907e-9*A5*g3 + 
     9.21824723042734146e-10*A2*g5 + 
     1.57013176618403867e-8*A7*g2*x2 - 
     7.07877152349972815e-8*A4*g4*x2 + 
     1.01145514044440416e-8*A*g6*x2 + 
     1.52755677874009072e-7*A6*g3*x4 - 
     2.78303968964189299e-7*A3*g5*x4 + 
     7.90216106829461597e-9*g7*x4 + 
     3.94839847004885584e-7*A5*g4*x6 - 
     2.95546266642869418e-7*A2*g6*x6 + 
     4.1812888733216445e-7*A4*g5*x8 - 
     1.09749260429676339e-7*A*g7*x8 + 
     2.15692160440115788e-7*A3*g6*x10 - 
     1.28547064754435117e-8*g8*x10 + 
     5.73688513495873601e-8*A2*g7*x12 + 
     7.55383153004710777e-9*A*g8*x14 + 
     3.89293296941875901e-10*g9*x16)*xbar2 + 
  eps16*(1.71721241125556891e-14*A9 - 
     1.58463391176416606e-9*A6*g2 + 
     3.70687203668986364e-9*A3*g4 - 
     1.21950914958299276e-10*g6 + 
     5.06426546628202339e-9*A8*g*x2 - 
     1.15919331839795365e-7*A5*g3*x2 + 
     6.813324046201634e-8*A2*g5*x2 + 
     6.59264102615256734e-8*A7*g2*x4 - 
     6.0783143535697607e-7*A4*g4*x4 + 
     1.08734552181364072e-7*A*g6*x4 + 
     2.08077893379438207e-7*A6*g3*x6 - 
     8.7376194571684116e-7*A3*g5*x6 + 
     3.31435423816449871e-8*g7*x6 + 
     2.67286143174399604e-7*A5*g4*x8 - 
     4.84990273878282454e-7*A2*g6*x8 + 
     1.71677767909550515e-7*A4*g5*x10 - 
     1.12268658721773254e-7*A*g7*x10 + 
     6.02176056859808662e-8*A3*g6*x12 - 
     9.09453722352822717e-9*g8*x12 + 
     1.17208819972660499e-8*A2*g7*x14 + 
     1.18834173730462595e-9*A*g8*x16 + 
     4.8940576382579539e-11*g9*x18)*xbar2 + 
  eps19*(-7.12707337587569786e-12*A9*g + 
     2.63376364359160315e-10*A6*g3 - 
     3.30780046645030994e-10*A3*g5 + 
     8.03679335161609342e-12*g7 - 
     2.18139573549146275e-9*A8*g2*x2 + 
     1.6989863583308778e-8*A5*g4*x2 - 
     6.4969385102430346e-9*A2*g6*x2 - 
     2.88250590711040757e-8*A7*g3*x4 + 
     9.81072496878526138e-8*A4*g5*x4 - 
     1.18346882869724656e-8*A*g7*x4 - 
     1.00731210992033847e-7*A6*g4*x6 + 
     1.59691202088983395e-7*A3*g6*x6 - 
     4.13548363870289057e-9*g8*x6 - 
     1.45496453255537213e-7*A5*g5*x8 + 
     1.00501516554651165e-7*A2*g7*x8 - 
     1.05051610378898918e-7*A4*g6*x10 + 
     2.62399674415998082e-8*A*g8*x10 - 
     4.12244346987175346e-8*A3*g7*x12 + 
     2.38101241880130705e-9*g9*x12 - 
     8.92371773273422321e-9*A2*g8*x14 - 
     1.00013636391153993e-9*A*g9*x16 - 
     4.52724718151082609e-11*g10*x18)*xbar2 + 
  eps18*(-4.34973739711612375e-16*A10 + 
     2.04866596742209561e-10*A7*g2 - 
     9.13337973503563032e-10*A4*g4 + 
     1.29494994082815314e-10*A*g6 - 
     5.70128780114804572e-10*A9*g*x2 + 
     2.13523668994309077e-8*A6*g3*x2 - 
     2.7041278749459319e-8*A3*g5*x2 + 
     6.61136770529593115e-10*g7*x2 - 
     1.00900226220693725e-8*A8*g2*x4 + 
     1.59771473522731497e-7*A5*g4*x4 - 
     7.62149977963186539e-8*A2*g6*x4 - 
     4.26288251723329756e-8*A7*g3*x6 + 
     3.32905368200259132e-7*A4*g5*x6 - 
     5.34789893441100738e-8*A*g7*x6 - 
     7.31666710191171495e-8*A6*g4*x8 + 
     2.80197106079331506e-7*A3*g6*x8 - 
     9.98659790379859243e-9*g8*x8 - 
     6.35106992331774466e-8*A5*g5*x10 + 
     1.08995209478400767e-7*A2*g7*x10 - 
     3.09539659674895079e-8*A4*g6*x12 + 
     1.95483783519714526e-8*A*g8*x12 - 
     8.83724740598401241e-9*A3*g7*x14 + 
     1.30582050443893102e-9*g9*x14 - 
     1.46593717511110234e-9*A2*g8*x16 - 
     1.30772635674859038e-10*A*g9*x18 - 
     4.84955398928857724e-12*g10*x20)*xbar2 + 
  eps21*(7.22090117277105046e-13*A10*g - 
     4.13991085301446953e-11*A7*g3 + 
     9.76589682716262956e-11*A4*g5 - 
     1.01171462635282484e-11*A*g7 + 
     2.94059482872196453e-10*A9*g2*x2 - 
     3.68979054877682005e-9*A6*g4*x2 + 
     3.00808714445394687e-9*A3*g6*x2 - 
     5.76746247671597889e-11*g8*x2 + 
     5.12696720776491515e-9*A8*g3*x4 - 
     2.96928069363177013e-8*A5*g5*x4 + 
     9.47962261651077826e-9*A2*g7*x4 + 
     2.35049540761358863e-8*A7*g4*x6 - 
     6.88556064847354174e-8*A4*g6*x6 + 
     7.5086659172629484e-9*A*g8*x6 + 
     4.47020768444263473e-8*A6*g5*x8 - 
     6.48548347717962229e-8*A3*g7*x8 + 
     1.57872287719044645e-9*g9*x8 + 
     4.31283591778531503e-8*A5*g6*x10 - 
     2.81624636750572854e-8*A2*g8*x10 + 
     2.3304946259676748e-8*A4*g7*x12 - 
     5.6106802334762125e-9*A*g9*x12 + 
     7.34468856466444926e-9*A3*g8*x14 - 
     4.14021761190658312e-10*g10*x14 + 
     1.33841053507869873e-9*A2*g9*x16 + 
     1.30531947930356562e-10*A*g10*x18 + 
     5.26795343697585529e-12*g11*x20)*xbar2 + 
  eps20*(1.1018005656720459e-17*A11 - 
     2.57889246901160178e-11*A8*g2 + 
     1.98990234155769708e-10*A5*g4 - 
     7.55965424361672699e-11*A2*g6 + 
     6.35426896472572163e-11*A10*g*x2 - 
     3.68388963577669912e-9*A7*g3*x2 + 
     8.75177480890399108e-9*A4*g5*x2 - 
     9.11535637885301799e-10*A*g7*x2 + 
     1.48649455332149944e-9*A9*g2*x4 - 
     3.77359746051647268e-8*A6*g4*x4 + 
     3.82594204726996217e-8*A3*g6*x4 - 
     8.13304101172221063e-10*g8*x4 + 
     8.18713369443791778e-9*A8*g3*x6 - 
     1.08366523313337395e-7*A5*g5*x6 + 
     4.5944289943616577e-8*A2*g7*x6 + 
     1.82487684327326814e-8*A7*g4*x8 - 
     1.28729795350649249e-7*A4*g6*x8 + 
     1.92747318307891877e-8*A*g8*x8 + 
     2.06867607666613227e-8*A6*g5*x10 - 
     7.43763204190519753e-8*A3*g7*x10 + 
     2.53626156501045944e-9*g9*x10 + 
     1.33838352059798451e-8*A5*g6*x12 - 
     2.20494122463979174e-8*A2*g8*x12 + 
     5.23330987914141423e-9*A4*g7*x14 - 
     3.21750395058170305e-9*A*g9*x14 + 
     1.25827561244148185e-9*A3*g8*x16 - 
     1.82713361623688652e-10*g10*x16 + 
     1.81827783439828152e-10*A2*g9*x18 + 
     1.44818570824073778e-11*A*g10*x20 + 
     4.88417660313835094e-13*g11*x22)*xbar2 + 
  eps23*(-7.31620058828327886e-14*A11*g + 
     6.2244144715351518e-12*A8*g3 - 
     2.50972722113902645e-11*A5*g5 + 
     6.90195578112387954e-12*A2*g7 - 
     3.86661866535845128e-11*A10*g2*x2 + 
     7.40985528302493753e-10*A7*g4*x2 - 
     1.12263534560497836e-9*A4*g6*x2 + 
     9.10038912793887614e-11*A*g8*x2 - 
     8.68557303415569482e-10*A9*g3*x4 + 
     7.99751265225702085e-9*A6*g5*x4 - 
     5.38995025036586533e-9*A3*g7*x4 + 
     9.11682355767971334e-11*g9*x4 - 
     5.09949189194303306e-9*A8*g4*x6 + 
     2.517151280314285e-8*A5*g6*x6 - 
     7.20688202607308513e-9*A2*g8*x6 - 
     1.24293927810383763e-8*A7*g5*x8 + 
     3.30698321741881119e-8*A4*g7*x8 - 
     3.36777220246894258e-9*A*g9*x8 - 
     1.55006071785928367e-8*A6*g6*x10 + 
     2.11300984088409138e-8*A3*g8*x10 - 
     4.91764411032702861e-10*g10*x10 - 
     1.10270946906705895e-8*A5*g7*x12 + 
     6.90528529828172647e-9*A2*g9*x12 - 
     4.72730487747526667e-9*A4*g8*x14 + 
     1.10602336934435099e-9*A*g10*x14 - 
     1.24144324312375269e-9*A3*g9*x16 + 
     6.86305256373542116e-11*g11*x16 - 
     1.95159691471731057e-10*A2*g10*x18 - 
     1.68433306811216689e-11*A*g11*x20 - 
     6.13262463130406207e-13*g12*x22)*xbar2 + 
  eps22*(-2.79089293716250467e-19*A12 + 
     3.17766604095748225e-12*A9*g2 - 
     3.95577368582764204e-11*A6*g4 + 
     3.2068101326980409e-11*A3*g6 - 
     6.12076747703341304e-13*g8 - 
     7.02351204594746519e-12*A11*g*x2 + 
     6.03214212931090113e-10*A8*g3*x2 - 
     2.44702734746155151e-9*A5*g5*x2 + 
     6.76097426096149884e-10*A2*g7*x2 - 
     2.12157940796992025e-10*A10*g2*x4 + 
     8.1916797369498686e-9*A7*g4*x4 - 
     1.53944612844692757e-8*A4*g6*x4 + 
     1.38109622177934475e-9*A*g8*x4 - 
     1.49038549899160153e-9*A9*g3*x6 + 
     3.12551588277558658e-8*A6*g5*x6 - 
     2.79047223116628872e-8*A3*g7*x6 + 
     5.436847471574281e-10*g9*x6 - 
     4.21695720957640858e-9*A8*g4*x8 + 
     4.99819767239979985e-8*A5*g6*x8 - 
     1.96069567048585921e-8*A2*g8*x8 - 
     6.0820173561110201e-9*A7*g5*x10 + 
     4.00069800775570726e-8*A4*g7*x10 - 
     5.69705873785929584e-9*A*g9*x10 - 
     5.05592156438231298e-9*A6*g6*x12 + 
     1.73541009641709023e-8*A3*g8*x12 - 
     5.72444406380114732e-10*g10*x12 - 
     2.58984982240261447e-9*A5*g7*x14 + 
     4.13461348937075909e-9*A2*g9*x14 - 
     8.43540110516749951e-10*A4*g8*x16 + 
     5.07648285991122299e-10*A*g10*x16 - 
     1.75053485949267209e-10*A3*g9*x18 + 
     2.50585955675889897e-11*g11*x18 - 
     2.24065847218371337e-11*A2*g10*x20 - 
     1.61190422371025444e-12*A*g11*x22 - 
     4.98497255151051565e-14*g12*x24)*xbar2 + 
  eps25*(7.41283040826477982e-15*A12*g - 
     9.02635849548132915e-13*A9*g3 + 
     5.808192723300797e-12*A6*g5 - 
     3.38057427569094457e-12*A3*g7 + 
     5.29100393497390523e-14*g9 + 
     4.97920609040144658e-12*A11*g2*x2 - 
     1.39694069095383245e-10*A8*g4*x2 + 
     3.58402228305301032e-10*A5*g6*x2 - 
     7.65495191386971796e-11*A2*g8*x2 + 
     1.4125212696675559e-10*A10*g3*x4 - 
     1.96338748728595609e-9*A7*g5*x4 + 
     2.43765341823600507e-9*A4*g7*x4 - 
     1.73076565727920605e-10*A*g9*x4 + 
     1.04116644719005016e-9*A9*g4*x6 - 
     8.09905476228113474e-9*A6*g6*x6 + 
     4.85986711480587249e-9*A3*g8*x6 - 
     7.57303676890670029e-11*g10*x6 + 
     3.18313608725054007e-9*A8*g5*x8 - 
     1.41719309600437594e-8*A5*g7*x8 + 
     3.76671783453056944e-9*A2*g9*x8 + 
     5.00343186081653831e-9*A7*g6*x10 - 
     1.24378552441987574e-8*A4*g8*x10 + 
     1.20496661429663104e-9*A*g10*x10 + 
     4.53880717317622481e-9*A6*g7*x12 - 
     5.90571016995380991e-9*A3*g9*x12 + 
     1.32811990726503565e-10*g11*x12 + 
     2.53296660339142496e-9*A5*g8*x14 - 
     1.53532762899011833e-9*A2*g10*x14 + 
     8.96296897032458165e-10*A4*g9*x16 - 
     2.04947909641080151e-10*A*g11*x16 + 
     2.01417828995844438e-10*A3*g10*x18 - 
     1.09580840956783665e-11*g12*x18 + 
     2.78250438436826e-11*A2*g11*x20 + 
     2.15336350583630878e-12*A*g12*x22 + 
     7.14181481885948442e-14*g13*x24)*xbar2 + 
  eps24*(7.06941407925893494e-21*A13 - 
     3.84741654463843396e-13*A10*g2 + 
     7.32293254814967057e-12*A7*g4 - 
     1.10404290967107504e-11*A4*g6 + 
     8.91430430592888932e-13*A*g8 + 
     7.70933065507593765e-13*A12*g*x2 - 
     9.46392329053276403e-11*A9*g3*x2 + 
     6.12204723118016064e-10*A6*g5*x2 - 
     3.57786436948859923e-10*A3*g7*x2 + 
     5.61900352465916136e-12*g9*x2 + 
     2.94794501076642169e-11*A11*g2*x4 - 
     1.66054285997922112e-9*A8*g4*x4 + 
     5.27270026858442259e-9*A5*g6*x4 - 
     1.24441828714339168e-9*A2*g8*x4 + 
     2.5932143768735243e-10*A10*g3*x6 - 
     8.18440975363309936e-9*A7*g5*x6 + 
     1.34316391603932223e-8*A4*g7*x6 - 
     1.0967577860615365e-9*A*g9*x6 + 
     9.14099216298559597e-10*A9*g4*x8 - 
     1.70303761165690513e-8*A6*g6*x8 + 
     1.39743392988134275e-8*A3*g8*x8 - 
     2.56275349412587196e-10*g10*x8 + 
     1.64295978902062036e-9*A8*g5*x10 - 
     1.80454719563725777e-8*A5*g7*x10 + 
     6.69540001883729058e-9*A2*g9*x10 + 
     1.71211385785801628e-9*A7*g6*x12 - 
     1.06969476032442112e-8*A4*g8*x12 + 
     1.46666897500527102e-9*A*g10*x12 + 
     1.11324562362569516e-9*A6*g7*x14 - 
     3.68698661561997461e-9*A3*g9*x14 + 
     1.18497108911150463e-10*g11*x14 + 
     4.70206598723156244e-10*A5*g8*x16 - 
     7.32089723755050849e-10*A2*g10*x16 + 
     1.31051469702399336e-10*A4*g9*x18 - 
     7.74991097074319971e-11*A*g11*x18 + 
     2.39115858864581722e-11*A3*g10*x20 - 
     3.38215281496470102e-12*g12*x20 + 
     2.74671447656417087e-12*A2*g11*x22 + 
     1.80167001235699906e-13*A*g12*x24 + 
     5.14468471968218436e-15*g13*x26)*xbar2 + 
  eps26*(-1.79070348540750937e-22*A14 + 
     4.59064378043914658e-14*A11*g2 - 
     1.28030566526092309e-12*A8*g4 + 
     3.27066666352992692e-12*A5*g6 - 
     6.96122544470052509e-13*A2*g8 - 
     8.41204536665769716e-14*A13*g*x2 + 
     1.43280455193797042e-11*A10*g3*x2 - 
     1.40273974291259099e-10*A7*g5*x2 + 
     1.51283231860462901e-10*A4*g7*x2 - 
     9.98551158367175128e-12*A*g9*x2 - 
     4.00333440491699611e-12*A12*g2*x4 + 
     3.18015053542555029e-10*A9*g4*x4 - 
     1.59520735961063233e-9*A6*g6*x4 + 
     7.90439808401736791e-10*A3*g8*x4 - 
     1.10881173257059828e-11*g10*x4 - 
     4.34093541154382073e-11*A11*g3*x6 + 
     1.97976173597291254e-9*A8*g5*x6 - 
     5.44840751323234817e-9*A5*g7*x6 + 
     1.16297756207798465e-9*A2*g9*x6 - 
     1.87645728811177992e-10*A10*g4*x8 + 
     5.22333666100318922e-9*A7*g6*x8 - 
     7.83026501022594579e-9*A4*g8*x8 + 
     5.98605008455371809e-10*A*g10*x8 - 
     4.13221853558421767e-10*A9*g5*x10 + 
     7.0930748517934503e-9*A6*g7*x10 - 
     5.47699171024144332e-9*A3*g9*x10 + 
     9.60336772604947622e-11*g11*x10 - 
     5.29402656244831828e-10*A8*g6*x12 + 
     5.49671855849442248e-9*A5*g8*x12 - 
     1.95523008426311717e-9*A2*g10*x12 - 
     4.26701447988946737e-10*A7*g7*x14 + 
     2.56206141566278962e-9*A4*g9*x14 - 
     3.410012726945875e-10*A*g11*x14 - 
     2.26624447643405895e-10*A6*g8*x16 + 
     7.29466473293570049e-10*A3*g10*x16 - 
     2.29576353915048113e-11*g12*x16 - 
     8.12511797350192351e-11*A5*g9*x18 + 
     1.23935273887572293e-10*A2*g11*x18 - 
     1.97726428661170689e-11*A4*g10*x20 + 
     1.1522889199786472e-11*A*g12*x20 - 
     3.21807538962660607e-12*A3*g11*x22 + 
     4.50555068931041406e-13*g13*x22 - 
     3.35257433966932062e-13*A2*g12*x24 - 
     2.02087347024185195e-14*A*g13*x26 - 
     5.35972002923398376e-16*g14*x28)*xbar2 + 
  0.00833333333333333333*g*xbar4 - 
  0.0000462962962962962963*eps3*g2*xbar4 + 
  eps2*(-0.000396825396825396825*A*g - 
     0.000694444444444444444*g2*x2)*xbar4 + 
  eps5*(9.11896745230078563e-6*A*g2 + 
     0.0000308641975308641975*g3*x2)*xbar4 + 
  eps4*(0.0000198412698412698413*A2*g + 
     0.000195105820105820106*A*g2*x2 + 
     0.0000617283950617283951*g3*x4)*xbar4 + 
  eps7*(-1.31581381581381581e-6*A2*g2 - 
     0.0000151318588818588819*A*g3*x2 - 
     6.8455207344096233e-6*g4*x4)*xbar4 + 
  eps6*(-9.01875901875901876e-7*A3*g + 
     9.90714532381199048e-7*g3 - 
     0.0000389059243225909893*A2*g2*x2 - 
     0.0000351397573619795842*A*g3*x4 - 
     5.9477880658436214e-6*g4*x6)*xbar4 + 
  eps9*(1.71045640622360199e-7*A3*g2 - 
     3.60906857706966639e-8*g4 + 
     4.53245406122390249e-6*A2*g3*x2 + 
     5.38783061931210079e-6*A*g4*x4 + 
     1.17492514772607365e-6*g5*x6)*xbar4 + 
  eps8*(3.77616945077262538e-8*A4*g - 
     3.91505723846993688e-7*A*g3 + 
     6.55938527962337486e-6*A3*g2*x2 - 
     1.61985166325444103e-6*g4*x2 + 
     0.0000121547079219036891*A2*g3*x4 + 
     5.20508405346368309e-6*A*g4*x6 + 
     6.02301130368259998e-7*g5*x8)*xbar4 + 
  eps11*(-2.12135350797297057e-8*A4*g2 + 
     2.14460056215349951e-8*A*g4 - 
     1.06401470496877178e-6*A3*g3*x2 + 
     9.9419658966568008e-8*g5*x2 - 
     2.4228308825712602e-6*A2*g4*x4 - 
     1.28380796826126347e-6*A*g5*x6 - 
     1.80516340332649186e-7*g6*x8)*xbar4 + 
  eps10*(-1.48202033122668043e-9*A5*g + 
     9.77137892841674354e-8*A2*g3 - 
     9.98537198520664129e-7*A4*g2*x2 + 
     1.12096864298613054e-6*A*g4*x2 - 
     3.25929867376075489e-6*A3*g3*x4 + 
     6.52088831782005348e-7*g5*x4 - 
     2.59007734102806854e-6*A2*g4*x6 - 
     7.14333704061713321e-7*A*g5*x8 - 
     6.28878290312510992e-8*g6*x10)*xbar4 + 
  eps13*(2.55551047231023315e-9*A5*g2 - 
     7.48454109323006102e-9*A2*g4 + 
     2.14869723911233424e-7*A4*g3*x2 - 
     8.87037184673700903e-8*A*g5*x2 + 
     8.1367411096167446e-7*A3*g4*x4 - 
     6.24554324051377381e-8*g6*x4 + 
     7.73534185148061632e-7*A2*g5*x6 + 
     2.53114332805174734e-7*A*g6*x8 + 
     2.60907174059342559e-8*g7*x10)*xbar4 + 
  eps12*(5.52620037914155561e-11*A6*g - 
     1.96395897468419557e-8*A3*g3 + 
     1.73105497543500998e-9*g5 + 
     1.41930118072774209e-7*A5*g2*x2 - 
     4.4751871911848506e-7*A2*g4*x2 + 
     7.4329679752095632e-7*A4*g3*x4 - 
     6.48579919839268283e-7*A*g5*x4 + 
     9.56849686940199225e-7*A3*g4*x6 - 
     1.72592309647809413e-7*g6*x6 + 
     4.6549037372399414e-7*A2*g5*x8 + 
     9.4234108977460504e-8*A*g6*x10 + 
     6.6997976279157566e-9*g7*x12)*xbar4 + 
  eps15*(-3.01110179246578381e-10*A6*g2 + 
     1.99854473307210245e-9*A3*g4 - 
     1.0075222178954846e-10*g6 - 
     3.91236879782746971e-8*A5*g3*x2 + 
     4.42468326545839399e-8*A2*g5*x2 - 
     2.26449722207185509e-7*A4*g4*x4 + 
     7.48610321580336637e-8*A*g6*x4 - 
     3.38794481457344831e-7*A3*g5*x6 + 
     2.34467193453680488e-8*g7*x6 - 
     1.91586076465687549e-7*A2*g6*x8 - 
     4.4705147415174641e-8*A*g7*x10 - 
     3.62790374951045814e-9*g8*x12)*xbar4 + 
  eps14*(-1.97753534590218582e-12*A7*g + 
     3.46651613447685113e-9*A4*g3 - 
     1.3675698718070872e-9*A*g5 - 
     1.92080361104674656e-8*A6*g2*x2 + 
     1.34714593349386061e-7*A3*g4*x2 - 
     7.0165116069938331e-9*g6*x2 - 
     1.51234778678998732e-7*A5*g3*x4 + 
     3.57677410764887609e-7*A2*g5*x4 - 
     2.9119323970204683e-7*A4*g4*x6 + 
     2.24757818721415644e-7*A*g6*x6 - 
     2.19654624683123427e-7*A3*g5*x8 + 
     3.71577620957842484e-8*g7*x8 - 
     7.60245440599503551e-8*A2*g6*x10 - 
     1.21363875909823901e-8*A*g7*x12 - 
     7.23898306636066601e-10*g8*x14)*xbar4 + 
  eps17*(3.48460743277465292e-11*A7*g2 - 
     4.51506468378503526e-10*A4*g4 + 
     9.93046484625324211e-11*A*g6 + 
     6.6025042810186813e-9*A6*g3*x2 - 
     1.62520631488663842e-8*A3*g5*x2 + 
     5.61230122018474251e-10*g7*x2 + 
     5.51380920101008308e-8*A5*g4*x4 - 
     4.88479275078761747e-8*A2*g6*x4 + 
     1.20320332856371923e-7*A4*g5*x6 - 
     3.5365653527819202e-8*A*g7*x6 + 
     1.03628614951869648e-7*A3*g6*x8 - 
     6.71263413921269682e-9*g8*x8 + 
     4.07776601703241782e-8*A2*g7*x10 + 
     7.34880420888892836e-9*A*g8*x12 + 
     4.91163816649064884e-10*g9*x14)*xbar4 + 
  eps16*(6.84233044511131468e-14*A8*g - 
     5.60464705059266925e-10*A5*g3 + 
     6.1113506912043867e-10*A2*g5 + 
     2.50582201503812155e-9*A7*g2*x2 - 
     3.39024845059116986e-8*A4*g4*x2 + 
     7.66141086125169516e-9*A*g6*x2 + 
     2.82533097805425257e-8*A6*g3*x4 - 
     1.44153074493338505e-7*A3*g5*x4 + 
     6.29165697711773721e-9*g7*x4 + 
     7.70955531949116842e-8*A5*g4*x6 - 
     1.5856345215569678e-7*A2*g6*x6 + 
     8.37319173204484218e-8*A4*g5*x8 - 
     5.99155536147365961e-8*A*g7*x8 + 
     4.37139891312553985e-8*A3*g6*x10 - 
     7.07392441584795305e-9*g8*x10 + 
     1.16805756794796047e-8*A2*g7*x12 + 
     1.53807088851897092e-9*A*g8*x14 + 
     7.90314013633620188e-11*g9*x16)*xbar4 + 
  eps19*(-3.97340865876564659e-12*A8*g2 + 
     9.08389634660042267e-11*A5*g4 - 
     5.40989729447639056e-11*A2*g6 - 
     1.05114495716806379e-9*A7*g3*x2 + 
     4.89773729086143515e-9*A4*g5*x2 - 
     7.24791876301819899e-10*A*g7*x2 - 
     1.21370267986698838e-8*A6*g4*x4 + 
     2.29597017376750524e-8*A3*g6*x4 - 
     6.7748721115604107e-10*g8*x4 - 
     3.67138156717417151e-8*A5*g5*x6 + 
     2.85584385486008741e-8*A2*g7*x6 - 
     4.48093489348219503e-8*A4*g6*x8 + 
     1.22153837054061484e-8*A*g8*x8 - 
     2.6272947304230525e-8*A3*g7*x10 + 
     1.62436680861277498e-9*g9*x10 - 
     7.84757421369128482e-9*A2*g8*x12 - 
     1.1484952449755475e-9*A*g9*x14 - 
     6.52079226899128072e-11*g10*x16)*xbar4 + 
  eps18*(-2.30220514713186019e-15*A9*g + 
     8.50336672523331952e-11*A6*g3 - 
     2.03099120170330866e-10*A3*g5 + 
     6.86599038065945835e-12*g7 - 
     3.17730510813967685e-10*A8*g2*x2 + 
     7.52334651318304606e-9*A5*g4*x2 - 
     4.58441975864061026e-9*A2*g6*x2 - 
     4.93856631341031329e-9*A7*g3*x4 + 
     4.73460373170155555e-8*A4*g5*x4 - 
     8.81541701496240287e-9*A*g7*x4 - 
     1.83568265106518087e-8*A6*g4*x6 + 
     8.0214964397589886e-8*A3*g6*x6 - 
     3.16831385872351314e-9*g8*x6 - 
     2.73264771648576643e-8*A5*g5*x8 + 
     5.15584868924249984e-8*A2*g7*x8 - 
     2.00422243527645685e-8*A4*g6*x10 + 
     1.36105580520898305e-8*A*g8*x10 - 
     7.92549659107905268e-9*A3*g7*x12 + 
     1.24112226442452554e-9*g9*x12 - 
     1.72024465137340275e-9*A2*g8*x14 - 
     1.92684278620064115e-10*A*g9*x16 - 
     8.69704747258045207e-12*g10*x18)*xbar4 + 
  eps21*(4.47608018566873029e-13*A9*g2 - 
     1.67753308125991472e-11*A6*g4 + 
     2.15143559796472255e-11*A3*g6 - 
     5.36097713439665228e-13*g8 + 
     1.59789748504864926e-10*A8*g3*x2 - 
     1.28169491309084248e-9*A5*g5*x2 + 
     5.05873112365848404e-10*A2*g7*x2 + 
     2.46793239696357667e-9*A7*g4*x4 - 
     8.69126604407042738e-9*A4*g6*x4 + 
     1.08592337487209441e-9*A*g8*x4 + 
     9.97215933211799948e-9*A6*g5*x6 - 
     1.63775632230861457e-8*A3*g7*x6 + 
     4.39638545658591092e-10*g9*x6 + 
     1.6446217893554322e-8*A5*g6*x8 - 
     1.17661894622675905e-8*A2*g8*x8 + 
     1.33981457517207347e-8*A4*g7*x10 - 
     3.46334251627866228e-9*A*g9*x10 + 
     5.87002262267861254e-9*A3*g8*x12 - 
     3.50481841251753294e-10*g10*x12 + 
     1.40564140813720233e-9*A2*g9*x14 + 
     1.72885003376200776e-10*A*g10*x16 + 
     8.52860757101693105e-12*g11*x18)*xbar4 + 
  eps20*(7.56595105695415785e-17*A10*g - 
     1.22932630659041053e-11*A7*g3 + 
     5.58459887241763578e-11*A4*g5 - 
     8.11455810014543089e-12*A*g7 + 
     3.9383320785984906e-11*A9*g2*x2 - 
     1.51976152664836327e-9*A6*g4*x2 + 
     1.98780657022334646e-9*A3*g6*x2 - 
     5.0284224652211995e-11*g8*x2 + 
     8.18366713361052766e-10*A8*g3*x4 - 
     1.34227304693417849e-8*A5*g5*x4 + 
     6.6399136914675485e-9*A2*g7*x4 + 
     4.01847928057574067e-9*A7*g4*x6 - 
     3.25458326731869081e-8*A4*g6*x6 + 
     5.42627614195641677e-9*A*g8*x6 + 
     7.91216320845347941e-9*A6*g5*x8 - 
     3.14137939839749592e-8*A3*g7*x8 + 
     1.16149233526855299e-9*g9*x8 + 
     7.7806358292877523e-9*A5*g6*x10 - 
     1.38304354148956577e-8*A2*g8*x10 + 
     4.24844294383596806e-9*A4*g7*x12 - 
     2.77563538429180564e-9*A*g9*x12 + 
     1.34573608785890679e-9*A3*g8*x14 - 
     2.05451606449403644e-10*g10*x14 + 
     2.45603481008104843e-10*A2*g9*x16 + 
     2.39299395598715992e-11*A*g10*x18 + 
     9.63092387870827136e-13*g11*x20)*xbar4 + 
  eps23*(-4.99202514118831333e-14*A10*g2 + 
     2.89962490735076355e-12*A7*g4 - 
     6.97186084528071566e-12*A4*g6 + 
     7.39113581154999613e-13*A*g8 - 
     2.3394917837884362e-11*A9*g3*x2 + 
     3.01433272680195764e-10*A6*g5*x2 - 
     2.52901008371964216e-10*A3*g7*x2 + 
     4.9975823717035003e-12*g9*x2 - 
     4.70635007764103411e-10*A8*g4*x4 + 
     2.81182652238779472e-9*A5*g6*x4 - 
     9.27102400382163909e-10*A2*g8*x4 - 
     2.46882746644613326e-9*A7*g5*x6 + 
     7.47170357614364372e-9*A4*g7*x6 - 
     8.42342156242855593e-10*A*g9*x6 - 
     5.31658207824290054e-9*A6*g6*x8 + 
     7.96948615558779495e-9*A3*g8*x8 - 
     2.00535355872142721e-10*g10*x8 - 
     5.74925362613453206e-9*A5*g7*x10 + 
     3.87667862850608752e-9*A2*g9*x10 - 
     3.44992473074412105e-9*A4*g8*x12 + 
     8.569346015302056e-10*A*g10*x12 - 
     1.19748784968841458e-9*A3*g9*x14 + 
     6.95772409909226155e-11*g11*x14 - 
     2.38602512157003406e-10*A2*g10*x16 - 
     2.52826017059561289e-11*A*g11*x18 - 
     1.10236531866119468e-12*g12*x20)*xbar4 + 
  eps22*(-2.43710422261727909e-18*A11*g + 
     1.71109183419778529e-12*A8*g3 - 
     1.34309072457408887e-11*A5*g5 + 
     5.2173544345517194e-12*A2*g7 - 
     4.7920869812117813e-12*A10*g2*x2 + 
     2.85329265230758798e-10*A7*g4*x2 - 
     6.97857430562307631e-10*A4*g6*x2 + 
     7.49694255924035744e-11*A*g8*x2 - 
     1.29794915911680679e-10*A9*g3*x4 + 
     3.40176751053615467e-9*A6*g5*x4 - 
     3.56524460909925476e-9*A3*g7*x4 + 
     7.84071353306302568e-11*g9*x4 - 
     8.21445917536130217e-10*A8*g4*x6 + 
     1.12426357550003378e-8*A5*g6*x6 - 
     4.93283496356209241e-9*A2*g8*x6 - 
     2.08160234188537877e-9*A7*g5*x8 + 
     1.51837246414786265e-8*A4*g7*x8 - 
     2.35241679748374184e-9*A*g9*x8 - 
     2.65426623474241136e-9*A6*g6*x10 + 
     9.86143500745746335e-9*A3*g8*x10 - 
     3.47704012872899376e-10*g10*x10 - 
     1.91288185358486004e-9*A5*g7*x12 + 
     3.25348485105233778e-9*A2*g9*x12 - 
     8.26008166150946402e-10*A4*g8*x14 + 
     5.23734714713970356e-10*A*g10*x14 - 
     2.17662681277754724e-10*A3*g9*x16 + 
     3.25604627396838786e-11*g11*x16 - 
     3.42430735395904115e-11*A2*g10*x18 - 
     2.95184625537922171e-12*A*g11*x20 - 
     1.07193479659543963e-13*g12*x22)*xbar4 + 
  eps25*(5.52110506767784823e-15*A11*g2 - 
     4.75457501278592475e-13*A8*g4 + 
     1.95091086985767411e-12*A5*g6 - 
     5.4799904221049527e-13*A2*g8 + 
     3.32019238817893755e-12*A10*g3*x2 - 
     6.51730724398874192e-11*A7*g5*x2 + 
     1.01363516265109903e-10*A4*g7*x2 - 
     8.44789910534162239e-12*A*g9*x2 + 
     8.51083543466993974e-11*A9*g4*x4 - 
     8.06323901456713728e-10*A6*g6*x4 + 
     5.59802124945716162e-10*A3*g8*x4 - 
     9.76067472405711475e-12*g10*x4 + 
     5.66519419429771184e-10*A8*g5*x6 - 
     2.8819770278242875e-9*A5*g7*x6 + 
     8.51033871024505535e-10*A2*g9*x6 + 
     1.55194749123254554e-9*A7*g6*x8 - 
     4.25684634896380492e-9*A4*g8*x8 + 
     4.47161048996184315e-10*A*g10*x8 + 
     2.15624685611586417e-9*A6*g7*x10 - 
     3.0292495877704562e-9*A3*g9*x10 + 
     7.26885557001226871e-11*g11*x10 + 
     1.69504305032585424e-9*A5*g8*x12 - 
     1.09320524328573703e-9*A2*g10*x12 + 
     7.97072138471286562e-10*A4*g9*x14 - 
     1.91910963351846343e-10*A*g11*x14 + 
     2.28095958403189066e-10*A3*g10*x16 - 
     1.29653228354651865e-11*g12*x16 + 
     3.88462248089520305e-11*A2*g11*x18 + 
     3.61325068184705851e-12*A*g12*x20 + 
     1.41129299633557724e-13*g13*x22)*xbar4 + 
  eps24*(7.71585736870360985e-20*A12*g - 
     2.30992258376006814e-13*A9*g3 + 
     2.92102366881800346e-12*A6*g5 - 
     2.41669954412293445e-12*A3*g7 + 
     4.72216204539068631e-14*g9 + 
     5.74184634945686335e-13*A11*g2*x2 - 
     5.05105154346589262e-11*A8*g4*x2 + 
     2.10380593488870381e-10*A5*g6*x2 - 
     5.97933596683359805e-11*A2*g8*x2 + 
     1.98448558495321466e-11*A10*g3*x4 - 
     7.88832679162696204e-10*A7*g5*x4 + 
     1.52819851860648456e-9*A4*g7*x4 - 
     1.41460420089467831e-10*A*g9*x4 + 
     1.58609533764471402e-10*A9*g4*x6 - 
     3.43038983424224915e-9*A6*g6*x6 + 
     3.16143488249608422e-9*A3*g8*x6 - 
     6.36135955205512617e-11*g10*x6 + 
     5.0613788167530953e-10*A8*g5*x8 - 
     6.18873950256648937e-9*A5*g7*x8 + 
     2.5062720440597051e-9*A2*g9*x8 + 
     8.15831547687990564e-10*A7*g6*x10 - 
     5.53396691054777854e-9*A4*g8*x10 + 
     8.13144274490680289e-10*A*g10*x10 + 
     7.51495225003727191e-10*A6*g7*x12 - 
     2.65804849164409833e-9*A3*g9*x12 + 
     9.04010499952531028e-11*g11*x12 + 
     4.23273801532746854e-10*A5*g8*x14 - 
     6.95727565670343238e-10*A2*g10*x14 + 
     1.50552227564369774e-10*A4*g9*x16 - 
     9.31966125875092865e-11*A*g11*x16 + 
     3.39107891271974624e-11*A3*g10*x18 - 
     4.98855443293551953e-12*g12*x18 + 
     4.68573921494252176e-12*A2*g11*x20 + 
     3.62148289824228147e-13*A*g12*x22 + 
     1.1980881282823611e-14*g13*x24)*xbar4 - 
  0.0000154320987654320988*eps2*g2*xbar6 + 
  3.56125356125356125e-7*eps5*g3*xbar6 + 
  eps4*(1.90396023729357063e-6*A*g2 + 
     7.71604938271604938e-6*g3*x2)*xbar6 + 
  eps7*(-1.06760523427190094e-7*A*g3 - 
     5.83649889205444761e-7*g4*x2)*xbar6 + 
  eps6*(-1.58222876476844731e-7*A2*g2 - 
     3.0990100434544879e-6*A*g3*x2 - 
     1.45170544476100032e-6*g4*x4)*xbar6 + 
  eps9*(2.10474956623416007e-8*A2*g3 + 
     3.52066889376257568e-7*A*g4*x2 + 
     2.15683591284989252e-7*g5*x4)*xbar6 + 
  eps8*(1.0639753805538638e-8*A3*g2 - 
     1.44647796358943781e-8*g4 + 
     7.89019059521705024e-7*A2*g3*x2 + 
     9.93278626380478232e-7*A*g4*x4 + 
     2.19830466744046991e-7*g5*x6)*xbar6 + 
  eps11*(-3.48009271425128996e-9*A3*g3 + 
     7.74456172615070677e-10*g5 - 
     1.24759056081950737e-7*A2*g4*x2 - 
     1.93124743183608916e-7*A*g5*x4 - 
     5.26262283781649553e-8*g6*x6)*xbar6 + 
  eps10*(-6.21784885258793341e-10*A4*g2 + 
     7.35917308458240036e-9*A*g4 - 
     1.61082849737015107e-7*A3*g3*x2 + 
     4.25042008023580282e-8*g5*x2 - 
     3.97181909847740069e-7*A2*g4*x4 - 
     2.15693489113968417e-7*A*g5*x6 - 
     3.05361793587726322e-8*g6*x8)*xbar6 + 
  eps13*(5.22929181665348026e-10*A4*g3 - 
     5.49761548927799316e-10*A*g5 + 
     3.37795673591345898e-8*A3*g4*x2 - 
     3.32362369023656752e-9*g6*x2 + 
     9.70864128827426103e-8*A2*g5*x4 + 
     6.29082935052959515e-8*A*g6*x6 + 
     1.05359214957493409e-8*g7*x8)*xbar6 + 
  eps12*(3.28023733515722384e-11*A5*g2 - 
     2.2483490443839068e-9*A2*g4 + 
     2.87554439944054822e-8*A4*g3*x2 - 
     3.41643318587639607e-8*A*g5*x2 + 
     1.20413081223750724e-7*A3*g4*x4 - 
     2.54382194661358481e-8*g6*x4 + 
     1.18403247344882478e-7*A2*g5*x6 + 
     3.92485363936068314e-8*A*g6*x8 + 
     4.05810532585570662e-9*g7*x10)*xbar6 + 
  eps15*(-7.38610165433134699e-11*A5*g3 + 
     2.23185618064230175e-10*A2*g5 - 
     7.72550467360774725e-9*A4*g4*x2 + 
     3.33675225731002428e-9*A*g6*x2 - 
     3.60024022499056884e-8*A3*g5*x4 + 
     2.89391686340197044e-9*g7*x4 - 
     4.11034234008140627e-8*A2*g6*x6 - 
     1.58061594311664227e-8*A*g7*x8 - 
     1.88044966020543737e-9*g8*x10)*xbar6 + 
  eps14*(-1.59924972891624396e-12*A6*g2 + 
     5.34559467656326695e-10*A3*g4 - 
     4.89531412255654985e-11*g6 - 
     4.68743656687813986e-9*A5*g3*x2 + 
     1.55203340852120435e-8*A2*g5*x2 - 
     3.05848967636635251e-8*A4*g4*x4 + 
     2.80191583068273077e-8*A*g6*x4 - 
     4.77391188802852923e-8*A3*g5*x6 + 
     9.0249644584421326e-9*g7*x6 - 
     2.7500470429085428e-8*A2*g6*x8 - 
     6.46467617732357999e-9*A*g7*x10 - 
     5.25206836466407194e-10*g8*x12)*xbar6 + 
  eps17*(9.97455222947976728e-12*A6*g3 - 
     6.79725936335510667e-11*A3*g5 + 
     3.53973893285757087e-12*g7 + 
     1.57106382527547975e-9*A5*g4*x2 - 
     1.84906281043290629e-9*A2*g6*x2 + 
     1.0959810274248971e-8*A4*g5*x4 - 
     3.77750956813660573e-9*A*g7*x4 + 
     1.93914172243944712e-8*A3*g6*x6 - 
     1.39852236310538808e-9*g8*x6 + 
     1.27378874003962749e-8*A2*g7*x8 + 
     3.39967157316226349e-9*A*g8*x10 + 
     3.11454821672654227e-10*g9*x12)*xbar6 + 
  eps16*(7.32043787188737753e-14*A7*g2 - 
     1.08932623361419343e-10*A4*g4 + 
     4.43882953795228996e-11*A*g6 + 
     7.1553877265847084e-10*A6*g3*x2 - 
     5.23629960443907472e-9*A3*g5*x2 + 
     2.84608830720512483e-10*g7*x2 + 
     6.85430762519816909e-9*A5*g4*x4 - 
     1.69359418456327738e-8*A2*g6*x4 + 
     1.57308771746978335e-8*A4*g5*x6 - 
     1.26738239683828291e-8*A*g7*x6 + 
     1.38726146998630169e-8*A3*g6*x8 - 
     2.44574523622132431e-9*g8*x8 + 
     5.52081375700205184e-9*A2*g7*x10 + 
     9.99298373572599506e-10*A*g8*x12 + 
     6.67917519196695508e-11*g9*x14)*xbar6 + 
  eps19*(-1.30114590146037234e-12*A7*g3 + 
     1.72511713934239417e-11*A4*g5 - 
     3.90436685140620179e-12*A*g7 - 
     2.92867814057581221e-10*A6*g4*x2 + 
     7.46902977877224456e-10*A3*g6*x2 - 
     2.67522864508407854e-11*g8*x2 - 
     2.89699505443225961e-9*A5*g5*x4 + 
     2.66562938868512264e-9*A2*g7*x4 - 
     7.37795565467524207e-9*A4*g6*x6 + 
     2.25247153971908075e-9*A*g8*x6 - 
     7.30651817416318482e-9*A3*g7*x8 + 
     4.91176292870876797e-10*g9*x8 - 
     3.26224960924321828e-9*A2*g8*x10 - 
     6.59449314458554338e-10*A*g9*x12 - 
     4.89514760970749125e-11*g10*x14)*xbar6 + 
  eps18*(-3.18177848990088646e-15*A8*g2 + 
     1.99695443999379049e-11*A5*g4 - 
     2.23943125358944015e-11*A2*g6 - 
     1.03933552034436454e-10*A7*g3*x2 + 
     1.45959832999336206e-9*A4*g5*x2 - 
     3.42631031918890525e-10*A*g7*x2 - 
     1.39812800630481225e-9*A6*g4*x4 + 
     7.42096889844293084e-9*A3*g6*x4 - 
     3.37099552457525213e-10*g8*x4 - 
     4.48155653124553849e-9*A5*g5*x6 + 
     9.58666614025997167e-9*A2*g7*x6 - 
     5.62734416286699799e-9*A4*g6*x8 + 
     4.18363357640745376e-9*A*g8*x8 - 
     3.34880212849529458e-9*A3*g7*x10 + 
     5.62255597605531686e-10*g9*x10 - 
     1.00758346454303337e-9*A2*g8*x12 - 
     1.478403576160079e-10*A*g9*x14 - 
     8.38903736074731077e-12*g10*x16)*xbar6 + 
  eps21*(1.65107570494289514e-13*A8*g3 - 
     3.85243170234057994e-12*A5*g5 + 
     2.35361375548192462e-12*A2*g7 + 
     5.10417794581330247e-11*A7*g4*x2 - 
     2.45495411183393324e-10*A4*g6*x2 + 
     3.75511182588112891e-11*A*g8*x2 + 
     6.87936705237642027e-10*A6*g5*x4 - 
     1.34714877461804848e-9*A3*g7*x4 + 
     4.11758068629525797e-11*g9*x4 + 
     2.400949695111526e-9*A5*g6*x6 - 
     1.93419604503727388e-9*A2*g8*x6 + 
     3.33918824376270404e-9*A4*g7*x8 - 
     9.42270610564786763e-10*A*g9*x8 + 
     2.20558587287283118e-9*A3*g8*x10 - 
     1.41026346318580081e-10*g10*x10 + 
     7.34671001558905886e-10*A2*g9*x12 + 
     1.18846098758935012e-10*A*g10*x14 + 
     7.4012085886463764e-12*g11*x16)*xbar6 + 
  eps20*(1.32423923182168128e-16*A9*g2 - 
     3.38762545168358761e-12*A6*g4 + 
     8.2936742090468515e-12*A3*g6 - 
     2.88553271599458446e-13*g8 + 
     1.45206721816612312e-11*A8*g3*x2 - 
     3.55365267771350475e-10*A5*g5*x2 + 
     2.24067642028217925e-10*A2*g7*x2 + 
     2.64931375976082846e-10*A7*g4*x4 - 
     2.63256077540054192e-9*A4*g6*x4 + 
     5.08380778036583002e-10*A*g8*x4 + 
     1.14232293931335993e-9*A6*g5*x6 - 
     5.17535342835764208e-9*A3*g7*x6 + 
     2.12052573958312186e-10*g9*x6 + 
     1.94686955319541028e-9*A5*g6*x8 - 
     3.80593235862788058e-9*A2*g8*x8 + 
     1.61506335347690598e-9*A4*g7*x10 - 
     1.13519934804077239e-9*A*g9*x10 + 
     7.1467043552215311e-10*A3*g8*x12 - 
     1.15698350133799093e-10*g10*x12 + 
     1.719691436452393e-10*A2*g9*x14 + 
     2.11817828858919301e-11*A*g10*x16 + 
     1.0439296901669795e-12*g11*x18)*xbar6 + 
  eps23*(-2.04862878355181306e-14*A9*g3 + 
     7.81972174797918537e-13*A6*g5 - 
     1.02619259166044427e-12*A3*g7 + 
     2.62433518896336934e-14*g9 - 
     8.43060024092694187e-12*A8*g4*x2 + 
     6.95862769500813447e-11*A5*g6*x2 - 
     2.83043426411699199e-11*A2*g8*x2 - 
     1.50105719428983393e-10*A7*g5*x4 + 
     5.45631016826002967e-10*A4*g7*x4 - 
     7.04209555461881305e-11*A*g9*x4 - 
     6.92804131934363177e-10*A6*g6*x6 + 
     1.17532183940399869e-9*A3*g8*x6 - 
     3.2607052539653876e-11*g10*x6 - 
     1.29157220680419803e-9*A5*g7*x8 + 
     9.54295239973687871e-10*A2*g9*x8 - 
     1.17766893656649956e-9*A4*g8*x10 + 
     3.14180951036205697e-10*A*g10*x10 - 
     5.72342109737974456e-10*A3*g9*x12 + 
     3.52378082126753302e-11*g11*x12 - 
     1.50826983016266947e-10*A2*g10*x14 - 
     2.0272522360825874e-11*A*g11*x16 - 
     1.08615017352219442e-12*g12*x18)*xbar6 + 
  eps22*(-5.31170301889157885e-18*A10*g2 + 
     5.41512008345912225e-13*A7*g4 - 
     2.51484843977932421e-12*A4*g6 + 
     3.74997952559516213e-13*A*g8 - 
     1.96622519209470769e-12*A9*g3*x2 + 
     7.81432830846281016e-11*A6*g5*x2 - 
     1.0541243620224235e-10*A3*g7*x2 + 
     2.75343063440850494e-12*g9*x2 - 
     4.73066561901215884e-11*A8*g4*x4 + 
     8.01663669414465443e-10*A5*g6*x4 - 
     4.10061241924541413e-10*A2*g8*x4 - 
     2.66530256112802594e-10*A7*g5*x6 + 
     2.23182456344329143e-9*A4*g7*x6 - 
     3.84966796590767183e-10*A*g9*x6 - 
     5.95626630491287062e-10*A6*g6*x8 + 
     2.44421723666841458e-9*A3*g8*x8 - 
     9.34592147729657581e-11*g10*x8 - 
     6.57899358910793091e-10*A5*g7*x10 + 
     1.20777680989039448e-9*A2*g9*x10 - 
     3.99711629253997661e-10*A4*g8*x12 + 
     2.69443230465710687e-10*A*g10*x12 - 
     1.39709228180795027e-10*A3*g9*x14 + 
     2.19843031752725675e-11*g11*x14 - 
     2.79291327736950798e-11*A2*g10*x16 - 
     2.96151288108938101e-12*A*g11*x18 - 
     1.2897624149994603e-13*g12*x20)*xbar6 + 
  eps24*(2.06387813484462373e-19*A11*g2 - 
     8.25816672282089385e-14*A8*g4 + 
     6.61224936974016378e-13*A5*g6 - 
     2.6296608110606801e-13*A2*g8 + 
     2.59487556558260317e-13*A10*g3*x2 - 
     1.58652084976253468e-11*A7*g5*x2 + 
     3.99067733898254196e-11*A4*g7*x2 - 
     4.41486037628790473e-12*A*g9*x2 + 
     8.04335423698123335e-12*A9*g4*x4 - 
     2.17197514727606655e-10*A6*g6*x4 + 
     2.34756708639459969e-10*A3*g8*x4 - 
     5.32762009285759642e-12*g10*x4 + 
     5.78511754053948431e-11*A8*g5*x6 - 
     8.16589511753311956e-10*A5*g7*x6 + 
     3.69778863261878567e-10*A2*g9*x6 + 
     1.65106656495643349e-10*A7*g6*x8 - 
     1.24201778524548735e-9*A4*g8*x8 + 
     1.98568405951987234e-10*A*g10*x8 + 
     2.34986277079273996e-10*A6*g7*x10 - 
     8.99890172295623428e-10*A3*g9*x10 + 
     3.27229290168583213e-11*g11*x10 + 
     1.87460264805506997e-10*A5*g8*x12 - 
     3.28389964017235726e-10*A2*g10*x12 + 
     8.89367704930636301e-11*A4*g9*x14 - 
     5.80300246028472628e-11*A*g11*x14 + 
     2.55778143867196837e-11*A3*g10*x16 - 
     3.93390423737093991e-12*g12*x16 + 
     4.36578811240031125e-12*A2*g11*x18 + 
     4.06167949307034346e-13*A*g12*x20 + 
     1.58438482461786504e-14*g13*x22)*xbar6 + 
  5.93542260208926876e-8*eps4*g3*xbar8 - 
  3.12288574815807931e-9*eps7*g4*xbar8 + 
  eps6*(-1.14340392118169896e-8*A*g3 - 
     9.02678854067742957e-8*g4*x2)*xbar8 + 
  eps9*(1.26121885620031857e-9*A*g4 + 
     1.00859349622512295e-8*g5*x2)*xbar8 + 
  eps8*(1.32727772394750297e-9*A2*g3 + 
     4.65033697944917988e-8*A*g4*x2 + 
     2.99054295797669073e-8*g5*x4)*xbar8 + 
  eps11*(-3.15709843216944468e-10*A2*g4 - 
     7.21099301568180965e-9*A*g5*x2 - 
     5.69746824484251863e-9*g6*x4)*xbar8 + 
  eps10*(-1.18235613578975095e-10*A3*g3 + 
     2.04522364126337295e-10*g5 - 
     1.4372001684607648e-8*A2*g4*x2 - 
     2.38545902650207871e-8*A*g5*x4 - 
     6.6442647298050802e-9*g6*x6)*xbar8 + 
  eps13*(6.34254881618462429e-11*A3*g4 - 
     1.4977795563804726e-11*g6 + 
     2.95036268409924151e-9*A2*g5*x2 + 
     5.72733871097688746e-9*A*g6*x4 + 
     1.89780374932858316e-9*g7*x6)*xbar8 + 
  eps12*(8.85933436332280376e-12*A4*g3 - 
     1.2695043367275619e-10*A*g5 + 
     3.44553148081436095e-9*A3*g4*x2 - 
     9.66117808074637814e-10*g6*x2 + 
     1.08393242236143663e-8*A2*g5*x4 + 
     7.24181767567549532e-9*A*g6*x6 + 
     1.22738677265426237e-9*g7*x8)*xbar8 + 
  eps15*(-1.1209244129052603e-11*A4*g4 + 
     1.23354796462055584e-11*A*g6 - 
     9.05322252904213583e-10*A3*g5*x2 + 
     9.34529456546429641e-11*g7*x2 - 
     3.18804749658072552e-9*A2*g6*x4 - 
     2.46989894878460521e-9*A*g7*x6 - 
     4.84553260391626981e-10*g8*x8)*xbar8 + 
  eps14*(-5.85591473164617337e-13*A5*g3 + 
     4.58152437519766974e-11*A2*g5 - 
     7.06061940978074562e-10*A4*g4*x2 + 
     8.8437067488213914e-10*A*g6*x2 - 
     3.6718459581734819e-9*A3*g5*x4 + 
     8.14572670487090063e-10*g7*x4 - 
     4.35865819040676537e-9*A2*g6*x6 - 
     1.70511399881374369e-9*A*g7*x8 - 
     2.04267683542374506e-10*g8*x10)*xbar8 + 
  eps17*(1.81850832862627129e-12*A5*g4 - 
     5.7018133606605742e-12*A2*g6 + 
     2.31363157692796144e-10*A4*g5*x2 - 
     1.04268313475235866e-10*A*g7*x2 + 
     1.29559671265166405e-9*A3*g6*x4 - 
     1.08608812804810835e-10*g8*x4 + 
     1.74321237740579218e-9*A2*g7*x6 + 
     7.76515634579396129e-10*A*g8*x8 + 
     1.05455124124405657e-10*g9*x10)*xbar8 + 
  eps16*(3.51441987362562031e-14*A6*g3 - 
     1.25669585862967901e-11*A3*g5 + 
     1.19873609386538047e-12*g7 + 
     1.29917477297039227e-10*A5*g4*x2 - 
     4.50505663684441363e-10*A2*g6*x2 + 
     1.0294836459233229e-9*A4*g5*x4 - 
     9.85762364733873057e-10*A*g7*x4 + 
     1.90892686734913978e-9*A3*g6*x6 - 
     3.76480107979462358e-10*g8*x6 + 
     1.28194605951425965e-9*A2*g7*x8 + 
     3.45797358676807567e-10*A*g8*x10 + 
     3.18111454415424726e-11*g9*x12)*xbar8 + 
  eps19*(-2.77181792125363476e-13*A6*g4 + 
     1.94851026920691567e-12*A3*g6 - 
     1.04933332657610013e-13*g8 - 
     5.1992259514176436e-11*A5*g5*x2 + 
     6.35571518081156783e-11*A2*g7*x2 - 
     4.28732342024609978e-10*A4*g6*x4 + 
     1.53545689985903239e-10*A*g8*x4 - 
     8.82875940509388448e-10*A3*g7*x6 + 
     6.61143800669246729e-11*g9*x6 - 
     6.65258660548452332e-10*A2*g8*x8 - 
     2.01099007966251153e-10*A*g9*x10 - 
     2.06386033152073184e-11*g10*x12)*xbar8 + 
  eps18*(-1.95213901631847725e-15*A7*g3 + 
     2.9024042061210064e-12*A4*g5 - 
     1.22464345499091446e-12*A*g7 - 
     2.20948357179324358e-11*A6*g4*x2 + 
     1.68407222784752482e-10*A3*g6*x2 - 
     9.52673617116155421e-12*g8*x2 - 
     2.52285174010719033e-10*A5*g5*x4 + 
     6.48893132761825578e-10*A2*g7*x4 - 
     6.78403369061433162e-10*A4*g6*x6 + 
     5.68290125969521456e-10*A*g8*x6 - 
     6.90033763945661382e-10*A3*g7*x8 + 
     1.26310595431481278e-10*g9*x8 - 
     3.12443265284225916e-10*A2*g8*x10 - 
     6.3597958994265421e-11*A*g9*x12 - 
     4.73255306775791468e-12*g10*x14)*xbar8 + 
  eps21*(4.02698278092183264e-14*A7*g4 - 
     5.48456153392839097e-13*A4*g6 + 
     1.27878322517070527e-13*A*g8 + 
     1.06134424697227182e-11*A6*g5*x2 - 
     2.8004805743707356e-11*A3*g7*x2 + 
     1.03826550082836709e-12*g9*x2 + 
     1.22375351923488345e-10*A5*g6*x4 - 
     1.16626518182467646e-10*A2*g8*x4 + 
     3.58798538233177846e-10*A4*g7*x6 - 
     1.13425693456240496e-10*A*g9*x6 + 
     4.04078829257981979e-10*A3*g8*x8 - 
     2.81051427782846787e-11*g10*x8 + 
     2.02913314961737926e-10*A2*g9*x10 + 
     4.56865113489605372e-11*A*g10*x12 + 
     3.74535590061231334e-12*g11*x14)*xbar8 + 
  eps20*(1.01735256778363072e-16*A8*g3 - 
     5.94748498729256522e-13*A5*g5 + 
     6.8752666515941573e-13*A2*g7 + 
     3.53810789377630122e-12*A7*g4*x2 - 
     5.15152807107229022e-11*A4*g6*x2 + 
     1.25362167426384833e-11*A*g8*x2 + 
     5.5847059374569765e-11*A6*g5*x4 - 
     3.07470180635305607e-10*A3*g7*x4 + 
     1.44903732082026135e-11*g9*x4 + 
     2.07246456352654245e-10*A5*g6*x6 - 
     4.59578840273247801e-10*A2*g8*x6 + 
     2.97340805913634912e-10*A4*g7*x8 - 
     2.2892955313025694e-10*A*g9*x8 + 
     1.99809393100334618e-10*A3*g8*x10 - 
     3.47015927264758897e-11*g10*x10 + 
     6.71900005565290136e-11*A2*g9*x12 + 
     1.09198252656076105e-11*A*g10*x14 + 
     6.80982990694437919e-13*g11*x16)*xbar8 + 
  eps23*(-5.6315187454878941e-15*A8*g4 + 
     1.34545805184805001e-13*A5*g6 - 
     8.4419630758147657e-14*A2*g8 - 
     2.01037270814629847e-12*A7*g5*x2 + 
     9.97117770896026235e-12*A4*g7*x2 - 
     1.57395528411072087e-12*A*g9*x2 - 
     3.1206130449635691e-11*A6*g6*x4 + 
     6.31142612191228433e-11*A3*g8*x4 - 
     1.99325127719395794e-12*g10*x4 - 
     1.24186739426227379e-10*A5*g7*x6 + 
     1.03337422325237485e-10*A2*g9*x6 - 
     1.94902502779695254e-10*A4*g8*x8 + 
     5.67801881002407209e-11*A*g10*x8 - 
     1.43878618574681894e-10*A3*g9*x10 + 
     9.49021948141154828e-12*g11*x10 - 
     5.31016521055310535e-11*A2*g10*x12 - 
     9.44535164544286831e-12*A*g11*x14 - 
     6.42414962794072381e-13*g12*x16)*xbar8 + 
  eps22*(-5.02476115994067526e-18*A9*g3 + 
     1.11539174575339278e-13*A6*g5 - 
     2.80495886362028979e-13*A3*g7 + 
     1.00479606252282625e-14*g9 - 
     5.40259809426922891e-13*A8*g4*x2 + 
     1.3655596937180689e-11*A5*g6*x2 - 
     8.89567598025371328e-12*A2*g8*x2 - 
     1.14125112021298833e-11*A7*g5*x4 + 
     1.17262639629103968e-10*A4*g7*x4 - 
     2.34248563243440911e-11*A*g9*x4 - 
     5.63758532628371665e-11*A6*g6*x6 + 
     2.64073536988736149e-10*A3*g8*x6 - 
     1.11917659757112919e-11*g10*x6 - 
     1.08869701145208113e-10*A5*g7*x8 + 
     2.19898065169051477e-10*A2*g9*x8 - 
     1.01295754866412102e-10*A4*g8*x10 + 
     7.34969922028006648e-11*A*g10*x10 - 
     4.98170652624686903e-11*A3*g9*x12 + 
     8.31685179548676633e-12*g11*x12 - 
     1.3215860235187506e-11*A2*g10*x14 - 
     1.78195799356499145e-12*A*g11*x16 - 
     9.55378197871579756e-14*g12*x18)*xbar8 - 
  2.95801289810004407e-10*eps6*g4*xbar10 + 
  2.94346529368315861e-11*eps9*g5*xbar10 + 
  eps8*(7.69281785172546935e-11*A*g4 + 
     1.07490632635875918e-9*g5*x2)*xbar10 + 
  eps11*(-1.49854878334381416e-11*A*g5 - 
     1.64414869918985145e-10*g6*x2)*xbar10 + 
  eps10*(-1.14623038722347948e-11*A2*g4 - 
     6.72527675714427998e-10*A*g5*x2 - 
     5.64942074025452747e-10*g6*x4)*xbar10 + 
  eps13*(4.55203920804202245e-12*A2*g5 + 
     1.35763920347428776e-10*A*g6*x2 + 
     1.33652228562929386e-10*g7*x4)*xbar10 + 
  eps12*(1.27157831390982766e-12*A3*g4 - 
     2.82877994364105943e-12*g6 + 
     2.44160830279527547e-10*A2*g5*x2 + 
     5.14076796669365287e-10*A*g6*x4 + 
     1.75139799425245342e-10*g7*x6)*xbar10 + 
  eps15*(-1.07685636895144654e-12*A3*g5 + 
     2.70026199694243437e-13*g7 - 
     6.29652746661281415e-11*A2*g6*x2 - 
     1.49092240439933003e-10*A*g7*x4 - 
     5.88096054052166419e-11*g8*x6)*xbar10 + 
  eps14*(-1.16205790093287907e-13*A4*g4 + 
     2.06949189356323779e-12*A*g6 - 
     6.72146134669773312e-11*A3*g5*x2 + 
     1.99437288401862085e-11*g7*x2 - 
     2.61681510848862049e-10*A2*g6*x4 - 
     2.10127602166714473e-10*A*g7*x6 - 
     4.18842380479881739e-11*g8*x8)*xbar10 + 
  eps17*(2.18937302179867743e-13*A4*g5 - 
     2.52743776628905178e-13*A*g7 + 
     2.15933914153368247e-11*A3*g6*x2 - 
     2.33174044228357075e-12*g8*x2 + 
     9.10889047339860176e-11*A2*g7*x4 + 
     8.28793584781457544e-11*A*g8*x6 + 
     1.87814134450040901e-11*g9*x8)*xbar10 + 
  eps16*(9.22277143780367963e-15*A5*g4 - 
     8.60637474674818858e-13*A2*g6 + 
     1.55522012194999734e-11*A4*g5*x2 - 
     2.04738873511014663e-11*A*g7*x2 + 
     9.80212032242431517e-11*A3*g6*x4 - 
     2.27433206141358192e-11*g8*x4 + 
     1.3776069368825939e-10*A2*g7*x6 + 
     6.26447221848720574e-11*A*g8*x8 + 
     8.59289553201749293e-12*g9*x10)*xbar10 + 
  eps19*(-4.01386516110057917e-14*A5*g5 + 
     1.3091834712452921e-13*A2*g7 - 
     6.0989736648541878e-12*A4*g6*x2 + 
     2.86173201964551467e-12*A*g8*x2 - 
     4.02840475527683715e-11*A3*g7*x4 + 
     3.510880308676512e-12*g9*x4 - 
     6.29106001544106061e-11*A2*g8*x6 - 
     3.20688619604414165e-11*A*g9*x8 - 
     4.92343192873666106e-12*g10*x10)*xbar10 + 
  eps18*(-6.56399733698215579e-16*A6*g4 + 
     2.67367086954926804e-13*A3*g6 - 
     2.65773724648037072e-14*g8 - 
     3.1891761064266082e-12*A5*g5*x2 + 
     1.1556733294634019e-11*A2*g7*x2 - 
     3.00891865934477623e-11*A4*g6*x4 + 
     3.00144725725027383e-11*A*g8*x4 - 
     6.52019833501791742e-11*A3*g7*x6 + 
     1.33683467827448483e-11*g9*x6 - 
     5.03812647605675579e-11*A2*g8*x8 - 
     1.54328716110212964e-11*A*g9*x10 - 
     1.5943182436056292e-12*g10*x12)*xbar10 + 
  eps21*(6.81948054057362119e-15*A6*g5 - 
     4.95730577363766302e-14*A3*g7 + 
     2.76104504451824809e-15*g9 + 
     1.50108691344008234e-12*A5*g6*x2 - 
     1.90279881030008194e-12*A2*g8*x2 + 
     1.44066974529341e-11*A4*g7*x4 - 
     5.34733489141200454e-12*A*g9*x4 + 
     3.40794085764526502e-11*A3*g8*x6 - 
     2.64239721989513932e-12*g10*x6 + 
     2.91433177396476386e-11*A2*g9*x8 + 
     9.89175324887470848e-12*A*g10*x10 + 
     1.1292802715742771e-12*g11*x12)*xbar10 + 
  eps20*(4.27976553989265789e-17*A7*g4 - 
     6.89934943139530425e-14*A4*g6 + 
     3.01698740413725238e-14*A*g8 + 
     5.98132658710965791e-13*A6*g5*x2 - 
     4.74116732715012842e-12*A3*g7*x2 + 
     2.78541034399807552e-13*g9*x2 + 
     8.00945275253022047e-12*A5*g6*x4 - 
     2.13863386293836158e-11*A2*g8*x4 + 
     2.48849376049208704e-11*A4*g7*x6 - 
     2.16096622933769274e-11*A*g9*x6 + 
     2.88625342578349044e-11*A3*g8*x8 - 
     5.46942831323172719e-12*g10*x8 + 
     1.47325399109498875e-11*A2*g9*x10 + 
     3.34719700407126729e-12*A*g10*x12 + 
     2.75625052642210253e-13*g11*x14)*xbar10 + 
  eps22*(-2.59530959394910739e-18*A8*g4 + 
     1.56250827735261162e-14*A5*g6 - 
     1.86384253756143204e-14*A2*g8 - 
     1.04716236495971179e-13*A7*g5*x2 + 
     1.57911568324388851e-12*A4*g7*x2 - 
     3.97696537675898684e-13*A*g9*x2 - 
     1.91339334657969896e-12*A6*g6*x4 + 
     1.09023789657915762e-11*A3*g8*x4 - 
     5.31746105151784319e-13*g10*x4 - 
     8.12230075160805238e-12*A5*g7*x6 + 
     1.8624019115509357e-11*A2*g9*x6 - 
     1.31819089102919353e-11*A4*g8*x8 + 
     1.0483480357330514e-11*A*g10*x8 - 
     9.92032656167012319e-12*A3*g9*x10 + 
     1.77778344733062833e-12*g11*x10 - 
     3.70309998579539791e-12*A2*g10*x12 - 
     6.62904547687516285e-13*A*g11*x14 - 
     4.52240509458340008e-14*g12*x16)*xbar10 + 
  1.69722051530330397e-12*eps8*g5*xbar12 - 
  2.90595190793452012e-13*eps11*g6*xbar12 + 
  eps10*(-5.54575148020670988e-13*A*g5 - 
     1.29008964169185665e-11*g6*x2)*xbar12 + 
  eps13*(1.78798720202615632e-13*A*g6 + 
     2.57210159823889116e-12*g7*x2)*xbar12 + 
  eps12*(1.00869657097464141e-13*A2*g5 + 
     9.47632013657176953e-12*A*g6*x2 + 
     1.00368310409322369e-11*g7*x4)*xbar12 + 
  eps15*(-6.39010493062016058e-14*A2*g6 - 
     2.40693363499189255e-12*A*g7*x2 - 
     2.87715768832048683e-12*g8*x4)*xbar12 + 
  eps14*(-1.33953977785016062e-14*A3*g5 + 
     3.84980892713537606e-14*g7 - 
     3.94928486633783273e-12*A2*g6*x2 - 
     1.02511581325767213e-11*A*g7*x4 - 
     4.17899415533904787e-12*g8*x6)*xbar12 + 
  eps17*(1.73998403455957848e-14*A3*g6 - 
     4.62636803886378434e-15*g8 + 
     1.24741423146112554e-12*A2*g7*x2 + 
     3.52693455958173369e-12*A*g8*x4 + 
     1.62821302569789988e-12*g9*x6)*xbar12 + 
  eps16*(1.44440682820300384e-15*A4*g5 - 
     3.24022688540454265e-14*A*g7 + 
     1.22741801273679764e-12*A3*g6*x2 - 
     3.84061473377336244e-13*g8*x2 + 
     5.77793844380739442e-12*A2*g7*x4 + 
     5.47447616200335818e-12*A*g8*x6 + 
     1.26471026695269685e-12*g9*x8)*xbar12 + 
  eps19*(-4.00106875821619636e-15*A4*g6 + 
     4.84590692629411758e-15*A*g8 - 
     4.72763385349764825e-13*A3*g7*x2 + 
     5.32739458894566085e-14*g9*x2 - 
     2.34696797887097322e-12*A2*g8*x4 - 
     2.47171834511294782e-12*A*g9*x6 - 
     6.39422064458918014e-13*g10*x8)*xbar12 + 
  eps18*(-1.33739060725578634e-16*A5*g5 + 
     1.52467406929696226e-14*A2*g7 - 
     3.16506850006518787e-13*A4*g6*x2 + 
     4.36808508700696498e-13*A*g8*x2 - 
     2.37192884056053272e-12*A3*g7*x4 + 
     5.73811638250132219e-13*g9*x4 - 
     3.88549767072102607e-12*A2*g8*x6 - 
     2.02801867312185292e-12*A*g9*x8 - 
     3.15279597165500734e-13*g10*x10)*xbar12 + 
  eps21*(8.18212199689786031e-16*A5*g6 - 
     2.77850155214879458e-15*A2*g8 + 
     1.46242985972961813e-13*A4*g7*x2 - 
     7.13099260240197077e-14*A*g9*x2 + 
     1.12245977611596647e-12*A3*g8*x4 - 
     1.01453307525349774e-13*g10*x4 + 
     2.0091654459041284e-12*A2*g9*x6 + 
     1.1599532499763162e-12*A*g10*x8 + 
     1.99618834474701725e-13*g11*x10)*xbar12 + 
  eps20*(1.10024592611551253e-17*A6*g5 - 
     5.28888834827941102e-15*A3*g7 + 
     5.47612344010328206e-16*g9 + 
     7.15818767506558215e-14*A5*g6*x2 - 
     2.70559177977642949e-13*A2*g8*x2 + 
     7.91459587667159745e-13*A4*g7*x4 - 
     8.20326742698849044e-13*A*g9*x4 + 
     1.97757621860341566e-12*A3*g8*x6 - 
     4.20357694313370931e-13*g10*x6 + 
     1.73888738668498436e-12*A2*g9*x8 + 
     5.99434847996843799e-13*A*g10*x10 + 
     6.90257861666477261e-14*g11*x12)*xbar12 - 
  1.06551186196798794e-14*eps10*g6*xbar14 + 
  2.96371424137457707e-15*eps13*g7*xbar14 + 
  eps12*(4.1883104771160436e-15*A*g6 + 
     1.55454784378046993e-13*g7*x2)*xbar14 + 
  eps15*(-2.14017433818550597e-15*A*g7 - 
     3.90198867402243257e-14*g8*x2)*xbar14 + 
  eps14*(-8.99454744512618591e-16*A2*g6 - 
     1.30968415155813316e-13*A*g7*x2 - 
     1.70308449198607365e-13*g8*x4)*xbar14 + 
  eps17*(8.79886328932693487e-16*A2*g7 + 
     4.07855521267175371e-14*A*g8*x2 + 
     5.8024185244265147e-14*g9*x4)*xbar14 + 
  eps16*(1.39116436986363771e-16*A3*g6 - 
     5.17467765013076258e-16*g8 + 
     6.15890327064823114e-14*A2*g7*x2 + 
     1.92792938842998867e-13*A*g8*x4 + 
     9.24186997248047774e-14*g9*x6)*xbar14 + 
  eps19*(-2.71043966692226229e-16*A3*g7 + 
     7.62461032065408102e-17*g9 - 
     2.33529672481396755e-14*A2*g8*x2 - 
     7.75214641947405959e-14*A*g9*x4 - 
     4.13090807033447583e-14*g10*x6)*xbar14 + 
  eps18*(-1.72867499565968957e-17*A4*g6 + 
     4.9217313236453732e-16*A*g8 - 
     2.13260411115595534e-14*A3*g7*x2 + 
     7.01612347492652808e-15*g9*x2 - 
     1.19175537714779419e-13*A2*g8*x4 - 
     1.31262296085466213e-13*A*g9*x6 - 
     3.47201752597269316e-14*g10*x8)*xbar14 + 
  eps20*(1.82877741622247625e-18*A5*g6 - 
     2.58382411798017243e-16*A2*g8 + 
     6.06418528687686859e-15*A4*g7*x2 - 
     8.75387708088179125e-15*A*g9*x2 + 
     5.32096477905912181e-14*A3*g8*x4 - 
     1.33872464203048517e-14*g10*x4 + 
     1.00297233267464412e-13*A2*g9*x6 + 
     5.94498264966954685e-14*A*g10*x8 + 
     1.03825306645524673e-14*g11*x10)*xbar14 + 
  7.1230636127202905e-17*eps12*g7*xbar16 - 
  3.09644400991606704e-17*eps15*g8*xbar16 + 
  eps14*(-3.27091744222075652e-17*A*g7 - 
     1.87737117146802168e-15*g8*x2)*xbar16 + 
  eps17*(2.56820081466394239e-17*A*g8 + 
     5.77970340504678044e-16*g9*x2)*xbar16 + 
  eps16*(8.09908041993038944e-18*A2*g7 + 
     1.78317218006896548e-15*A*g8*x2 + 
     2.78832594974046941e-15*g9*x4)*xbar16 + 
  eps19*(-1.19399144787300174e-17*A2*g8 - 
     6.67124890749264713e-16*A*g9*x2 - 
     1.11157044100254144e-15*g10*x4)*xbar16 + 
  eps18*(-1.42980374801906325e-18*A3*g7 + 
     6.88701015696998715e-18*g9 - 
     9.33716646729179203e-16*A2*g8*x2 - 
     3.46339329805719736e-15*A*g9*x4 - 
     1.92478458861582261e-15*g10*x6)*xbar16 - 
  4.98845119121947873e-19*eps14*g8*xbar18 + 
  3.29589363262920182e-19*eps17*g9*xbar18 + 
  eps16*(2.61992075966627237e-19*A*g8 + 
     2.27018895731900669e-17*g9*x2)*xbar18 + 
  eps18*(-7.34772661645623638e-20*A2*g8 - 
     2.39905600259048083e-17*A*g9*x2 - 
     4.43602818448693464e-17*g10*x4)*xbar18 + 
  3.62101682176476165e-21*eps16*g9*xbar20;
}
#endif

#ifdef p29
double Wp(void)
{
   return 0.5*A*x2 + 0.0416666666666666667*g*x4 + 
  eps*(0.0833333333333333333*A + 0.0416666666666666667*g*x2) + 
  eps3*(-0.00277777777777777778*A2 - 
     0.0111111111111111111*A*g*x2 - 
     0.00208333333333333333*g2*x4) + 
  eps2*(0.00416666666666666667*g - 
     0.0416666666666666667*A2*x2 - 
     0.0138888888888888889*A*g*x4 - 
     0.00115740740740740741*g2*x6) + 
  eps5*(0.0001763668430335097*A3 - 
     0.0000388558201058201058*g2 + 
     0.00214947089947089947*A2*g*x2 + 
     0.00124007936507936508*A*g2*x4 + 
     0.000154320987654320988*g3*x6) + 
  eps4*(-0.000595238095238095238*A*g + 
     0.00416666666666666667*A3*x2 - 
     0.000868055555555555556*g2*x2 + 
     0.00347222222222222222*A2*g*x4 + 
     0.000810185185185185185*A*g2*x6 + 
     0.0000578703703703703704*g3*x8) + 
  eps7*(-0.0000132275132275132275*A4 + 
     0.000013452982202982203*A*g2 - 
     0.000353835978835978836*A3*g*x2 + 
     0.0000292107583774250441*g3*x2 - 
     0.000438161375661375661*A2*g2*x4 - 
     0.000141369047619047619*A*g3*x6 - 
     0.0000131815843621399177*g4*x8) + 
  eps6*(0.0000793650793650793651*A2*g - 
     0.000421626984126984127*A4*x2 + 
     0.000412533068783068783*A*g2*x2 - 
     0.000710978835978835979*A3*g*x4 + 
     0.00012359457671957672*g3*x4 - 
     0.000332065696649029982*A2*g2*x6 - 
     0.0000592482363315696649*A*g3*x8 - 
     3.61689814814814815e-6*g4*x10) + 
  eps9*(1.06888995777884667e-6*A5 - 
     3.09484386865339246e-6*A2*g2 + 
     0.000052889176153065042*A4*g*x2 - 
     0.0000196739667225778337*A*g3*x2 + 
     0.000118621733205066538*A3*g2*x4 - 
     8.12834124466068911e-6*g4*x4 + 
     0.0000723776288012399124*A2*g3*x6 + 
     0.0000162595142340512711*A*g4*x8 + 
     1.2123306755829904e-6*g5*x10) + 
  eps8*(-0.0000100208433541766875*A3*g + 
     8.50711788211788212e-7*g3 + 
     0.0000427138447971781305*A5*x2 - 
     0.000120331539602372936*A2*g2*x2 + 
     0.000127911890064667842*A4*g*x4 - 
     0.000098836830607663941*A*g3*x4 + 
     0.000102804110327258475*A3*g2*x6 - 
     0.0000165018585880854399*g4*x6 + 
     0.0000336428938859494415*A2*g3*x8 + 
     4.8512364050558495e-6*A*g4*x10 + 
     2.56755115454961134e-7*g5*x12) + 
  eps11*(-9.01835117002665504e-8*A6 + 
     5.87400058299529199e-7*A3*g2 - 
     2.81868399275952575e-8*g4 - 
     7.41416841780598394e-6*A5*g*x2 + 
     7.67116473755031956e-6*A2*g3*x2 - 
     0.000027147462601331649*A4*g2*x4 + 
     8.12031936990601012e-6*A*g4*x4 - 
     0.0000272310450812986086*A3*g3*x6 + 
     1.70667153812408442e-6*g5*x6 - 
     0.0000108933015093453806*A2*g4*x8 - 
     1.87850642976993286e-6*A*g5*x10 - 
     1.16690477054095881e-7*g6*x12) + 
  eps10*(1.21747740795359843e-6*A4*g - 
     4.62417873132158846e-7*A*g3 - 
     4.32775172358505692e-6*A6*x2 + 
     0.0000276277014248244407*A3*g2*x2 - 
     1.30445706075046353e-6*g4*x2 - 
     0.0000210333326652771097*A5*g*x4 + 
     0.0000447391253752860896*A2*g3*x4 - 
     0.0000265668910778864483*A4*g2*x6 + 
     0.0000184769777868736202*A*g4*x6 - 
     0.0000139376709110505407*A3*g3*x8 + 
     2.13520310814871e-6*g5*x8 - 
     3.5181249916492972e-6*A2*g4*x10 - 
     4.25407416871537242e-7*A*g5*x12 - 
     1.98147969535893919e-8*g6*x14) + 
  eps13*(7.83069566138349207e-9*A7 - 
     9.93094869534334209e-8*A4*g2 + 
     2.08755249185163841e-8*A*g4 + 
     9.92791119692574719e-7*A6*g*x2 - 
     2.26246788359770127e-6*A3*g3*x2 + 
     7.19774046753493046e-8*g5*x2 + 
     5.52538741816188906e-6*A5*g2*x4 - 
     4.47883727161149936e-6*A2*g4*x4 + 
     8.38601213983571788e-6*A4*g3*x6 - 
     2.25348627386308778e-6*A*g5*x6 + 
     5.24445855604457162e-6*A3*g4*x8 - 
     3.11392974798759566e-7*g6*x8 + 
     1.55465050346795001e-6*A2*g5*x10 + 
     2.17600880397466046e-7*A*g6*x12 + 
     1.15841884836628278e-8*g7*x14) + 
  eps12*(-1.43889032777921667e-7*A5*g + 
     1.51283642180000723e-7*A2*g3 + 
     4.38492191964414187e-7*A7*x2 - 
     5.47671197834474951e-6*A4*g2*x2 + 
     1.1365151365172641e-6*A*g4*x2 + 
     3.23789133106262736e-6*A6*g*x4 - 
     0.0000150481673660823793*A3*g3*x4 + 
     5.97324614725086198e-7*g5*x4 + 
     6.03932684613625972e-6*A5*g2*x6 - 
     0.0000113106765525436987*A2*g4*x6 + 
     4.69528859165240338e-6*A4*g3*x8 - 
     3.0694501391598228e-6*A*g5*x8 + 
     1.82557370238215146e-6*A3*g4*x10 - 
     2.71046144994230449e-7*g6*x10 + 
     3.7535031778135559e-7*A2*g5*x12 + 
     3.90681314457195373e-8*A*g6*x14 + 
     1.62260932077515154e-9*g7*x16) + 
  eps15*(-6.94206524686864971e-10*A8 + 
     1.55258266251201437e-8*A5*g2 - 
     8.87063997906019346e-9*A2*g4 - 
     1.28444091425696105e-7*A7*g*x2 + 
     5.59355511978255916e-7*A4*g3*x2 - 
     7.69591961687451275e-8*A*g5*x2 - 
     1.03084425773136674e-6*A6*g2*x4 + 
     1.80099658500984157e-6*A3*g4*x4 - 
     4.89852640150590245e-8*g6*x4 - 
     2.23744987275327073e-6*A5*g3*x6 + 
     1.60416803829389571e-6*A2*g5*x6 - 
     2.02887475090349778e-6*A4*g4*x8 + 
     5.10536772376168298e-7*A*g6*x8 - 
     9.11746562790846727e-7*A3*g5*x10 + 
     5.21769349658492833e-8*g7*x10 - 
     2.14341780318485671e-7*A2*g6*x12 - 
     2.52490551976121104e-8*A*g7*x14 - 
     1.17600420262660865e-9*g8*x16) + 
  eps14*(1.66609565924847593e-8*A6*g - 
     3.84541066603365207e-8*A3*g3 + 
     1.23616495716322489e-9*g5 - 
     4.44285396439000936e-8*A8*x2 + 
     9.81807578832239391e-7*A5*g2*x2 - 
     5.55101746448534654e-7*A2*g4*x2 - 
     4.73967830600877338e-7*A7*g*x4 + 
     4.18284859452059839e-6*A4*g3*x4 - 
     7.15343253702736788e-7*A*g5*x4 - 
     1.24663165145441196e-6*A6*g2*x6 + 
     5.00514675879205854e-6*A3*g4*x6 - 
     1.81402700349001079e-7*g6*x6 - 
     1.36226318220021373e-6*A5*g3*x8 + 
     2.36606032230627314e-6*A2*g5*x8 - 
     7.58172593612770117e-7*A4*g4*x10 + 
     4.75471890972483691e-7*A*g6*x10 - 
     2.34027522244261325e-7*A3*g5*x12 + 
     3.3963539821117207e-8*g7*x12 - 
     4.06050820222736176e-8*A2*g6*x14 - 
     3.70938742929349711e-9*A*g7*x16 - 
     1.38898528337180163e-10*g8*x18) + 
  eps17*(6.25217958800249802e-11*A9 - 
     2.29312206278746533e-9*A6*g2 + 
     2.8310089717477044e-9*A3*g4 - 
     6.71998649148490015e-11*g6 + 
     1.61783182535963035e-8*A8*g*x2 - 
     1.222198282975496e-7*A5*g3*x2 + 
     4.51903487294323094e-8*A2*g5*x2 + 
     1.79787422789127715e-7*A7*g2*x4 - 
     5.89386352242391962e-7*A4*g4*x4 + 
     6.83924293854497039e-8*A*g6*x4 + 
     5.35385253592035249e-7*A6*g3*x6 - 
     8.16161936426993263e-7*A3*g5*x6 + 
     2.03110694856709656e-8*g7*x6 + 
     6.69429955495357485e-7*A5*g4*x8 - 
     4.44812062546498445e-7*A2*g6*x8 + 
     4.24544759374608395e-7*A4*g5*x10 - 
     1.02125278182278717e-7*A*g7*x10 + 
     1.48190757087105866e-7*A3*g6*x12 - 
     8.25465653164429909e-9*g8*x12 + 
     2.8842218900714868e-8*A2*g7*x14 + 
     2.93316966296752154e-9*A*g8*x16 + 
     1.21426224678902097e-10*g9*x18) + 
  eps16*(-1.89909954985575877e-9*A7*g + 
     8.35603474047208798e-9*A4*g3 - 
     1.15966243496214952e-9*A*g5 + 
     4.50155213123768602e-9*A9*x2 - 
     1.63520154608933337e-7*A6*g2*x2 + 
     2.00125773929144853e-7*A3*g4*x2 - 
     4.71643935891082883e-9*g6*x2 + 
     6.66827009985439445e-8*A8*g*x4 - 
     1.01569722853466271e-6*A5*g3*x4 + 
     4.653753986331283e-7*A2*g5*x4 + 
     2.38609112997144637e-7*A7*g2*x6 - 
     1.78931879078472604e-6*A4*g4*x6 + 
     2.75782412054904595e-7*A*g6*x6 + 
     3.5257503626825941e-7*A6*g3*x8 - 
     1.29719583644083582e-6*A3*g5*x8 + 
     4.43904638337799842e-8*g7*x8 + 
     2.67563783428073661e-7*A5*g4*x10 - 
     4.41739629456479988e-7*A2*g6*x10 + 
     1.15544405881940575e-7*A4*g5*x12 - 
     7.03094817586759951e-8*A*g7*x12 + 
     2.95627516533174602e-8*A3*g6*x14 - 
     4.21593686904484474e-9*g8*x14 + 
     4.43746780874914946e-9*A2*g7*x16 + 
     3.61167459558351774e-10*A*g8*x18 + 
     1.23066706066192904e-11*g9*x20) + 
  eps19*(-5.70128780114804572e-12*A10 + 
     3.24325759393455769e-10*A7*g2 - 
     7.52920392642037898e-10*A4*g4 + 
     7.63432039813829238e-11*A*g6 - 
     1.99446765051272661e-9*A9*g*x2 + 
     2.43560018179573397e-8*A6*g3*x2 - 
     1.92651473964731419e-8*A3*g5*x2 + 
     3.57664504054283011e-10*g7*x2 - 
     2.97138844105769473e-8*A8*g2*x4 + 
     1.66367899286352586e-7*A5*g4*x4 - 
     5.12763843043703477e-8*A2*g6*x4 - 
     1.17558487781038256e-7*A7*g3*x6 + 
     3.32274083849900958e-7*A4*g5*x6 - 
     3.49339293457975036e-8*A*g7*x6 - 
     1.95421595481198395e-7*A6*g4*x8 + 
     2.73546099832218964e-7*A3*g6*x8 - 
     6.42119893976624269e-9*g8*x8 - 
     1.66845932629322826e-7*A5*g5*x10 + 
     1.05196992302604677e-7*A2*g7*x10 - 
     8.06653736383214643e-8*A4*g6*x12 + 
     1.87723844343482559e-8*A*g8*x12 - 
     2.29644918467110207e-8*A3*g7*x14 + 
     1.25288025697957571e-9*g9*x14 - 
     3.81165485194947533e-9*A2*g8*x16 - 
     3.41033212304414905e-10*A*g9*x18 - 
     1.27053709821831841e-11*g10*x20) + 
  eps18*(2.13798292543051714e-10*A8*g - 
     1.62899940163818617e-9*A5*g3 + 
     6.06739124374671626e-10*A2*g5 - 
     4.56102589118103946e-10*A10*x2 + 
     2.5741194154734252e-8*A7*g2*x2 - 
     5.93202934378594688e-8*A4*g4*x2 + 
     5.97796132442781859e-9*A*g6*x2 - 
     9.086017175115798e-9*A9*g*x4 + 
     2.22788546277779156e-7*A6*g3*x4 - 
     2.17818061292066124e-7*A3*g5*x4 + 
     4.46060201054250811e-9*g7*x4 - 
     4.29736286745591606e-8*A8*g2*x6 + 
     5.48218484132244335e-7*A5*g4*x6 - 
     2.23798601959230444e-7*A2*g6*x6 - 
     8.3334504765293729e-8*A7*g3*x8 + 
     5.66588387939462102e-7*A4*g5*x8 - 
     8.17078651256326395e-8*A*g7*x8 - 
     8.32572408053676287e-8*A6*g4*x10 + 
     2.88769211893932833e-7*A3*g6*x10 - 
     9.49367158787967084e-9*g8*x10 - 
     4.80270155903927102e-8*A5*g5*x12 + 
     7.64234973061525259e-8*A2*g7*x12 - 
     1.69136821548003748e-8*A4*g6*x14 + 
     1.00575293092506873e-8*A*g8*x14 - 
     3.69466622059472975e-9*A3*g7*x16 + 
     5.19597646877020836e-10*g9*x16 - 
     4.88723854749631574e-10*A2*g8*x18 - 
     3.58645537045585288e-11*A*g9*x20 - 
     1.12084057456710382e-12*g10*x22) + 
  eps21*(5.2514619543187782e-13*A11 - 
     4.43285954755604869e-11*A8*g2 + 
     1.76083788279021689e-10*A5*g4 - 
     4.74728753998211342e-11*A2*g6 + 
     2.41589075467910444e-10*A10*g*x2 - 
     4.51824485857656974e-9*A7*g3*x2 + 
     6.66083029216207287e-9*A4*g5*x2 - 
     5.24335874922835697e-10*A*g7*x2 + 
     4.69949475640663485e-9*A9*g2*x4 - 
     4.19656758646856316e-8*A6*g4*x4 + 
     2.73885212294566607e-8*A3*g6*x4 - 
     4.48244578272414887e-10*g8*x4 + 
     2.40727904510809782e-8*A8*g3*x6 - 
     1.14987302708287038e-7*A5*g5*x6 + 
     3.18314156293579248e-8*A2*g7*x6 + 
     5.1729556293745067e-8*A7*g4*x8 - 
     1.33139310440523761e-7*A4*g6*x8 + 
     1.31084047358048264e-8*A*g8*x8 + 
     5.74763592331078553e-8*A6*g5*x10 - 
     7.58285646214704478e-8*A3*g7*x10 + 
     1.70719938146989968e-9*g9*x10 + 
     3.67818305341475603e-8*A5*g6*x12 - 
     2.23107719453182269e-8*A2*g8*x12 + 
     1.43062528484956471e-8*A4*g7*x14 - 
     3.24546888412113238e-9*A*g9*x14 + 
     3.43426667042232431e-9*A3*g8*x16 - 
     1.84284319077257175e-10*g10*x16 + 
     4.96756814596081739e-10*A2*g9*x18 + 
     3.96764099826891058e-11*A*g10*x20 + 
     1.34372144042558418e-12*g11*x22) + 
  eps20*(-2.38285086177214561e-11*A9*g + 
     2.93087835503767857e-10*A6*g3 - 
     2.33284850513311582e-10*A3*g5 + 
     4.35358687387975124e-12*g7 + 
     4.62128541799995915e-11*A11*x2 - 
     3.87512747715920683e-9*A8*g2*x2 + 
     1.52963831343981389e-8*A5*g4*x2 - 
     4.10201649274809254e-9*A2*g6*x2 + 
     1.2058131859727143e-9*A10*g*x4 - 
     4.51251014708823542e-8*A7*g3*x4 + 
     8.20524658045556169e-8*A4*g5*x4 - 
     7.11455083461241557e-9*A*g7*x4 + 
     7.36094104464716057e-9*A9*g2*x6 - 
     1.49255884116928141e-7*A6*g4*x6 + 
     1.28707565844365563e-7*A3*g6*x6 - 
     2.42078453530071715e-9*g8*x6 + 
     1.82893288628610935e-8*A8*g3*x8 - 
     2.09524543137285467e-7*A5*g5*x8 + 
     7.93810679543179244e-8*A2*g7*x8 + 
     2.34179153309909358e-8*A7*g4*x10 - 
     1.48969846228119514e-7*A4*g6*x10 + 
     2.05019199855671562e-8*A*g8*x10 + 
     1.74575105847696841e-8*A6*g5*x12 - 
     5.80036979689224998e-8*A3*g7*x12 + 
     1.8510046912641176e-9*g9*x12 + 
     8.09148869608194122e-9*A5*g6*x14 - 
     1.251808839252206e-8*A2*g8*x14 + 
     2.40348962003249252e-9*A4*g7*x16 - 
     1.40328230011170153e-9*A*g9*x16 + 
     4.58007384146693616e-10*A3*g8*x18 - 
     6.36787892934133022e-11*g10*x18 + 
     5.41571641768509377e-11*A2*g9*x20 + 
     3.61823810155023661e-12*A*g10*x22 + 
     1.04407319287969897e-13*g11*x24) + 
  eps23*(-4.87743892079685082e-14*A12 + 
     5.89316491267758974e-12*A9*g2 - 
     3.73943263170943611e-11*A6*g4 + 
     2.13679155317563112e-11*A3*g6 - 
     3.27361153325515243e-13*g8 - 
     2.88368279506519334e-11*A11*g*x2 + 
     7.91374895139060628e-10*A8*g3*x2 - 
     1.98046179372144604e-9*A5*g5*x2 + 
     4.11786639583657111e-10*A2*g7*x2 - 
     7.16497851551313523e-10*A10*g2*x4 + 
     9.68464471525289276e-9*A7*g4*x4 - 
     1.16748393728030986e-8*A4*g6*x4 + 
     8.04127478183736051e-10*A*g8*x4 - 
     4.65194608412246558e-9*A9*g3*x6 + 
     3.51082372037893695e-8*A6*g5*x6 - 
     2.04201982013264592e-8*A3*g7*x6 + 
     3.08310721156552306e-10*g9*x6 - 
     1.26357673284535273e-8*A8*g4*x8 + 
     5.45476416156654204e-8*A5*g6*x8 - 
     1.40486405551536498e-8*A2*g8*x8 - 
     1.7805212696568686e-8*A7*g5*x10 + 
     4.2926305860153371e-8*A4*g7*x10 - 
     4.0312366550615087e-9*A*g9*x10 - 
     1.46022546131613235e-8*A6*g6*x12 + 
     1.843836447337074e-8*A3*g8*x12 - 
     4.02235197734030437e-10*g10*x12 - 
     7.42369322805527411e-9*A5*g7*x14 + 
     4.37038526225414347e-9*A2*g9*x14 - 
     2.40937437944208411e-9*A4*g8*x16 + 
     5.35568097093309146e-10*A*g10*x16 - 
     4.99603251087911808e-10*A3*g9*x18 + 
     2.64472477748035067e-11*g11*x18 - 
     6.40255800593810452e-11*A2*g10*x20 - 
     4.61829796410311992e-12*A*g11*x22 - 
     1.43368406597132889e-13*g12*x24) + 
  eps22*(2.63381701723029945e-12*A10*g - 
     4.95613474685512438e-11*A7*g3 + 
     7.3461839787322817e-11*A4*g5 - 
     5.80927196941699941e-12*A*g7 - 
     4.68234108487568308e-12*A12*x2 + 
     5.62566165576091132e-10*A9*g2*x2 - 
     3.55029758958278224e-9*A6*g4*x2 + 
     2.01925178972162547e-9*A3*g6*x2 - 
     3.0814593971546122e-11*g8*x2 - 
     1.56527781346397019e-10*A11*g*x4 + 
     8.57069278143073356e-9*A8*g3*x4 - 
     2.64080665694219489e-8*A5*g5*x4 + 
     6.0407259102082057e-9*A2*g7*x4 - 
     1.20889938892283076e-9*A10*g2*x6 + 
     3.69930387182005496e-8*A7*g4*x6 - 
     5.87976309873423814e-8*A4*g6*x6 + 
     4.64691762189073441e-9*A*g8*x6 - 
     3.7731495679189183e-9*A9*g3*x8 + 
     6.81148651466673022e-8*A6*g5*x8 - 
     5.41126426776092471e-8*A3*g7*x8 + 
     9.60423280700958978e-10*g9*x8 - 
     6.06051978329905884e-9*A8*g4*x10 + 
     6.45172101423398301e-8*A5*g6*x10 - 
     2.31853730369969274e-8*A2*g8*x10 - 
     5.69384641167539249e-9*A7*g5*x12 + 
     3.45031778931260666e-8*A4*g7*x12 - 
     4.5856200745095094e-9*A*g9*x12 - 
     3.36446046321516529e-9*A6*g6*x14 + 
     1.08170138123001676e-8*A3*g8*x14 - 
     3.37300366179434001e-10*g10*x14 - 
     1.30060474988550597e-9*A5*g7*x16 + 
     1.9676600421073939e-9*A2*g9*x16 - 
     3.33854146037989048e-10*A4*g8*x18 + 
     1.92027951778477411e-10*A*g10*x18 - 
     5.64147807443152692e-11*A3*g9*x20 + 
     7.76866625886353525e-12*g11*x20 - 
     6.03122771185984168e-12*A2*g10*x22 - 
     3.69809171837544212e-13*A*g11*x24 - 
     9.90994892123906548e-15*g12*x26) + 
  eps25*(4.5617341154295489e-15*A13 - 
     7.65681973581163408e-13*A10*g2 + 
     7.36427533361146046e-12*A7*g4 - 
     7.77915357825993505e-12*A4*g6 + 
     5.01822372498827554e-13*A*g8 + 
     3.39946554308810257e-12*A12*g*x2 - 
     1.32218967001765988e-10*A9*g3*x2 + 
     5.24826694161013285e-10*A6*g5*x2 - 
     2.29911014730304061e-10*A3*g7*x2 + 
     2.97396110366290561e-12*g9*x2 + 
     1.05899009942419973e-10*A11*g2*x4 - 
     2.07888236061736146e-9*A8*g4*x4 + 
     4.2205345488109798e-9*A5*g6*x4 - 
     7.62725505811220135e-10*A2*g8*x4 + 
     8.56030817990639683e-10*A10*g3*x6 - 
     9.69700200555032466e-9*A7*g5*x6 + 
     1.0345307489459437e-8*A4*g7*x6 - 
     6.53391446848804187e-10*A*g9*x6 + 
     2.88536112350769269e-9*A9*g4*x8 - 
     1.95458369290004387e-8*A6*g6*x8 + 
     1.05141608097548792e-8*A3*g8*x8 - 
     1.49985208961406861e-10*g10*x8 + 
     5.0517190817639561e-9*A8*g5*x10 - 
     2.03127428588433698e-8*A5*g7*x10 + 
     4.96479103747145285e-9*A2*g9*x10 + 
     5.18105920734004777e-9*A7*g6*x12 - 
     1.18984582771191454e-8*A4*g8*x12 + 
     1.07801501997213091e-9*A*g10*x12 + 
     3.33667223847150641e-9*A6*g7*x14 - 
     4.07258881748425756e-9*A3*g9*x14 + 
     8.66712686070301579e-11*g11*x14 + 
     1.4017941285304863e-9*A5*g8*x16 - 
     8.05772603894054025e-10*A2*g10*x16 + 
     3.89757092431598696e-10*A4*g9*x18 - 
     8.52041965373136873e-11*A*g11*x18 + 
     7.10964158735397762e-11*A3*g10*x20 - 
     3.72103988693417535e-12*g12*x20 + 
     8.17773394901589543e-12*A2*g11*x22 + 
     5.37775729072728217e-13*A*g12*x24 + 
     1.54097984854059648e-14*g13*x26) + 
  eps24*(-2.89099899565347662e-13*A11*g + 
     7.9759930961059578e-12*A8*g3 - 
     2.00555906593283631e-11*A5*g5 + 
     4.18688595364780991e-12*A2*g7 + 
     4.74420340935259007e-13*A13*x2 - 
     7.92461835979771511e-11*A10*g2*x2 + 
     7.58561702147442218e-10*A7*g4*x2 - 
     7.97991543042322495e-10*A4*g6*x2 + 
     5.12980963092851767e-11*A*g8*x2 + 
     1.99411637693229689e-11*A12*g*x4 - 
     1.54367310321517635e-9*A9*g3*x4 + 
     7.53265555420091332e-9*A6*g5*x4 - 
     3.62648374581728425e-9*A3*g7*x4 + 
     4.93947743563747665e-11*g9*x4 + 
     1.91553592353180707e-10*A11*g2*x6 - 
     8.49094217698978774e-9*A8*g4*x6 + 
     2.26856565220020088e-8*A5*g6*x6 - 
     4.69772329949351813e-9*A2*g8*x6 + 
     7.38610816404395504e-10*A10*g3*x8 - 
     1.99662166333330706e-8*A7*g5*x8 + 
     2.9041859633440226e-8*A4*g7*x8 - 
     2.15327269006722961e-9*A*g9*x8 + 
     1.46232224612947612e-9*A9*g4*x10 - 
     2.43772139379355154e-8*A6*g6*x10 + 
     1.82674355319716322e-8*A3*g8*x10 - 
     3.10752555543901178e-10*g10*x10 + 
     1.69732946496891816e-9*A8*g5*x12 - 
     1.71231822209617444e-8*A5*g7*x12 + 
     5.9144501741718517e-9*A2*g9*x12 + 
     1.24827250807789759e-9*A7*g6*x14 - 
     7.28755328956029511e-9*A4*g8*x14 + 
     9.42570128461049658e-10*A*g10*x14 + 
     6.08812904258686911e-10*A6*g7*x16 - 
     1.90694699932313329e-9*A3*g9*x16 + 
     5.83702428173174224e-11*g11*x16 + 
     2.01600973965553078e-10*A5*g8*x18 - 
     2.99487561260952419e-10*A2*g10*x18 + 
     4.5544937416083891e-11*A4*g9*x20 - 
     2.58715552328237504e-11*A*g11*x20 + 
     6.91310656589337861e-12*A3*g10*x22 - 
     9.44207238480244009e-13*g12*x22 + 
     6.74432494205638096e-13*A2*g11*x24 + 
     3.82104888900742578e-14*A*g12*x26 + 
     9.55678585992729762e-16*g13*x28) + 
  eps27*(-4.29185988094780467e-16*A14 + 
     9.75792282712677276e-14*A11*g2 - 
     1.3646853162570345e-12*A8*g4 + 
     2.42949425613405441e-12*A5*g6 - 
     4.11394545518213554e-13*A2*g8 - 
     3.96490174257524041e-13*A13*g*x2 + 
     2.12343279256552213e-11*A10*g3*x2 - 
     1.26943061490106314e-10*A7*g5*x2 + 
     1.02247921943695124e-10*A4*g7*x2 - 
     5.5423483777730116e-12*A*g9*x2 - 
     1.52404782309247872e-11*A12*g2*x4 + 
     4.20166632359481189e-10*A9*g4*x4 - 
     1.34342557916077234e-9*A6*g6*x4 + 
     5.08454526341145697e-10*A3*g8*x4 - 
     5.93267483507724836e-12*g10*x4 - 
     1.5105589569086578e-10*A11*g3*x6 + 
     2.46644028677531692e-9*A8*g5*x6 - 
     4.40356140879596708e-9*A5*g7*x6 + 
     7.2573930556411028e-10*A2*g9*x6 - 
     6.22095324902653748e-10*A10*g4*x8 + 
     6.28605537544467192e-9*A7*g6*x8 - 
     6.16872976090627993e-9*A4*g8*x8 + 
     3.66333923503317899e-10*A*g10*x8 - 
     1.3307708807396243e-9*A9*g5*x10 + 
     8.35325491249095651e-9*A6*g7*x10 - 
     4.24450814830156289e-9*A3*g9*x10 + 
     5.80327450488696854e-11*g11*x10 - 
     1.6742025695565531e-9*A8*g6*x12 + 
     6.38443699559690024e-9*A5*g8*x12 - 
     1.49942990889307018e-9*A2*g10*x12 - 
     1.33401488172649674e-9*A7*g7*x14 + 
     2.95015965374919579e-9*A4*g9*x14 - 
     2.59836904724562695e-10*A*g11*x14 - 
     7.03555104941829487e-10*A6*g8*x16 + 
     8.35706570206888892e-10*A3*g10*x16 - 
     1.74326212154086689e-11*g12*x16 - 
     2.51267260438286454e-10*A5*g9*x18 + 
     1.41631829044548074e-10*A2*g11*x18 - 
     6.10485807554465637e-11*A4*g10*x20 + 
     1.31608120750337335e-11*A*g12*x20 - 
     9.93693264312864106e-12*A3*g11*x22 + 
     5.15065776106236279e-13*g13*x22 - 
     1.03668290285869099e-12*A2*g12*x24 - 
     6.26408647094493891e-14*A*g13*x26 - 
     1.66670051667820424e-15*g14*x28) + 
  eps26*(3.15451701249663644e-14*A12*g - 
     1.23260743380846408e-12*A9*g3 + 
     4.91328598966957483e-12*A6*g5 - 
     2.16010730561106487e-12*A3*g7 + 
     2.80265846575244876e-14*g9 - 
     4.80688304875450638e-14*A14*x2 + 
     1.0882967128577594e-11*A11*g2*x2 - 
     1.51564449755526941e-10*A8*g4*x2 + 
     2.68832690023484167e-10*A5*g6*x2 - 
     4.53800665535698655e-11*A2*g8*x2 - 
     2.49976348277787481e-12*A13*g*x4 + 
     2.65894282403365961e-10*A10*g3*x4 - 
     1.95152833009846442e-9*A7*g5*x4 + 
     1.72592503214026419e-9*A4*g7*x4 - 
     9.84468564911047601e-11*A*g9*x4 - 
     2.9429564195639701e-11*A12*g2*x6 + 
     1.82782910902163964e-9*A9*g4*x6 - 
     7.67829334489098475e-9*A6*g6*x6 + 
     3.32590234296463859e-9*A3*g8*x6 - 
     4.19820646804651369e-11*g10*x6 - 
     1.38204464610680452e-10*A11*g3*x8 + 
     5.37351949422549083e-9*A8*g5*x8 - 
     1.30589400763732115e-8*A5*g7*x8 + 
     2.52344638346505715e-9*A2*g9*x8 - 
     3.32321907447622297e-10*A10*g4*x10 + 
     8.24783952385426657e-9*A7*g6*x10 - 
     1.1258556884547882e-8*A4*g8*x10 + 
     7.96395396558461894e-10*A*g10*x10 - 
     4.68876173390562072e-10*A9*g5*x12 + 
     7.37174695327914701e-9*A6*g7*x12 - 
     5.2863782907904963e-9*A3*g9*x12 + 
     8.70473987527200665e-11*g11*x12 - 
     4.21139769024652842e-10*A8*g6*x14 + 
     4.07659424674585697e-9*A5*g8*x14 - 
     1.36514999589867453e-9*A2*g10*x14 - 
     2.53184281042569276e-10*A7*g7*x16 + 
     1.43498819528840929e-9*A4*g9*x16 - 
     1.81588742992582398e-10*A*g11*x16 - 
     1.04910984884796622e-10*A6*g8*x18 + 
     3.21680373413064642e-10*A3*g10*x18 - 
     9.69728250369714944e-12*g12*x18 - 
     3.03594939414036236e-11*A5*g9*x20 + 
     4.44197711547649947e-11*A2*g11*x20 - 
     6.12305100850786679e-12*A4*g10*x22 + 
     3.44141679543564567e-12*A*g12*x22 - 
     8.43545071546764867e-13*A3*g11*x24 + 
     1.14398078813312878e-13*g13*x24 - 
     7.56779797267724648e-14*A2*g12*x26 - 
     3.98471719227870099e-15*A*g13*x28 - 
     9.34260000972918927e-17*g14*x30) + 
  eps28*(-3.42449353535391123e-15*A13*g + 
     1.84149637365791136e-13*A10*g3 - 
     1.1050080873966546e-12*A7*g5 + 
     8.92914813217674881e-13*A4*g7 - 
     4.85334548141852657e-14*A*g9 + 
     4.87039080130076884e-15*A15*x2 - 
     1.46243857134180913e-12*A12*g2*x2 + 
     2.86469187305027265e-11*A9*g4*x2 - 
     8.01046401001525524e-11*A6*g6*x2 + 
     2.83390803597765611e-11*A3*g8*x2 - 
     3.17935732638901522e-13*g10*x2 + 
     3.08997725939711303e-13*A14*g*x4 - 
     4.40881232995903364e-11*A11*g3*x4 + 
     4.67270929147381534e-10*A8*g5*x4 - 
     6.92508097837570655e-10*A5*g7*x4 + 
     1.03176779132993969e-10*A2*g9*x4 + 
     4.40151413846244465e-12*A13*g2*x6 - 
     3.72611012872960704e-10*A10*g4*x6 + 
     2.33896053999641589e-9*A7*g6*x6 - 
     1.85076152700597453e-9*A4*g8*x6 + 
     9.73546889932565398e-11*A*g10*x6 + 
     2.48641511603740223e-11*A12*g3*x8 - 
     1.34582689296840159e-9*A9*g5*x8 + 
     5.1140460796628628e-9*A6*g7*x8 - 
     2.0570070090932405e-9*A3*g9*x8 + 
     2.45730759326416844e-11*g11*x8 + 
     7.1702923091107546e-11*A11*g4*x10 - 
     2.54607352322993814e-9*A8*g6*x10 + 
     5.77943820119451463e-9*A5*g8*x10 - 
     1.06095247142717178e-9*A2*g10*x10 + 
     1.2131500328791563e-10*A10*g5*x12 - 
     2.82707146362666275e-9*A7*g7*x12 + 
     3.67801985870440129e-9*A4*g9*x12 - 
     2.50903669106862355e-10*A*g11*x12 + 
     1.31050021791628478e-10*A9*g6*x14 - 
     1.96949908360014888e-9*A6*g8*x14 + 
     1.3644828493201679e-9*A3*g10*x14 - 
     2.18943788516381651e-11*g12*x14 + 
     9.53596786211020254e-11*A8*g7*x16 - 
     8.93201150460212866e-10*A5*g9*x16 + 
     2.91741725069643471e-10*A2*g11*x16 + 
     4.83328521248353745e-11*A7*g8*x18 - 
     2.67394075003739542e-10*A4*g10*x18 + 
     3.32333838170053206e-11*A*g12*x18 + 
     1.73860565862725499e-11*A6*g9*x20 - 
     5.2370974939069083e-11*A3*g11*x20 + 
     1.55867178465730428e-12*g13*x20 + 
     4.46556790482617333e-12*A5*g10*x22 - 
     6.44988561121731387e-12*A2*g12*x22 + 
     8.13268877653918674e-13*A4*g11*x24 - 
     4.52921962533507132e-13*A*g13*x24 + 
     1.02564448524934742e-13*A3*g12*x26 - 
     1.38230362423873659e-14*g14*x26 + 
     8.51681830544114951e-15*A2*g13*x28 + 
     4.18850310798987491e-16*A*g14*x30 + 
     9.24169435429845849e-18*g15*x32) + 
  0.00833333333333333333*eps*g*xbar2 + 
  0.166666666666666667*(A + 0.5*g*x2)*xbar2 + 
  eps3*(-0.000793650793650793651*A*g - 
     0.00138888888888888889*g2*x2)*xbar2 + 
  eps2*(-0.00277777777777777778*A2 - 
     0.0111111111111111111*A*g*x2 - 
     0.00208333333333333333*g2*x4)*xbar2 + 
  eps5*(0.0000727513227513227513*A2*g + 
     0.000522486772486772487*A*g2*x2 + 
     0.000162037037037037037*g3*x4)*xbar2 + 
  eps4*(0.0000661375661375661376*A3 - 
     0.0000644841269841269841*g2 + 
     0.0015873015873015873*A2*g*x2 + 
     0.00094246031746031746*A*g2*x4 + 
     0.000115740740740740741*g3*x6)*xbar2 + 
  eps7*(-6.91438191438191438e-6*A3*g + 
     1.41486599819933153e-6*g3 - 
     0.000128066378066378066*A2*g2*x2 - 
     0.000110705266955266955*A*g3*x4 - 
     0.000018647119341563786*g4*x6)*xbar2 + 
  eps6*(-1.65343915343915344e-6*A4 + 
     0.0000179623617123617124*A*g2 - 
     0.00021164021164021164*A3*g*x2 + 
     0.0000485008818342151675*g3*x2 - 
     0.000276951058201058201*A2*g2*x4 - 
     0.0000898368606701940035*A*g3*x6 - 
     8.27867798353909465e-6*g4*x8)*xbar2 + 
  eps9*(6.79829796893288957e-7*A4*g - 
     6.72419695237155555e-7*A*g3 + 
     0.0000254975770848786722*A3*g2*x2 - 
     2.25056258042369153e-6*g4*x2 + 
     0.0000441438108848823135*A2*g3*x4 + 
     0.0000185871013417309714*A*g4*x6 + 
     2.15148764772607365e-6*g5*x8)*xbar2 + 
  eps8*(4.1753513975736198e-8*A5 - 
     3.46221514376276281e-6*A2*g2 + 
     0.0000267222489444711667*A4*g*x2 - 
     0.0000281804101248545693*A*g3*x2 + 
     0.0000649475909892576559*A3*g2*x4 - 
     0.0000122030666735527847*g4*x4 + 
     0.0000403965247715247715*A2*g3*x6 + 
     9.0700810463541945e-6*A*g4*x8 + 
     6.69795953360768176e-7*g5*x10)*xbar2 + 
  eps11*(-6.80612866459427306e-8*A5*g + 
     1.95584655809718057e-7*A2*g3 - 
     4.47269759439071608e-6*A4*g2*x2 + 
     1.75829988748211593e-6*A*g4*x2 - 
     0.0000133314481239415102*A3*g3*x4 + 
     9.71399147418687179e-7*g5*x4 - 
     0.0000103064498801381517*A2*g4*x6 - 
     2.82142523293179157e-6*A*g5*x8 - 
     2.4892365507720446e-7*g6*x10)*xbar2 + 
  eps10*(-1.05683802773749864e-9*A6 + 
     5.67501373552960855e-7*A3*g2 - 
     4.8511255774108832e-8*g4 - 
     3.24660642120959581e-6*A5*g*x2 + 
     9.71126169538867952e-6*A2*g3*x2 - 
     0.0000131832441790279092*A4*g2*x4 + 
     0.0000108846610427711618*A*g4*x4 - 
     0.0000136365860158849577*A3*g3*x6 + 
     2.33168885512635513e-6*g5*x6 - 
     5.4993290386188865e-6*A2*g4*x8 - 
     9.46094479080590192e-7*A*g5*x10 - 
     5.8302302889011994e-8*g6*x12)*xbar2 + 
  eps13*(6.86627585651083939e-9*A6*g - 
     4.47785160224899766e-8*A3*g3 + 
     2.19249275444418889e-9*g5 + 
     7.19946098097358602e-7*A5*g2*x2 - 
     7.80379784965903039e-7*A2*g4*x2 + 
     3.37142842641135708e-6*A4*g3*x4 - 
     1.06398186364605041e-6*A*g5*x4 + 
     4.18165456228327982e-6*A3*g4*x6 - 
     2.76351067919865578e-7*g6*x6 + 
     2.00589567077445504e-6*A2*g5*x8 + 
     4.04753308555164946e-7*A*g6*x10 + 
     2.88571475583667131e-8*g7*x12)*xbar2 + 
  eps12*(2.67650730613693577e-11*A7 - 
     8.46192910475220622e-8*A4*g2 + 
     3.25142589196534057e-8*A*g4 + 
     3.83704087407791111e-7*A6*g*x2 - 
     2.57283359783619147e-6*A3*g3*x2 + 
     1.27951218977907431e-7*g5*x2 + 
     2.41765559329216737e-6*A5*g2*x4 - 
     5.44480881814382923e-6*A2*g4*x4 + 
     3.82233569685344377e-6*A4*g3*x6 - 
     2.81139544164632672e-6*A*g5*x6 + 
     2.42710273474001612e-6*A3*g4*x8 - 
     3.92027350262991887e-7*g6*x8 + 
     7.21984500196305752e-7*A2*g5*x10 + 
     1.007566064009769e-7*A*g6*x12 + 
     5.32759708629371695e-9*g7*x14)*xbar2 + 
  eps15*(-6.94677964495491896e-10*A7*g + 
     8.85485037384606633e-9*A4*g3 - 
     1.89784940868103996e-9*A*g5 - 
     1.08873720111587578e-7*A6*g2*x2 + 
     2.58200627219967634e-7*A3*g4*x2 - 
     8.57415659878293831e-9*g6*x2 - 
     7.52178044272582197e-7*A5*g3*x4 + 
     6.39174172204870162e-7*A2*g5*x4 - 
     1.38311030669262085e-6*A4*g4*x6 + 
     3.89805821462228289e-7*A*g6*x6 - 
     1.02272071613530239e-6*A3*g5*x8 + 
     6.35874554600849527e-8*g7*x8 - 
     3.51191445940869782e-7*A2*g6*x10 - 
     5.59975947545884819e-8*A*g7*x12 - 
     3.35001083013772154e-9*g8*x14)*xbar2 + 
  eps14*(-6.77936059264516573e-13*A8 + 
     1.18453251754498057e-8*A5*g2 - 
     1.26192122113177278e-8*A2*g4 - 
     4.44292175799593582e-8*A7*g*x2 + 
     5.78235471803035281e-7*A4*g3*x2 - 
     1.25465164813262727e-7*A*g5*x2 - 
     4.11093596933471078e-7*A6*g2*x4 + 
     2.00802343589623813e-6*A3*g4*x4 - 
     8.38456228452171631e-8*g6*x4 - 
     9.37962675222683393e-7*A5*g3*x6 + 
     1.84660973293660698e-6*A2*g5*x6 - 
     8.68952732620502728e-7*A4*g4*x8 + 
     5.95974150882540242e-7*A*g6*x8 - 
     3.93789587968658131e-7*A3*g5*x10 + 
     6.11861559616332661e-8*g7*x10 - 
     9.26911580977221589e-8*A2*g6*x12 - 
     1.08851336477984649e-8*A*g7*x14 - 
     5.04016698893419468e-10*g8*x16)*xbar2 + 
  eps17*(7.03519796756268115e-11*A8*g - 
     1.58412622695254907e-9*A5*g3 + 
     9.21824723042734146e-10*A2*g5 + 
     1.57013176618403867e-8*A7*g2*x2 - 
     7.07877152349972815e-8*A4*g4*x2 + 
     1.01145514044440416e-8*A*g6*x2 + 
     1.52755677874009072e-7*A6*g3*x4 - 
     2.78303968964189299e-7*A3*g5*x4 + 
     7.90216106829461597e-9*g7*x4 + 
     3.94839847004885584e-7*A5*g4*x6 - 
     2.95546266642869418e-7*A2*g6*x6 + 
     4.1812888733216445e-7*A4*g5*x8 - 
     1.09749260429676339e-7*A*g7*x8 + 
     2.15692160440115788e-7*A3*g6*x10 - 
     1.28547064754435117e-8*g8*x10 + 
     5.73688513495873601e-8*A2*g7*x12 + 
     7.55383153004710777e-9*A*g8*x14 + 
     3.89293296941875901e-10*g9*x16)*xbar2 + 
  eps16*(1.71721241125556891e-14*A9 - 
     1.58463391176416606e-9*A6*g2 + 
     3.70687203668986364e-9*A3*g4 - 
     1.21950914958299276e-10*g6 + 
     5.06426546628202339e-9*A8*g*x2 - 
     1.15919331839795365e-7*A5*g3*x2 + 
     6.813324046201634e-8*A2*g5*x2 + 
     6.59264102615256734e-8*A7*g2*x4 - 
     6.0783143535697607e-7*A4*g4*x4 + 
     1.08734552181364072e-7*A*g6*x4 + 
     2.08077893379438207e-7*A6*g3*x6 - 
     8.7376194571684116e-7*A3*g5*x6 + 
     3.31435423816449871e-8*g7*x6 + 
     2.67286143174399604e-7*A5*g4*x8 - 
     4.84990273878282454e-7*A2*g6*x8 + 
     1.71677767909550515e-7*A4*g5*x10 - 
     1.12268658721773254e-7*A*g7*x10 + 
     6.02176056859808662e-8*A3*g6*x12 - 
     9.09453722352822717e-9*g8*x12 + 
     1.17208819972660499e-8*A2*g7*x14 + 
     1.18834173730462595e-9*A*g8*x16 + 
     4.8940576382579539e-11*g9*x18)*xbar2 + 
  eps19*(-7.12707337587569786e-12*A9*g + 
     2.63376364359160315e-10*A6*g3 - 
     3.30780046645030994e-10*A3*g5 + 
     8.03679335161609342e-12*g7 - 
     2.18139573549146275e-9*A8*g2*x2 + 
     1.6989863583308778e-8*A5*g4*x2 - 
     6.4969385102430346e-9*A2*g6*x2 - 
     2.88250590711040757e-8*A7*g3*x4 + 
     9.81072496878526138e-8*A4*g5*x4 - 
     1.18346882869724656e-8*A*g7*x4 - 
     1.00731210992033847e-7*A6*g4*x6 + 
     1.59691202088983395e-7*A3*g6*x6 - 
     4.13548363870289057e-9*g8*x6 - 
     1.45496453255537213e-7*A5*g5*x8 + 
     1.00501516554651165e-7*A2*g7*x8 - 
     1.05051610378898918e-7*A4*g6*x10 + 
     2.62399674415998082e-8*A*g8*x10 - 
     4.12244346987175346e-8*A3*g7*x12 + 
     2.38101241880130705e-9*g9*x12 - 
     8.92371773273422321e-9*A2*g8*x14 - 
     1.00013636391153993e-9*A*g9*x16 - 
     4.52724718151082609e-11*g10*x18)*xbar2 + 
  eps18*(-4.34973739711612375e-16*A10 + 
     2.04866596742209561e-10*A7*g2 - 
     9.13337973503563032e-10*A4*g4 + 
     1.29494994082815314e-10*A*g6 - 
     5.70128780114804572e-10*A9*g*x2 + 
     2.13523668994309077e-8*A6*g3*x2 - 
     2.7041278749459319e-8*A3*g5*x2 + 
     6.61136770529593115e-10*g7*x2 - 
     1.00900226220693725e-8*A8*g2*x4 + 
     1.59771473522731497e-7*A5*g4*x4 - 
     7.62149977963186539e-8*A2*g6*x4 - 
     4.26288251723329756e-8*A7*g3*x6 + 
     3.32905368200259132e-7*A4*g5*x6 - 
     5.34789893441100738e-8*A*g7*x6 - 
     7.31666710191171495e-8*A6*g4*x8 + 
     2.80197106079331506e-7*A3*g6*x8 - 
     9.98659790379859243e-9*g8*x8 - 
     6.35106992331774466e-8*A5*g5*x10 + 
     1.08995209478400767e-7*A2*g7*x10 - 
     3.09539659674895079e-8*A4*g6*x12 + 
     1.95483783519714526e-8*A*g8*x12 - 
     8.83724740598401241e-9*A3*g7*x14 + 
     1.30582050443893102e-9*g9*x14 - 
     1.46593717511110234e-9*A2*g8*x16 - 
     1.30772635674859038e-10*A*g9*x18 - 
     4.84955398928857724e-12*g10*x20)*xbar2 + 
  eps21*(7.22090117277105046e-13*A10*g - 
     4.13991085301446953e-11*A7*g3 + 
     9.76589682716262956e-11*A4*g5 - 
     1.01171462635282484e-11*A*g7 + 
     2.94059482872196453e-10*A9*g2*x2 - 
     3.68979054877682005e-9*A6*g4*x2 + 
     3.00808714445394687e-9*A3*g6*x2 - 
     5.76746247671597889e-11*g8*x2 + 
     5.12696720776491515e-9*A8*g3*x4 - 
     2.96928069363177013e-8*A5*g5*x4 + 
     9.47962261651077826e-9*A2*g7*x4 + 
     2.35049540761358863e-8*A7*g4*x6 - 
     6.88556064847354174e-8*A4*g6*x6 + 
     7.5086659172629484e-9*A*g8*x6 + 
     4.47020768444263473e-8*A6*g5*x8 - 
     6.48548347717962229e-8*A3*g7*x8 + 
     1.57872287719044645e-9*g9*x8 + 
     4.31283591778531503e-8*A5*g6*x10 - 
     2.81624636750572854e-8*A2*g8*x10 + 
     2.3304946259676748e-8*A4*g7*x12 - 
     5.6106802334762125e-9*A*g9*x12 + 
     7.34468856466444926e-9*A3*g8*x14 - 
     4.14021761190658312e-10*g10*x14 + 
     1.33841053507869873e-9*A2*g9*x16 + 
     1.30531947930356562e-10*A*g10*x18 + 
     5.26795343697585529e-12*g11*x20)*xbar2 + 
  eps20*(1.1018005656720459e-17*A11 - 
     2.57889246901160178e-11*A8*g2 + 
     1.98990234155769708e-10*A5*g4 - 
     7.55965424361672699e-11*A2*g6 + 
     6.35426896472572163e-11*A10*g*x2 - 
     3.68388963577669912e-9*A7*g3*x2 + 
     8.75177480890399108e-9*A4*g5*x2 - 
     9.11535637885301799e-10*A*g7*x2 + 
     1.48649455332149944e-9*A9*g2*x4 - 
     3.77359746051647268e-8*A6*g4*x4 + 
     3.82594204726996217e-8*A3*g6*x4 - 
     8.13304101172221063e-10*g8*x4 + 
     8.18713369443791778e-9*A8*g3*x6 - 
     1.08366523313337395e-7*A5*g5*x6 + 
     4.5944289943616577e-8*A2*g7*x6 + 
     1.82487684327326814e-8*A7*g4*x8 - 
     1.28729795350649249e-7*A4*g6*x8 + 
     1.92747318307891877e-8*A*g8*x8 + 
     2.06867607666613227e-8*A6*g5*x10 - 
     7.43763204190519753e-8*A3*g7*x10 + 
     2.53626156501045944e-9*g9*x10 + 
     1.33838352059798451e-8*A5*g6*x12 - 
     2.20494122463979174e-8*A2*g8*x12 + 
     5.23330987914141423e-9*A4*g7*x14 - 
     3.21750395058170305e-9*A*g9*x14 + 
     1.25827561244148185e-9*A3*g8*x16 - 
     1.82713361623688652e-10*g10*x16 + 
     1.81827783439828152e-10*A2*g9*x18 + 
     1.44818570824073778e-11*A*g10*x20 + 
     4.88417660313835094e-13*g11*x22)*xbar2 + 
  eps23*(-7.31620058828327886e-14*A11*g + 
     6.2244144715351518e-12*A8*g3 - 
     2.50972722113902645e-11*A5*g5 + 
     6.90195578112387954e-12*A2*g7 - 
     3.86661866535845128e-11*A10*g2*x2 + 
     7.40985528302493753e-10*A7*g4*x2 - 
     1.12263534560497836e-9*A4*g6*x2 + 
     9.10038912793887614e-11*A*g8*x2 - 
     8.68557303415569482e-10*A9*g3*x4 + 
     7.99751265225702085e-9*A6*g5*x4 - 
     5.38995025036586533e-9*A3*g7*x4 + 
     9.11682355767971334e-11*g9*x4 - 
     5.09949189194303306e-9*A8*g4*x6 + 
     2.517151280314285e-8*A5*g6*x6 - 
     7.20688202607308513e-9*A2*g8*x6 - 
     1.24293927810383763e-8*A7*g5*x8 + 
     3.30698321741881119e-8*A4*g7*x8 - 
     3.36777220246894258e-9*A*g9*x8 - 
     1.55006071785928367e-8*A6*g6*x10 + 
     2.11300984088409138e-8*A3*g8*x10 - 
     4.91764411032702861e-10*g10*x10 - 
     1.10270946906705895e-8*A5*g7*x12 + 
     6.90528529828172647e-9*A2*g9*x12 - 
     4.72730487747526667e-9*A4*g8*x14 + 
     1.10602336934435099e-9*A*g10*x14 - 
     1.24144324312375269e-9*A3*g9*x16 + 
     6.86305256373542116e-11*g11*x16 - 
     1.95159691471731057e-10*A2*g10*x18 - 
     1.68433306811216689e-11*A*g11*x20 - 
     6.13262463130406207e-13*g12*x22)*xbar2 + 
  eps22*(-2.79089293716250467e-19*A12 + 
     3.17766604095748225e-12*A9*g2 - 
     3.95577368582764204e-11*A6*g4 + 
     3.2068101326980409e-11*A3*g6 - 
     6.12076747703341304e-13*g8 - 
     7.02351204594746519e-12*A11*g*x2 + 
     6.03214212931090113e-10*A8*g3*x2 - 
     2.44702734746155151e-9*A5*g5*x2 + 
     6.76097426096149884e-10*A2*g7*x2 - 
     2.12157940796992025e-10*A10*g2*x4 + 
     8.1916797369498686e-9*A7*g4*x4 - 
     1.53944612844692757e-8*A4*g6*x4 + 
     1.38109622177934475e-9*A*g8*x4 - 
     1.49038549899160153e-9*A9*g3*x6 + 
     3.12551588277558658e-8*A6*g5*x6 - 
     2.79047223116628872e-8*A3*g7*x6 + 
     5.436847471574281e-10*g9*x6 - 
     4.21695720957640858e-9*A8*g4*x8 + 
     4.99819767239979985e-8*A5*g6*x8 - 
     1.96069567048585921e-8*A2*g8*x8 - 
     6.0820173561110201e-9*A7*g5*x10 + 
     4.00069800775570726e-8*A4*g7*x10 - 
     5.69705873785929584e-9*A*g9*x10 - 
     5.05592156438231298e-9*A6*g6*x12 + 
     1.73541009641709023e-8*A3*g8*x12 - 
     5.72444406380114732e-10*g10*x12 - 
     2.58984982240261447e-9*A5*g7*x14 + 
     4.13461348937075909e-9*A2*g9*x14 - 
     8.43540110516749951e-10*A4*g8*x16 + 
     5.07648285991122299e-10*A*g10*x16 - 
     1.75053485949267209e-10*A3*g9*x18 + 
     2.50585955675889897e-11*g11*x18 - 
     2.24065847218371337e-11*A2*g10*x20 - 
     1.61190422371025444e-12*A*g11*x22 - 
     4.98497255151051565e-14*g12*x24)*xbar2 + 
  eps25*(7.41283040826477982e-15*A12*g - 
     9.02635849548132915e-13*A9*g3 + 
     5.808192723300797e-12*A6*g5 - 
     3.38057427569094457e-12*A3*g7 + 
     5.29100393497390523e-14*g9 + 
     4.97920609040144658e-12*A11*g2*x2 - 
     1.39694069095383245e-10*A8*g4*x2 + 
     3.58402228305301032e-10*A5*g6*x2 - 
     7.65495191386971796e-11*A2*g8*x2 + 
     1.4125212696675559e-10*A10*g3*x4 - 
     1.96338748728595609e-9*A7*g5*x4 + 
     2.43765341823600507e-9*A4*g7*x4 - 
     1.73076565727920605e-10*A*g9*x4 + 
     1.04116644719005016e-9*A9*g4*x6 - 
     8.09905476228113474e-9*A6*g6*x6 + 
     4.85986711480587249e-9*A3*g8*x6 - 
     7.57303676890670029e-11*g10*x6 + 
     3.18313608725054007e-9*A8*g5*x8 - 
     1.41719309600437594e-8*A5*g7*x8 + 
     3.76671783453056944e-9*A2*g9*x8 + 
     5.00343186081653831e-9*A7*g6*x10 - 
     1.24378552441987574e-8*A4*g8*x10 + 
     1.20496661429663104e-9*A*g10*x10 + 
     4.53880717317622481e-9*A6*g7*x12 - 
     5.90571016995380991e-9*A3*g9*x12 + 
     1.32811990726503565e-10*g11*x12 + 
     2.53296660339142496e-9*A5*g8*x14 - 
     1.53532762899011833e-9*A2*g10*x14 + 
     8.96296897032458165e-10*A4*g9*x16 - 
     2.04947909641080151e-10*A*g11*x16 + 
     2.01417828995844438e-10*A3*g10*x18 - 
     1.09580840956783665e-11*g12*x18 + 
     2.78250438436826e-11*A2*g11*x20 + 
     2.15336350583630878e-12*A*g12*x22 + 
     7.14181481885948442e-14*g13*x24)*xbar2 + 
  eps24*(7.06941407925893494e-21*A13 - 
     3.84741654463843396e-13*A10*g2 + 
     7.32293254814967057e-12*A7*g4 - 
     1.10404290967107504e-11*A4*g6 + 
     8.91430430592888932e-13*A*g8 + 
     7.70933065507593765e-13*A12*g*x2 - 
     9.46392329053276403e-11*A9*g3*x2 + 
     6.12204723118016064e-10*A6*g5*x2 - 
     3.57786436948859923e-10*A3*g7*x2 + 
     5.61900352465916136e-12*g9*x2 + 
     2.94794501076642169e-11*A11*g2*x4 - 
     1.66054285997922112e-9*A8*g4*x4 + 
     5.27270026858442259e-9*A5*g6*x4 - 
     1.24441828714339168e-9*A2*g8*x4 + 
     2.5932143768735243e-10*A10*g3*x6 - 
     8.18440975363309936e-9*A7*g5*x6 + 
     1.34316391603932223e-8*A4*g7*x6 - 
     1.0967577860615365e-9*A*g9*x6 + 
     9.14099216298559597e-10*A9*g4*x8 - 
     1.70303761165690513e-8*A6*g6*x8 + 
     1.39743392988134275e-8*A3*g8*x8 - 
     2.56275349412587196e-10*g10*x8 + 
     1.64295978902062036e-9*A8*g5*x10 - 
     1.80454719563725777e-8*A5*g7*x10 + 
     6.69540001883729058e-9*A2*g9*x10 + 
     1.71211385785801628e-9*A7*g6*x12 - 
     1.06969476032442112e-8*A4*g8*x12 + 
     1.46666897500527102e-9*A*g10*x12 + 
     1.11324562362569516e-9*A6*g7*x14 - 
     3.68698661561997461e-9*A3*g9*x14 + 
     1.18497108911150463e-10*g11*x14 + 
     4.70206598723156244e-10*A5*g8*x16 - 
     7.32089723755050849e-10*A2*g10*x16 + 
     1.31051469702399336e-10*A4*g9*x18 - 
     7.74991097074319971e-11*A*g11*x18 + 
     2.39115858864581722e-11*A3*g10*x20 - 
     3.38215281496470102e-12*g12*x20 + 
     2.74671447656417087e-12*A2*g11*x22 + 
     1.80167001235699906e-13*A*g12*x24 + 
     5.14468471968218436e-15*g13*x26)*xbar2 + 
  eps27*(-7.51075843529661214e-16*A13*g + 
     1.27030008776550472e-13*A10*g3 - 
     1.23787664790561913e-12*A7*g5 + 
     1.33019638955516254e-12*A4*g7 - 
     8.75323806724792164e-14*A*g9 - 
     6.29897142455818647e-13*A12*g2*x2 + 
     2.49970513387192938e-11*A9*g4*x2 - 
     1.0151027849161936e-10*A6*g6*x2 + 
     4.55816229506986659e-11*A3*g8*x2 - 
     6.05079004055138099e-13*g10*x2 - 
     2.21864408565359165e-11*A11*g3*x4 + 
     4.46844885997837561e-10*A8*g5*x4 - 
     9.32148098458465571e-10*A5*g7*x4 + 
     1.73258271490234049e-10*A2*g9*x4 - 
     2.01903912835646714e-10*A10*g4*x6 + 
     2.3520545127039623e-9*A7*g6*x6 - 
     2.58299973973554577e-9*A4*g8*x6 + 
     1.68010587801441092e-10*A*g10*x6 - 
     7.60717456057238184e-10*A9*g5*x8 + 
     5.3035966583288928e-9*A6*g7*x8 - 
     2.93817404535934839e-9*A3*g9*x8 + 
     4.31762252962423416e-11*g11*x8 - 
     1.47734599003688525e-9*A8*g6*x10 + 
     6.11354887209435414e-9*A5*g8*x10 - 
     1.5386347665145731e-9*A2*g10*x10 - 
     1.66823527450663911e-9*A7*g7*x12 + 
     3.94111855521203731e-9*A4*g9*x12 - 
     3.67480562505678573e-10*A*g11*x12 - 
     1.17484922387971434e-9*A6*g8*x14 + 
     1.47416329157764893e-9*A3*g10*x14 - 
     3.22644970036886805e-11*g12*x14 - 
     5.36421779678852887e-10*A5*g9*x16 + 
     3.1674778190064466e-10*A2*g11*x16 - 
     1.61202978156834228e-10*A4*g10*x18 + 
     3.61721347255152469e-11*A*g12*x18 - 
     3.16257866721202736e-11*A3*g11*x20 + 
     1.69763752975172776e-12*g13*x20 - 
     3.89515288561440053e-12*A2*g12*x22 - 
     2.73194264984077097e-13*A*g13*x24 - 
     8.31954367803020154e-15*g14*x26)*xbar2 + 
  eps26*(-1.79070348540750937e-22*A14 + 
     4.59064378043914658e-14*A11*g2 - 
     1.28030566526092309e-12*A8*g4 + 
     3.27066666352992692e-12*A5*g6 - 
     6.96122544470052509e-13*A2*g8 - 
     8.41204536665769716e-14*A13*g*x2 + 
     1.43280455193797042e-11*A10*g3*x2 - 
     1.40273974291259099e-10*A7*g5*x2 + 
     1.51283231860462901e-10*A4*g7*x2 - 
     9.98551158367175128e-12*A*g9*x2 - 
     4.00333440491699611e-12*A12*g2*x4 + 
     3.18015053542555029e-10*A9*g4*x4 - 
     1.59520735961063233e-9*A6*g6*x4 + 
     7.90439808401736791e-10*A3*g8*x4 - 
     1.10881173257059828e-11*g10*x4 - 
     4.34093541154382073e-11*A11*g3*x6 + 
     1.97976173597291254e-9*A8*g5*x6 - 
     5.44840751323234817e-9*A5*g7*x6 + 
     1.16297756207798465e-9*A2*g9*x6 - 
     1.87645728811177992e-10*A10*g4*x8 + 
     5.22333666100318922e-9*A7*g6*x8 - 
     7.83026501022594579e-9*A4*g8*x8 + 
     5.98605008455371809e-10*A*g10*x8 - 
     4.13221853558421767e-10*A9*g5*x10 + 
     7.0930748517934503e-9*A6*g7*x10 - 
     5.47699171024144332e-9*A3*g9*x10 + 
     9.60336772604947622e-11*g11*x10 - 
     5.29402656244831828e-10*A8*g6*x12 + 
     5.49671855849442248e-9*A5*g8*x12 - 
     1.95523008426311717e-9*A2*g10*x12 - 
     4.26701447988946737e-10*A7*g7*x14 + 
     2.56206141566278962e-9*A4*g9*x14 - 
     3.410012726945875e-10*A*g11*x14 - 
     2.26624447643405895e-10*A6*g8*x16 + 
     7.29466473293570049e-10*A3*g10*x16 - 
     2.29576353915048113e-11*g12*x16 - 
     8.12511797350192351e-11*A5*g9*x18 + 
     1.23935273887572293e-10*A2*g11*x18 - 
     1.97726428661170689e-11*A4*g10*x20 + 
     1.1522889199786472e-11*A*g12*x20 - 
     3.21807538962660607e-12*A3*g11*x22 + 
     4.50555068931041406e-13*g13*x22 - 
     3.35257433966932062e-13*A2*g12*x24 - 
     2.02087347024185195e-14*A*g13*x26 - 
     5.35972002923398376e-16*g14*x28)*xbar2 + 
  0.00833333333333333333*g*xbar4 - 
  0.0000462962962962962963*eps3*g2*xbar4 + 
  eps2*(-0.000396825396825396825*A*g - 
     0.000694444444444444444*g2*x2)*xbar4 + 
  eps5*(9.11896745230078563e-6*A*g2 + 
     0.0000308641975308641975*g3*x2)*xbar4 + 
  eps4*(0.0000198412698412698413*A2*g + 
     0.000195105820105820106*A*g2*x2 + 
     0.0000617283950617283951*g3*x4)*xbar4 + 
  eps7*(-1.31581381581381581e-6*A2*g2 - 
     0.0000151318588818588819*A*g3*x2 - 
     6.8455207344096233e-6*g4*x4)*xbar4 + 
  eps6*(-9.01875901875901876e-7*A3*g + 
     9.90714532381199048e-7*g3 - 
     0.0000389059243225909893*A2*g2*x2 - 
     0.0000351397573619795842*A*g3*x4 - 
     5.9477880658436214e-6*g4*x6)*xbar4 + 
  eps9*(1.71045640622360199e-7*A3*g2 - 
     3.60906857706966639e-8*g4 + 
     4.53245406122390249e-6*A2*g3*x2 + 
     5.38783061931210079e-6*A*g4*x4 + 
     1.17492514772607365e-6*g5*x6)*xbar4 + 
  eps8*(3.77616945077262538e-8*A4*g - 
     3.91505723846993688e-7*A*g3 + 
     6.55938527962337486e-6*A3*g2*x2 - 
     1.61985166325444103e-6*g4*x2 + 
     0.0000121547079219036891*A2*g3*x4 + 
     5.20508405346368309e-6*A*g4*x6 + 
     6.02301130368259998e-7*g5*x8)*xbar4 + 
  eps11*(-2.12135350797297057e-8*A4*g2 + 
     2.14460056215349951e-8*A*g4 - 
     1.06401470496877178e-6*A3*g3*x2 + 
     9.9419658966568008e-8*g5*x2 - 
     2.4228308825712602e-6*A2*g4*x4 - 
     1.28380796826126347e-6*A*g5*x6 - 
     1.80516340332649186e-7*g6*x8)*xbar4 + 
  eps10*(-1.48202033122668043e-9*A5*g + 
     9.77137892841674354e-8*A2*g3 - 
     9.98537198520664129e-7*A4*g2*x2 + 
     1.12096864298613054e-6*A*g4*x2 - 
     3.25929867376075489e-6*A3*g3*x4 + 
     6.52088831782005348e-7*g5*x4 - 
     2.59007734102806854e-6*A2*g4*x6 - 
     7.14333704061713321e-7*A*g5*x8 - 
     6.28878290312510992e-8*g6*x10)*xbar4 + 
  eps13*(2.55551047231023315e-9*A5*g2 - 
     7.48454109323006102e-9*A2*g4 + 
     2.14869723911233424e-7*A4*g3*x2 - 
     8.87037184673700903e-8*A*g5*x2 + 
     8.1367411096167446e-7*A3*g4*x4 - 
     6.24554324051377381e-8*g6*x4 + 
     7.73534185148061632e-7*A2*g5*x6 + 
     2.53114332805174734e-7*A*g6*x8 + 
     2.60907174059342559e-8*g7*x10)*xbar4 + 
  eps12*(5.52620037914155561e-11*A6*g - 
     1.96395897468419557e-8*A3*g3 + 
     1.73105497543500998e-9*g5 + 
     1.41930118072774209e-7*A5*g2*x2 - 
     4.4751871911848506e-7*A2*g4*x2 + 
     7.4329679752095632e-7*A4*g3*x4 - 
     6.48579919839268283e-7*A*g5*x4 + 
     9.56849686940199225e-7*A3*g4*x6 - 
     1.72592309647809413e-7*g6*x6 + 
     4.6549037372399414e-7*A2*g5*x8 + 
     9.4234108977460504e-8*A*g6*x10 + 
     6.6997976279157566e-9*g7*x12)*xbar4 + 
  eps15*(-3.01110179246578381e-10*A6*g2 + 
     1.99854473307210245e-9*A3*g4 - 
     1.0075222178954846e-10*g6 - 
     3.91236879782746971e-8*A5*g3*x2 + 
     4.42468326545839399e-8*A2*g5*x2 - 
     2.26449722207185509e-7*A4*g4*x4 + 
     7.48610321580336637e-8*A*g6*x4 - 
     3.38794481457344831e-7*A3*g5*x6 + 
     2.34467193453680488e-8*g7*x6 - 
     1.91586076465687549e-7*A2*g6*x8 - 
     4.4705147415174641e-8*A*g7*x10 - 
     3.62790374951045814e-9*g8*x12)*xbar4 + 
  eps14*(-1.97753534590218582e-12*A7*g + 
     3.46651613447685113e-9*A4*g3 - 
     1.3675698718070872e-9*A*g5 - 
     1.92080361104674656e-8*A6*g2*x2 + 
     1.34714593349386061e-7*A3*g4*x2 - 
     7.0165116069938331e-9*g6*x2 - 
     1.51234778678998732e-7*A5*g3*x4 + 
     3.57677410764887609e-7*A2*g5*x4 - 
     2.9119323970204683e-7*A4*g4*x6 + 
     2.24757818721415644e-7*A*g6*x6 - 
     2.19654624683123427e-7*A3*g5*x8 + 
     3.71577620957842484e-8*g7*x8 - 
     7.60245440599503551e-8*A2*g6*x10 - 
     1.21363875909823901e-8*A*g7*x12 - 
     7.23898306636066601e-10*g8*x14)*xbar4 + 
  eps17*(3.48460743277465292e-11*A7*g2 - 
     4.51506468378503526e-10*A4*g4 + 
     9.93046484625324211e-11*A*g6 + 
     6.6025042810186813e-9*A6*g3*x2 - 
     1.62520631488663842e-8*A3*g5*x2 + 
     5.61230122018474251e-10*g7*x2 + 
     5.51380920101008308e-8*A5*g4*x4 - 
     4.88479275078761747e-8*A2*g6*x4 + 
     1.20320332856371923e-7*A4*g5*x6 - 
     3.5365653527819202e-8*A*g7*x6 + 
     1.03628614951869648e-7*A3*g6*x8 - 
     6.71263413921269682e-9*g8*x8 + 
     4.07776601703241782e-8*A2*g7*x10 + 
     7.34880420888892836e-9*A*g8*x12 + 
     4.91163816649064884e-10*g9*x14)*xbar4 + 
  eps16*(6.84233044511131468e-14*A8*g - 
     5.60464705059266925e-10*A5*g3 + 
     6.1113506912043867e-10*A2*g5 + 
     2.50582201503812155e-9*A7*g2*x2 - 
     3.39024845059116986e-8*A4*g4*x2 + 
     7.66141086125169516e-9*A*g6*x2 + 
     2.82533097805425257e-8*A6*g3*x4 - 
     1.44153074493338505e-7*A3*g5*x4 + 
     6.29165697711773721e-9*g7*x4 + 
     7.70955531949116842e-8*A5*g4*x6 - 
     1.5856345215569678e-7*A2*g6*x6 + 
     8.37319173204484218e-8*A4*g5*x8 - 
     5.99155536147365961e-8*A*g7*x8 + 
     4.37139891312553985e-8*A3*g6*x10 - 
     7.07392441584795305e-9*g8*x10 + 
     1.16805756794796047e-8*A2*g7*x12 + 
     1.53807088851897092e-9*A*g8*x14 + 
     7.90314013633620188e-11*g9*x16)*xbar4 + 
  eps19*(-3.97340865876564659e-12*A8*g2 + 
     9.08389634660042267e-11*A5*g4 - 
     5.40989729447639056e-11*A2*g6 - 
     1.05114495716806379e-9*A7*g3*x2 + 
     4.89773729086143515e-9*A4*g5*x2 - 
     7.24791876301819899e-10*A*g7*x2 - 
     1.21370267986698838e-8*A6*g4*x4 + 
     2.29597017376750524e-8*A3*g6*x4 - 
     6.7748721115604107e-10*g8*x4 - 
     3.67138156717417151e-8*A5*g5*x6 + 
     2.85584385486008741e-8*A2*g7*x6 - 
     4.48093489348219503e-8*A4*g6*x8 + 
     1.22153837054061484e-8*A*g8*x8 - 
     2.6272947304230525e-8*A3*g7*x10 + 
     1.62436680861277498e-9*g9*x10 - 
     7.84757421369128482e-9*A2*g8*x12 - 
     1.1484952449755475e-9*A*g9*x14 - 
     6.52079226899128072e-11*g10*x16)*xbar4 + 
  eps18*(-2.30220514713186019e-15*A9*g + 
     8.50336672523331952e-11*A6*g3 - 
     2.03099120170330866e-10*A3*g5 + 
     6.86599038065945835e-12*g7 - 
     3.17730510813967685e-10*A8*g2*x2 + 
     7.52334651318304606e-9*A5*g4*x2 - 
     4.58441975864061026e-9*A2*g6*x2 - 
     4.93856631341031329e-9*A7*g3*x4 + 
     4.73460373170155555e-8*A4*g5*x4 - 
     8.81541701496240287e-9*A*g7*x4 - 
     1.83568265106518087e-8*A6*g4*x6 + 
     8.0214964397589886e-8*A3*g6*x6 - 
     3.16831385872351314e-9*g8*x6 - 
     2.73264771648576643e-8*A5*g5*x8 + 
     5.15584868924249984e-8*A2*g7*x8 - 
     2.00422243527645685e-8*A4*g6*x10 + 
     1.36105580520898305e-8*A*g8*x10 - 
     7.92549659107905268e-9*A3*g7*x12 + 
     1.24112226442452554e-9*g9*x12 - 
     1.72024465137340275e-9*A2*g8*x14 - 
     1.92684278620064115e-10*A*g9*x16 - 
     8.69704747258045207e-12*g10*x18)*xbar4 + 
  eps21*(4.47608018566873029e-13*A9*g2 - 
     1.67753308125991472e-11*A6*g4 + 
     2.15143559796472255e-11*A3*g6 - 
     5.36097713439665228e-13*g8 + 
     1.59789748504864926e-10*A8*g3*x2 - 
     1.28169491309084248e-9*A5*g5*x2 + 
     5.05873112365848404e-10*A2*g7*x2 + 
     2.46793239696357667e-9*A7*g4*x4 - 
     8.69126604407042738e-9*A4*g6*x4 + 
     1.08592337487209441e-9*A*g8*x4 + 
     9.97215933211799948e-9*A6*g5*x6 - 
     1.63775632230861457e-8*A3*g7*x6 + 
     4.39638545658591092e-10*g9*x6 + 
     1.6446217893554322e-8*A5*g6*x8 - 
     1.17661894622675905e-8*A2*g8*x8 + 
     1.33981457517207347e-8*A4*g7*x10 - 
     3.46334251627866228e-9*A*g9*x10 + 
     5.87002262267861254e-9*A3*g8*x12 - 
     3.50481841251753294e-10*g10*x12 + 
     1.40564140813720233e-9*A2*g9*x14 + 
     1.72885003376200776e-10*A*g10*x16 + 
     8.52860757101693105e-12*g11*x18)*xbar4 + 
  eps20*(7.56595105695415785e-17*A10*g - 
     1.22932630659041053e-11*A7*g3 + 
     5.58459887241763578e-11*A4*g5 - 
     8.11455810014543089e-12*A*g7 + 
     3.9383320785984906e-11*A9*g2*x2 - 
     1.51976152664836327e-9*A6*g4*x2 + 
     1.98780657022334646e-9*A3*g6*x2 - 
     5.0284224652211995e-11*g8*x2 + 
     8.18366713361052766e-10*A8*g3*x4 - 
     1.34227304693417849e-8*A5*g5*x4 + 
     6.6399136914675485e-9*A2*g7*x4 + 
     4.01847928057574067e-9*A7*g4*x6 - 
     3.25458326731869081e-8*A4*g6*x6 + 
     5.42627614195641677e-9*A*g8*x6 + 
     7.91216320845347941e-9*A6*g5*x8 - 
     3.14137939839749592e-8*A3*g7*x8 + 
     1.16149233526855299e-9*g9*x8 + 
     7.7806358292877523e-9*A5*g6*x10 - 
     1.38304354148956577e-8*A2*g8*x10 + 
     4.24844294383596806e-9*A4*g7*x12 - 
     2.77563538429180564e-9*A*g9*x12 + 
     1.34573608785890679e-9*A3*g8*x14 - 
     2.05451606449403644e-10*g10*x14 + 
     2.45603481008104843e-10*A2*g9*x16 + 
     2.39299395598715992e-11*A*g10*x18 + 
     9.63092387870827136e-13*g11*x20)*xbar4 + 
  eps23*(-4.99202514118831333e-14*A10*g2 + 
     2.89962490735076355e-12*A7*g4 - 
     6.97186084528071566e-12*A4*g6 + 
     7.39113581154999613e-13*A*g8 - 
     2.3394917837884362e-11*A9*g3*x2 + 
     3.01433272680195764e-10*A6*g5*x2 - 
     2.52901008371964216e-10*A3*g7*x2 + 
     4.9975823717035003e-12*g9*x2 - 
     4.70635007764103411e-10*A8*g4*x4 + 
     2.81182652238779472e-9*A5*g6*x4 - 
     9.27102400382163909e-10*A2*g8*x4 - 
     2.46882746644613326e-9*A7*g5*x6 + 
     7.47170357614364372e-9*A4*g7*x6 - 
     8.42342156242855593e-10*A*g9*x6 - 
     5.31658207824290054e-9*A6*g6*x8 + 
     7.96948615558779495e-9*A3*g8*x8 - 
     2.00535355872142721e-10*g10*x8 - 
     5.74925362613453206e-9*A5*g7*x10 + 
     3.87667862850608752e-9*A2*g9*x10 - 
     3.44992473074412105e-9*A4*g8*x12 + 
     8.569346015302056e-10*A*g10*x12 - 
     1.19748784968841458e-9*A3*g9*x14 + 
     6.95772409909226155e-11*g11*x14 - 
     2.38602512157003406e-10*A2*g10*x16 - 
     2.52826017059561289e-11*A*g11*x18 - 
     1.10236531866119468e-12*g12*x20)*xbar4 + 
  eps22*(-2.43710422261727909e-18*A11*g + 
     1.71109183419778529e-12*A8*g3 - 
     1.34309072457408887e-11*A5*g5 + 
     5.2173544345517194e-12*A2*g7 - 
     4.7920869812117813e-12*A10*g2*x2 + 
     2.85329265230758798e-10*A7*g4*x2 - 
     6.97857430562307631e-10*A4*g6*x2 + 
     7.49694255924035744e-11*A*g8*x2 - 
     1.29794915911680679e-10*A9*g3*x4 + 
     3.40176751053615467e-9*A6*g5*x4 - 
     3.56524460909925476e-9*A3*g7*x4 + 
     7.84071353306302568e-11*g9*x4 - 
     8.21445917536130217e-10*A8*g4*x6 + 
     1.12426357550003378e-8*A5*g6*x6 - 
     4.93283496356209241e-9*A2*g8*x6 - 
     2.08160234188537877e-9*A7*g5*x8 + 
     1.51837246414786265e-8*A4*g7*x8 - 
     2.35241679748374184e-9*A*g9*x8 - 
     2.65426623474241136e-9*A6*g6*x10 + 
     9.86143500745746335e-9*A3*g8*x10 - 
     3.47704012872899376e-10*g10*x10 - 
     1.91288185358486004e-9*A5*g7*x12 + 
     3.25348485105233778e-9*A2*g9*x12 - 
     8.26008166150946402e-10*A4*g8*x14 + 
     5.23734714713970356e-10*A*g10*x14 - 
     2.17662681277754724e-10*A3*g9*x16 + 
     3.25604627396838786e-11*g11*x16 - 
     3.42430735395904115e-11*A2*g10*x18 - 
     2.95184625537922171e-12*A*g11*x20 - 
     1.07193479659543963e-13*g12*x22)*xbar4 + 
  eps25*(5.52110506767784823e-15*A11*g2 - 
     4.75457501278592475e-13*A8*g4 + 
     1.95091086985767411e-12*A5*g6 - 
     5.4799904221049527e-13*A2*g8 + 
     3.32019238817893755e-12*A10*g3*x2 - 
     6.51730724398874192e-11*A7*g5*x2 + 
     1.01363516265109903e-10*A4*g7*x2 - 
     8.44789910534162239e-12*A*g9*x2 + 
     8.51083543466993974e-11*A9*g4*x4 - 
     8.06323901456713728e-10*A6*g6*x4 + 
     5.59802124945716162e-10*A3*g8*x4 - 
     9.76067472405711475e-12*g10*x4 + 
     5.66519419429771184e-10*A8*g5*x6 - 
     2.8819770278242875e-9*A5*g7*x6 + 
     8.51033871024505535e-10*A2*g9*x6 + 
     1.55194749123254554e-9*A7*g6*x8 - 
     4.25684634896380492e-9*A4*g8*x8 + 
     4.47161048996184315e-10*A*g10*x8 + 
     2.15624685611586417e-9*A6*g7*x10 - 
     3.0292495877704562e-9*A3*g9*x10 + 
     7.26885557001226871e-11*g11*x10 + 
     1.69504305032585424e-9*A5*g8*x12 - 
     1.09320524328573703e-9*A2*g10*x12 + 
     7.97072138471286562e-10*A4*g9*x14 - 
     1.91910963351846343e-10*A*g11*x14 + 
     2.28095958403189066e-10*A3*g10*x16 - 
     1.29653228354651865e-11*g12*x16 + 
     3.88462248089520305e-11*A2*g11*x18 + 
     3.61325068184705851e-12*A*g12*x20 + 
     1.41129299633557724e-13*g13*x22)*xbar4 + 
  eps24*(7.71585736870360985e-20*A12*g - 
     2.30992258376006814e-13*A9*g3 + 
     2.92102366881800346e-12*A6*g5 - 
     2.41669954412293445e-12*A3*g7 + 
     4.72216204539068631e-14*g9 + 
     5.74184634945686335e-13*A11*g2*x2 - 
     5.05105154346589262e-11*A8*g4*x2 + 
     2.10380593488870381e-10*A5*g6*x2 - 
     5.97933596683359805e-11*A2*g8*x2 + 
     1.98448558495321466e-11*A10*g3*x4 - 
     7.88832679162696204e-10*A7*g5*x4 + 
     1.52819851860648456e-9*A4*g7*x4 - 
     1.41460420089467831e-10*A*g9*x4 + 
     1.58609533764471402e-10*A9*g4*x6 - 
     3.43038983424224915e-9*A6*g6*x6 + 
     3.16143488249608422e-9*A3*g8*x6 - 
     6.36135955205512617e-11*g10*x6 + 
     5.0613788167530953e-10*A8*g5*x8 - 
     6.18873950256648937e-9*A5*g7*x8 + 
     2.5062720440597051e-9*A2*g9*x8 + 
     8.15831547687990564e-10*A7*g6*x10 - 
     5.53396691054777854e-9*A4*g8*x10 + 
     8.13144274490680289e-10*A*g10*x10 + 
     7.51495225003727191e-10*A6*g7*x12 - 
     2.65804849164409833e-9*A3*g9*x12 + 
     9.04010499952531028e-11*g11*x12 + 
     4.23273801532746854e-10*A5*g8*x14 - 
     6.95727565670343238e-10*A2*g10*x14 + 
     1.50552227564369774e-10*A4*g9*x16 - 
     9.31966125875092865e-11*A*g11*x16 + 
     3.39107891271974624e-11*A3*g10*x18 - 
     4.98855443293551953e-12*g12*x18 + 
     4.68573921494252176e-12*A2*g11*x20 + 
     3.62148289824228147e-13*A*g12*x22 + 
     1.1980881282823611e-14*g13*x24)*xbar4 + 
  eps26*(-2.40642944243818635e-21*A13*g + 
     3.04076267712359871e-14*A10*g3 - 
     5.87195948302404653e-13*A7*g5 + 
     9.02024049542844894e-13*A4*g7 - 
     7.44236616778245869e-14*A*g9 - 
     6.79097450394172245e-14*A12*g2*x2 + 
     8.51963574281276708e-12*A9*g4*x2 - 
     5.64546785590600388e-11*A6*g6*x2 + 
     3.38607923476519669e-11*A3*g8*x2 - 
     5.46405541321999628e-13*g10*x2 - 
     2.94120416719332449e-12*A11*g3*x4 + 
     1.7014263234465762e-10*A8*g5*x4 - 
     5.55586418016715407e-10*A5*g7*x4 + 
     1.34977648095717031e-10*A2*g9*x4 - 
     2.9181367456125663e-11*A10*g4*x6 + 
     9.47639077544887723e-10*A7*g6*x6 - 
     1.60171638895294337e-9*A4*g8*x6 + 
     1.34775506533895858e-10*A*g10*x6 - 
     1.15182756156558058e-10*A9*g5*x8 + 
     2.20916412108007294e-9*A6*g7*x8 - 
     1.86753303861358136e-9*A3*g9*x8 + 
     3.52966346576477379e-11*g11*x8 - 
     2.30014920617832728e-10*A8*g6*x10 + 
     2.60032285423373586e-9*A5*g8*x10 - 
     9.93669928603769451e-10*A2*g10*x10 - 
     2.64323489013737578e-10*A7*g7*x12 + 
     1.69887680881412942e-9*A4*g9*x12 - 
     2.39763019711547791e-10*A*g11*x12 - 
     1.88221747596454675e-10*A6*g8*x14 + 
     6.40830830030619142e-10*A3*g10*x14 - 
     2.11838087406217002e-11*g12*x14 - 
     8.65239787552783906e-11*A5*g9*x16 + 
     1.38377453950046014e-10*A2*g11*x16 - 
     2.60995135254219062e-11*A4*g10*x18 + 
     1.58412457476077222e-11*A*g12*x18 - 
     5.12826665801042948e-12*A3*g11*x20 + 
     7.43887970125067621e-13*g13*x20 - 
     6.31542723119822078e-13*A2*g12*x22 - 
     4.42328923105620097e-14*A*g13*x24 - 
     1.34380744386943457e-15*g14*x26)*xbar4 - 
  0.0000154320987654320988*eps2*g2*xbar6 + 
  3.56125356125356125e-7*eps5*g3*xbar6 + 
  eps4*(1.90396023729357063e-6*A*g2 + 
     7.71604938271604938e-6*g3*x2)*xbar6 + 
  eps7*(-1.06760523427190094e-7*A*g3 - 
     5.83649889205444761e-7*g4*x2)*xbar6 + 
  eps6*(-1.58222876476844731e-7*A2*g2 - 
     3.0990100434544879e-6*A*g3*x2 - 
     1.45170544476100032e-6*g4*x4)*xbar6 + 
  eps9*(2.10474956623416007e-8*A2*g3 + 
     3.52066889376257568e-7*A*g4*x2 + 
     2.15683591284989252e-7*g5*x4)*xbar6 + 
  eps8*(1.0639753805538638e-8*A3*g2 - 
     1.44647796358943781e-8*g4 + 
     7.89019059521705024e-7*A2*g3*x2 + 
     9.93278626380478232e-7*A*g4*x4 + 
     2.19830466744046991e-7*g5*x6)*xbar6 + 
  eps11*(-3.48009271425128996e-9*A3*g3 + 
     7.74456172615070677e-10*g5 - 
     1.24759056081950737e-7*A2*g4*x2 - 
     1.93124743183608916e-7*A*g5*x4 - 
     5.26262283781649553e-8*g6*x6)*xbar6 + 
  eps10*(-6.21784885258793341e-10*A4*g2 + 
     7.35917308458240036e-9*A*g4 - 
     1.61082849737015107e-7*A3*g3*x2 + 
     4.25042008023580282e-8*g5*x2 - 
     3.97181909847740069e-7*A2*g4*x4 - 
     2.15693489113968417e-7*A*g5*x6 - 
     3.05361793587726322e-8*g6*x8)*xbar6 + 
  eps13*(5.22929181665348026e-10*A4*g3 - 
     5.49761548927799316e-10*A*g5 + 
     3.37795673591345898e-8*A3*g4*x2 - 
     3.32362369023656752e-9*g6*x2 + 
     9.70864128827426103e-8*A2*g5*x4 + 
     6.29082935052959515e-8*A*g6*x6 + 
     1.05359214957493409e-8*g7*x8)*xbar6 + 
  eps12*(3.28023733515722384e-11*A5*g2 - 
     2.2483490443839068e-9*A2*g4 + 
     2.87554439944054822e-8*A4*g3*x2 - 
     3.41643318587639607e-8*A*g5*x2 + 
     1.20413081223750724e-7*A3*g4*x4 - 
     2.54382194661358481e-8*g6*x4 + 
     1.18403247344882478e-7*A2*g5*x6 + 
     3.92485363936068314e-8*A*g6*x8 + 
     4.05810532585570662e-9*g7*x10)*xbar6 + 
  eps15*(-7.38610165433134699e-11*A5*g3 + 
     2.23185618064230175e-10*A2*g5 - 
     7.72550467360774725e-9*A4*g4*x2 + 
     3.33675225731002428e-9*A*g6*x2 - 
     3.60024022499056884e-8*A3*g5*x4 + 
     2.89391686340197044e-9*g7*x4 - 
     4.11034234008140627e-8*A2*g6*x6 - 
     1.58061594311664227e-8*A*g7*x8 - 
     1.88044966020543737e-9*g8*x10)*xbar6 + 
  eps14*(-1.59924972891624396e-12*A6*g2 + 
     5.34559467656326695e-10*A3*g4 - 
     4.89531412255654985e-11*g6 - 
     4.68743656687813986e-9*A5*g3*x2 + 
     1.55203340852120435e-8*A2*g5*x2 - 
     3.05848967636635251e-8*A4*g4*x4 + 
     2.80191583068273077e-8*A*g6*x4 - 
     4.77391188802852923e-8*A3*g5*x6 + 
     9.0249644584421326e-9*g7*x6 - 
     2.7500470429085428e-8*A2*g6*x8 - 
     6.46467617732357999e-9*A*g7*x10 - 
     5.25206836466407194e-10*g8*x12)*xbar6 + 
  eps17*(9.97455222947976728e-12*A6*g3 - 
     6.79725936335510667e-11*A3*g5 + 
     3.53973893285757087e-12*g7 + 
     1.57106382527547975e-9*A5*g4*x2 - 
     1.84906281043290629e-9*A2*g6*x2 + 
     1.0959810274248971e-8*A4*g5*x4 - 
     3.77750956813660573e-9*A*g7*x4 + 
     1.93914172243944712e-8*A3*g6*x6 - 
     1.39852236310538808e-9*g8*x6 + 
     1.27378874003962749e-8*A2*g7*x8 + 
     3.39967157316226349e-9*A*g8*x10 + 
     3.11454821672654227e-10*g9*x12)*xbar6 + 
  eps16*(7.32043787188737753e-14*A7*g2 - 
     1.08932623361419343e-10*A4*g4 + 
     4.43882953795228996e-11*A*g6 + 
     7.1553877265847084e-10*A6*g3*x2 - 
     5.23629960443907472e-9*A3*g5*x2 + 
     2.84608830720512483e-10*g7*x2 + 
     6.85430762519816909e-9*A5*g4*x4 - 
     1.69359418456327738e-8*A2*g6*x4 + 
     1.57308771746978335e-8*A4*g5*x6 - 
     1.26738239683828291e-8*A*g7*x6 + 
     1.38726146998630169e-8*A3*g6*x8 - 
     2.44574523622132431e-9*g8*x8 + 
     5.52081375700205184e-9*A2*g7*x10 + 
     9.99298373572599506e-10*A*g8*x12 + 
     6.67917519196695508e-11*g9*x14)*xbar6 + 
  eps19*(-1.30114590146037234e-12*A7*g3 + 
     1.72511713934239417e-11*A4*g5 - 
     3.90436685140620179e-12*A*g7 - 
     2.92867814057581221e-10*A6*g4*x2 + 
     7.46902977877224456e-10*A3*g6*x2 - 
     2.67522864508407854e-11*g8*x2 - 
     2.89699505443225961e-9*A5*g5*x4 + 
     2.66562938868512264e-9*A2*g7*x4 - 
     7.37795565467524207e-9*A4*g6*x6 + 
     2.25247153971908075e-9*A*g8*x6 - 
     7.30651817416318482e-9*A3*g7*x8 + 
     4.91176292870876797e-10*g9*x8 - 
     3.26224960924321828e-9*A2*g8*x10 - 
     6.59449314458554338e-10*A*g9*x12 - 
     4.89514760970749125e-11*g10*x14)*xbar6 + 
  eps18*(-3.18177848990088646e-15*A8*g2 + 
     1.99695443999379049e-11*A5*g4 - 
     2.23943125358944015e-11*A2*g6 - 
     1.03933552034436454e-10*A7*g3*x2 + 
     1.45959832999336206e-9*A4*g5*x2 - 
     3.42631031918890525e-10*A*g7*x2 - 
     1.39812800630481225e-9*A6*g4*x4 + 
     7.42096889844293084e-9*A3*g6*x4 - 
     3.37099552457525213e-10*g8*x4 - 
     4.48155653124553849e-9*A5*g5*x6 + 
     9.58666614025997167e-9*A2*g7*x6 - 
     5.62734416286699799e-9*A4*g6*x8 + 
     4.18363357640745376e-9*A*g8*x8 - 
     3.34880212849529458e-9*A3*g7*x10 + 
     5.62255597605531686e-10*g9*x10 - 
     1.00758346454303337e-9*A2*g8*x12 - 
     1.478403576160079e-10*A*g9*x14 - 
     8.38903736074731077e-12*g10*x16)*xbar6 + 
  eps21*(1.65107570494289514e-13*A8*g3 - 
     3.85243170234057994e-12*A5*g5 + 
     2.35361375548192462e-12*A2*g7 + 
     5.10417794581330247e-11*A7*g4*x2 - 
     2.45495411183393324e-10*A4*g6*x2 + 
     3.75511182588112891e-11*A*g8*x2 + 
     6.87936705237642027e-10*A6*g5*x4 - 
     1.34714877461804848e-9*A3*g7*x4 + 
     4.11758068629525797e-11*g9*x4 + 
     2.400949695111526e-9*A5*g6*x6 - 
     1.93419604503727388e-9*A2*g8*x6 + 
     3.33918824376270404e-9*A4*g7*x8 - 
     9.42270610564786763e-10*A*g9*x8 + 
     2.20558587287283118e-9*A3*g8*x10 - 
     1.41026346318580081e-10*g10*x10 + 
     7.34671001558905886e-10*A2*g9*x12 + 
     1.18846098758935012e-10*A*g10*x14 + 
     7.4012085886463764e-12*g11*x16)*xbar6 + 
  eps20*(1.32423923182168128e-16*A9*g2 - 
     3.38762545168358761e-12*A6*g4 + 
     8.2936742090468515e-12*A3*g6 - 
     2.88553271599458446e-13*g8 + 
     1.45206721816612312e-11*A8*g3*x2 - 
     3.55365267771350475e-10*A5*g5*x2 + 
     2.24067642028217925e-10*A2*g7*x2 + 
     2.64931375976082846e-10*A7*g4*x4 - 
     2.63256077540054192e-9*A4*g6*x4 + 
     5.08380778036583002e-10*A*g8*x4 + 
     1.14232293931335993e-9*A6*g5*x6 - 
     5.17535342835764208e-9*A3*g7*x6 + 
     2.12052573958312186e-10*g9*x6 + 
     1.94686955319541028e-9*A5*g6*x8 - 
     3.80593235862788058e-9*A2*g8*x8 + 
     1.61506335347690598e-9*A4*g7*x10 - 
     1.13519934804077239e-9*A*g9*x10 + 
     7.1467043552215311e-10*A3*g8*x12 - 
     1.15698350133799093e-10*g10*x12 + 
     1.719691436452393e-10*A2*g9*x14 + 
     2.11817828858919301e-11*A*g10*x16 + 
     1.0439296901669795e-12*g11*x18)*xbar6 + 
  eps23*(-2.04862878355181306e-14*A9*g3 + 
     7.81972174797918537e-13*A6*g5 - 
     1.02619259166044427e-12*A3*g7 + 
     2.62433518896336934e-14*g9 - 
     8.43060024092694187e-12*A8*g4*x2 + 
     6.95862769500813447e-11*A5*g6*x2 - 
     2.83043426411699199e-11*A2*g8*x2 - 
     1.50105719428983393e-10*A7*g5*x4 + 
     5.45631016826002967e-10*A4*g7*x4 - 
     7.04209555461881305e-11*A*g9*x4 - 
     6.92804131934363177e-10*A6*g6*x6 + 
     1.17532183940399869e-9*A3*g8*x6 - 
     3.2607052539653876e-11*g10*x6 - 
     1.29157220680419803e-9*A5*g7*x8 + 
     9.54295239973687871e-10*A2*g9*x8 - 
     1.17766893656649956e-9*A4*g8*x10 + 
     3.14180951036205697e-10*A*g10*x10 - 
     5.72342109737974456e-10*A3*g9*x12 + 
     3.52378082126753302e-11*g11*x12 - 
     1.50826983016266947e-10*A2*g10*x14 - 
     2.0272522360825874e-11*A*g11*x16 - 
     1.08615017352219442e-12*g12*x18)*xbar6 + 
  eps22*(-5.31170301889157885e-18*A10*g2 + 
     5.41512008345912225e-13*A7*g4 - 
     2.51484843977932421e-12*A4*g6 + 
     3.74997952559516213e-13*A*g8 - 
     1.96622519209470769e-12*A9*g3*x2 + 
     7.81432830846281016e-11*A6*g5*x2 - 
     1.0541243620224235e-10*A3*g7*x2 + 
     2.75343063440850494e-12*g9*x2 - 
     4.73066561901215884e-11*A8*g4*x4 + 
     8.01663669414465443e-10*A5*g6*x4 - 
     4.10061241924541413e-10*A2*g8*x4 - 
     2.66530256112802594e-10*A7*g5*x6 + 
     2.23182456344329143e-9*A4*g7*x6 - 
     3.84966796590767183e-10*A*g9*x6 - 
     5.95626630491287062e-10*A6*g6*x8 + 
     2.44421723666841458e-9*A3*g8*x8 - 
     9.34592147729657581e-11*g10*x8 - 
     6.57899358910793091e-10*A5*g7*x10 + 
     1.20777680989039448e-9*A2*g9*x10 - 
     3.99711629253997661e-10*A4*g8*x12 + 
     2.69443230465710687e-10*A*g10*x12 - 
     1.39709228180795027e-10*A3*g9*x14 + 
     2.19843031752725675e-11*g11*x14 - 
     2.79291327736950798e-11*A2*g10*x16 - 
     2.96151288108938101e-12*A*g11*x18 - 
     1.2897624149994603e-13*g12*x20)*xbar6 + 
  eps25*(2.49529026185645818e-15*A10*g3 - 
     1.47364999575620113e-13*A7*g5 + 
     3.61793330174044282e-13*A4*g7 - 
     3.9275827608463396e-14*A*g9 + 
     1.33267432811445249e-12*A9*g4*x2 - 
     1.76226656347218737e-11*A6*g6*x2 + 
     1.51981285144972782e-11*A3*g8*x2 - 
     3.09047867049178855e-13*g10*x2 + 
     3.05759645727357997e-11*A8*g5*x4 - 
     1.88074902764808623e-10*A5*g7*x4 + 
     6.38987124625316395e-11*A2*g9*x4 + 
     1.81594794134116284e-10*A7*g6*x6 - 
     5.66388647497927962e-10*A4*g8*x6 + 
     6.58443356039861601e-11*A*g10*x6 + 
     4.38886401428118561e-10*A6*g7*x8 - 
     6.78019204359987597e-10*A3*g9*x8 + 
     1.75910452362917948e-11*g11*x8 + 
     5.28081354282393227e-10*A5*g8*x10 - 
     3.66812184128119593e-10*A2*g10*x10 + 
     3.4980339641893081e-10*A4*g9*x12 - 
     8.94452198882115659e-11*A*g11*x12 + 
     1.33078990927212951e-10*A3*g10*x14 - 
     7.95340803513130482e-12*g12*x14 + 
     2.88781928840622656e-11*A2*g11*x16 + 
     3.31366831051057885e-12*A*g12*x18 + 
     1.55671198912292546e-13*g13*x20)*xbar6 + 
  eps24*(2.06387813484462373e-19*A11*g2 - 
     8.25816672282089385e-14*A8*g4 + 
     6.61224936974016378e-13*A5*g6 - 
     2.6296608110606801e-13*A2*g8 + 
     2.59487556558260317e-13*A10*g3*x2 - 
     1.58652084976253468e-11*A7*g5*x2 + 
     3.99067733898254196e-11*A4*g7*x2 - 
     4.41486037628790473e-12*A*g9*x2 + 
     8.04335423698123335e-12*A9*g4*x4 - 
     2.17197514727606655e-10*A6*g6*x4 + 
     2.34756708639459969e-10*A3*g8*x4 - 
     5.32762009285759642e-12*g10*x4 + 
     5.78511754053948431e-11*A8*g5*x6 - 
     8.16589511753311956e-10*A5*g7*x6 + 
     3.69778863261878567e-10*A2*g9*x6 + 
     1.65106656495643349e-10*A7*g6*x8 - 
     1.24201778524548735e-9*A4*g8*x8 + 
     1.98568405951987234e-10*A*g10*x8 + 
     2.34986277079273996e-10*A6*g7*x10 - 
     8.99890172295623428e-10*A3*g9*x10 + 
     3.27229290168583213e-11*g11*x10 + 
     1.87460264805506997e-10*A5*g8*x12 - 
     3.28389964017235726e-10*A2*g10*x12 + 
     8.89367704930636301e-11*A4*g9*x14 - 
     5.80300246028472628e-11*A*g11*x14 + 
     2.55778143867196837e-11*A3*g10*x16 - 
     3.93390423737093991e-12*g12*x16 + 
     4.36578811240031125e-12*A2*g11*x18 + 
     4.06167949307034346e-13*A*g12*x20 + 
     1.58438482461786504e-14*g13*x22)*xbar6 + 
  5.93542260208926876e-8*eps4*g3*xbar8 - 
  3.12288574815807931e-9*eps7*g4*xbar8 + 
  eps6*(-1.14340392118169896e-8*A*g3 - 
     9.02678854067742957e-8*g4*x2)*xbar8 + 
  eps9*(1.26121885620031857e-9*A*g4 + 
     1.00859349622512295e-8*g5*x2)*xbar8 + 
  eps8*(1.32727772394750297e-9*A2*g3 + 
     4.65033697944917988e-8*A*g4*x2 + 
     2.99054295797669073e-8*g5*x4)*xbar8 + 
  eps11*(-3.15709843216944468e-10*A2*g4 - 
     7.21099301568180965e-9*A*g5*x2 - 
     5.69746824484251863e-9*g6*x4)*xbar8 + 
  eps10*(-1.18235613578975095e-10*A3*g3 + 
     2.04522364126337295e-10*g5 - 
     1.4372001684607648e-8*A2*g4*x2 - 
     2.38545902650207871e-8*A*g5*x4 - 
     6.6442647298050802e-9*g6*x6)*xbar8 + 
  eps13*(6.34254881618462429e-11*A3*g4 - 
     1.4977795563804726e-11*g6 + 
     2.95036268409924151e-9*A2*g5*x2 + 
     5.72733871097688746e-9*A*g6*x4 + 
     1.89780374932858316e-9*g7*x6)*xbar8 + 
  eps12*(8.85933436332280376e-12*A4*g3 - 
     1.2695043367275619e-10*A*g5 + 
     3.44553148081436095e-9*A3*g4*x2 - 
     9.66117808074637814e-10*g6*x2 + 
     1.08393242236143663e-8*A2*g5*x4 + 
     7.24181767567549532e-9*A*g6*x6 + 
     1.22738677265426237e-9*g7*x8)*xbar8 + 
  eps15*(-1.1209244129052603e-11*A4*g4 + 
     1.23354796462055584e-11*A*g6 - 
     9.05322252904213583e-10*A3*g5*x2 + 
     9.34529456546429641e-11*g7*x2 - 
     3.18804749658072552e-9*A2*g6*x4 - 
     2.46989894878460521e-9*A*g7*x6 - 
     4.84553260391626981e-10*g8*x8)*xbar8 + 
  eps14*(-5.85591473164617337e-13*A5*g3 + 
     4.58152437519766974e-11*A2*g5 - 
     7.06061940978074562e-10*A4*g4*x2 + 
     8.8437067488213914e-10*A*g6*x2 - 
     3.6718459581734819e-9*A3*g5*x4 + 
     8.14572670487090063e-10*g7*x4 - 
     4.35865819040676537e-9*A2*g6*x6 - 
     1.70511399881374369e-9*A*g7*x8 - 
     2.04267683542374506e-10*g8*x10)*xbar8 + 
  eps17*(1.81850832862627129e-12*A5*g4 - 
     5.7018133606605742e-12*A2*g6 + 
     2.31363157692796144e-10*A4*g5*x2 - 
     1.04268313475235866e-10*A*g7*x2 + 
     1.29559671265166405e-9*A3*g6*x4 - 
     1.08608812804810835e-10*g8*x4 + 
     1.74321237740579218e-9*A2*g7*x6 + 
     7.76515634579396129e-10*A*g8*x8 + 
     1.05455124124405657e-10*g9*x10)*xbar8 + 
  eps16*(3.51441987362562031e-14*A6*g3 - 
     1.25669585862967901e-11*A3*g5 + 
     1.19873609386538047e-12*g7 + 
     1.29917477297039227e-10*A5*g4*x2 - 
     4.50505663684441363e-10*A2*g6*x2 + 
     1.0294836459233229e-9*A4*g5*x4 - 
     9.85762364733873057e-10*A*g7*x4 + 
     1.90892686734913978e-9*A3*g6*x6 - 
     3.76480107979462358e-10*g8*x6 + 
     1.28194605951425965e-9*A2*g7*x8 + 
     3.45797358676807567e-10*A*g8*x10 + 
     3.18111454415424726e-11*g9*x12)*xbar8 + 
  eps19*(-2.77181792125363476e-13*A6*g4 + 
     1.94851026920691567e-12*A3*g6 - 
     1.04933332657610013e-13*g8 - 
     5.1992259514176436e-11*A5*g5*x2 + 
     6.35571518081156783e-11*A2*g7*x2 - 
     4.28732342024609978e-10*A4*g6*x4 + 
     1.53545689985903239e-10*A*g8*x4 - 
     8.82875940509388448e-10*A3*g7*x6 + 
     6.61143800669246729e-11*g9*x6 - 
     6.65258660548452332e-10*A2*g8*x8 - 
     2.01099007966251153e-10*A*g9*x10 - 
     2.06386033152073184e-11*g10*x12)*xbar8 + 
  eps18*(-1.95213901631847725e-15*A7*g3 + 
     2.9024042061210064e-12*A4*g5 - 
     1.22464345499091446e-12*A*g7 - 
     2.20948357179324358e-11*A6*g4*x2 + 
     1.68407222784752482e-10*A3*g6*x2 - 
     9.52673617116155421e-12*g8*x2 - 
     2.52285174010719033e-10*A5*g5*x4 + 
     6.48893132761825578e-10*A2*g7*x4 - 
     6.78403369061433162e-10*A4*g6*x6 + 
     5.68290125969521456e-10*A*g8*x6 - 
     6.90033763945661382e-10*A3*g7*x8 + 
     1.26310595431481278e-10*g9*x8 - 
     3.12443265284225916e-10*A2*g8*x10 - 
     6.3597958994265421e-11*A*g9*x12 - 
     4.73255306775791468e-12*g10*x14)*xbar8 + 
  eps21*(4.02698278092183264e-14*A7*g4 - 
     5.48456153392839097e-13*A4*g6 + 
     1.27878322517070527e-13*A*g8 + 
     1.06134424697227182e-11*A6*g5*x2 - 
     2.8004805743707356e-11*A3*g7*x2 + 
     1.03826550082836709e-12*g9*x2 + 
     1.22375351923488345e-10*A5*g6*x4 - 
     1.16626518182467646e-10*A2*g8*x4 + 
     3.58798538233177846e-10*A4*g7*x6 - 
     1.13425693456240496e-10*A*g9*x6 + 
     4.04078829257981979e-10*A3*g8*x8 - 
     2.81051427782846787e-11*g10*x8 + 
     2.02913314961737926e-10*A2*g9*x10 + 
     4.56865113489605372e-11*A*g10*x12 + 
     3.74535590061231334e-12*g11*x14)*xbar8 + 
  eps20*(1.01735256778363072e-16*A8*g3 - 
     5.94748498729256522e-13*A5*g5 + 
     6.8752666515941573e-13*A2*g7 + 
     3.53810789377630122e-12*A7*g4*x2 - 
     5.15152807107229022e-11*A4*g6*x2 + 
     1.25362167426384833e-11*A*g8*x2 + 
     5.5847059374569765e-11*A6*g5*x4 - 
     3.07470180635305607e-10*A3*g7*x4 + 
     1.44903732082026135e-11*g9*x4 + 
     2.07246456352654245e-10*A5*g6*x6 - 
     4.59578840273247801e-10*A2*g8*x6 + 
     2.97340805913634912e-10*A4*g7*x8 - 
     2.2892955313025694e-10*A*g9*x8 + 
     1.99809393100334618e-10*A3*g8*x10 - 
     3.47015927264758897e-11*g10*x10 + 
     6.71900005565290136e-11*A2*g9*x12 + 
     1.09198252656076105e-11*A*g10*x14 + 
     6.80982990694437919e-13*g11*x16)*xbar8 + 
  eps23*(-5.6315187454878941e-15*A8*g4 + 
     1.34545805184805001e-13*A5*g6 - 
     8.4419630758147657e-14*A2*g8 - 
     2.01037270814629847e-12*A7*g5*x2 + 
     9.97117770896026235e-12*A4*g7*x2 - 
     1.57395528411072087e-12*A*g9*x2 - 
     3.1206130449635691e-11*A6*g6*x4 + 
     6.31142612191228433e-11*A3*g8*x4 - 
     1.99325127719395794e-12*g10*x4 - 
     1.24186739426227379e-10*A5*g7*x6 + 
     1.03337422325237485e-10*A2*g9*x6 - 
     1.94902502779695254e-10*A4*g8*x8 + 
     5.67801881002407209e-11*A*g10*x8 - 
     1.43878618574681894e-10*A3*g9*x10 + 
     9.49021948141154828e-12*g11*x10 - 
     5.31016521055310535e-11*A2*g10*x12 - 
     9.44535164544286831e-12*A*g11*x14 - 
     6.42414962794072381e-13*g12*x16)*xbar8 + 
  eps22*(-5.02476115994067526e-18*A9*g3 + 
     1.11539174575339278e-13*A6*g5 - 
     2.80495886362028979e-13*A3*g7 + 
     1.00479606252282625e-14*g9 - 
     5.40259809426922891e-13*A8*g4*x2 + 
     1.3655596937180689e-11*A5*g6*x2 - 
     8.89567598025371328e-12*A2*g8*x2 - 
     1.14125112021298833e-11*A7*g5*x4 + 
     1.17262639629103968e-10*A4*g7*x4 - 
     2.34248563243440911e-11*A*g9*x4 - 
     5.63758532628371665e-11*A6*g6*x6 + 
     2.64073536988736149e-10*A3*g8*x6 - 
     1.11917659757112919e-11*g10*x6 - 
     1.08869701145208113e-10*A5*g7*x8 + 
     2.19898065169051477e-10*A2*g9*x8 - 
     1.01295754866412102e-10*A4*g8*x10 + 
     7.34969922028006648e-11*A*g10*x10 - 
     4.98170652624686903e-11*A3*g9*x12 + 
     8.31685179548676633e-12*g11*x12 - 
     1.3215860235187506e-11*A2*g10*x14 - 
     1.78195799356499145e-12*A*g11*x16 - 
     9.55378197871579756e-14*g12*x18)*xbar8 + 
  eps24*(2.37030116313804979e-19*A10*g3 - 
     1.9533346518480291e-14*A7*g5 + 
     9.29145870030915526e-14*A4*g7 - 
     1.42254376835246143e-14*A*g9 + 
     7.93786579339025037e-14*A9*g4*x2 - 
     3.24770686591320867e-12*A6*g6*x2 + 
     4.51308884050389727e-12*A3*g8*x2 - 
     1.21528532165806402e-13*g10*x2 + 
     2.18599026266802557e-12*A8*g5*x4 - 
     3.81997188670301742e-11*A5*g7*x4 + 
     2.01602969504349973e-11*A2*g9*x4 + 
     1.39805947309574113e-11*A7*g6*x6 - 
     1.20750170632766463e-10*A4*g8*x6 + 
     2.14942707895956151e-11*A*g10*x6 + 
     3.51380103516320996e-11*A6*g7*x8 - 
     1.48670139875840985e-10*A3*g9*x8 + 
     5.8641446418595619e-12*g11*x8 + 
     4.32647592364454306e-11*A5*g8*x10 - 
     8.18363208526036942e-11*A2*g10*x10 + 
     2.90657796422669121e-11*A4*g9*x12 - 
     2.01711868869462944e-11*A*g11*x12 + 
     1.11525616827608266e-11*A3*g10*x14 - 
     1.80514406961528201e-12*g12*x14 + 
     2.4317483218867822e-12*A2*g11*x16 + 
     2.79634654155701318e-13*A*g12*x18 + 
     1.31394550428528868e-14*g13*x20)*xbar8 - 
  2.95801289810004407e-10*eps6*g4*xbar10 + 
  2.94346529368315861e-11*eps9*g5*xbar10 + 
  eps8*(7.69281785172546935e-11*A*g4 + 
     1.07490632635875918e-9*g5*x2)*xbar10 + 
  eps11*(-1.49854878334381416e-11*A*g5 - 
     1.64414869918985145e-10*g6*x2)*xbar10 + 
  eps10*(-1.14623038722347948e-11*A2*g4 - 
     6.72527675714427998e-10*A*g5*x2 - 
     5.64942074025452747e-10*g6*x4)*xbar10 + 
  eps13*(4.55203920804202245e-12*A2*g5 + 
     1.35763920347428776e-10*A*g6*x2 + 
     1.33652228562929386e-10*g7*x4)*xbar10 + 
  eps12*(1.27157831390982766e-12*A3*g4 - 
     2.82877994364105943e-12*g6 + 
     2.44160830279527547e-10*A2*g5*x2 + 
     5.14076796669365287e-10*A*g6*x4 + 
     1.75139799425245342e-10*g7*x6)*xbar10 + 
  eps15*(-1.07685636895144654e-12*A3*g5 + 
     2.70026199694243437e-13*g7 - 
     6.29652746661281415e-11*A2*g6*x2 - 
     1.49092240439933003e-10*A*g7*x4 - 
     5.88096054052166419e-11*g8*x6)*xbar10 + 
  eps14*(-1.16205790093287907e-13*A4*g4 + 
     2.06949189356323779e-12*A*g6 - 
     6.72146134669773312e-11*A3*g5*x2 + 
     1.99437288401862085e-11*g7*x2 - 
     2.61681510848862049e-10*A2*g6*x4 - 
     2.10127602166714473e-10*A*g7*x6 - 
     4.18842380479881739e-11*g8*x8)*xbar10 + 
  eps17*(2.18937302179867743e-13*A4*g5 - 
     2.52743776628905178e-13*A*g7 + 
     2.15933914153368247e-11*A3*g6*x2 - 
     2.33174044228357075e-12*g8*x2 + 
     9.10889047339860176e-11*A2*g7*x4 + 
     8.28793584781457544e-11*A*g8*x6 + 
     1.87814134450040901e-11*g9*x8)*xbar10 + 
  eps16*(9.22277143780367963e-15*A5*g4 - 
     8.60637474674818858e-13*A2*g6 + 
     1.55522012194999734e-11*A4*g5*x2 - 
     2.04738873511014663e-11*A*g7*x2 + 
     9.80212032242431517e-11*A3*g6*x4 - 
     2.27433206141358192e-11*g8*x4 + 
     1.3776069368825939e-10*A2*g7*x6 + 
     6.26447221848720574e-11*A*g8*x8 + 
     8.59289553201749293e-12*g9*x10)*xbar10 + 
  eps19*(-4.01386516110057917e-14*A5*g5 + 
     1.3091834712452921e-13*A2*g7 - 
     6.0989736648541878e-12*A4*g6*x2 + 
     2.86173201964551467e-12*A*g8*x2 - 
     4.02840475527683715e-11*A3*g7*x4 + 
     3.510880308676512e-12*g9*x4 - 
     6.29106001544106061e-11*A2*g8*x6 - 
     3.20688619604414165e-11*A*g9*x8 - 
     4.92343192873666106e-12*g10*x10)*xbar10 + 
  eps18*(-6.56399733698215579e-16*A6*g4 + 
     2.67367086954926804e-13*A3*g6 - 
     2.65773724648037072e-14*g8 - 
     3.1891761064266082e-12*A5*g5*x2 + 
     1.1556733294634019e-11*A2*g7*x2 - 
     3.00891865934477623e-11*A4*g6*x4 + 
     3.00144725725027383e-11*A*g8*x4 - 
     6.52019833501791742e-11*A3*g7*x6 + 
     1.33683467827448483e-11*g9*x6 - 
     5.03812647605675579e-11*A2*g8*x8 - 
     1.54328716110212964e-11*A*g9*x10 - 
     1.5943182436056292e-12*g10*x12)*xbar10 + 
  eps21*(6.81948054057362119e-15*A6*g5 - 
     4.95730577363766302e-14*A3*g7 + 
     2.76104504451824809e-15*g9 + 
     1.50108691344008234e-12*A5*g6*x2 - 
     1.90279881030008194e-12*A2*g8*x2 + 
     1.44066974529341e-11*A4*g7*x4 - 
     5.34733489141200454e-12*A*g9*x4 + 
     3.40794085764526502e-11*A3*g8*x6 - 
     2.64239721989513932e-12*g10*x6 + 
     2.91433177396476386e-11*A2*g9*x8 + 
     9.89175324887470848e-12*A*g10*x10 + 
     1.1292802715742771e-12*g11*x12)*xbar10 + 
  eps20*(4.27976553989265789e-17*A7*g4 - 
     6.89934943139530425e-14*A4*g6 + 
     3.01698740413725238e-14*A*g8 + 
     5.98132658710965791e-13*A6*g5*x2 - 
     4.74116732715012842e-12*A3*g7*x2 + 
     2.78541034399807552e-13*g9*x2 + 
     8.00945275253022047e-12*A5*g6*x4 - 
     2.13863386293836158e-11*A2*g8*x4 + 
     2.48849376049208704e-11*A4*g7*x6 - 
     2.16096622933769274e-11*A*g9*x6 + 
     2.88625342578349044e-11*A3*g8*x8 - 
     5.46942831323172719e-12*g10*x8 + 
     1.47325399109498875e-11*A2*g9*x10 + 
     3.34719700407126729e-12*A*g10*x12 + 
     2.75625052642210253e-13*g11*x14)*xbar10 + 
  eps23*(-1.09246620876972326e-15*A7*g5 + 
     1.5318252699987865e-14*A4*g7 - 
     3.68066535807379783e-15*A*g9 - 
     3.33083243580660176e-13*A6*g6*x2 + 
     9.08215852708082357e-13*A3*g8*x2 - 
     3.4794379491004643e-14*g10*x2 - 
     4.41858871800109535e-12*A5*g7*x4 + 
     4.35208843090363193e-12*A2*g9*x4 - 
     1.47461048791896167e-11*A4*g8*x6 + 
     4.81523154629728511e-12*A*g10*x6 - 
     1.87079103097809155e-11*A3*g9*x8 + 
     1.34299877609914984e-12*g11*x8 - 
     1.04839336902361225e-11*A2*g10*x10 - 
     2.61235659744083548e-12*A*g11*x12 - 
     2.35268338409651259e-13*g12*x14)*xbar10 + 
  eps22*(-2.59530959394910739e-18*A8*g4 + 
     1.56250827735261162e-14*A5*g6 - 
     1.86384253756143204e-14*A2*g8 - 
     1.04716236495971179e-13*A7*g5*x2 + 
     1.57911568324388851e-12*A4*g7*x2 - 
     3.97696537675898684e-13*A*g9*x2 - 
     1.91339334657969896e-12*A6*g6*x4 + 
     1.09023789657915762e-11*A3*g8*x4 - 
     5.31746105151784319e-13*g10*x4 - 
     8.12230075160805238e-12*A5*g7*x6 + 
     1.8624019115509357e-11*A2*g9*x6 - 
     1.31819089102919353e-11*A4*g8*x8 + 
     1.0483480357330514e-11*A*g10*x8 - 
     9.92032656167012319e-12*A3*g9*x10 + 
     1.77778344733062833e-12*g11*x10 - 
     3.70309998579539791e-12*A2*g10*x12 - 
     6.62904547687516285e-13*A*g11*x14 - 
     4.52240509458340008e-14*g12*x16)*xbar10 + 
  1.69722051530330397e-12*eps8*g5*xbar12 - 
  2.90595190793452012e-13*eps11*g6*xbar12 + 
  eps10*(-5.54575148020670988e-13*A*g5 - 
     1.29008964169185665e-11*g6*x2)*xbar12 + 
  eps13*(1.78798720202615632e-13*A*g6 + 
     2.57210159823889116e-12*g7*x2)*xbar12 + 
  eps12*(1.00869657097464141e-13*A2*g5 + 
     9.47632013657176953e-12*A*g6*x2 + 
     1.00368310409322369e-11*g7*x4)*xbar12 + 
  eps15*(-6.39010493062016058e-14*A2*g6 - 
     2.40693363499189255e-12*A*g7*x2 - 
     2.87715768832048683e-12*g8*x4)*xbar12 + 
  eps14*(-1.33953977785016062e-14*A3*g5 + 
     3.84980892713537606e-14*g7 - 
     3.94928486633783273e-12*A2*g6*x2 - 
     1.02511581325767213e-11*A*g7*x4 - 
     4.17899415533904787e-12*g8*x6)*xbar12 + 
  eps17*(1.73998403455957848e-14*A3*g6 - 
     4.62636803886378434e-15*g8 + 
     1.24741423146112554e-12*A2*g7*x2 + 
     3.52693455958173369e-12*A*g8*x4 + 
     1.62821302569789988e-12*g9*x6)*xbar12 + 
  eps16*(1.44440682820300384e-15*A4*g5 - 
     3.24022688540454265e-14*A*g7 + 
     1.22741801273679764e-12*A3*g6*x2 - 
     3.84061473377336244e-13*g8*x2 + 
     5.77793844380739442e-12*A2*g7*x4 + 
     5.47447616200335818e-12*A*g8*x6 + 
     1.26471026695269685e-12*g9*x8)*xbar12 + 
  eps19*(-4.00106875821619636e-15*A4*g6 + 
     4.84590692629411758e-15*A*g8 - 
     4.72763385349764825e-13*A3*g7*x2 + 
     5.32739458894566085e-14*g9*x2 - 
     2.34696797887097322e-12*A2*g8*x4 - 
     2.47171834511294782e-12*A*g9*x6 - 
     6.39422064458918014e-13*g10*x8)*xbar12 + 
  eps18*(-1.33739060725578634e-16*A5*g5 + 
     1.52467406929696226e-14*A2*g7 - 
     3.16506850006518787e-13*A4*g6*x2 + 
     4.36808508700696498e-13*A*g8*x2 - 
     2.37192884056053272e-12*A3*g7*x4 + 
     5.73811638250132219e-13*g9*x4 - 
     3.88549767072102607e-12*A2*g8*x6 - 
     2.02801867312185292e-12*A*g9*x8 - 
     3.15279597165500734e-13*g10*x10)*xbar12 + 
  eps21*(8.18212199689786031e-16*A5*g6 - 
     2.77850155214879458e-15*A2*g8 + 
     1.46242985972961813e-13*A4*g7*x2 - 
     7.13099260240197077e-14*A*g9*x2 + 
     1.12245977611596647e-12*A3*g8*x4 - 
     1.01453307525349774e-13*g10*x4 + 
     2.0091654459041284e-12*A2*g9*x6 + 
     1.1599532499763162e-12*A*g10*x8 + 
     1.99618834474701725e-13*g11*x10)*xbar12 + 
  eps20*(1.10024592611551253e-17*A6*g5 - 
     5.28888834827941102e-15*A3*g7 + 
     5.47612344010328206e-16*g9 + 
     7.15818767506558215e-14*A5*g6*x2 - 
     2.70559177977642949e-13*A2*g8*x2 + 
     7.91459587667159745e-13*A4*g7*x4 - 
     8.20326742698849044e-13*A*g9*x4 + 
     1.97757621860341566e-12*A3*g8*x6 - 
     4.20357694313370931e-13*g10*x6 + 
     1.73888738668498436e-12*A2*g9*x8 + 
     5.99434847996843799e-13*A*g10*x10 + 
     6.90257861666477261e-14*g11*x12)*xbar12 + 
  eps22*(-8.22795182119939417e-19*A7*g5 + 
     1.50770677982272589e-15*A4*g7 - 
     6.83286257353858413e-16*A*g9 - 
     1.46797411254395335e-14*A6*g6*x2 + 
     1.20844830087105867e-13*A3*g8*x2 - 
     7.35959455974364916e-15*g10*x2 - 
     2.27486573977748777e-13*A5*g7*x4 + 
     6.29215515561348402e-13*A2*g9*x4 - 
     8.07221681057317846e-13*A4*g8*x6 + 
     7.24935763935350501e-13*A*g10*x6 - 
     1.05726036679409544e-12*A3*g9*x8 + 
     2.06916186826177124e-13*g11*x8 - 
     6.03469894029266334e-13*A2*g10*x10 - 
     1.52010427845838981e-13*A*g11*x12 - 
     1.3774189023674826e-14*g12*x14)*xbar12 - 
  1.06551186196798794e-14*eps10*g6*xbar14 + 
  2.96371424137457707e-15*eps13*g7*xbar14 + 
  eps12*(4.1883104771160436e-15*A*g6 + 
     1.55454784378046993e-13*g7*x2)*xbar14 + 
  eps15*(-2.14017433818550597e-15*A*g7 - 
     3.90198867402243257e-14*g8*x2)*xbar14 + 
  eps14*(-8.99454744512618591e-16*A2*g6 - 
     1.30968415155813316e-13*A*g7*x2 - 
     1.70308449198607365e-13*g8*x4)*xbar14 + 
  eps17*(8.79886328932693487e-16*A2*g7 + 
     4.07855521267175371e-14*A*g8*x2 + 
     5.8024185244265147e-14*g9*x4)*xbar14 + 
  eps16*(1.39116436986363771e-16*A3*g6 - 
     5.17467765013076258e-16*g8 + 
     6.15890327064823114e-14*A2*g7*x2 + 
     1.92792938842998867e-13*A*g8*x4 + 
     9.24186997248047774e-14*g9*x6)*xbar14 + 
  eps19*(-2.71043966692226229e-16*A3*g7 + 
     7.62461032065408102e-17*g9 - 
     2.33529672481396755e-14*A2*g8*x2 - 
     7.75214641947405959e-14*A*g9*x4 - 
     4.13090807033447583e-14*g10*x6)*xbar14 + 
  eps18*(-1.72867499565968957e-17*A4*g6 + 
     4.9217313236453732e-16*A*g8 - 
     2.13260411115595534e-14*A3*g7*x2 + 
     7.01612347492652808e-15*g9*x2 - 
     1.19175537714779419e-13*A2*g8*x4 - 
     1.31262296085466213e-13*A*g9*x6 - 
     3.47201752597269316e-14*g10*x8)*xbar14 + 
  eps21*(6.95527507361396729e-17*A4*g7 - 
     8.83062918064961145e-17*A*g9 + 
     9.69147997163643325e-15*A3*g8*x2 - 
     1.13725225229483657e-15*g10*x2 + 
     5.58135479458087437e-14*A2*g9*x4 + 
     6.72233462597832795e-14*A*g10*x6 + 
     1.96552278109310559e-14*g11*x8)*xbar14 + 
  eps20*(1.82877741622247625e-18*A5*g6 - 
     2.58382411798017243e-16*A2*g8 + 
     6.06418528687686859e-15*A4*g7*x2 - 
     8.75387708088179125e-15*A*g9*x2 + 
     5.32096477905912181e-14*A3*g8*x4 - 
     1.33872464203048517e-14*g10*x4 + 
     1.00297233267464412e-13*A2*g9*x6 + 
     5.94498264966954685e-14*A*g10*x8 + 
     1.03825306645524673e-14*g11*x10)*xbar14 + 
  7.1230636127202905e-17*eps12*g7*xbar16 - 
  3.09644400991606704e-17*eps15*g8*xbar16 + 
  eps14*(-3.27091744222075652e-17*A*g7 - 
     1.87737117146802168e-15*g8*x2)*xbar16 + 
  eps17*(2.56820081466394239e-17*A*g8 + 
     5.77970340504678044e-16*g9*x2)*xbar16 + 
  eps16*(8.09908041993038944e-18*A2*g7 + 
     1.78317218006896548e-15*A*g8*x2 + 
     2.78832594974046941e-15*g9*x4)*xbar16 + 
  eps19*(-1.19399144787300174e-17*A2*g8 - 
     6.67124890749264713e-16*A*g9*x2 - 
     1.11157044100254144e-15*g10*x4)*xbar16 + 
  eps18*(-1.42980374801906325e-18*A3*g7 + 
     6.88701015696998715e-18*g9 - 
     9.33716646729179203e-16*A2*g8*x2 - 
     3.46339329805719736e-15*A*g9*x4 - 
     1.92478458861582261e-15*g10*x6)*xbar16 + 
  eps20*(2.01155912712848607e-19*A4*g7 - 
     7.30080971811155416e-18*A*g9 + 
     3.56400456280639278e-16*A3*g8*x2 - 
     1.2296396496067157e-16*g10*x2 + 
     2.32934306679785846e-15*A2*g9*x4 + 
     2.9459266889986156e-15*A*g10*x6 + 
     8.83078646848089353e-16*g11*x8)*xbar16 - 
  4.98845119121947873e-19*eps14*g8*xbar18 + 
  3.29589363262920182e-19*eps17*g9*xbar18 + 
  eps16*(2.61992075966627237e-19*A*g8 + 
     2.27018895731900669e-17*g9*x2)*xbar18 + 
  eps19*(-3.0880236512109574e-19*A*g9 - 
     8.39862229741645369e-18*g10*x2)*xbar18 + 
  eps18*(-7.34772661645623638e-20*A2*g8 - 
     2.39905600259048083e-17*A*g9*x2 - 
     4.43602818448693464e-17*g10*x4)*xbar18 + 
  3.62101682176476165e-21*eps16*g9*xbar20 + 
  eps18*(-2.14042456564486975e-21*A*g9 - 
     2.74739666662032349e-19*g10*x2)*xbar20;
}
#endif

#ifdef p30
double Wp(void)
{
   return 0.5*A*x2 + 0.0416666666666666667*g*x4 + 
  eps*(0.0833333333333333333*A + 0.0416666666666666667*g*x2) + 
  eps3*(-0.00277777777777777778*A2 - 
     0.0111111111111111111*A*g*x2 - 
     0.00208333333333333333*g2*x4) + 
  eps2*(0.00416666666666666667*g - 
     0.0416666666666666667*A2*x2 - 
     0.0138888888888888889*A*g*x4 - 
     0.00115740740740740741*g2*x6) + 
  eps5*(0.0001763668430335097*A3 - 
     0.0000388558201058201058*g2 + 
     0.00214947089947089947*A2*g*x2 + 
     0.00124007936507936508*A*g2*x4 + 
     0.000154320987654320988*g3*x6) + 
  eps4*(-0.000595238095238095238*A*g + 
     0.00416666666666666667*A3*x2 - 
     0.000868055555555555556*g2*x2 + 
     0.00347222222222222222*A2*g*x4 + 
     0.000810185185185185185*A*g2*x6 + 
     0.0000578703703703703704*g3*x8) + 
  eps7*(-0.0000132275132275132275*A4 + 
     0.000013452982202982203*A*g2 - 
     0.000353835978835978836*A3*g*x2 + 
     0.0000292107583774250441*g3*x2 - 
     0.000438161375661375661*A2*g2*x4 - 
     0.000141369047619047619*A*g3*x6 - 
     0.0000131815843621399177*g4*x8) + 
  eps6*(0.0000793650793650793651*A2*g - 
     0.000421626984126984127*A4*x2 + 
     0.000412533068783068783*A*g2*x2 - 
     0.000710978835978835979*A3*g*x4 + 
     0.00012359457671957672*g3*x4 - 
     0.000332065696649029982*A2*g2*x6 - 
     0.0000592482363315696649*A*g3*x8 - 
     3.61689814814814815e-6*g4*x10) + 
  eps9*(1.06888995777884667e-6*A5 - 
     3.09484386865339246e-6*A2*g2 + 
     0.000052889176153065042*A4*g*x2 - 
     0.0000196739667225778337*A*g3*x2 + 
     0.000118621733205066538*A3*g2*x4 - 
     8.12834124466068911e-6*g4*x4 + 
     0.0000723776288012399124*A2*g3*x6 + 
     0.0000162595142340512711*A*g4*x8 + 
     1.2123306755829904e-6*g5*x10) + 
  eps8*(-0.0000100208433541766875*A3*g + 
     8.50711788211788212e-7*g3 + 
     0.0000427138447971781305*A5*x2 - 
     0.000120331539602372936*A2*g2*x2 + 
     0.000127911890064667842*A4*g*x4 - 
     0.000098836830607663941*A*g3*x4 + 
     0.000102804110327258475*A3*g2*x6 - 
     0.0000165018585880854399*g4*x6 + 
     0.0000336428938859494415*A2*g3*x8 + 
     4.8512364050558495e-6*A*g4*x10 + 
     2.56755115454961134e-7*g5*x12) + 
  eps11*(-9.01835117002665504e-8*A6 + 
     5.87400058299529199e-7*A3*g2 - 
     2.81868399275952575e-8*g4 - 
     7.41416841780598394e-6*A5*g*x2 + 
     7.67116473755031956e-6*A2*g3*x2 - 
     0.000027147462601331649*A4*g2*x4 + 
     8.12031936990601012e-6*A*g4*x4 - 
     0.0000272310450812986086*A3*g3*x6 + 
     1.70667153812408442e-6*g5*x6 - 
     0.0000108933015093453806*A2*g4*x8 - 
     1.87850642976993286e-6*A*g5*x10 - 
     1.16690477054095881e-7*g6*x12) + 
  eps10*(1.21747740795359843e-6*A4*g - 
     4.62417873132158846e-7*A*g3 - 
     4.32775172358505692e-6*A6*x2 + 
     0.0000276277014248244407*A3*g2*x2 - 
     1.30445706075046353e-6*g4*x2 - 
     0.0000210333326652771097*A5*g*x4 + 
     0.0000447391253752860896*A2*g3*x4 - 
     0.0000265668910778864483*A4*g2*x6 + 
     0.0000184769777868736202*A*g4*x6 - 
     0.0000139376709110505407*A3*g3*x8 + 
     2.13520310814871e-6*g5*x8 - 
     3.5181249916492972e-6*A2*g4*x10 - 
     4.25407416871537242e-7*A*g5*x12 - 
     1.98147969535893919e-8*g6*x14) + 
  eps13*(7.83069566138349207e-9*A7 - 
     9.93094869534334209e-8*A4*g2 + 
     2.08755249185163841e-8*A*g4 + 
     9.92791119692574719e-7*A6*g*x2 - 
     2.26246788359770127e-6*A3*g3*x2 + 
     7.19774046753493046e-8*g5*x2 + 
     5.52538741816188906e-6*A5*g2*x4 - 
     4.47883727161149936e-6*A2*g4*x4 + 
     8.38601213983571788e-6*A4*g3*x6 - 
     2.25348627386308778e-6*A*g5*x6 + 
     5.24445855604457162e-6*A3*g4*x8 - 
     3.11392974798759566e-7*g6*x8 + 
     1.55465050346795001e-6*A2*g5*x10 + 
     2.17600880397466046e-7*A*g6*x12 + 
     1.15841884836628278e-8*g7*x14) + 
  eps12*(-1.43889032777921667e-7*A5*g + 
     1.51283642180000723e-7*A2*g3 + 
     4.38492191964414187e-7*A7*x2 - 
     5.47671197834474951e-6*A4*g2*x2 + 
     1.1365151365172641e-6*A*g4*x2 + 
     3.23789133106262736e-6*A6*g*x4 - 
     0.0000150481673660823793*A3*g3*x4 + 
     5.97324614725086198e-7*g5*x4 + 
     6.03932684613625972e-6*A5*g2*x6 - 
     0.0000113106765525436987*A2*g4*x6 + 
     4.69528859165240338e-6*A4*g3*x8 - 
     3.0694501391598228e-6*A*g5*x8 + 
     1.82557370238215146e-6*A3*g4*x10 - 
     2.71046144994230449e-7*g6*x10 + 
     3.7535031778135559e-7*A2*g5*x12 + 
     3.90681314457195373e-8*A*g6*x14 + 
     1.62260932077515154e-9*g7*x16) + 
  eps15*(-6.94206524686864971e-10*A8 + 
     1.55258266251201437e-8*A5*g2 - 
     8.87063997906019346e-9*A2*g4 - 
     1.28444091425696105e-7*A7*g*x2 + 
     5.59355511978255916e-7*A4*g3*x2 - 
     7.69591961687451275e-8*A*g5*x2 - 
     1.03084425773136674e-6*A6*g2*x4 + 
     1.80099658500984157e-6*A3*g4*x4 - 
     4.89852640150590245e-8*g6*x4 - 
     2.23744987275327073e-6*A5*g3*x6 + 
     1.60416803829389571e-6*A2*g5*x6 - 
     2.02887475090349778e-6*A4*g4*x8 + 
     5.10536772376168298e-7*A*g6*x8 - 
     9.11746562790846727e-7*A3*g5*x10 + 
     5.21769349658492833e-8*g7*x10 - 
     2.14341780318485671e-7*A2*g6*x12 - 
     2.52490551976121104e-8*A*g7*x14 - 
     1.17600420262660865e-9*g8*x16) + 
  eps14*(1.66609565924847593e-8*A6*g - 
     3.84541066603365207e-8*A3*g3 + 
     1.23616495716322489e-9*g5 - 
     4.44285396439000936e-8*A8*x2 + 
     9.81807578832239391e-7*A5*g2*x2 - 
     5.55101746448534654e-7*A2*g4*x2 - 
     4.73967830600877338e-7*A7*g*x4 + 
     4.18284859452059839e-6*A4*g3*x4 - 
     7.15343253702736788e-7*A*g5*x4 - 
     1.24663165145441196e-6*A6*g2*x6 + 
     5.00514675879205854e-6*A3*g4*x6 - 
     1.81402700349001079e-7*g6*x6 - 
     1.36226318220021373e-6*A5*g3*x8 + 
     2.36606032230627314e-6*A2*g5*x8 - 
     7.58172593612770117e-7*A4*g4*x10 + 
     4.75471890972483691e-7*A*g6*x10 - 
     2.34027522244261325e-7*A3*g5*x12 + 
     3.3963539821117207e-8*g7*x12 - 
     4.06050820222736176e-8*A2*g6*x14 - 
     3.70938742929349711e-9*A*g7*x16 - 
     1.38898528337180163e-10*g8*x18) + 
  eps17*(6.25217958800249802e-11*A9 - 
     2.29312206278746533e-9*A6*g2 + 
     2.8310089717477044e-9*A3*g4 - 
     6.71998649148490015e-11*g6 + 
     1.61783182535963035e-8*A8*g*x2 - 
     1.222198282975496e-7*A5*g3*x2 + 
     4.51903487294323094e-8*A2*g5*x2 + 
     1.79787422789127715e-7*A7*g2*x4 - 
     5.89386352242391962e-7*A4*g4*x4 + 
     6.83924293854497039e-8*A*g6*x4 + 
     5.35385253592035249e-7*A6*g3*x6 - 
     8.16161936426993263e-7*A3*g5*x6 + 
     2.03110694856709656e-8*g7*x6 + 
     6.69429955495357485e-7*A5*g4*x8 - 
     4.44812062546498445e-7*A2*g6*x8 + 
     4.24544759374608395e-7*A4*g5*x10 - 
     1.02125278182278717e-7*A*g7*x10 + 
     1.48190757087105866e-7*A3*g6*x12 - 
     8.25465653164429909e-9*g8*x12 + 
     2.8842218900714868e-8*A2*g7*x14 + 
     2.93316966296752154e-9*A*g8*x16 + 
     1.21426224678902097e-10*g9*x18) + 
  eps16*(-1.89909954985575877e-9*A7*g + 
     8.35603474047208798e-9*A4*g3 - 
     1.15966243496214952e-9*A*g5 + 
     4.50155213123768602e-9*A9*x2 - 
     1.63520154608933337e-7*A6*g2*x2 + 
     2.00125773929144853e-7*A3*g4*x2 - 
     4.71643935891082883e-9*g6*x2 + 
     6.66827009985439445e-8*A8*g*x4 - 
     1.01569722853466271e-6*A5*g3*x4 + 
     4.653753986331283e-7*A2*g5*x4 + 
     2.38609112997144637e-7*A7*g2*x6 - 
     1.78931879078472604e-6*A4*g4*x6 + 
     2.75782412054904595e-7*A*g6*x6 + 
     3.5257503626825941e-7*A6*g3*x8 - 
     1.29719583644083582e-6*A3*g5*x8 + 
     4.43904638337799842e-8*g7*x8 + 
     2.67563783428073661e-7*A5*g4*x10 - 
     4.41739629456479988e-7*A2*g6*x10 + 
     1.15544405881940575e-7*A4*g5*x12 - 
     7.03094817586759951e-8*A*g7*x12 + 
     2.95627516533174602e-8*A3*g6*x14 - 
     4.21593686904484474e-9*g8*x14 + 
     4.43746780874914946e-9*A2*g7*x16 + 
     3.61167459558351774e-10*A*g8*x18 + 
     1.23066706066192904e-11*g9*x20) + 
  eps19*(-5.70128780114804572e-12*A10 + 
     3.24325759393455769e-10*A7*g2 - 
     7.52920392642037898e-10*A4*g4 + 
     7.63432039813829238e-11*A*g6 - 
     1.99446765051272661e-9*A9*g*x2 + 
     2.43560018179573397e-8*A6*g3*x2 - 
     1.92651473964731419e-8*A3*g5*x2 + 
     3.57664504054283011e-10*g7*x2 - 
     2.97138844105769473e-8*A8*g2*x4 + 
     1.66367899286352586e-7*A5*g4*x4 - 
     5.12763843043703477e-8*A2*g6*x4 - 
     1.17558487781038256e-7*A7*g3*x6 + 
     3.32274083849900958e-7*A4*g5*x6 - 
     3.49339293457975036e-8*A*g7*x6 - 
     1.95421595481198395e-7*A6*g4*x8 + 
     2.73546099832218964e-7*A3*g6*x8 - 
     6.42119893976624269e-9*g8*x8 - 
     1.66845932629322826e-7*A5*g5*x10 + 
     1.05196992302604677e-7*A2*g7*x10 - 
     8.06653736383214643e-8*A4*g6*x12 + 
     1.87723844343482559e-8*A*g8*x12 - 
     2.29644918467110207e-8*A3*g7*x14 + 
     1.25288025697957571e-9*g9*x14 - 
     3.81165485194947533e-9*A2*g8*x16 - 
     3.41033212304414905e-10*A*g9*x18 - 
     1.27053709821831841e-11*g10*x20) + 
  eps18*(2.13798292543051714e-10*A8*g - 
     1.62899940163818617e-9*A5*g3 + 
     6.06739124374671626e-10*A2*g5 - 
     4.56102589118103946e-10*A10*x2 + 
     2.5741194154734252e-8*A7*g2*x2 - 
     5.93202934378594688e-8*A4*g4*x2 + 
     5.97796132442781859e-9*A*g6*x2 - 
     9.086017175115798e-9*A9*g*x4 + 
     2.22788546277779156e-7*A6*g3*x4 - 
     2.17818061292066124e-7*A3*g5*x4 + 
     4.46060201054250811e-9*g7*x4 - 
     4.29736286745591606e-8*A8*g2*x6 + 
     5.48218484132244335e-7*A5*g4*x6 - 
     2.23798601959230444e-7*A2*g6*x6 - 
     8.3334504765293729e-8*A7*g3*x8 + 
     5.66588387939462102e-7*A4*g5*x8 - 
     8.17078651256326395e-8*A*g7*x8 - 
     8.32572408053676287e-8*A6*g4*x10 + 
     2.88769211893932833e-7*A3*g6*x10 - 
     9.49367158787967084e-9*g8*x10 - 
     4.80270155903927102e-8*A5*g5*x12 + 
     7.64234973061525259e-8*A2*g7*x12 - 
     1.69136821548003748e-8*A4*g6*x14 + 
     1.00575293092506873e-8*A*g8*x14 - 
     3.69466622059472975e-9*A3*g7*x16 + 
     5.19597646877020836e-10*g9*x16 - 
     4.88723854749631574e-10*A2*g8*x18 - 
     3.58645537045585288e-11*A*g9*x20 - 
     1.12084057456710382e-12*g10*x22) + 
  eps21*(5.2514619543187782e-13*A11 - 
     4.43285954755604869e-11*A8*g2 + 
     1.76083788279021689e-10*A5*g4 - 
     4.74728753998211342e-11*A2*g6 + 
     2.41589075467910444e-10*A10*g*x2 - 
     4.51824485857656974e-9*A7*g3*x2 + 
     6.66083029216207287e-9*A4*g5*x2 - 
     5.24335874922835697e-10*A*g7*x2 + 
     4.69949475640663485e-9*A9*g2*x4 - 
     4.19656758646856316e-8*A6*g4*x4 + 
     2.73885212294566607e-8*A3*g6*x4 - 
     4.48244578272414887e-10*g8*x4 + 
     2.40727904510809782e-8*A8*g3*x6 - 
     1.14987302708287038e-7*A5*g5*x6 + 
     3.18314156293579248e-8*A2*g7*x6 + 
     5.1729556293745067e-8*A7*g4*x8 - 
     1.33139310440523761e-7*A4*g6*x8 + 
     1.31084047358048264e-8*A*g8*x8 + 
     5.74763592331078553e-8*A6*g5*x10 - 
     7.58285646214704478e-8*A3*g7*x10 + 
     1.70719938146989968e-9*g9*x10 + 
     3.67818305341475603e-8*A5*g6*x12 - 
     2.23107719453182269e-8*A2*g8*x12 + 
     1.43062528484956471e-8*A4*g7*x14 - 
     3.24546888412113238e-9*A*g9*x14 + 
     3.43426667042232431e-9*A3*g8*x16 - 
     1.84284319077257175e-10*g10*x16 + 
     4.96756814596081739e-10*A2*g9*x18 + 
     3.96764099826891058e-11*A*g10*x20 + 
     1.34372144042558418e-12*g11*x22) + 
  eps20*(-2.38285086177214561e-11*A9*g + 
     2.93087835503767857e-10*A6*g3 - 
     2.33284850513311582e-10*A3*g5 + 
     4.35358687387975124e-12*g7 + 
     4.62128541799995915e-11*A11*x2 - 
     3.87512747715920683e-9*A8*g2*x2 + 
     1.52963831343981389e-8*A5*g4*x2 - 
     4.10201649274809254e-9*A2*g6*x2 + 
     1.2058131859727143e-9*A10*g*x4 - 
     4.51251014708823542e-8*A7*g3*x4 + 
     8.20524658045556169e-8*A4*g5*x4 - 
     7.11455083461241557e-9*A*g7*x4 + 
     7.36094104464716057e-9*A9*g2*x6 - 
     1.49255884116928141e-7*A6*g4*x6 + 
     1.28707565844365563e-7*A3*g6*x6 - 
     2.42078453530071715e-9*g8*x6 + 
     1.82893288628610935e-8*A8*g3*x8 - 
     2.09524543137285467e-7*A5*g5*x8 + 
     7.93810679543179244e-8*A2*g7*x8 + 
     2.34179153309909358e-8*A7*g4*x10 - 
     1.48969846228119514e-7*A4*g6*x10 + 
     2.05019199855671562e-8*A*g8*x10 + 
     1.74575105847696841e-8*A6*g5*x12 - 
     5.80036979689224998e-8*A3*g7*x12 + 
     1.8510046912641176e-9*g9*x12 + 
     8.09148869608194122e-9*A5*g6*x14 - 
     1.251808839252206e-8*A2*g8*x14 + 
     2.40348962003249252e-9*A4*g7*x16 - 
     1.40328230011170153e-9*A*g9*x16 + 
     4.58007384146693616e-10*A3*g8*x18 - 
     6.36787892934133022e-11*g10*x18 + 
     5.41571641768509377e-11*A2*g9*x20 + 
     3.61823810155023661e-12*A*g10*x22 + 
     1.04407319287969897e-13*g11*x24) + 
  eps23*(-4.87743892079685082e-14*A12 + 
     5.89316491267758974e-12*A9*g2 - 
     3.73943263170943611e-11*A6*g4 + 
     2.13679155317563112e-11*A3*g6 - 
     3.27361153325515243e-13*g8 - 
     2.88368279506519334e-11*A11*g*x2 + 
     7.91374895139060628e-10*A8*g3*x2 - 
     1.98046179372144604e-9*A5*g5*x2 + 
     4.11786639583657111e-10*A2*g7*x2 - 
     7.16497851551313523e-10*A10*g2*x4 + 
     9.68464471525289276e-9*A7*g4*x4 - 
     1.16748393728030986e-8*A4*g6*x4 + 
     8.04127478183736051e-10*A*g8*x4 - 
     4.65194608412246558e-9*A9*g3*x6 + 
     3.51082372037893695e-8*A6*g5*x6 - 
     2.04201982013264592e-8*A3*g7*x6 + 
     3.08310721156552306e-10*g9*x6 - 
     1.26357673284535273e-8*A8*g4*x8 + 
     5.45476416156654204e-8*A5*g6*x8 - 
     1.40486405551536498e-8*A2*g8*x8 - 
     1.7805212696568686e-8*A7*g5*x10 + 
     4.2926305860153371e-8*A4*g7*x10 - 
     4.0312366550615087e-9*A*g9*x10 - 
     1.46022546131613235e-8*A6*g6*x12 + 
     1.843836447337074e-8*A3*g8*x12 - 
     4.02235197734030437e-10*g10*x12 - 
     7.42369322805527411e-9*A5*g7*x14 + 
     4.37038526225414347e-9*A2*g9*x14 - 
     2.40937437944208411e-9*A4*g8*x16 + 
     5.35568097093309146e-10*A*g10*x16 - 
     4.99603251087911808e-10*A3*g9*x18 + 
     2.64472477748035067e-11*g11*x18 - 
     6.40255800593810452e-11*A2*g10*x20 - 
     4.61829796410311992e-12*A*g11*x22 - 
     1.43368406597132889e-13*g12*x24) + 
  eps22*(2.63381701723029945e-12*A10*g - 
     4.95613474685512438e-11*A7*g3 + 
     7.3461839787322817e-11*A4*g5 - 
     5.80927196941699941e-12*A*g7 - 
     4.68234108487568308e-12*A12*x2 + 
     5.62566165576091132e-10*A9*g2*x2 - 
     3.55029758958278224e-9*A6*g4*x2 + 
     2.01925178972162547e-9*A3*g6*x2 - 
     3.0814593971546122e-11*g8*x2 - 
     1.56527781346397019e-10*A11*g*x4 + 
     8.57069278143073356e-9*A8*g3*x4 - 
     2.64080665694219489e-8*A5*g5*x4 + 
     6.0407259102082057e-9*A2*g7*x4 - 
     1.20889938892283076e-9*A10*g2*x6 + 
     3.69930387182005496e-8*A7*g4*x6 - 
     5.87976309873423814e-8*A4*g6*x6 + 
     4.64691762189073441e-9*A*g8*x6 - 
     3.7731495679189183e-9*A9*g3*x8 + 
     6.81148651466673022e-8*A6*g5*x8 - 
     5.41126426776092471e-8*A3*g7*x8 + 
     9.60423280700958978e-10*g9*x8 - 
     6.06051978329905884e-9*A8*g4*x10 + 
     6.45172101423398301e-8*A5*g6*x10 - 
     2.31853730369969274e-8*A2*g8*x10 - 
     5.69384641167539249e-9*A7*g5*x12 + 
     3.45031778931260666e-8*A4*g7*x12 - 
     4.5856200745095094e-9*A*g9*x12 - 
     3.36446046321516529e-9*A6*g6*x14 + 
     1.08170138123001676e-8*A3*g8*x14 - 
     3.37300366179434001e-10*g10*x14 - 
     1.30060474988550597e-9*A5*g7*x16 + 
     1.9676600421073939e-9*A2*g9*x16 - 
     3.33854146037989048e-10*A4*g8*x18 + 
     1.92027951778477411e-10*A*g10*x18 - 
     5.64147807443152692e-11*A3*g9*x20 + 
     7.76866625886353525e-12*g11*x20 - 
     6.03122771185984168e-12*A2*g10*x22 - 
     3.69809171837544212e-13*A*g11*x24 - 
     9.90994892123906548e-15*g12*x26) + 
  eps25*(4.5617341154295489e-15*A13 - 
     7.65681973581163408e-13*A10*g2 + 
     7.36427533361146046e-12*A7*g4 - 
     7.77915357825993505e-12*A4*g6 + 
     5.01822372498827554e-13*A*g8 + 
     3.39946554308810257e-12*A12*g*x2 - 
     1.32218967001765988e-10*A9*g3*x2 + 
     5.24826694161013285e-10*A6*g5*x2 - 
     2.29911014730304061e-10*A3*g7*x2 + 
     2.97396110366290561e-12*g9*x2 + 
     1.05899009942419973e-10*A11*g2*x4 - 
     2.07888236061736146e-9*A8*g4*x4 + 
     4.2205345488109798e-9*A5*g6*x4 - 
     7.62725505811220135e-10*A2*g8*x4 + 
     8.56030817990639683e-10*A10*g3*x6 - 
     9.69700200555032466e-9*A7*g5*x6 + 
     1.0345307489459437e-8*A4*g7*x6 - 
     6.53391446848804187e-10*A*g9*x6 + 
     2.88536112350769269e-9*A9*g4*x8 - 
     1.95458369290004387e-8*A6*g6*x8 + 
     1.05141608097548792e-8*A3*g8*x8 - 
     1.49985208961406861e-10*g10*x8 + 
     5.0517190817639561e-9*A8*g5*x10 - 
     2.03127428588433698e-8*A5*g7*x10 + 
     4.96479103747145285e-9*A2*g9*x10 + 
     5.18105920734004777e-9*A7*g6*x12 - 
     1.18984582771191454e-8*A4*g8*x12 + 
     1.07801501997213091e-9*A*g10*x12 + 
     3.33667223847150641e-9*A6*g7*x14 - 
     4.07258881748425756e-9*A3*g9*x14 + 
     8.66712686070301579e-11*g11*x14 + 
     1.4017941285304863e-9*A5*g8*x16 - 
     8.05772603894054025e-10*A2*g10*x16 + 
     3.89757092431598696e-10*A4*g9*x18 - 
     8.52041965373136873e-11*A*g11*x18 + 
     7.10964158735397762e-11*A3*g10*x20 - 
     3.72103988693417535e-12*g12*x20 + 
     8.17773394901589543e-12*A2*g11*x22 + 
     5.37775729072728217e-13*A*g12*x24 + 
     1.54097984854059648e-14*g13*x26) + 
  eps24*(-2.89099899565347662e-13*A11*g + 
     7.9759930961059578e-12*A8*g3 - 
     2.00555906593283631e-11*A5*g5 + 
     4.18688595364780991e-12*A2*g7 + 
     4.74420340935259007e-13*A13*x2 - 
     7.92461835979771511e-11*A10*g2*x2 + 
     7.58561702147442218e-10*A7*g4*x2 - 
     7.97991543042322495e-10*A4*g6*x2 + 
     5.12980963092851767e-11*A*g8*x2 + 
     1.99411637693229689e-11*A12*g*x4 - 
     1.54367310321517635e-9*A9*g3*x4 + 
     7.53265555420091332e-9*A6*g5*x4 - 
     3.62648374581728425e-9*A3*g7*x4 + 
     4.93947743563747665e-11*g9*x4 + 
     1.91553592353180707e-10*A11*g2*x6 - 
     8.49094217698978774e-9*A8*g4*x6 + 
     2.26856565220020088e-8*A5*g6*x6 - 
     4.69772329949351813e-9*A2*g8*x6 + 
     7.38610816404395504e-10*A10*g3*x8 - 
     1.99662166333330706e-8*A7*g5*x8 + 
     2.9041859633440226e-8*A4*g7*x8 - 
     2.15327269006722961e-9*A*g9*x8 + 
     1.46232224612947612e-9*A9*g4*x10 - 
     2.43772139379355154e-8*A6*g6*x10 + 
     1.82674355319716322e-8*A3*g8*x10 - 
     3.10752555543901178e-10*g10*x10 + 
     1.69732946496891816e-9*A8*g5*x12 - 
     1.71231822209617444e-8*A5*g7*x12 + 
     5.9144501741718517e-9*A2*g9*x12 + 
     1.24827250807789759e-9*A7*g6*x14 - 
     7.28755328956029511e-9*A4*g8*x14 + 
     9.42570128461049658e-10*A*g10*x14 + 
     6.08812904258686911e-10*A6*g7*x16 - 
     1.90694699932313329e-9*A3*g9*x16 + 
     5.83702428173174224e-11*g11*x16 + 
     2.01600973965553078e-10*A5*g8*x18 - 
     2.99487561260952419e-10*A2*g10*x18 + 
     4.5544937416083891e-11*A4*g9*x20 - 
     2.58715552328237504e-11*A*g11*x20 + 
     6.91310656589337861e-12*A3*g10*x22 - 
     9.44207238480244009e-13*g12*x22 + 
     6.74432494205638096e-13*A2*g11*x24 + 
     3.82104888900742578e-14*A*g12*x26 + 
     9.55678585992729762e-16*g13*x28) + 
  eps27*(-4.29185988094780467e-16*A14 + 
     9.75792282712677276e-14*A11*g2 - 
     1.3646853162570345e-12*A8*g4 + 
     2.42949425613405441e-12*A5*g6 - 
     4.11394545518213554e-13*A2*g8 - 
     3.96490174257524041e-13*A13*g*x2 + 
     2.12343279256552213e-11*A10*g3*x2 - 
     1.26943061490106314e-10*A7*g5*x2 + 
     1.02247921943695124e-10*A4*g7*x2 - 
     5.5423483777730116e-12*A*g9*x2 - 
     1.52404782309247872e-11*A12*g2*x4 + 
     4.20166632359481189e-10*A9*g4*x4 - 
     1.34342557916077234e-9*A6*g6*x4 + 
     5.08454526341145697e-10*A3*g8*x4 - 
     5.93267483507724836e-12*g10*x4 - 
     1.5105589569086578e-10*A11*g3*x6 + 
     2.46644028677531692e-9*A8*g5*x6 - 
     4.40356140879596708e-9*A5*g7*x6 + 
     7.2573930556411028e-10*A2*g9*x6 - 
     6.22095324902653748e-10*A10*g4*x8 + 
     6.28605537544467192e-9*A7*g6*x8 - 
     6.16872976090627993e-9*A4*g8*x8 + 
     3.66333923503317899e-10*A*g10*x8 - 
     1.3307708807396243e-9*A9*g5*x10 + 
     8.35325491249095651e-9*A6*g7*x10 - 
     4.24450814830156289e-9*A3*g9*x10 + 
     5.80327450488696854e-11*g11*x10 - 
     1.6742025695565531e-9*A8*g6*x12 + 
     6.38443699559690024e-9*A5*g8*x12 - 
     1.49942990889307018e-9*A2*g10*x12 - 
     1.33401488172649674e-9*A7*g7*x14 + 
     2.95015965374919579e-9*A4*g9*x14 - 
     2.59836904724562695e-10*A*g11*x14 - 
     7.03555104941829487e-10*A6*g8*x16 + 
     8.35706570206888892e-10*A3*g10*x16 - 
     1.74326212154086689e-11*g12*x16 - 
     2.51267260438286454e-10*A5*g9*x18 + 
     1.41631829044548074e-10*A2*g11*x18 - 
     6.10485807554465637e-11*A4*g10*x20 + 
     1.31608120750337335e-11*A*g12*x20 - 
     9.93693264312864106e-12*A3*g11*x22 + 
     5.15065776106236279e-13*g13*x22 - 
     1.03668290285869099e-12*A2*g12*x24 - 
     6.26408647094493891e-14*A*g13*x26 - 
     1.66670051667820424e-15*g14*x28) + 
  eps26*(3.15451701249663644e-14*A12*g - 
     1.23260743380846408e-12*A9*g3 + 
     4.91328598966957483e-12*A6*g5 - 
     2.16010730561106487e-12*A3*g7 + 
     2.80265846575244876e-14*g9 - 
     4.80688304875450638e-14*A14*x2 + 
     1.0882967128577594e-11*A11*g2*x2 - 
     1.51564449755526941e-10*A8*g4*x2 + 
     2.68832690023484167e-10*A5*g6*x2 - 
     4.53800665535698655e-11*A2*g8*x2 - 
     2.49976348277787481e-12*A13*g*x4 + 
     2.65894282403365961e-10*A10*g3*x4 - 
     1.95152833009846442e-9*A7*g5*x4 + 
     1.72592503214026419e-9*A4*g7*x4 - 
     9.84468564911047601e-11*A*g9*x4 - 
     2.9429564195639701e-11*A12*g2*x6 + 
     1.82782910902163964e-9*A9*g4*x6 - 
     7.67829334489098475e-9*A6*g6*x6 + 
     3.32590234296463859e-9*A3*g8*x6 - 
     4.19820646804651369e-11*g10*x6 - 
     1.38204464610680452e-10*A11*g3*x8 + 
     5.37351949422549083e-9*A8*g5*x8 - 
     1.30589400763732115e-8*A5*g7*x8 + 
     2.52344638346505715e-9*A2*g9*x8 - 
     3.32321907447622297e-10*A10*g4*x10 + 
     8.24783952385426657e-9*A7*g6*x10 - 
     1.1258556884547882e-8*A4*g8*x10 + 
     7.96395396558461894e-10*A*g10*x10 - 
     4.68876173390562072e-10*A9*g5*x12 + 
     7.37174695327914701e-9*A6*g7*x12 - 
     5.2863782907904963e-9*A3*g9*x12 + 
     8.70473987527200665e-11*g11*x12 - 
     4.21139769024652842e-10*A8*g6*x14 + 
     4.07659424674585697e-9*A5*g8*x14 - 
     1.36514999589867453e-9*A2*g10*x14 - 
     2.53184281042569276e-10*A7*g7*x16 + 
     1.43498819528840929e-9*A4*g9*x16 - 
     1.81588742992582398e-10*A*g11*x16 - 
     1.04910984884796622e-10*A6*g8*x18 + 
     3.21680373413064642e-10*A3*g10*x18 - 
     9.69728250369714944e-12*g12*x18 - 
     3.03594939414036236e-11*A5*g9*x20 + 
     4.44197711547649947e-11*A2*g11*x20 - 
     6.12305100850786679e-12*A4*g10*x22 + 
     3.44141679543564567e-12*A*g12*x22 - 
     8.43545071546764867e-13*A3*g11*x24 + 
     1.14398078813312878e-13*g13*x24 - 
     7.56779797267724648e-14*A2*g12*x26 - 
     3.98471719227870099e-15*A*g13*x28 - 
     9.34260000972918927e-17*g14*x30) + 
  eps29*(4.05865900486389479e-17*A15 - 
     1.2232070714449044e-14*A12*g2 + 
     2.40504092135660182e-13*A9*g4 - 
     6.74738575828689179e-13*A6*g6 + 
     2.39381911122681039e-13*A3*g8 - 
     2.69213219888548754e-15*g10 + 
     4.58169598971352973e-14*A14*g*x2 - 
     3.29749864880754721e-12*A11*g3*x2 + 
     2.84995234107358922e-11*A8*g5*x2 - 
     3.84976786675743869e-11*A5*g7*x2 + 
     5.45374653866869622e-12*A2*g9*x2 + 
     2.14322519486742071e-12*A13*g2*x4 - 
     8.07007645017179636e-11*A10*g4*x4 + 
     3.86143690504161214e-10*A7*g6*x4 - 
     2.67264933428133016e-10*A4*g8*x4 + 
     1.30060739859532917e-11*A*g10*x4 + 
     2.57042124070992211e-11*A12*g3*x6 - 
     5.85401863249985406e-10*A9*g5*x6 + 
     1.6366437980586345e-9*A6*g7*x6 - 
     5.62084412109891713e-10*A3*g9*x6 + 
     6.10475796289889538e-12*g11*x6 + 
     1.27635257751946417e-10*A11*g4*x8 - 
     1.84842734471682952e-9*A8*g6*x8 + 
     3.02055957066298636e-9*A5*g8*x8 - 
     4.66006916572248814e-10*A2*g10*x8 + 
     3.28941980482021155e-10*A10*g5*x10 - 
     3.06518944955340029e-9*A7*g7*x10 + 
     2.82916461168825083e-9*A4*g9*x10 - 
     1.60405696998930675e-10*A*g11*x10 + 
     4.99716779713464207e-10*A9*g6*x12 - 
     2.96269847070394137e-9*A6*g8*x12 + 
     1.44113957839403762e-9*A3*g10*x12 - 
     1.9063076595271542e-11*g12*x12 + 
     4.83613034179590552e-10*A8*g7*x14 - 
     1.76967309661014434e-9*A5*g9*x14 + 
     4.02711165138915376e-10*A2*g11*x14 + 
     3.12917535195346864e-10*A7*g8*x16 - 
     6.71388442300792017e-10*A4*g10*x16 + 
     5.77927914536543629e-11*A*g12*x16 + 
     1.39278559360094665e-10*A6*g9*x18 - 
     1.61790433278237663e-10*A3*g11*x18 + 
     3.31945367662205212e-12*g13*x18 + 
     4.31932834753340963e-11*A5*g10*x20 - 
     2.39510866157057273e-11*A2*g12*x20 + 
     9.31282938426145148e-12*A4*g11*x22 - 
     1.98395826023817872e-12*A*g13*x22 + 
     1.36819705061174548e-12*A3*g12*x24 - 
     7.03275140900692293e-14*g14*x24 + 
     1.30587191916705482e-13*A2*g13*x26 + 
     7.29839341237499951e-15*A*g14*x28 + 
     1.81240169810327889e-16*g15*x30) + 
  eps28*(-3.42449353535391123e-15*A13*g + 
     1.84149637365791136e-13*A10*g3 - 
     1.1050080873966546e-12*A7*g5 + 
     8.92914813217674881e-13*A4*g7 - 
     4.85334548141852657e-14*A*g9 + 
     4.87039080130076884e-15*A15*x2 - 
     1.46243857134180913e-12*A12*g2*x2 + 
     2.86469187305027265e-11*A9*g4*x2 - 
     8.01046401001525524e-11*A6*g6*x2 + 
     2.83390803597765611e-11*A3*g8*x2 - 
     3.17935732638901522e-13*g10*x2 + 
     3.08997725939711303e-13*A14*g*x4 - 
     4.40881232995903364e-11*A11*g3*x4 + 
     4.67270929147381534e-10*A8*g5*x4 - 
     6.92508097837570655e-10*A5*g7*x4 + 
     1.03176779132993969e-10*A2*g9*x4 + 
     4.40151413846244465e-12*A13*g2*x6 - 
     3.72611012872960704e-10*A10*g4*x6 + 
     2.33896053999641589e-9*A7*g6*x6 - 
     1.85076152700597453e-9*A4*g8*x6 + 
     9.73546889932565398e-11*A*g10*x6 + 
     2.48641511603740223e-11*A12*g3*x8 - 
     1.34582689296840159e-9*A9*g5*x8 + 
     5.1140460796628628e-9*A6*g7*x8 - 
     2.0570070090932405e-9*A3*g9*x8 + 
     2.45730759326416844e-11*g11*x8 + 
     7.1702923091107546e-11*A11*g4*x10 - 
     2.54607352322993814e-9*A8*g6*x10 + 
     5.77943820119451463e-9*A5*g8*x10 - 
     1.06095247142717178e-9*A2*g10*x10 + 
     1.2131500328791563e-10*A10*g5*x12 - 
     2.82707146362666275e-9*A7*g7*x12 + 
     3.67801985870440129e-9*A4*g9*x12 - 
     2.50903669106862355e-10*A*g11*x12 + 
     1.31050021791628478e-10*A9*g6*x14 - 
     1.96949908360014888e-9*A6*g8*x14 + 
     1.3644828493201679e-9*A3*g10*x14 - 
     2.18943788516381651e-11*g12*x14 + 
     9.53596786211020254e-11*A8*g7*x16 - 
     8.93201150460212866e-10*A5*g9*x16 + 
     2.91741725069643471e-10*A2*g11*x16 + 
     4.83328521248353745e-11*A7*g8*x18 - 
     2.67394075003739542e-10*A4*g10*x18 + 
     3.32333838170053206e-11*A*g12*x18 + 
     1.73860565862725499e-11*A6*g9*x20 - 
     5.2370974939069083e-11*A3*g11*x20 + 
     1.55867178465730428e-12*g13*x20 + 
     4.46556790482617333e-12*A5*g10*x22 - 
     6.44988561121731387e-12*A2*g12*x22 + 
     8.13268877653918674e-13*A4*g11*x24 - 
     4.52921962533507132e-13*A*g13*x24 + 
     1.02564448524934742e-13*A3*g12*x26 - 
     1.38230362423873659e-14*g14*x26 + 
     8.51681830544114951e-15*A2*g13*x28 + 
     4.18850310798987491e-16*A*g14*x30 + 
     9.24169435429845849e-18*g15*x32) + 
  0.00833333333333333333*eps*g*xbar2 + 
  0.166666666666666667*(A + 0.5*g*x2)*xbar2 + 
  eps3*(-0.000793650793650793651*A*g - 
     0.00138888888888888889*g2*x2)*xbar2 + 
  eps2*(-0.00277777777777777778*A2 - 
     0.0111111111111111111*A*g*x2 - 
     0.00208333333333333333*g2*x4)*xbar2 + 
  eps5*(0.0000727513227513227513*A2*g + 
     0.000522486772486772487*A*g2*x2 + 
     0.000162037037037037037*g3*x4)*xbar2 + 
  eps4*(0.0000661375661375661376*A3 - 
     0.0000644841269841269841*g2 + 
     0.0015873015873015873*A2*g*x2 + 
     0.00094246031746031746*A*g2*x4 + 
     0.000115740740740740741*g3*x6)*xbar2 + 
  eps7*(-6.91438191438191438e-6*A3*g + 
     1.41486599819933153e-6*g3 - 
     0.000128066378066378066*A2*g2*x2 - 
     0.000110705266955266955*A*g3*x4 - 
     0.000018647119341563786*g4*x6)*xbar2 + 
  eps6*(-1.65343915343915344e-6*A4 + 
     0.0000179623617123617124*A*g2 - 
     0.00021164021164021164*A3*g*x2 + 
     0.0000485008818342151675*g3*x2 - 
     0.000276951058201058201*A2*g2*x4 - 
     0.0000898368606701940035*A*g3*x6 - 
     8.27867798353909465e-6*g4*x8)*xbar2 + 
  eps9*(6.79829796893288957e-7*A4*g - 
     6.72419695237155555e-7*A*g3 + 
     0.0000254975770848786722*A3*g2*x2 - 
     2.25056258042369153e-6*g4*x2 + 
     0.0000441438108848823135*A2*g3*x4 + 
     0.0000185871013417309714*A*g4*x6 + 
     2.15148764772607365e-6*g5*x8)*xbar2 + 
  eps8*(4.1753513975736198e-8*A5 - 
     3.46221514376276281e-6*A2*g2 + 
     0.0000267222489444711667*A4*g*x2 - 
     0.0000281804101248545693*A*g3*x2 + 
     0.0000649475909892576559*A3*g2*x4 - 
     0.0000122030666735527847*g4*x4 + 
     0.0000403965247715247715*A2*g3*x6 + 
     9.0700810463541945e-6*A*g4*x8 + 
     6.69795953360768176e-7*g5*x10)*xbar2 + 
  eps11*(-6.80612866459427306e-8*A5*g + 
     1.95584655809718057e-7*A2*g3 - 
     4.47269759439071608e-6*A4*g2*x2 + 
     1.75829988748211593e-6*A*g4*x2 - 
     0.0000133314481239415102*A3*g3*x4 + 
     9.71399147418687179e-7*g5*x4 - 
     0.0000103064498801381517*A2*g4*x6 - 
     2.82142523293179157e-6*A*g5*x8 - 
     2.4892365507720446e-7*g6*x10)*xbar2 + 
  eps10*(-1.05683802773749864e-9*A6 + 
     5.67501373552960855e-7*A3*g2 - 
     4.8511255774108832e-8*g4 - 
     3.24660642120959581e-6*A5*g*x2 + 
     9.71126169538867952e-6*A2*g3*x2 - 
     0.0000131832441790279092*A4*g2*x4 + 
     0.0000108846610427711618*A*g4*x4 - 
     0.0000136365860158849577*A3*g3*x6 + 
     2.33168885512635513e-6*g5*x6 - 
     5.4993290386188865e-6*A2*g4*x8 - 
     9.46094479080590192e-7*A*g5*x10 - 
     5.8302302889011994e-8*g6*x12)*xbar2 + 
  eps13*(6.86627585651083939e-9*A6*g - 
     4.47785160224899766e-8*A3*g3 + 
     2.19249275444418889e-9*g5 + 
     7.19946098097358602e-7*A5*g2*x2 - 
     7.80379784965903039e-7*A2*g4*x2 + 
     3.37142842641135708e-6*A4*g3*x4 - 
     1.06398186364605041e-6*A*g5*x4 + 
     4.18165456228327982e-6*A3*g4*x6 - 
     2.76351067919865578e-7*g6*x6 + 
     2.00589567077445504e-6*A2*g5*x8 + 
     4.04753308555164946e-7*A*g6*x10 + 
     2.88571475583667131e-8*g7*x12)*xbar2 + 
  eps12*(2.67650730613693577e-11*A7 - 
     8.46192910475220622e-8*A4*g2 + 
     3.25142589196534057e-8*A*g4 + 
     3.83704087407791111e-7*A6*g*x2 - 
     2.57283359783619147e-6*A3*g3*x2 + 
     1.27951218977907431e-7*g5*x2 + 
     2.41765559329216737e-6*A5*g2*x4 - 
     5.44480881814382923e-6*A2*g4*x4 + 
     3.82233569685344377e-6*A4*g3*x6 - 
     2.81139544164632672e-6*A*g5*x6 + 
     2.42710273474001612e-6*A3*g4*x8 - 
     3.92027350262991887e-7*g6*x8 + 
     7.21984500196305752e-7*A2*g5*x10 + 
     1.007566064009769e-7*A*g6*x12 + 
     5.32759708629371695e-9*g7*x14)*xbar2 + 
  eps15*(-6.94677964495491896e-10*A7*g + 
     8.85485037384606633e-9*A4*g3 - 
     1.89784940868103996e-9*A*g5 - 
     1.08873720111587578e-7*A6*g2*x2 + 
     2.58200627219967634e-7*A3*g4*x2 - 
     8.57415659878293831e-9*g6*x2 - 
     7.52178044272582197e-7*A5*g3*x4 + 
     6.39174172204870162e-7*A2*g5*x4 - 
     1.38311030669262085e-6*A4*g4*x6 + 
     3.89805821462228289e-7*A*g6*x6 - 
     1.02272071613530239e-6*A3*g5*x8 + 
     6.35874554600849527e-8*g7*x8 - 
     3.51191445940869782e-7*A2*g6*x10 - 
     5.59975947545884819e-8*A*g7*x12 - 
     3.35001083013772154e-9*g8*x14)*xbar2 + 
  eps14*(-6.77936059264516573e-13*A8 + 
     1.18453251754498057e-8*A5*g2 - 
     1.26192122113177278e-8*A2*g4 - 
     4.44292175799593582e-8*A7*g*x2 + 
     5.78235471803035281e-7*A4*g3*x2 - 
     1.25465164813262727e-7*A*g5*x2 - 
     4.11093596933471078e-7*A6*g2*x4 + 
     2.00802343589623813e-6*A3*g4*x4 - 
     8.38456228452171631e-8*g6*x4 - 
     9.37962675222683393e-7*A5*g3*x6 + 
     1.84660973293660698e-6*A2*g5*x6 - 
     8.68952732620502728e-7*A4*g4*x8 + 
     5.95974150882540242e-7*A*g6*x8 - 
     3.93789587968658131e-7*A3*g5*x10 + 
     6.11861559616332661e-8*g7*x10 - 
     9.26911580977221589e-8*A2*g6*x12 - 
     1.08851336477984649e-8*A*g7*x14 - 
     5.04016698893419468e-10*g8*x16)*xbar2 + 
  eps17*(7.03519796756268115e-11*A8*g - 
     1.58412622695254907e-9*A5*g3 + 
     9.21824723042734146e-10*A2*g5 + 
     1.57013176618403867e-8*A7*g2*x2 - 
     7.07877152349972815e-8*A4*g4*x2 + 
     1.01145514044440416e-8*A*g6*x2 + 
     1.52755677874009072e-7*A6*g3*x4 - 
     2.78303968964189299e-7*A3*g5*x4 + 
     7.90216106829461597e-9*g7*x4 + 
     3.94839847004885584e-7*A5*g4*x6 - 
     2.95546266642869418e-7*A2*g6*x6 + 
     4.1812888733216445e-7*A4*g5*x8 - 
     1.09749260429676339e-7*A*g7*x8 + 
     2.15692160440115788e-7*A3*g6*x10 - 
     1.28547064754435117e-8*g8*x10 + 
     5.73688513495873601e-8*A2*g7*x12 + 
     7.55383153004710777e-9*A*g8*x14 + 
     3.89293296941875901e-10*g9*x16)*xbar2 + 
  eps16*(1.71721241125556891e-14*A9 - 
     1.58463391176416606e-9*A6*g2 + 
     3.70687203668986364e-9*A3*g4 - 
     1.21950914958299276e-10*g6 + 
     5.06426546628202339e-9*A8*g*x2 - 
     1.15919331839795365e-7*A5*g3*x2 + 
     6.813324046201634e-8*A2*g5*x2 + 
     6.59264102615256734e-8*A7*g2*x4 - 
     6.0783143535697607e-7*A4*g4*x4 + 
     1.08734552181364072e-7*A*g6*x4 + 
     2.08077893379438207e-7*A6*g3*x6 - 
     8.7376194571684116e-7*A3*g5*x6 + 
     3.31435423816449871e-8*g7*x6 + 
     2.67286143174399604e-7*A5*g4*x8 - 
     4.84990273878282454e-7*A2*g6*x8 + 
     1.71677767909550515e-7*A4*g5*x10 - 
     1.12268658721773254e-7*A*g7*x10 + 
     6.02176056859808662e-8*A3*g6*x12 - 
     9.09453722352822717e-9*g8*x12 + 
     1.17208819972660499e-8*A2*g7*x14 + 
     1.18834173730462595e-9*A*g8*x16 + 
     4.8940576382579539e-11*g9*x18)*xbar2 + 
  eps19*(-7.12707337587569786e-12*A9*g + 
     2.63376364359160315e-10*A6*g3 - 
     3.30780046645030994e-10*A3*g5 + 
     8.03679335161609342e-12*g7 - 
     2.18139573549146275e-9*A8*g2*x2 + 
     1.6989863583308778e-8*A5*g4*x2 - 
     6.4969385102430346e-9*A2*g6*x2 - 
     2.88250590711040757e-8*A7*g3*x4 + 
     9.81072496878526138e-8*A4*g5*x4 - 
     1.18346882869724656e-8*A*g7*x4 - 
     1.00731210992033847e-7*A6*g4*x6 + 
     1.59691202088983395e-7*A3*g6*x6 - 
     4.13548363870289057e-9*g8*x6 - 
     1.45496453255537213e-7*A5*g5*x8 + 
     1.00501516554651165e-7*A2*g7*x8 - 
     1.05051610378898918e-7*A4*g6*x10 + 
     2.62399674415998082e-8*A*g8*x10 - 
     4.12244346987175346e-8*A3*g7*x12 + 
     2.38101241880130705e-9*g9*x12 - 
     8.92371773273422321e-9*A2*g8*x14 - 
     1.00013636391153993e-9*A*g9*x16 - 
     4.52724718151082609e-11*g10*x18)*xbar2 + 
  eps18*(-4.34973739711612375e-16*A10 + 
     2.04866596742209561e-10*A7*g2 - 
     9.13337973503563032e-10*A4*g4 + 
     1.29494994082815314e-10*A*g6 - 
     5.70128780114804572e-10*A9*g*x2 + 
     2.13523668994309077e-8*A6*g3*x2 - 
     2.7041278749459319e-8*A3*g5*x2 + 
     6.61136770529593115e-10*g7*x2 - 
     1.00900226220693725e-8*A8*g2*x4 + 
     1.59771473522731497e-7*A5*g4*x4 - 
     7.62149977963186539e-8*A2*g6*x4 - 
     4.26288251723329756e-8*A7*g3*x6 + 
     3.32905368200259132e-7*A4*g5*x6 - 
     5.34789893441100738e-8*A*g7*x6 - 
     7.31666710191171495e-8*A6*g4*x8 + 
     2.80197106079331506e-7*A3*g6*x8 - 
     9.98659790379859243e-9*g8*x8 - 
     6.35106992331774466e-8*A5*g5*x10 + 
     1.08995209478400767e-7*A2*g7*x10 - 
     3.09539659674895079e-8*A4*g6*x12 + 
     1.95483783519714526e-8*A*g8*x12 - 
     8.83724740598401241e-9*A3*g7*x14 + 
     1.30582050443893102e-9*g9*x14 - 
     1.46593717511110234e-9*A2*g8*x16 - 
     1.30772635674859038e-10*A*g9*x18 - 
     4.84955398928857724e-12*g10*x20)*xbar2 + 
  eps21*(7.22090117277105046e-13*A10*g - 
     4.13991085301446953e-11*A7*g3 + 
     9.76589682716262956e-11*A4*g5 - 
     1.01171462635282484e-11*A*g7 + 
     2.94059482872196453e-10*A9*g2*x2 - 
     3.68979054877682005e-9*A6*g4*x2 + 
     3.00808714445394687e-9*A3*g6*x2 - 
     5.76746247671597889e-11*g8*x2 + 
     5.12696720776491515e-9*A8*g3*x4 - 
     2.96928069363177013e-8*A5*g5*x4 + 
     9.47962261651077826e-9*A2*g7*x4 + 
     2.35049540761358863e-8*A7*g4*x6 - 
     6.88556064847354174e-8*A4*g6*x6 + 
     7.5086659172629484e-9*A*g8*x6 + 
     4.47020768444263473e-8*A6*g5*x8 - 
     6.48548347717962229e-8*A3*g7*x8 + 
     1.57872287719044645e-9*g9*x8 + 
     4.31283591778531503e-8*A5*g6*x10 - 
     2.81624636750572854e-8*A2*g8*x10 + 
     2.3304946259676748e-8*A4*g7*x12 - 
     5.6106802334762125e-9*A*g9*x12 + 
     7.34468856466444926e-9*A3*g8*x14 - 
     4.14021761190658312e-10*g10*x14 + 
     1.33841053507869873e-9*A2*g9*x16 + 
     1.30531947930356562e-10*A*g10*x18 + 
     5.26795343697585529e-12*g11*x20)*xbar2 + 
  eps20*(1.1018005656720459e-17*A11 - 
     2.57889246901160178e-11*A8*g2 + 
     1.98990234155769708e-10*A5*g4 - 
     7.55965424361672699e-11*A2*g6 + 
     6.35426896472572163e-11*A10*g*x2 - 
     3.68388963577669912e-9*A7*g3*x2 + 
     8.75177480890399108e-9*A4*g5*x2 - 
     9.11535637885301799e-10*A*g7*x2 + 
     1.48649455332149944e-9*A9*g2*x4 - 
     3.77359746051647268e-8*A6*g4*x4 + 
     3.82594204726996217e-8*A3*g6*x4 - 
     8.13304101172221063e-10*g8*x4 + 
     8.18713369443791778e-9*A8*g3*x6 - 
     1.08366523313337395e-7*A5*g5*x6 + 
     4.5944289943616577e-8*A2*g7*x6 + 
     1.82487684327326814e-8*A7*g4*x8 - 
     1.28729795350649249e-7*A4*g6*x8 + 
     1.92747318307891877e-8*A*g8*x8 + 
     2.06867607666613227e-8*A6*g5*x10 - 
     7.43763204190519753e-8*A3*g7*x10 + 
     2.53626156501045944e-9*g9*x10 + 
     1.33838352059798451e-8*A5*g6*x12 - 
     2.20494122463979174e-8*A2*g8*x12 + 
     5.23330987914141423e-9*A4*g7*x14 - 
     3.21750395058170305e-9*A*g9*x14 + 
     1.25827561244148185e-9*A3*g8*x16 - 
     1.82713361623688652e-10*g10*x16 + 
     1.81827783439828152e-10*A2*g9*x18 + 
     1.44818570824073778e-11*A*g10*x20 + 
     4.88417660313835094e-13*g11*x22)*xbar2 + 
  eps23*(-7.31620058828327886e-14*A11*g + 
     6.2244144715351518e-12*A8*g3 - 
     2.50972722113902645e-11*A5*g5 + 
     6.90195578112387954e-12*A2*g7 - 
     3.86661866535845128e-11*A10*g2*x2 + 
     7.40985528302493753e-10*A7*g4*x2 - 
     1.12263534560497836e-9*A4*g6*x2 + 
     9.10038912793887614e-11*A*g8*x2 - 
     8.68557303415569482e-10*A9*g3*x4 + 
     7.99751265225702085e-9*A6*g5*x4 - 
     5.38995025036586533e-9*A3*g7*x4 + 
     9.11682355767971334e-11*g9*x4 - 
     5.09949189194303306e-9*A8*g4*x6 + 
     2.517151280314285e-8*A5*g6*x6 - 
     7.20688202607308513e-9*A2*g8*x6 - 
     1.24293927810383763e-8*A7*g5*x8 + 
     3.30698321741881119e-8*A4*g7*x8 - 
     3.36777220246894258e-9*A*g9*x8 - 
     1.55006071785928367e-8*A6*g6*x10 + 
     2.11300984088409138e-8*A3*g8*x10 - 
     4.91764411032702861e-10*g10*x10 - 
     1.10270946906705895e-8*A5*g7*x12 + 
     6.90528529828172647e-9*A2*g9*x12 - 
     4.72730487747526667e-9*A4*g8*x14 + 
     1.10602336934435099e-9*A*g10*x14 - 
     1.24144324312375269e-9*A3*g9*x16 + 
     6.86305256373542116e-11*g11*x16 - 
     1.95159691471731057e-10*A2*g10*x18 - 
     1.68433306811216689e-11*A*g11*x20 - 
     6.13262463130406207e-13*g12*x22)*xbar2 + 
  eps22*(-2.79089293716250467e-19*A12 + 
     3.17766604095748225e-12*A9*g2 - 
     3.95577368582764204e-11*A6*g4 + 
     3.2068101326980409e-11*A3*g6 - 
     6.12076747703341304e-13*g8 - 
     7.02351204594746519e-12*A11*g*x2 + 
     6.03214212931090113e-10*A8*g3*x2 - 
     2.44702734746155151e-9*A5*g5*x2 + 
     6.76097426096149884e-10*A2*g7*x2 - 
     2.12157940796992025e-10*A10*g2*x4 + 
     8.1916797369498686e-9*A7*g4*x4 - 
     1.53944612844692757e-8*A4*g6*x4 + 
     1.38109622177934475e-9*A*g8*x4 - 
     1.49038549899160153e-9*A9*g3*x6 + 
     3.12551588277558658e-8*A6*g5*x6 - 
     2.79047223116628872e-8*A3*g7*x6 + 
     5.436847471574281e-10*g9*x6 - 
     4.21695720957640858e-9*A8*g4*x8 + 
     4.99819767239979985e-8*A5*g6*x8 - 
     1.96069567048585921e-8*A2*g8*x8 - 
     6.0820173561110201e-9*A7*g5*x10 + 
     4.00069800775570726e-8*A4*g7*x10 - 
     5.69705873785929584e-9*A*g9*x10 - 
     5.05592156438231298e-9*A6*g6*x12 + 
     1.73541009641709023e-8*A3*g8*x12 - 
     5.72444406380114732e-10*g10*x12 - 
     2.58984982240261447e-9*A5*g7*x14 + 
     4.13461348937075909e-9*A2*g9*x14 - 
     8.43540110516749951e-10*A4*g8*x16 + 
     5.07648285991122299e-10*A*g10*x16 - 
     1.75053485949267209e-10*A3*g9*x18 + 
     2.50585955675889897e-11*g11*x18 - 
     2.24065847218371337e-11*A2*g10*x20 - 
     1.61190422371025444e-12*A*g11*x22 - 
     4.98497255151051565e-14*g12*x24)*xbar2 + 
  eps25*(7.41283040826477982e-15*A12*g - 
     9.02635849548132915e-13*A9*g3 + 
     5.808192723300797e-12*A6*g5 - 
     3.38057427569094457e-12*A3*g7 + 
     5.29100393497390523e-14*g9 + 
     4.97920609040144658e-12*A11*g2*x2 - 
     1.39694069095383245e-10*A8*g4*x2 + 
     3.58402228305301032e-10*A5*g6*x2 - 
     7.65495191386971796e-11*A2*g8*x2 + 
     1.4125212696675559e-10*A10*g3*x4 - 
     1.96338748728595609e-9*A7*g5*x4 + 
     2.43765341823600507e-9*A4*g7*x4 - 
     1.73076565727920605e-10*A*g9*x4 + 
     1.04116644719005016e-9*A9*g4*x6 - 
     8.09905476228113474e-9*A6*g6*x6 + 
     4.85986711480587249e-9*A3*g8*x6 - 
     7.57303676890670029e-11*g10*x6 + 
     3.18313608725054007e-9*A8*g5*x8 - 
     1.41719309600437594e-8*A5*g7*x8 + 
     3.76671783453056944e-9*A2*g9*x8 + 
     5.00343186081653831e-9*A7*g6*x10 - 
     1.24378552441987574e-8*A4*g8*x10 + 
     1.20496661429663104e-9*A*g10*x10 + 
     4.53880717317622481e-9*A6*g7*x12 - 
     5.90571016995380991e-9*A3*g9*x12 + 
     1.32811990726503565e-10*g11*x12 + 
     2.53296660339142496e-9*A5*g8*x14 - 
     1.53532762899011833e-9*A2*g10*x14 + 
     8.96296897032458165e-10*A4*g9*x16 - 
     2.04947909641080151e-10*A*g11*x16 + 
     2.01417828995844438e-10*A3*g10*x18 - 
     1.09580840956783665e-11*g12*x18 + 
     2.78250438436826e-11*A2*g11*x20 + 
     2.15336350583630878e-12*A*g12*x22 + 
     7.14181481885948442e-14*g13*x24)*xbar2 + 
  eps24*(7.06941407925893494e-21*A13 - 
     3.84741654463843396e-13*A10*g2 + 
     7.32293254814967057e-12*A7*g4 - 
     1.10404290967107504e-11*A4*g6 + 
     8.91430430592888932e-13*A*g8 + 
     7.70933065507593765e-13*A12*g*x2 - 
     9.46392329053276403e-11*A9*g3*x2 + 
     6.12204723118016064e-10*A6*g5*x2 - 
     3.57786436948859923e-10*A3*g7*x2 + 
     5.61900352465916136e-12*g9*x2 + 
     2.94794501076642169e-11*A11*g2*x4 - 
     1.66054285997922112e-9*A8*g4*x4 + 
     5.27270026858442259e-9*A5*g6*x4 - 
     1.24441828714339168e-9*A2*g8*x4 + 
     2.5932143768735243e-10*A10*g3*x6 - 
     8.18440975363309936e-9*A7*g5*x6 + 
     1.34316391603932223e-8*A4*g7*x6 - 
     1.0967577860615365e-9*A*g9*x6 + 
     9.14099216298559597e-10*A9*g4*x8 - 
     1.70303761165690513e-8*A6*g6*x8 + 
     1.39743392988134275e-8*A3*g8*x8 - 
     2.56275349412587196e-10*g10*x8 + 
     1.64295978902062036e-9*A8*g5*x10 - 
     1.80454719563725777e-8*A5*g7*x10 + 
     6.69540001883729058e-9*A2*g9*x10 + 
     1.71211385785801628e-9*A7*g6*x12 - 
     1.06969476032442112e-8*A4*g8*x12 + 
     1.46666897500527102e-9*A*g10*x12 + 
     1.11324562362569516e-9*A6*g7*x14 - 
     3.68698661561997461e-9*A3*g9*x14 + 
     1.18497108911150463e-10*g11*x14 + 
     4.70206598723156244e-10*A5*g8*x16 - 
     7.32089723755050849e-10*A2*g10*x16 + 
     1.31051469702399336e-10*A4*g9*x18 - 
     7.74991097074319971e-11*A*g11*x18 + 
     2.39115858864581722e-11*A3*g10*x20 - 
     3.38215281496470102e-12*g12*x20 + 
     2.74671447656417087e-12*A2*g11*x22 + 
     1.80167001235699906e-13*A*g12*x24 + 
     5.14468471968218436e-15*g13*x26)*xbar2 + 
  eps27*(-7.51075843529661214e-16*A13*g + 
     1.27030008776550472e-13*A10*g3 - 
     1.23787664790561913e-12*A7*g5 + 
     1.33019638955516254e-12*A4*g7 - 
     8.75323806724792164e-14*A*g9 - 
     6.29897142455818647e-13*A12*g2*x2 + 
     2.49970513387192938e-11*A9*g4*x2 - 
     1.0151027849161936e-10*A6*g6*x2 + 
     4.55816229506986659e-11*A3*g8*x2 - 
     6.05079004055138099e-13*g10*x2 - 
     2.21864408565359165e-11*A11*g3*x4 + 
     4.46844885997837561e-10*A8*g5*x4 - 
     9.32148098458465571e-10*A5*g7*x4 + 
     1.73258271490234049e-10*A2*g9*x4 - 
     2.01903912835646714e-10*A10*g4*x6 + 
     2.3520545127039623e-9*A7*g6*x6 - 
     2.58299973973554577e-9*A4*g8*x6 + 
     1.68010587801441092e-10*A*g10*x6 - 
     7.60717456057238184e-10*A9*g5*x8 + 
     5.3035966583288928e-9*A6*g7*x8 - 
     2.93817404535934839e-9*A3*g9*x8 + 
     4.31762252962423416e-11*g11*x8 - 
     1.47734599003688525e-9*A8*g6*x10 + 
     6.11354887209435414e-9*A5*g8*x10 - 
     1.5386347665145731e-9*A2*g10*x10 - 
     1.66823527450663911e-9*A7*g7*x12 + 
     3.94111855521203731e-9*A4*g9*x12 - 
     3.67480562505678573e-10*A*g11*x12 - 
     1.17484922387971434e-9*A6*g8*x14 + 
     1.47416329157764893e-9*A3*g10*x14 - 
     3.22644970036886805e-11*g12*x14 - 
     5.36421779678852887e-10*A5*g9*x16 + 
     3.1674778190064466e-10*A2*g11*x16 - 
     1.61202978156834228e-10*A4*g10*x18 + 
     3.61721347255152469e-11*A*g12*x18 - 
     3.16257866721202736e-11*A3*g11*x20 + 
     1.69763752975172776e-12*g13*x20 - 
     3.89515288561440053e-12*A2*g12*x22 - 
     2.73194264984077097e-13*A*g13*x24 - 
     8.31954367803020154e-15*g14*x26)*xbar2 + 
  eps26*(-1.79070348540750937e-22*A14 + 
     4.59064378043914658e-14*A11*g2 - 
     1.28030566526092309e-12*A8*g4 + 
     3.27066666352992692e-12*A5*g6 - 
     6.96122544470052509e-13*A2*g8 - 
     8.41204536665769716e-14*A13*g*x2 + 
     1.43280455193797042e-11*A10*g3*x2 - 
     1.40273974291259099e-10*A7*g5*x2 + 
     1.51283231860462901e-10*A4*g7*x2 - 
     9.98551158367175128e-12*A*g9*x2 - 
     4.00333440491699611e-12*A12*g2*x4 + 
     3.18015053542555029e-10*A9*g4*x4 - 
     1.59520735961063233e-9*A6*g6*x4 + 
     7.90439808401736791e-10*A3*g8*x4 - 
     1.10881173257059828e-11*g10*x4 - 
     4.34093541154382073e-11*A11*g3*x6 + 
     1.97976173597291254e-9*A8*g5*x6 - 
     5.44840751323234817e-9*A5*g7*x6 + 
     1.16297756207798465e-9*A2*g9*x6 - 
     1.87645728811177992e-10*A10*g4*x8 + 
     5.22333666100318922e-9*A7*g6*x8 - 
     7.83026501022594579e-9*A4*g8*x8 + 
     5.98605008455371809e-10*A*g10*x8 - 
     4.13221853558421767e-10*A9*g5*x10 + 
     7.0930748517934503e-9*A6*g7*x10 - 
     5.47699171024144332e-9*A3*g9*x10 + 
     9.60336772604947622e-11*g11*x10 - 
     5.29402656244831828e-10*A8*g6*x12 + 
     5.49671855849442248e-9*A5*g8*x12 - 
     1.95523008426311717e-9*A2*g10*x12 - 
     4.26701447988946737e-10*A7*g7*x14 + 
     2.56206141566278962e-9*A4*g9*x14 - 
     3.410012726945875e-10*A*g11*x14 - 
     2.26624447643405895e-10*A6*g8*x16 + 
     7.29466473293570049e-10*A3*g10*x16 - 
     2.29576353915048113e-11*g12*x16 - 
     8.12511797350192351e-11*A5*g9*x18 + 
     1.23935273887572293e-10*A2*g11*x18 - 
     1.97726428661170689e-11*A4*g10*x20 + 
     1.1522889199786472e-11*A*g12*x20 - 
     3.21807538962660607e-12*A3*g11*x22 + 
     4.50555068931041406e-13*g13*x22 - 
     3.35257433966932062e-13*A2*g12*x24 - 
     2.02087347024185195e-14*A*g13*x26 - 
     5.35972002923398376e-16*g14*x28)*xbar2 + 
  eps28*(4.53590490467536612e-24*A15 - 
     5.40991439207615254e-15*A12*g2 + 
     2.13572325776495319e-13*A9*g4 - 
     8.63988999290148989e-13*A6*g6 + 
     3.86748974945163587e-13*A3*g8 - 
     5.12013122735698219e-15*g10 + 
     9.13198276094376327e-15*A14*g*x2 - 
     2.10466395152949666e-12*A11*g3*x2 + 
     2.99221119573615308e-11*A8*g5*x2 - 
     5.43028283802785305e-11*A5*g7*x2 + 
     9.39323023305384053e-12*A2*g9*x2 + 
     5.32975810622098983e-13*A13*g2*x4 - 
     5.80501375188322573e-11*A10*g4*x4 + 
     4.37019357919065163e-10*A7*g6*x4 - 
     3.96940392701823555e-10*A4*g8*x4 + 
     2.32697144314946291e-11*A*g10*x4 + 
     7.02726857799546755e-12*A12*g3*x6 - 
     4.48099032082615037e-10*A9*g5*x6 + 
     1.93483038558514086e-9*A6*g7*x6 - 
     8.62091046575190556e-10*A3*g9*x6 + 
     1.11969653061492518e-11*g11*x6 + 
     3.67514622272442738e-11*A11*g4*x8 - 
     1.46851969916158753e-9*A8*g6*x8 + 
     3.67093207885254627e-9*A5*g8*x8 - 
     7.29997175436358399e-10*A2*g10*x8 + 
     9.77570879970920307e-11*A10*g5*x10 - 
     2.4937819519531606e-9*A7*g7*x10 + 
     3.50138772519325701e-9*A4*g9*x10 - 
     2.54844237335376222e-10*A*g11*x10 + 
     1.51551103111356592e-10*A9*g6*x12 - 
     2.44830289593819667e-9*A6*g8*x12 + 
     1.80516208982376366e-9*A3*g10*x12 - 
     3.05697442448458284e-11*g12*x12 + 
     1.48622282787020755e-10*A8*g7*x14 - 
     1.47744439669993501e-9*A5*g9*x14 + 
     5.08385861370867083e-10*A2*g11*x14 + 
     9.69900961277773013e-11*A7*g8*x16 - 
     5.64164139872020481e-10*A4*g10*x16 + 
     7.33057694868158047e-11*A*g12*x16 + 
     4.33970845131522305e-11*A6*g9*x18 - 
     1.36463983851389839e-10*A3*g11*x18 + 
     4.22094652479065705e-12*g13*x18 + 
     1.34966390319579822e-11*A5*g10*x20 - 
     2.02368017798006725e-11*A2*g12*x20 + 
     2.91298850556569867e-12*A4*g11*x22 - 
     1.67658546698404719e-12*A*g13*x22 + 
     4.27809470715471873e-13*A3*g12*x24 - 
     5.93702994278643299e-14*g14*x24 + 
     4.0773300599504767e-14*A2*g13*x26 + 
     2.27354318349331788e-15*A*g14*x28 + 
     5.62902053628343785e-17*g15*x30)*xbar2 + 
  0.00833333333333333333*g*xbar4 - 
  0.0000462962962962962963*eps3*g2*xbar4 + 
  eps2*(-0.000396825396825396825*A*g - 
     0.000694444444444444444*g2*x2)*xbar4 + 
  eps5*(9.11896745230078563e-6*A*g2 + 
     0.0000308641975308641975*g3*x2)*xbar4 + 
  eps4*(0.0000198412698412698413*A2*g + 
     0.000195105820105820106*A*g2*x2 + 
     0.0000617283950617283951*g3*x4)*xbar4 + 
  eps7*(-1.31581381581381581e-6*A2*g2 - 
     0.0000151318588818588819*A*g3*x2 - 
     6.8455207344096233e-6*g4*x4)*xbar4 + 
  eps6*(-9.01875901875901876e-7*A3*g + 
     9.90714532381199048e-7*g3 - 
     0.0000389059243225909893*A2*g2*x2 - 
     0.0000351397573619795842*A*g3*x4 - 
     5.9477880658436214e-6*g4*x6)*xbar4 + 
  eps9*(1.71045640622360199e-7*A3*g2 - 
     3.60906857706966639e-8*g4 + 
     4.53245406122390249e-6*A2*g3*x2 + 
     5.38783061931210079e-6*A*g4*x4 + 
     1.17492514772607365e-6*g5*x6)*xbar4 + 
  eps8*(3.77616945077262538e-8*A4*g - 
     3.91505723846993688e-7*A*g3 + 
     6.55938527962337486e-6*A3*g2*x2 - 
     1.61985166325444103e-6*g4*x2 + 
     0.0000121547079219036891*A2*g3*x4 + 
     5.20508405346368309e-6*A*g4*x6 + 
     6.02301130368259998e-7*g5*x8)*xbar4 + 
  eps11*(-2.12135350797297057e-8*A4*g2 + 
     2.14460056215349951e-8*A*g4 - 
     1.06401470496877178e-6*A3*g3*x2 + 
     9.9419658966568008e-8*g5*x2 - 
     2.4228308825712602e-6*A2*g4*x4 - 
     1.28380796826126347e-6*A*g5*x6 - 
     1.80516340332649186e-7*g6*x8)*xbar4 + 
  eps10*(-1.48202033122668043e-9*A5*g + 
     9.77137892841674354e-8*A2*g3 - 
     9.98537198520664129e-7*A4*g2*x2 + 
     1.12096864298613054e-6*A*g4*x2 - 
     3.25929867376075489e-6*A3*g3*x4 + 
     6.52088831782005348e-7*g5*x4 - 
     2.59007734102806854e-6*A2*g4*x6 - 
     7.14333704061713321e-7*A*g5*x8 - 
     6.28878290312510992e-8*g6*x10)*xbar4 + 
  eps13*(2.55551047231023315e-9*A5*g2 - 
     7.48454109323006102e-9*A2*g4 + 
     2.14869723911233424e-7*A4*g3*x2 - 
     8.87037184673700903e-8*A*g5*x2 + 
     8.1367411096167446e-7*A3*g4*x4 - 
     6.24554324051377381e-8*g6*x4 + 
     7.73534185148061632e-7*A2*g5*x6 + 
     2.53114332805174734e-7*A*g6*x8 + 
     2.60907174059342559e-8*g7*x10)*xbar4 + 
  eps12*(5.52620037914155561e-11*A6*g - 
     1.96395897468419557e-8*A3*g3 + 
     1.73105497543500998e-9*g5 + 
     1.41930118072774209e-7*A5*g2*x2 - 
     4.4751871911848506e-7*A2*g4*x2 + 
     7.4329679752095632e-7*A4*g3*x4 - 
     6.48579919839268283e-7*A*g5*x4 + 
     9.56849686940199225e-7*A3*g4*x6 - 
     1.72592309647809413e-7*g6*x6 + 
     4.6549037372399414e-7*A2*g5*x8 + 
     9.4234108977460504e-8*A*g6*x10 + 
     6.6997976279157566e-9*g7*x12)*xbar4 + 
  eps15*(-3.01110179246578381e-10*A6*g2 + 
     1.99854473307210245e-9*A3*g4 - 
     1.0075222178954846e-10*g6 - 
     3.91236879782746971e-8*A5*g3*x2 + 
     4.42468326545839399e-8*A2*g5*x2 - 
     2.26449722207185509e-7*A4*g4*x4 + 
     7.48610321580336637e-8*A*g6*x4 - 
     3.38794481457344831e-7*A3*g5*x6 + 
     2.34467193453680488e-8*g7*x6 - 
     1.91586076465687549e-7*A2*g6*x8 - 
     4.4705147415174641e-8*A*g7*x10 - 
     3.62790374951045814e-9*g8*x12)*xbar4 + 
  eps14*(-1.97753534590218582e-12*A7*g + 
     3.46651613447685113e-9*A4*g3 - 
     1.3675698718070872e-9*A*g5 - 
     1.92080361104674656e-8*A6*g2*x2 + 
     1.34714593349386061e-7*A3*g4*x2 - 
     7.0165116069938331e-9*g6*x2 - 
     1.51234778678998732e-7*A5*g3*x4 + 
     3.57677410764887609e-7*A2*g5*x4 - 
     2.9119323970204683e-7*A4*g4*x6 + 
     2.24757818721415644e-7*A*g6*x6 - 
     2.19654624683123427e-7*A3*g5*x8 + 
     3.71577620957842484e-8*g7*x8 - 
     7.60245440599503551e-8*A2*g6*x10 - 
     1.21363875909823901e-8*A*g7*x12 - 
     7.23898306636066601e-10*g8*x14)*xbar4 + 
  eps17*(3.48460743277465292e-11*A7*g2 - 
     4.51506468378503526e-10*A4*g4 + 
     9.93046484625324211e-11*A*g6 + 
     6.6025042810186813e-9*A6*g3*x2 - 
     1.62520631488663842e-8*A3*g5*x2 + 
     5.61230122018474251e-10*g7*x2 + 
     5.51380920101008308e-8*A5*g4*x4 - 
     4.88479275078761747e-8*A2*g6*x4 + 
     1.20320332856371923e-7*A4*g5*x6 - 
     3.5365653527819202e-8*A*g7*x6 + 
     1.03628614951869648e-7*A3*g6*x8 - 
     6.71263413921269682e-9*g8*x8 + 
     4.07776601703241782e-8*A2*g7*x10 + 
     7.34880420888892836e-9*A*g8*x12 + 
     4.91163816649064884e-10*g9*x14)*xbar4 + 
  eps16*(6.84233044511131468e-14*A8*g - 
     5.60464705059266925e-10*A5*g3 + 
     6.1113506912043867e-10*A2*g5 + 
     2.50582201503812155e-9*A7*g2*x2 - 
     3.39024845059116986e-8*A4*g4*x2 + 
     7.66141086125169516e-9*A*g6*x2 + 
     2.82533097805425257e-8*A6*g3*x4 - 
     1.44153074493338505e-7*A3*g5*x4 + 
     6.29165697711773721e-9*g7*x4 + 
     7.70955531949116842e-8*A5*g4*x6 - 
     1.5856345215569678e-7*A2*g6*x6 + 
     8.37319173204484218e-8*A4*g5*x8 - 
     5.99155536147365961e-8*A*g7*x8 + 
     4.37139891312553985e-8*A3*g6*x10 - 
     7.07392441584795305e-9*g8*x10 + 
     1.16805756794796047e-8*A2*g7*x12 + 
     1.53807088851897092e-9*A*g8*x14 + 
     7.90314013633620188e-11*g9*x16)*xbar4 + 
  eps19*(-3.97340865876564659e-12*A8*g2 + 
     9.08389634660042267e-11*A5*g4 - 
     5.40989729447639056e-11*A2*g6 - 
     1.05114495716806379e-9*A7*g3*x2 + 
     4.89773729086143515e-9*A4*g5*x2 - 
     7.24791876301819899e-10*A*g7*x2 - 
     1.21370267986698838e-8*A6*g4*x4 + 
     2.29597017376750524e-8*A3*g6*x4 - 
     6.7748721115604107e-10*g8*x4 - 
     3.67138156717417151e-8*A5*g5*x6 + 
     2.85584385486008741e-8*A2*g7*x6 - 
     4.48093489348219503e-8*A4*g6*x8 + 
     1.22153837054061484e-8*A*g8*x8 - 
     2.6272947304230525e-8*A3*g7*x10 + 
     1.62436680861277498e-9*g9*x10 - 
     7.84757421369128482e-9*A2*g8*x12 - 
     1.1484952449755475e-9*A*g9*x14 - 
     6.52079226899128072e-11*g10*x16)*xbar4 + 
  eps18*(-2.30220514713186019e-15*A9*g + 
     8.50336672523331952e-11*A6*g3 - 
     2.03099120170330866e-10*A3*g5 + 
     6.86599038065945835e-12*g7 - 
     3.17730510813967685e-10*A8*g2*x2 + 
     7.52334651318304606e-9*A5*g4*x2 - 
     4.58441975864061026e-9*A2*g6*x2 - 
     4.93856631341031329e-9*A7*g3*x4 + 
     4.73460373170155555e-8*A4*g5*x4 - 
     8.81541701496240287e-9*A*g7*x4 - 
     1.83568265106518087e-8*A6*g4*x6 + 
     8.0214964397589886e-8*A3*g6*x6 - 
     3.16831385872351314e-9*g8*x6 - 
     2.73264771648576643e-8*A5*g5*x8 + 
     5.15584868924249984e-8*A2*g7*x8 - 
     2.00422243527645685e-8*A4*g6*x10 + 
     1.36105580520898305e-8*A*g8*x10 - 
     7.92549659107905268e-9*A3*g7*x12 + 
     1.24112226442452554e-9*g9*x12 - 
     1.72024465137340275e-9*A2*g8*x14 - 
     1.92684278620064115e-10*A*g9*x16 - 
     8.69704747258045207e-12*g10*x18)*xbar4 + 
  eps21*(4.47608018566873029e-13*A9*g2 - 
     1.67753308125991472e-11*A6*g4 + 
     2.15143559796472255e-11*A3*g6 - 
     5.36097713439665228e-13*g8 + 
     1.59789748504864926e-10*A8*g3*x2 - 
     1.28169491309084248e-9*A5*g5*x2 + 
     5.05873112365848404e-10*A2*g7*x2 + 
     2.46793239696357667e-9*A7*g4*x4 - 
     8.69126604407042738e-9*A4*g6*x4 + 
     1.08592337487209441e-9*A*g8*x4 + 
     9.97215933211799948e-9*A6*g5*x6 - 
     1.63775632230861457e-8*A3*g7*x6 + 
     4.39638545658591092e-10*g9*x6 + 
     1.6446217893554322e-8*A5*g6*x8 - 
     1.17661894622675905e-8*A2*g8*x8 + 
     1.33981457517207347e-8*A4*g7*x10 - 
     3.46334251627866228e-9*A*g9*x10 + 
     5.87002262267861254e-9*A3*g8*x12 - 
     3.50481841251753294e-10*g10*x12 + 
     1.40564140813720233e-9*A2*g9*x14 + 
     1.72885003376200776e-10*A*g10*x16 + 
     8.52860757101693105e-12*g11*x18)*xbar4 + 
  eps20*(7.56595105695415785e-17*A10*g - 
     1.22932630659041053e-11*A7*g3 + 
     5.58459887241763578e-11*A4*g5 - 
     8.11455810014543089e-12*A*g7 + 
     3.9383320785984906e-11*A9*g2*x2 - 
     1.51976152664836327e-9*A6*g4*x2 + 
     1.98780657022334646e-9*A3*g6*x2 - 
     5.0284224652211995e-11*g8*x2 + 
     8.18366713361052766e-10*A8*g3*x4 - 
     1.34227304693417849e-8*A5*g5*x4 + 
     6.6399136914675485e-9*A2*g7*x4 + 
     4.01847928057574067e-9*A7*g4*x6 - 
     3.25458326731869081e-8*A4*g6*x6 + 
     5.42627614195641677e-9*A*g8*x6 + 
     7.91216320845347941e-9*A6*g5*x8 - 
     3.14137939839749592e-8*A3*g7*x8 + 
     1.16149233526855299e-9*g9*x8 + 
     7.7806358292877523e-9*A5*g6*x10 - 
     1.38304354148956577e-8*A2*g8*x10 + 
     4.24844294383596806e-9*A4*g7*x12 - 
     2.77563538429180564e-9*A*g9*x12 + 
     1.34573608785890679e-9*A3*g8*x14 - 
     2.05451606449403644e-10*g10*x14 + 
     2.45603481008104843e-10*A2*g9*x16 + 
     2.39299395598715992e-11*A*g10*x18 + 
     9.63092387870827136e-13*g11*x20)*xbar4 + 
  eps23*(-4.99202514118831333e-14*A10*g2 + 
     2.89962490735076355e-12*A7*g4 - 
     6.97186084528071566e-12*A4*g6 + 
     7.39113581154999613e-13*A*g8 - 
     2.3394917837884362e-11*A9*g3*x2 + 
     3.01433272680195764e-10*A6*g5*x2 - 
     2.52901008371964216e-10*A3*g7*x2 + 
     4.9975823717035003e-12*g9*x2 - 
     4.70635007764103411e-10*A8*g4*x4 + 
     2.81182652238779472e-9*A5*g6*x4 - 
     9.27102400382163909e-10*A2*g8*x4 - 
     2.46882746644613326e-9*A7*g5*x6 + 
     7.47170357614364372e-9*A4*g7*x6 - 
     8.42342156242855593e-10*A*g9*x6 - 
     5.31658207824290054e-9*A6*g6*x8 + 
     7.96948615558779495e-9*A3*g8*x8 - 
     2.00535355872142721e-10*g10*x8 - 
     5.74925362613453206e-9*A5*g7*x10 + 
     3.87667862850608752e-9*A2*g9*x10 - 
     3.44992473074412105e-9*A4*g8*x12 + 
     8.569346015302056e-10*A*g10*x12 - 
     1.19748784968841458e-9*A3*g9*x14 + 
     6.95772409909226155e-11*g11*x14 - 
     2.38602512157003406e-10*A2*g10*x16 - 
     2.52826017059561289e-11*A*g11*x18 - 
     1.10236531866119468e-12*g12*x20)*xbar4 + 
  eps22*(-2.43710422261727909e-18*A11*g + 
     1.71109183419778529e-12*A8*g3 - 
     1.34309072457408887e-11*A5*g5 + 
     5.2173544345517194e-12*A2*g7 - 
     4.7920869812117813e-12*A10*g2*x2 + 
     2.85329265230758798e-10*A7*g4*x2 - 
     6.97857430562307631e-10*A4*g6*x2 + 
     7.49694255924035744e-11*A*g8*x2 - 
     1.29794915911680679e-10*A9*g3*x4 + 
     3.40176751053615467e-9*A6*g5*x4 - 
     3.56524460909925476e-9*A3*g7*x4 + 
     7.84071353306302568e-11*g9*x4 - 
     8.21445917536130217e-10*A8*g4*x6 + 
     1.12426357550003378e-8*A5*g6*x6 - 
     4.93283496356209241e-9*A2*g8*x6 - 
     2.08160234188537877e-9*A7*g5*x8 + 
     1.51837246414786265e-8*A4*g7*x8 - 
     2.35241679748374184e-9*A*g9*x8 - 
     2.65426623474241136e-9*A6*g6*x10 + 
     9.86143500745746335e-9*A3*g8*x10 - 
     3.47704012872899376e-10*g10*x10 - 
     1.91288185358486004e-9*A5*g7*x12 + 
     3.25348485105233778e-9*A2*g9*x12 - 
     8.26008166150946402e-10*A4*g8*x14 + 
     5.23734714713970356e-10*A*g10*x14 - 
     2.17662681277754724e-10*A3*g9*x16 + 
     3.25604627396838786e-11*g11*x16 - 
     3.42430735395904115e-11*A2*g10*x18 - 
     2.95184625537922171e-12*A*g11*x20 - 
     1.07193479659543963e-13*g12*x22)*xbar4 + 
  eps25*(5.52110506767784823e-15*A11*g2 - 
     4.75457501278592475e-13*A8*g4 + 
     1.95091086985767411e-12*A5*g6 - 
     5.4799904221049527e-13*A2*g8 + 
     3.32019238817893755e-12*A10*g3*x2 - 
     6.51730724398874192e-11*A7*g5*x2 + 
     1.01363516265109903e-10*A4*g7*x2 - 
     8.44789910534162239e-12*A*g9*x2 + 
     8.51083543466993974e-11*A9*g4*x4 - 
     8.06323901456713728e-10*A6*g6*x4 + 
     5.59802124945716162e-10*A3*g8*x4 - 
     9.76067472405711475e-12*g10*x4 + 
     5.66519419429771184e-10*A8*g5*x6 - 
     2.8819770278242875e-9*A5*g7*x6 + 
     8.51033871024505535e-10*A2*g9*x6 + 
     1.55194749123254554e-9*A7*g6*x8 - 
     4.25684634896380492e-9*A4*g8*x8 + 
     4.47161048996184315e-10*A*g10*x8 + 
     2.15624685611586417e-9*A6*g7*x10 - 
     3.0292495877704562e-9*A3*g9*x10 + 
     7.26885557001226871e-11*g11*x10 + 
     1.69504305032585424e-9*A5*g8*x12 - 
     1.09320524328573703e-9*A2*g10*x12 + 
     7.97072138471286562e-10*A4*g9*x14 - 
     1.91910963351846343e-10*A*g11*x14 + 
     2.28095958403189066e-10*A3*g10*x16 - 
     1.29653228354651865e-11*g12*x16 + 
     3.88462248089520305e-11*A2*g11*x18 + 
     3.61325068184705851e-12*A*g12*x20 + 
     1.41129299633557724e-13*g13*x22)*xbar4 + 
  eps24*(7.71585736870360985e-20*A12*g - 
     2.30992258376006814e-13*A9*g3 + 
     2.92102366881800346e-12*A6*g5 - 
     2.41669954412293445e-12*A3*g7 + 
     4.72216204539068631e-14*g9 + 
     5.74184634945686335e-13*A11*g2*x2 - 
     5.05105154346589262e-11*A8*g4*x2 + 
     2.10380593488870381e-10*A5*g6*x2 - 
     5.97933596683359805e-11*A2*g8*x2 + 
     1.98448558495321466e-11*A10*g3*x4 - 
     7.88832679162696204e-10*A7*g5*x4 + 
     1.52819851860648456e-9*A4*g7*x4 - 
     1.41460420089467831e-10*A*g9*x4 + 
     1.58609533764471402e-10*A9*g4*x6 - 
     3.43038983424224915e-9*A6*g6*x6 + 
     3.16143488249608422e-9*A3*g8*x6 - 
     6.36135955205512617e-11*g10*x6 + 
     5.0613788167530953e-10*A8*g5*x8 - 
     6.18873950256648937e-9*A5*g7*x8 + 
     2.5062720440597051e-9*A2*g9*x8 + 
     8.15831547687990564e-10*A7*g6*x10 - 
     5.53396691054777854e-9*A4*g8*x10 + 
     8.13144274490680289e-10*A*g10*x10 + 
     7.51495225003727191e-10*A6*g7*x12 - 
     2.65804849164409833e-9*A3*g9*x12 + 
     9.04010499952531028e-11*g11*x12 + 
     4.23273801532746854e-10*A5*g8*x14 - 
     6.95727565670343238e-10*A2*g10*x14 + 
     1.50552227564369774e-10*A4*g9*x16 - 
     9.31966125875092865e-11*A*g11*x16 + 
     3.39107891271974624e-11*A3*g10*x18 - 
     4.98855443293551953e-12*g12*x18 + 
     4.68573921494252176e-12*A2*g11*x20 + 
     3.62148289824228147e-13*A*g12*x22 + 
     1.1980881282823611e-14*g13*x24)*xbar4 + 
  eps27*(-6.06340569115627967e-16*A12*g2 + 
     7.46743581432114588e-14*A9*g4 - 
     4.88321923065870447e-13*A6*g6 + 
     2.89829268628320837e-13*A3*g8 - 
     4.63616021004233398e-15*g10 - 
     4.58982875494843554e-13*A11*g3*x2 + 
     1.31620855929153655e-11*A8*g5*x2 - 
     3.45910592121808914e-11*A5*g7*x2 + 
     7.57962719819450509e-12*A2*g9*x2 - 
     1.47174853920458438e-11*A10*g4*x4 + 
     2.10008562713466686e-10*A7*g6*x4 - 
     2.67994693241196884e-10*A4*g8*x4 + 
     1.95721481255834084e-11*A*g10*x4 - 
     1.21996854201187947e-10*A9*g5*x6 + 
     9.75929847124729717e-10*A6*g7*x6 - 
     6.02712116556836984e-10*A3*g9*x6 + 
     9.66978501184038613e-12*g11*x6 - 
     4.16404979550286193e-10*A8*g6*x8 + 
     1.90748492730919674e-9*A5*g8*x8 - 
     5.21939581027319205e-10*A2*g10*x8 - 
     7.25206097999541375e-10*A7*g7*x10 + 
     1.85458303963180277e-9*A4*g9*x10 - 
     1.84921744999698115e-10*A*g11*x10 - 
     7.23649740189886316e-10*A6*g8*x12 + 
     9.68181835665220969e-10*A3*g10*x12 - 
     2.23973823536211523e-11*g12*x12 - 
     4.41297002752502703e-10*A5*g9*x14 + 
     2.74863621293813848e-10*A2*g11*x14 - 
     1.69617347035784482e-10*A4*g10*x16 + 
     3.98251798469732974e-11*A*g12*x16 - 
     4.11815112392836099e-11*A3*g11*x18 + 
     2.29880733132433384e-12*g13*x18 - 
     6.11698836469376208e-12*A2*g12*x20 - 
     5.06807395871830976e-13*A*g13*x22 - 
     1.79255756224209755e-14*g14*x24)*xbar4 + 
  eps26*(-2.40642944243818635e-21*A13*g + 
     3.04076267712359871e-14*A10*g3 - 
     5.87195948302404653e-13*A7*g5 + 
     9.02024049542844894e-13*A4*g7 - 
     7.44236616778245869e-14*A*g9 - 
     6.79097450394172245e-14*A12*g2*x2 + 
     8.51963574281276708e-12*A9*g4*x2 - 
     5.64546785590600388e-11*A6*g6*x2 + 
     3.38607923476519669e-11*A3*g8*x2 - 
     5.46405541321999628e-13*g10*x2 - 
     2.94120416719332449e-12*A11*g3*x4 + 
     1.7014263234465762e-10*A8*g5*x4 - 
     5.55586418016715407e-10*A5*g7*x4 + 
     1.34977648095717031e-10*A2*g9*x4 - 
     2.9181367456125663e-11*A10*g4*x6 + 
     9.47639077544887723e-10*A7*g6*x6 - 
     1.60171638895294337e-9*A4*g8*x6 + 
     1.34775506533895858e-10*A*g10*x6 - 
     1.15182756156558058e-10*A9*g5*x8 + 
     2.20916412108007294e-9*A6*g7*x8 - 
     1.86753303861358136e-9*A3*g9*x8 + 
     3.52966346576477379e-11*g11*x8 - 
     2.30014920617832728e-10*A8*g6*x10 + 
     2.60032285423373586e-9*A5*g8*x10 - 
     9.93669928603769451e-10*A2*g10*x10 - 
     2.64323489013737578e-10*A7*g7*x12 + 
     1.69887680881412942e-9*A4*g9*x12 - 
     2.39763019711547791e-10*A*g11*x12 - 
     1.88221747596454675e-10*A6*g8*x14 + 
     6.40830830030619142e-10*A3*g10*x14 - 
     2.11838087406217002e-11*g12*x14 - 
     8.65239787552783906e-11*A5*g9*x16 + 
     1.38377453950046014e-10*A2*g11*x16 - 
     2.60995135254219062e-11*A4*g10*x18 + 
     1.58412457476077222e-11*A*g12*x18 - 
     5.12826665801042948e-12*A3*g11*x20 + 
     7.43887970125067621e-13*g13*x20 - 
     6.31542723119822078e-13*A2*g12*x22 - 
     4.42328923105620097e-14*A*g13*x24 - 
     1.34380744386943457e-15*g14*x26)*xbar4 - 
  0.0000154320987654320988*eps2*g2*xbar6 + 
  3.56125356125356125e-7*eps5*g3*xbar6 + 
  eps4*(1.90396023729357063e-6*A*g2 + 
     7.71604938271604938e-6*g3*x2)*xbar6 + 
  eps7*(-1.06760523427190094e-7*A*g3 - 
     5.83649889205444761e-7*g4*x2)*xbar6 + 
  eps6*(-1.58222876476844731e-7*A2*g2 - 
     3.0990100434544879e-6*A*g3*x2 - 
     1.45170544476100032e-6*g4*x4)*xbar6 + 
  eps9*(2.10474956623416007e-8*A2*g3 + 
     3.52066889376257568e-7*A*g4*x2 + 
     2.15683591284989252e-7*g5*x4)*xbar6 + 
  eps8*(1.0639753805538638e-8*A3*g2 - 
     1.44647796358943781e-8*g4 + 
     7.89019059521705024e-7*A2*g3*x2 + 
     9.93278626380478232e-7*A*g4*x4 + 
     2.19830466744046991e-7*g5*x6)*xbar6 + 
  eps11*(-3.48009271425128996e-9*A3*g3 + 
     7.74456172615070677e-10*g5 - 
     1.24759056081950737e-7*A2*g4*x2 - 
     1.93124743183608916e-7*A*g5*x4 - 
     5.26262283781649553e-8*g6*x6)*xbar6 + 
  eps10*(-6.21784885258793341e-10*A4*g2 + 
     7.35917308458240036e-9*A*g4 - 
     1.61082849737015107e-7*A3*g3*x2 + 
     4.25042008023580282e-8*g5*x2 - 
     3.97181909847740069e-7*A2*g4*x4 - 
     2.15693489113968417e-7*A*g5*x6 - 
     3.05361793587726322e-8*g6*x8)*xbar6 + 
  eps13*(5.22929181665348026e-10*A4*g3 - 
     5.49761548927799316e-10*A*g5 + 
     3.37795673591345898e-8*A3*g4*x2 - 
     3.32362369023656752e-9*g6*x2 + 
     9.70864128827426103e-8*A2*g5*x4 + 
     6.29082935052959515e-8*A*g6*x6 + 
     1.05359214957493409e-8*g7*x8)*xbar6 + 
  eps12*(3.28023733515722384e-11*A5*g2 - 
     2.2483490443839068e-9*A2*g4 + 
     2.87554439944054822e-8*A4*g3*x2 - 
     3.41643318587639607e-8*A*g5*x2 + 
     1.20413081223750724e-7*A3*g4*x4 - 
     2.54382194661358481e-8*g6*x4 + 
     1.18403247344882478e-7*A2*g5*x6 + 
     3.92485363936068314e-8*A*g6*x8 + 
     4.05810532585570662e-9*g7*x10)*xbar6 + 
  eps15*(-7.38610165433134699e-11*A5*g3 + 
     2.23185618064230175e-10*A2*g5 - 
     7.72550467360774725e-9*A4*g4*x2 + 
     3.33675225731002428e-9*A*g6*x2 - 
     3.60024022499056884e-8*A3*g5*x4 + 
     2.89391686340197044e-9*g7*x4 - 
     4.11034234008140627e-8*A2*g6*x6 - 
     1.58061594311664227e-8*A*g7*x8 - 
     1.88044966020543737e-9*g8*x10)*xbar6 + 
  eps14*(-1.59924972891624396e-12*A6*g2 + 
     5.34559467656326695e-10*A3*g4 - 
     4.89531412255654985e-11*g6 - 
     4.68743656687813986e-9*A5*g3*x2 + 
     1.55203340852120435e-8*A2*g5*x2 - 
     3.05848967636635251e-8*A4*g4*x4 + 
     2.80191583068273077e-8*A*g6*x4 - 
     4.77391188802852923e-8*A3*g5*x6 + 
     9.0249644584421326e-9*g7*x6 - 
     2.7500470429085428e-8*A2*g6*x8 - 
     6.46467617732357999e-9*A*g7*x10 - 
     5.25206836466407194e-10*g8*x12)*xbar6 + 
  eps17*(9.97455222947976728e-12*A6*g3 - 
     6.79725936335510667e-11*A3*g5 + 
     3.53973893285757087e-12*g7 + 
     1.57106382527547975e-9*A5*g4*x2 - 
     1.84906281043290629e-9*A2*g6*x2 + 
     1.0959810274248971e-8*A4*g5*x4 - 
     3.77750956813660573e-9*A*g7*x4 + 
     1.93914172243944712e-8*A3*g6*x6 - 
     1.39852236310538808e-9*g8*x6 + 
     1.27378874003962749e-8*A2*g7*x8 + 
     3.39967157316226349e-9*A*g8*x10 + 
     3.11454821672654227e-10*g9*x12)*xbar6 + 
  eps16*(7.32043787188737753e-14*A7*g2 - 
     1.08932623361419343e-10*A4*g4 + 
     4.43882953795228996e-11*A*g6 + 
     7.1553877265847084e-10*A6*g3*x2 - 
     5.23629960443907472e-9*A3*g5*x2 + 
     2.84608830720512483e-10*g7*x2 + 
     6.85430762519816909e-9*A5*g4*x4 - 
     1.69359418456327738e-8*A2*g6*x4 + 
     1.57308771746978335e-8*A4*g5*x6 - 
     1.26738239683828291e-8*A*g7*x6 + 
     1.38726146998630169e-8*A3*g6*x8 - 
     2.44574523622132431e-9*g8*x8 + 
     5.52081375700205184e-9*A2*g7*x10 + 
     9.99298373572599506e-10*A*g8*x12 + 
     6.67917519196695508e-11*g9*x14)*xbar6 + 
  eps19*(-1.30114590146037234e-12*A7*g3 + 
     1.72511713934239417e-11*A4*g5 - 
     3.90436685140620179e-12*A*g7 - 
     2.92867814057581221e-10*A6*g4*x2 + 
     7.46902977877224456e-10*A3*g6*x2 - 
     2.67522864508407854e-11*g8*x2 - 
     2.89699505443225961e-9*A5*g5*x4 + 
     2.66562938868512264e-9*A2*g7*x4 - 
     7.37795565467524207e-9*A4*g6*x6 + 
     2.25247153971908075e-9*A*g8*x6 - 
     7.30651817416318482e-9*A3*g7*x8 + 
     4.91176292870876797e-10*g9*x8 - 
     3.26224960924321828e-9*A2*g8*x10 - 
     6.59449314458554338e-10*A*g9*x12 - 
     4.89514760970749125e-11*g10*x14)*xbar6 + 
  eps18*(-3.18177848990088646e-15*A8*g2 + 
     1.99695443999379049e-11*A5*g4 - 
     2.23943125358944015e-11*A2*g6 - 
     1.03933552034436454e-10*A7*g3*x2 + 
     1.45959832999336206e-9*A4*g5*x2 - 
     3.42631031918890525e-10*A*g7*x2 - 
     1.39812800630481225e-9*A6*g4*x4 + 
     7.42096889844293084e-9*A3*g6*x4 - 
     3.37099552457525213e-10*g8*x4 - 
     4.48155653124553849e-9*A5*g5*x6 + 
     9.58666614025997167e-9*A2*g7*x6 - 
     5.62734416286699799e-9*A4*g6*x8 + 
     4.18363357640745376e-9*A*g8*x8 - 
     3.34880212849529458e-9*A3*g7*x10 + 
     5.62255597605531686e-10*g9*x10 - 
     1.00758346454303337e-9*A2*g8*x12 - 
     1.478403576160079e-10*A*g9*x14 - 
     8.38903736074731077e-12*g10*x16)*xbar6 + 
  eps21*(1.65107570494289514e-13*A8*g3 - 
     3.85243170234057994e-12*A5*g5 + 
     2.35361375548192462e-12*A2*g7 + 
     5.10417794581330247e-11*A7*g4*x2 - 
     2.45495411183393324e-10*A4*g6*x2 + 
     3.75511182588112891e-11*A*g8*x2 + 
     6.87936705237642027e-10*A6*g5*x4 - 
     1.34714877461804848e-9*A3*g7*x4 + 
     4.11758068629525797e-11*g9*x4 + 
     2.400949695111526e-9*A5*g6*x6 - 
     1.93419604503727388e-9*A2*g8*x6 + 
     3.33918824376270404e-9*A4*g7*x8 - 
     9.42270610564786763e-10*A*g9*x8 + 
     2.20558587287283118e-9*A3*g8*x10 - 
     1.41026346318580081e-10*g10*x10 + 
     7.34671001558905886e-10*A2*g9*x12 + 
     1.18846098758935012e-10*A*g10*x14 + 
     7.4012085886463764e-12*g11*x16)*xbar6 + 
  eps20*(1.32423923182168128e-16*A9*g2 - 
     3.38762545168358761e-12*A6*g4 + 
     8.2936742090468515e-12*A3*g6 - 
     2.88553271599458446e-13*g8 + 
     1.45206721816612312e-11*A8*g3*x2 - 
     3.55365267771350475e-10*A5*g5*x2 + 
     2.24067642028217925e-10*A2*g7*x2 + 
     2.64931375976082846e-10*A7*g4*x4 - 
     2.63256077540054192e-9*A4*g6*x4 + 
     5.08380778036583002e-10*A*g8*x4 + 
     1.14232293931335993e-9*A6*g5*x6 - 
     5.17535342835764208e-9*A3*g7*x6 + 
     2.12052573958312186e-10*g9*x6 + 
     1.94686955319541028e-9*A5*g6*x8 - 
     3.80593235862788058e-9*A2*g8*x8 + 
     1.61506335347690598e-9*A4*g7*x10 - 
     1.13519934804077239e-9*A*g9*x10 + 
     7.1467043552215311e-10*A3*g8*x12 - 
     1.15698350133799093e-10*g10*x12 + 
     1.719691436452393e-10*A2*g9*x14 + 
     2.11817828858919301e-11*A*g10*x16 + 
     1.0439296901669795e-12*g11*x18)*xbar6 + 
  eps23*(-2.04862878355181306e-14*A9*g3 + 
     7.81972174797918537e-13*A6*g5 - 
     1.02619259166044427e-12*A3*g7 + 
     2.62433518896336934e-14*g9 - 
     8.43060024092694187e-12*A8*g4*x2 + 
     6.95862769500813447e-11*A5*g6*x2 - 
     2.83043426411699199e-11*A2*g8*x2 - 
     1.50105719428983393e-10*A7*g5*x4 + 
     5.45631016826002967e-10*A4*g7*x4 - 
     7.04209555461881305e-11*A*g9*x4 - 
     6.92804131934363177e-10*A6*g6*x6 + 
     1.17532183940399869e-9*A3*g8*x6 - 
     3.2607052539653876e-11*g10*x6 - 
     1.29157220680419803e-9*A5*g7*x8 + 
     9.54295239973687871e-10*A2*g9*x8 - 
     1.17766893656649956e-9*A4*g8*x10 + 
     3.14180951036205697e-10*A*g10*x10 - 
     5.72342109737974456e-10*A3*g9*x12 + 
     3.52378082126753302e-11*g11*x12 - 
     1.50826983016266947e-10*A2*g10*x14 - 
     2.0272522360825874e-11*A*g11*x16 - 
     1.08615017352219442e-12*g12*x18)*xbar6 + 
  eps22*(-5.31170301889157885e-18*A10*g2 + 
     5.41512008345912225e-13*A7*g4 - 
     2.51484843977932421e-12*A4*g6 + 
     3.74997952559516213e-13*A*g8 - 
     1.96622519209470769e-12*A9*g3*x2 + 
     7.81432830846281016e-11*A6*g5*x2 - 
     1.0541243620224235e-10*A3*g7*x2 + 
     2.75343063440850494e-12*g9*x2 - 
     4.73066561901215884e-11*A8*g4*x4 + 
     8.01663669414465443e-10*A5*g6*x4 - 
     4.10061241924541413e-10*A2*g8*x4 - 
     2.66530256112802594e-10*A7*g5*x6 + 
     2.23182456344329143e-9*A4*g7*x6 - 
     3.84966796590767183e-10*A*g9*x6 - 
     5.95626630491287062e-10*A6*g6*x8 + 
     2.44421723666841458e-9*A3*g8*x8 - 
     9.34592147729657581e-11*g10*x8 - 
     6.57899358910793091e-10*A5*g7*x10 + 
     1.20777680989039448e-9*A2*g9*x10 - 
     3.99711629253997661e-10*A4*g8*x12 + 
     2.69443230465710687e-10*A*g10*x12 - 
     1.39709228180795027e-10*A3*g9*x14 + 
     2.19843031752725675e-11*g11*x14 - 
     2.79291327736950798e-11*A2*g10*x16 - 
     2.96151288108938101e-12*A*g11*x18 - 
     1.2897624149994603e-13*g12*x20)*xbar6 + 
  eps25*(2.49529026185645818e-15*A10*g3 - 
     1.47364999575620113e-13*A7*g5 + 
     3.61793330174044282e-13*A4*g7 - 
     3.9275827608463396e-14*A*g9 + 
     1.33267432811445249e-12*A9*g4*x2 - 
     1.76226656347218737e-11*A6*g6*x2 + 
     1.51981285144972782e-11*A3*g8*x2 - 
     3.09047867049178855e-13*g10*x2 + 
     3.05759645727357997e-11*A8*g5*x4 - 
     1.88074902764808623e-10*A5*g7*x4 + 
     6.38987124625316395e-11*A2*g9*x4 + 
     1.81594794134116284e-10*A7*g6*x6 - 
     5.66388647497927962e-10*A4*g8*x6 + 
     6.58443356039861601e-11*A*g10*x6 + 
     4.38886401428118561e-10*A6*g7*x8 - 
     6.78019204359987597e-10*A3*g9*x8 + 
     1.75910452362917948e-11*g11*x8 + 
     5.28081354282393227e-10*A5*g8*x10 - 
     3.66812184128119593e-10*A2*g10*x10 + 
     3.4980339641893081e-10*A4*g9*x12 - 
     8.94452198882115659e-11*A*g11*x12 + 
     1.33078990927212951e-10*A3*g10*x14 - 
     7.95340803513130482e-12*g12*x14 + 
     2.88781928840622656e-11*A2*g11*x16 + 
     3.31366831051057885e-12*A*g12*x18 + 
     1.55671198912292546e-13*g13*x20)*xbar6 + 
  eps24*(2.06387813484462373e-19*A11*g2 - 
     8.25816672282089385e-14*A8*g4 + 
     6.61224936974016378e-13*A5*g6 - 
     2.6296608110606801e-13*A2*g8 + 
     2.59487556558260317e-13*A10*g3*x2 - 
     1.58652084976253468e-11*A7*g5*x2 + 
     3.99067733898254196e-11*A4*g7*x2 - 
     4.41486037628790473e-12*A*g9*x2 + 
     8.04335423698123335e-12*A9*g4*x4 - 
     2.17197514727606655e-10*A6*g6*x4 + 
     2.34756708639459969e-10*A3*g8*x4 - 
     5.32762009285759642e-12*g10*x4 + 
     5.78511754053948431e-11*A8*g5*x6 - 
     8.16589511753311956e-10*A5*g7*x6 + 
     3.69778863261878567e-10*A2*g9*x6 + 
     1.65106656495643349e-10*A7*g6*x8 - 
     1.24201778524548735e-9*A4*g8*x8 + 
     1.98568405951987234e-10*A*g10*x8 + 
     2.34986277079273996e-10*A6*g7*x10 - 
     8.99890172295623428e-10*A3*g9*x10 + 
     3.27229290168583213e-11*g11*x10 + 
     1.87460264805506997e-10*A5*g8*x12 - 
     3.28389964017235726e-10*A2*g10*x12 + 
     8.89367704930636301e-11*A4*g9*x14 - 
     5.80300246028472628e-11*A*g11*x14 + 
     2.55778143867196837e-11*A3*g10*x16 - 
     3.93390423737093991e-12*g12*x16 + 
     4.36578811240031125e-12*A2*g11*x18 + 
     4.06167949307034346e-13*A*g12*x20 + 
     1.58438482461786504e-14*g13*x22)*xbar6 + 
  eps26*(-7.80001477184615311e-21*A12*g2 + 
     1.21218589749466703e-14*A9*g4 - 
     1.56082243655583651e-13*A6*g6 + 
     1.31936556118782478e-13*A3*g8 - 
     2.63987875137194496e-15*g10 - 
     3.3516756268987177e-14*A11*g3*x2 + 
     3.02004856028002491e-12*A8*g5*x2 - 
     1.29052862865870365e-11*A5*g7*x2 + 
     3.76830831610177068e-12*A2*g9*x2 - 
     1.31247557560719898e-12*A10*g4*x4 + 
     5.36221124147047872e-11*A7*g6*x4 - 
     1.06880151897524582e-10*A4*g8*x4 + 
     1.01863661046571699e-11*A*g10*x4 - 
     1.18212585759000783e-11*A9*g5*x6 + 
     2.63099638685890609e-10*A6*g7*x6 - 
     2.49708795471378992e-10*A3*g9*x6 + 
     5.17672182404929477e-12*g11*x6 - 
     4.2191391915218771e-11*A8*g6*x8 + 
     5.30978436314001257e-10*A5*g8*x8 - 
     2.2146248749457354e-10*A2*g10*x8 - 
     7.54750432524908277e-11*A7*g7*x10 + 
     5.26762452420300241e-10*A4*g9*x10 - 
     7.96839157178548693e-11*A*g11*x10 - 
     7.65929020563096896e-11*A6*g8*x12 + 
     2.78576666230141471e-10*A3*g10*x12 - 
     9.74781383690081166e-12*g12*x12 - 
     4.72093545364361295e-11*A5*g9*x14 + 
     7.97360971649011299e-11*A2*g11*x14 - 
     1.82645664810146611e-11*A4*g10*x16 + 
     1.1609063517587488e-11*A*g12*x16 - 
     4.45057950605498793e-12*A3*g11*x18 + 
     6.71718766379246008e-13*g13*x18 - 
     6.62060944673683483e-13*A2*g12*x20 - 
     5.48463949384646871e-14*A*g13*x22 - 
     1.93723554370435129e-15*g14*x24)*xbar6 + 
  5.93542260208926876e-8*eps4*g3*xbar8 - 
  3.12288574815807931e-9*eps7*g4*xbar8 + 
  eps6*(-1.14340392118169896e-8*A*g3 - 
     9.02678854067742957e-8*g4*x2)*xbar8 + 
  eps9*(1.26121885620031857e-9*A*g4 + 
     1.00859349622512295e-8*g5*x2)*xbar8 + 
  eps8*(1.32727772394750297e-9*A2*g3 + 
     4.65033697944917988e-8*A*g4*x2 + 
     2.99054295797669073e-8*g5*x4)*xbar8 + 
  eps11*(-3.15709843216944468e-10*A2*g4 - 
     7.21099301568180965e-9*A*g5*x2 - 
     5.69746824484251863e-9*g6*x4)*xbar8 + 
  eps10*(-1.18235613578975095e-10*A3*g3 + 
     2.04522364126337295e-10*g5 - 
     1.4372001684607648e-8*A2*g4*x2 - 
     2.38545902650207871e-8*A*g5*x4 - 
     6.6442647298050802e-9*g6*x6)*xbar8 + 
  eps13*(6.34254881618462429e-11*A3*g4 - 
     1.4977795563804726e-11*g6 + 
     2.95036268409924151e-9*A2*g5*x2 + 
     5.72733871097688746e-9*A*g6*x4 + 
     1.89780374932858316e-9*g7*x6)*xbar8 + 
  eps12*(8.85933436332280376e-12*A4*g3 - 
     1.2695043367275619e-10*A*g5 + 
     3.44553148081436095e-9*A3*g4*x2 - 
     9.66117808074637814e-10*g6*x2 + 
     1.08393242236143663e-8*A2*g5*x4 + 
     7.24181767567549532e-9*A*g6*x6 + 
     1.22738677265426237e-9*g7*x8)*xbar8 + 
  eps15*(-1.1209244129052603e-11*A4*g4 + 
     1.23354796462055584e-11*A*g6 - 
     9.05322252904213583e-10*A3*g5*x2 + 
     9.34529456546429641e-11*g7*x2 - 
     3.18804749658072552e-9*A2*g6*x4 - 
     2.46989894878460521e-9*A*g7*x6 - 
     4.84553260391626981e-10*g8*x8)*xbar8 + 
  eps14*(-5.85591473164617337e-13*A5*g3 + 
     4.58152437519766974e-11*A2*g5 - 
     7.06061940978074562e-10*A4*g4*x2 + 
     8.8437067488213914e-10*A*g6*x2 - 
     3.6718459581734819e-9*A3*g5*x4 + 
     8.14572670487090063e-10*g7*x4 - 
     4.35865819040676537e-9*A2*g6*x6 - 
     1.70511399881374369e-9*A*g7*x8 - 
     2.04267683542374506e-10*g8*x10)*xbar8 + 
  eps17*(1.81850832862627129e-12*A5*g4 - 
     5.7018133606605742e-12*A2*g6 + 
     2.31363157692796144e-10*A4*g5*x2 - 
     1.04268313475235866e-10*A*g7*x2 + 
     1.29559671265166405e-9*A3*g6*x4 - 
     1.08608812804810835e-10*g8*x4 + 
     1.74321237740579218e-9*A2*g7*x6 + 
     7.76515634579396129e-10*A*g8*x8 + 
     1.05455124124405657e-10*g9*x10)*xbar8 + 
  eps16*(3.51441987362562031e-14*A6*g3 - 
     1.25669585862967901e-11*A3*g5 + 
     1.19873609386538047e-12*g7 + 
     1.29917477297039227e-10*A5*g4*x2 - 
     4.50505663684441363e-10*A2*g6*x2 + 
     1.0294836459233229e-9*A4*g5*x4 - 
     9.85762364733873057e-10*A*g7*x4 + 
     1.90892686734913978e-9*A3*g6*x6 - 
     3.76480107979462358e-10*g8*x6 + 
     1.28194605951425965e-9*A2*g7*x8 + 
     3.45797358676807567e-10*A*g8*x10 + 
     3.18111454415424726e-11*g9*x12)*xbar8 + 
  eps19*(-2.77181792125363476e-13*A6*g4 + 
     1.94851026920691567e-12*A3*g6 - 
     1.04933332657610013e-13*g8 - 
     5.1992259514176436e-11*A5*g5*x2 + 
     6.35571518081156783e-11*A2*g7*x2 - 
     4.28732342024609978e-10*A4*g6*x4 + 
     1.53545689985903239e-10*A*g8*x4 - 
     8.82875940509388448e-10*A3*g7*x6 + 
     6.61143800669246729e-11*g9*x6 - 
     6.65258660548452332e-10*A2*g8*x8 - 
     2.01099007966251153e-10*A*g9*x10 - 
     2.06386033152073184e-11*g10*x12)*xbar8 + 
  eps18*(-1.95213901631847725e-15*A7*g3 + 
     2.9024042061210064e-12*A4*g5 - 
     1.22464345499091446e-12*A*g7 - 
     2.20948357179324358e-11*A6*g4*x2 + 
     1.68407222784752482e-10*A3*g6*x2 - 
     9.52673617116155421e-12*g8*x2 - 
     2.52285174010719033e-10*A5*g5*x4 + 
     6.48893132761825578e-10*A2*g7*x4 - 
     6.78403369061433162e-10*A4*g6*x6 + 
     5.68290125969521456e-10*A*g8*x6 - 
     6.90033763945661382e-10*A3*g7*x8 + 
     1.26310595431481278e-10*g9*x8 - 
     3.12443265284225916e-10*A2*g8*x10 - 
     6.3597958994265421e-11*A*g9*x12 - 
     4.73255306775791468e-12*g10*x14)*xbar8 + 
  eps21*(4.02698278092183264e-14*A7*g4 - 
     5.48456153392839097e-13*A4*g6 + 
     1.27878322517070527e-13*A*g8 + 
     1.06134424697227182e-11*A6*g5*x2 - 
     2.8004805743707356e-11*A3*g7*x2 + 
     1.03826550082836709e-12*g9*x2 + 
     1.22375351923488345e-10*A5*g6*x4 - 
     1.16626518182467646e-10*A2*g8*x4 + 
     3.58798538233177846e-10*A4*g7*x6 - 
     1.13425693456240496e-10*A*g9*x6 + 
     4.04078829257981979e-10*A3*g8*x8 - 
     2.81051427782846787e-11*g10*x8 + 
     2.02913314961737926e-10*A2*g9*x10 + 
     4.56865113489605372e-11*A*g10*x12 + 
     3.74535590061231334e-12*g11*x14)*xbar8 + 
  eps20*(1.01735256778363072e-16*A8*g3 - 
     5.94748498729256522e-13*A5*g5 + 
     6.8752666515941573e-13*A2*g7 + 
     3.53810789377630122e-12*A7*g4*x2 - 
     5.15152807107229022e-11*A4*g6*x2 + 
     1.25362167426384833e-11*A*g8*x2 + 
     5.5847059374569765e-11*A6*g5*x4 - 
     3.07470180635305607e-10*A3*g7*x4 + 
     1.44903732082026135e-11*g9*x4 + 
     2.07246456352654245e-10*A5*g6*x6 - 
     4.59578840273247801e-10*A2*g8*x6 + 
     2.97340805913634912e-10*A4*g7*x8 - 
     2.2892955313025694e-10*A*g9*x8 + 
     1.99809393100334618e-10*A3*g8*x10 - 
     3.47015927264758897e-11*g10*x10 + 
     6.71900005565290136e-11*A2*g9*x12 + 
     1.09198252656076105e-11*A*g10*x14 + 
     6.80982990694437919e-13*g11*x16)*xbar8 + 
  eps23*(-5.6315187454878941e-15*A8*g4 + 
     1.34545805184805001e-13*A5*g6 - 
     8.4419630758147657e-14*A2*g8 - 
     2.01037270814629847e-12*A7*g5*x2 + 
     9.97117770896026235e-12*A4*g7*x2 - 
     1.57395528411072087e-12*A*g9*x2 - 
     3.1206130449635691e-11*A6*g6*x4 + 
     6.31142612191228433e-11*A3*g8*x4 - 
     1.99325127719395794e-12*g10*x4 - 
     1.24186739426227379e-10*A5*g7*x6 + 
     1.03337422325237485e-10*A2*g9*x6 - 
     1.94902502779695254e-10*A4*g8*x8 + 
     5.67801881002407209e-11*A*g10*x8 - 
     1.43878618574681894e-10*A3*g9*x10 + 
     9.49021948141154828e-12*g11*x10 - 
     5.31016521055310535e-11*A2*g10*x12 - 
     9.44535164544286831e-12*A*g11*x14 - 
     6.42414962794072381e-13*g12*x16)*xbar8 + 
  eps22*(-5.02476115994067526e-18*A9*g3 + 
     1.11539174575339278e-13*A6*g5 - 
     2.80495886362028979e-13*A3*g7 + 
     1.00479606252282625e-14*g9 - 
     5.40259809426922891e-13*A8*g4*x2 + 
     1.3655596937180689e-11*A5*g6*x2 - 
     8.89567598025371328e-12*A2*g8*x2 - 
     1.14125112021298833e-11*A7*g5*x4 + 
     1.17262639629103968e-10*A4*g7*x4 - 
     2.34248563243440911e-11*A*g9*x4 - 
     5.63758532628371665e-11*A6*g6*x6 + 
     2.64073536988736149e-10*A3*g8*x6 - 
     1.11917659757112919e-11*g10*x6 - 
     1.08869701145208113e-10*A5*g7*x8 + 
     2.19898065169051477e-10*A2*g9*x8 - 
     1.01295754866412102e-10*A4*g8*x10 + 
     7.34969922028006648e-11*A*g10*x10 - 
     4.98170652624686903e-11*A3*g9*x12 + 
     8.31685179548676633e-12*g11*x12 - 
     1.3215860235187506e-11*A2*g10*x14 - 
     1.78195799356499145e-12*A*g11*x16 - 
     9.55378197871579756e-14*g12*x18)*xbar8 + 
  eps25*(7.63469061721341066e-16*A9*g4 - 
     2.97637883379777493e-14*A6*g6 + 
     4.0010726347973971e-14*A3*g8 - 
     1.05022719675942623e-15*g10 + 
     3.58597634877618154e-13*A8*g5*x2 - 
     3.04369064824137294e-12*A5*g7*x2 + 
     1.27425294402431606e-12*A2*g9*x2 + 
     7.27721861674195115e-12*A7*g6*x4 - 
     2.725210757919643e-11*A4*g8*x4 + 
     3.62556538322604991e-12*A*g10*x4 + 
     3.79743691822590252e-11*A6*g7*x6 - 
     6.63955991784961596e-11*A3*g9*x6 + 
     1.89923446418479853e-12*g11*x6 + 
     7.93359123221268897e-11*A5*g8*x8 - 
     6.03976880847451188e-11*A2*g10*x8 + 
     8.03865488933103033e-11*A4*g9*x10 - 
     2.20837266142637015e-11*A*g11*x10 + 
     4.30807444043567794e-11*A3*g10*x12 - 
     2.72927810653135497e-12*g12*x12 + 
     1.24329368880877811e-11*A2*g11*x14 + 
     1.8188249600469056e-12*A*g12*x16 + 
     1.05480254636569226e-13*g13*x18)*xbar8 + 
  eps24*(2.37030116313804979e-19*A10*g3 - 
     1.9533346518480291e-14*A7*g5 + 
     9.29145870030915526e-14*A4*g7 - 
     1.42254376835246143e-14*A*g9 + 
     7.93786579339025037e-14*A9*g4*x2 - 
     3.24770686591320867e-12*A6*g6*x2 + 
     4.51308884050389727e-12*A3*g8*x2 - 
     1.21528532165806402e-13*g10*x2 + 
     2.18599026266802557e-12*A8*g5*x4 - 
     3.81997188670301742e-11*A5*g7*x4 + 
     2.01602969504349973e-11*A2*g9*x4 + 
     1.39805947309574113e-11*A7*g6*x6 - 
     1.20750170632766463e-10*A4*g8*x6 + 
     2.14942707895956151e-11*A*g10*x6 + 
     3.51380103516320996e-11*A6*g7*x8 - 
     1.48670139875840985e-10*A3*g9*x8 + 
     5.8641446418595619e-12*g11*x8 + 
     4.32647592364454306e-11*A5*g8*x10 - 
     8.18363208526036942e-11*A2*g10*x10 + 
     2.90657796422669121e-11*A4*g9*x12 - 
     2.01711868869462944e-11*A*g11*x12 + 
     1.11525616827608266e-11*A3*g10*x14 - 
     1.80514406961528201e-12*g12*x14 + 
     2.4317483218867822e-12*A2*g11*x16 + 
     2.79634654155701318e-13*A*g12*x18 + 
     1.31394550428528868e-14*g13*x20)*xbar8 - 
  2.95801289810004407e-10*eps6*g4*xbar10 + 
  2.94346529368315861e-11*eps9*g5*xbar10 + 
  eps8*(7.69281785172546935e-11*A*g4 + 
     1.07490632635875918e-9*g5*x2)*xbar10 + 
  eps11*(-1.49854878334381416e-11*A*g5 - 
     1.64414869918985145e-10*g6*x2)*xbar10 + 
  eps10*(-1.14623038722347948e-11*A2*g4 - 
     6.72527675714427998e-10*A*g5*x2 - 
     5.64942074025452747e-10*g6*x4)*xbar10 + 
  eps13*(4.55203920804202245e-12*A2*g5 + 
     1.35763920347428776e-10*A*g6*x2 + 
     1.33652228562929386e-10*g7*x4)*xbar10 + 
  eps12*(1.27157831390982766e-12*A3*g4 - 
     2.82877994364105943e-12*g6 + 
     2.44160830279527547e-10*A2*g5*x2 + 
     5.14076796669365287e-10*A*g6*x4 + 
     1.75139799425245342e-10*g7*x6)*xbar10 + 
  eps15*(-1.07685636895144654e-12*A3*g5 + 
     2.70026199694243437e-13*g7 - 
     6.29652746661281415e-11*A2*g6*x2 - 
     1.49092240439933003e-10*A*g7*x4 - 
     5.88096054052166419e-11*g8*x6)*xbar10 + 
  eps14*(-1.16205790093287907e-13*A4*g4 + 
     2.06949189356323779e-12*A*g6 - 
     6.72146134669773312e-11*A3*g5*x2 + 
     1.99437288401862085e-11*g7*x2 - 
     2.61681510848862049e-10*A2*g6*x4 - 
     2.10127602166714473e-10*A*g7*x6 - 
     4.18842380479881739e-11*g8*x8)*xbar10 + 
  eps17*(2.18937302179867743e-13*A4*g5 - 
     2.52743776628905178e-13*A*g7 + 
     2.15933914153368247e-11*A3*g6*x2 - 
     2.33174044228357075e-12*g8*x2 + 
     9.10889047339860176e-11*A2*g7*x4 + 
     8.28793584781457544e-11*A*g8*x6 + 
     1.87814134450040901e-11*g9*x8)*xbar10 + 
  eps16*(9.22277143780367963e-15*A5*g4 - 
     8.60637474674818858e-13*A2*g6 + 
     1.55522012194999734e-11*A4*g5*x2 - 
     2.04738873511014663e-11*A*g7*x2 + 
     9.80212032242431517e-11*A3*g6*x4 - 
     2.27433206141358192e-11*g8*x4 + 
     1.3776069368825939e-10*A2*g7*x6 + 
     6.26447221848720574e-11*A*g8*x8 + 
     8.59289553201749293e-12*g9*x10)*xbar10 + 
  eps19*(-4.01386516110057917e-14*A5*g5 + 
     1.3091834712452921e-13*A2*g7 - 
     6.0989736648541878e-12*A4*g6*x2 + 
     2.86173201964551467e-12*A*g8*x2 - 
     4.02840475527683715e-11*A3*g7*x4 + 
     3.510880308676512e-12*g9*x4 - 
     6.29106001544106061e-11*A2*g8*x6 - 
     3.20688619604414165e-11*A*g9*x8 - 
     4.92343192873666106e-12*g10*x10)*xbar10 + 
  eps18*(-6.56399733698215579e-16*A6*g4 + 
     2.67367086954926804e-13*A3*g6 - 
     2.65773724648037072e-14*g8 - 
     3.1891761064266082e-12*A5*g5*x2 + 
     1.1556733294634019e-11*A2*g7*x2 - 
     3.00891865934477623e-11*A4*g6*x4 + 
     3.00144725725027383e-11*A*g8*x4 - 
     6.52019833501791742e-11*A3*g7*x6 + 
     1.33683467827448483e-11*g9*x6 - 
     5.03812647605675579e-11*A2*g8*x8 - 
     1.54328716110212964e-11*A*g9*x10 - 
     1.5943182436056292e-12*g10*x12)*xbar10 + 
  eps21*(6.81948054057362119e-15*A6*g5 - 
     4.95730577363766302e-14*A3*g7 + 
     2.76104504451824809e-15*g9 + 
     1.50108691344008234e-12*A5*g6*x2 - 
     1.90279881030008194e-12*A2*g8*x2 + 
     1.44066974529341e-11*A4*g7*x4 - 
     5.34733489141200454e-12*A*g9*x4 + 
     3.40794085764526502e-11*A3*g8*x6 - 
     2.64239721989513932e-12*g10*x6 + 
     2.91433177396476386e-11*A2*g9*x8 + 
     9.89175324887470848e-12*A*g10*x10 + 
     1.1292802715742771e-12*g11*x12)*xbar10 + 
  eps20*(4.27976553989265789e-17*A7*g4 - 
     6.89934943139530425e-14*A4*g6 + 
     3.01698740413725238e-14*A*g8 + 
     5.98132658710965791e-13*A6*g5*x2 - 
     4.74116732715012842e-12*A3*g7*x2 + 
     2.78541034399807552e-13*g9*x2 + 
     8.00945275253022047e-12*A5*g6*x4 - 
     2.13863386293836158e-11*A2*g8*x4 + 
     2.48849376049208704e-11*A4*g7*x6 - 
     2.16096622933769274e-11*A*g9*x6 + 
     2.88625342578349044e-11*A3*g8*x8 - 
     5.46942831323172719e-12*g10*x8 + 
     1.47325399109498875e-11*A2*g9*x10 + 
     3.34719700407126729e-12*A*g10*x12 + 
     2.75625052642210253e-13*g11*x14)*xbar10 + 
  eps23*(-1.09246620876972326e-15*A7*g5 + 
     1.5318252699987865e-14*A4*g7 - 
     3.68066535807379783e-15*A*g9 - 
     3.33083243580660176e-13*A6*g6*x2 + 
     9.08215852708082357e-13*A3*g8*x2 - 
     3.4794379491004643e-14*g10*x2 - 
     4.41858871800109535e-12*A5*g7*x4 + 
     4.35208843090363193e-12*A2*g9*x4 - 
     1.47461048791896167e-11*A4*g8*x6 + 
     4.81523154629728511e-12*A*g10*x6 - 
     1.87079103097809155e-11*A3*g9*x8 + 
     1.34299877609914984e-12*g11*x8 - 
     1.04839336902361225e-11*A2*g10*x10 - 
     2.61235659744083548e-12*A*g11*x12 - 
     2.35268338409651259e-13*g12*x14)*xbar10 + 
  eps22*(-2.59530959394910739e-18*A8*g4 + 
     1.56250827735261162e-14*A5*g6 - 
     1.86384253756143204e-14*A2*g8 - 
     1.04716236495971179e-13*A7*g5*x2 + 
     1.57911568324388851e-12*A4*g7*x2 - 
     3.97696537675898684e-13*A*g9*x2 - 
     1.91339334657969896e-12*A6*g6*x4 + 
     1.09023789657915762e-11*A3*g8*x4 - 
     5.31746105151784319e-13*g10*x4 - 
     8.12230075160805238e-12*A5*g7*x6 + 
     1.8624019115509357e-11*A2*g9*x6 - 
     1.31819089102919353e-11*A4*g8*x8 + 
     1.0483480357330514e-11*A*g10*x8 - 
     9.92032656167012319e-12*A3*g9*x10 + 
     1.77778344733062833e-12*g11*x10 - 
     3.70309998579539791e-12*A2*g10*x12 - 
     6.62904547687516285e-13*A*g11*x14 - 
     4.52240509458340008e-14*g12*x16)*xbar10 + 
  eps24*(1.48031029922157368e-19*A9*g4 - 
     3.20974417745883175e-15*A6*g6 + 
     8.30012302305088056e-15*A3*g8 - 
     3.06099316635608155e-16*g10 + 
     1.73552092135428521e-14*A8*g5*x2 - 
     4.52749472047764407e-13*A5*g7*x2 + 
     3.04315328920186898e-13*A2*g9*x2 + 
     4.19658115154116619e-13*A7*g6*x4 - 
     4.45045391274229128e-12*A4*g8*x4 + 
     9.17747333525599134e-13*A*g10*x4 + 
     2.35042272918516199e-12*A6*g7*x6 - 
     1.13580112654765625e-11*A3*g9*x6 + 
     4.96753719459872308e-13*g11*x6 + 
     5.09763825924764429e-12*A5*g8*x8 - 
     1.06143636014337245e-11*A2*g10*x8 + 
     5.28029530303501558e-12*A4*g9*x10 - 
     3.94623004405029036e-12*A*g11*x10 + 
     2.86834044949979105e-12*A3*g10*x12 - 
     4.9280225038198577e-13*g12*x12 + 
     8.34612464392658347e-13*A2*g11*x14 + 
     1.22661895396398397e-13*A*g12*x16 + 
     7.12837794898714158e-15*g13*x18)*xbar10 + 
  1.69722051530330397e-12*eps8*g5*xbar12 - 
  2.90595190793452012e-13*eps11*g6*xbar12 + 
  eps10*(-5.54575148020670988e-13*A*g5 - 
     1.29008964169185665e-11*g6*x2)*xbar12 + 
  eps13*(1.78798720202615632e-13*A*g6 + 
     2.57210159823889116e-12*g7*x2)*xbar12 + 
  eps12*(1.00869657097464141e-13*A2*g5 + 
     9.47632013657176953e-12*A*g6*x2 + 
     1.00368310409322369e-11*g7*x4)*xbar12 + 
  eps15*(-6.39010493062016058e-14*A2*g6 - 
     2.40693363499189255e-12*A*g7*x2 - 
     2.87715768832048683e-12*g8*x4)*xbar12 + 
  eps14*(-1.33953977785016062e-14*A3*g5 + 
     3.84980892713537606e-14*g7 - 
     3.94928486633783273e-12*A2*g6*x2 - 
     1.02511581325767213e-11*A*g7*x4 - 
     4.17899415533904787e-12*g8*x6)*xbar12 + 
  eps17*(1.73998403455957848e-14*A3*g6 - 
     4.62636803886378434e-15*g8 + 
     1.24741423146112554e-12*A2*g7*x2 + 
     3.52693455958173369e-12*A*g8*x4 + 
     1.62821302569789988e-12*g9*x6)*xbar12 + 
  eps16*(1.44440682820300384e-15*A4*g5 - 
     3.24022688540454265e-14*A*g7 + 
     1.22741801273679764e-12*A3*g6*x2 - 
     3.84061473377336244e-13*g8*x2 + 
     5.77793844380739442e-12*A2*g7*x4 + 
     5.47447616200335818e-12*A*g8*x6 + 
     1.26471026695269685e-12*g9*x8)*xbar12 + 
  eps19*(-4.00106875821619636e-15*A4*g6 + 
     4.84590692629411758e-15*A*g8 - 
     4.72763385349764825e-13*A3*g7*x2 + 
     5.32739458894566085e-14*g9*x2 - 
     2.34696797887097322e-12*A2*g8*x4 - 
     2.47171834511294782e-12*A*g9*x6 - 
     6.39422064458918014e-13*g10*x8)*xbar12 + 
  eps18*(-1.33739060725578634e-16*A5*g5 + 
     1.52467406929696226e-14*A2*g7 - 
     3.16506850006518787e-13*A4*g6*x2 + 
     4.36808508700696498e-13*A*g8*x2 - 
     2.37192884056053272e-12*A3*g7*x4 + 
     5.73811638250132219e-13*g9*x4 - 
     3.88549767072102607e-12*A2*g8*x6 - 
     2.02801867312185292e-12*A*g9*x8 - 
     3.15279597165500734e-13*g10*x10)*xbar12 + 
  eps21*(8.18212199689786031e-16*A5*g6 - 
     2.77850155214879458e-15*A2*g8 + 
     1.46242985972961813e-13*A4*g7*x2 - 
     7.13099260240197077e-14*A*g9*x2 + 
     1.12245977611596647e-12*A3*g8*x4 - 
     1.01453307525349774e-13*g10*x4 + 
     2.0091654459041284e-12*A2*g9*x6 + 
     1.1599532499763162e-12*A*g10*x8 + 
     1.99618834474701725e-13*g11*x10)*xbar12 + 
  eps20*(1.10024592611551253e-17*A6*g5 - 
     5.28888834827941102e-15*A3*g7 + 
     5.47612344010328206e-16*g9 + 
     7.15818767506558215e-14*A5*g6*x2 - 
     2.70559177977642949e-13*A2*g8*x2 + 
     7.91459587667159745e-13*A4*g7*x4 - 
     8.20326742698849044e-13*A*g9*x4 + 
     1.97757621860341566e-12*A3*g8*x6 - 
     4.20357694313370931e-13*g10*x6 + 
     1.73888738668498436e-12*A2*g9*x8 + 
     5.99434847996843799e-13*A*g10*x10 + 
     6.90257861666477261e-14*g11*x12)*xbar12 + 
  eps23*(-1.53361446306486824e-16*A6*g6 + 
     1.15413009990730513e-15*A3*g8 - 
     6.64552675715054054e-17*g10 - 
     3.91255027981294566e-14*A5*g7*x2 + 
     5.1355650677744863e-14*A2*g9*x2 - 
     4.31547003728676749e-13*A4*g8*x4 + 
     1.65659339836968041e-13*A*g10*x4 - 
     1.15990222960052123e-12*A3*g9*x6 + 
     9.2907324019893464e-14*g11*x6 - 
     1.11543597380987059e-12*A2*g10*x8 - 
     4.21873583398987557e-13*A*g11*x10 - 
     5.3236985802259894e-14*g12*x12)*xbar12 + 
  eps22*(-8.22795182119939417e-19*A7*g5 + 
     1.50770677982272589e-15*A4*g7 - 
     6.83286257353858413e-16*A*g9 - 
     1.46797411254395335e-14*A6*g6*x2 + 
     1.20844830087105867e-13*A3*g8*x2 - 
     7.35959455974364916e-15*g10*x2 - 
     2.27486573977748777e-13*A5*g7*x4 + 
     6.29215515561348402e-13*A2*g9*x4 - 
     8.07221681057317846e-13*A4*g8*x6 + 
     7.24935763935350501e-13*A*g10*x6 - 
     1.05726036679409544e-12*A3*g9*x8 + 
     2.06916186826177124e-13*g11*x8 - 
     6.03469894029266334e-13*A2*g10*x10 - 
     1.52010427845838981e-13*A*g11*x12 - 
     1.3774189023674826e-14*g12*x14)*xbar12 - 
  1.06551186196798794e-14*eps10*g6*xbar14 + 
  2.96371424137457707e-15*eps13*g7*xbar14 + 
  eps12*(4.1883104771160436e-15*A*g6 + 
     1.55454784378046993e-13*g7*x2)*xbar14 + 
  eps15*(-2.14017433818550597e-15*A*g7 - 
     3.90198867402243257e-14*g8*x2)*xbar14 + 
  eps14*(-8.99454744512618591e-16*A2*g6 - 
     1.30968415155813316e-13*A*g7*x2 - 
     1.70308449198607365e-13*g8*x4)*xbar14 + 
  eps17*(8.79886328932693487e-16*A2*g7 + 
     4.07855521267175371e-14*A*g8*x2 + 
     5.8024185244265147e-14*g9*x4)*xbar14 + 
  eps16*(1.39116436986363771e-16*A3*g6 - 
     5.17467765013076258e-16*g8 + 
     6.15890327064823114e-14*A2*g7*x2 + 
     1.92792938842998867e-13*A*g8*x4 + 
     9.24186997248047774e-14*g9*x6)*xbar14 + 
  eps19*(-2.71043966692226229e-16*A3*g7 + 
     7.62461032065408102e-17*g9 - 
     2.33529672481396755e-14*A2*g8*x2 - 
     7.75214641947405959e-14*A*g9*x4 - 
     4.13090807033447583e-14*g10*x6)*xbar14 + 
  eps18*(-1.72867499565968957e-17*A4*g6 + 
     4.9217313236453732e-16*A*g8 - 
     2.13260411115595534e-14*A3*g7*x2 + 
     7.01612347492652808e-15*g9*x2 - 
     1.19175537714779419e-13*A2*g8*x4 - 
     1.31262296085466213e-13*A*g9*x6 - 
     3.47201752597269316e-14*g10*x8)*xbar14 + 
  eps21*(6.95527507361396729e-17*A4*g7 - 
     8.83062918064961145e-17*A*g9 + 
     9.69147997163643325e-15*A3*g8*x2 - 
     1.13725225229483657e-15*g10*x2 + 
     5.58135479458087437e-14*A2*g9*x4 + 
     6.72233462597832795e-14*A*g10*x6 + 
     1.96552278109310559e-14*g11*x8)*xbar14 + 
  eps20*(1.82877741622247625e-18*A5*g6 - 
     2.58382411798017243e-16*A2*g8 + 
     6.06418528687686859e-15*A4*g7*x2 - 
     8.75387708088179125e-15*A*g9*x2 + 
     5.32096477905912181e-14*A3*g8*x4 - 
     1.33872464203048517e-14*g10*x4 + 
     1.00297233267464412e-13*A2*g9*x6 + 
     5.94498264966954685e-14*A*g10*x8 + 
     1.03825306645524673e-14*g11*x10)*xbar14 + 
  eps22*(-1.70673284728434989e-19*A6*g6 + 
     9.89594259148796609e-17*A3*g8 - 
     1.06628779076423243e-17*g10 - 
     1.49959038464702115e-15*A5*g7*x2 + 
     5.90194543867266504e-15*A2*g9*x2 - 
     1.91794637397715716e-14*A4*g8*x4 + 
     2.06113281490066586e-14*A*g10*x4 - 
     5.46439515853494756e-14*A3*g9*x6 + 
     1.2014981866293751e-14*g11*x6 - 
     5.41656899895825054e-14*A2*g10*x8 - 
     2.08477807786448153e-14*A*g11*x10 - 
     2.65822325621808403e-15*g12*x12)*xbar14 + 
  7.1230636127202905e-17*eps12*g7*xbar16 - 
  3.09644400991606704e-17*eps15*g8*xbar16 + 
  eps14*(-3.27091744222075652e-17*A*g7 - 
     1.87737117146802168e-15*g8*x2)*xbar16 + 
  eps17*(2.56820081466394239e-17*A*g8 + 
     5.77970340504678044e-16*g9*x2)*xbar16 + 
  eps16*(8.09908041993038944e-18*A2*g7 + 
     1.78317218006896548e-15*A*g8*x2 + 
     2.78832594974046941e-15*g9*x4)*xbar16 + 
  eps19*(-1.19399144787300174e-17*A2*g8 - 
     6.67124890749264713e-16*A*g9*x2 - 
     1.11157044100254144e-15*g10*x4)*xbar16 + 
  eps18*(-1.42980374801906325e-18*A3*g7 + 
     6.88701015696998715e-18*g9 - 
     9.33716646729179203e-16*A2*g8*x2 - 
     3.46339329805719736e-15*A*g9*x4 - 
     1.92478458861582261e-15*g10*x6)*xbar16 + 
  eps21*(4.10485665658066575e-18*A3*g8 - 
     1.21866664028124679e-18*g10 + 
     4.18129897968412552e-16*A2*g9*x2 + 
     1.6073247933349449e-15*A*g10*x4 + 
     9.77340143638583022e-16*g11*x6)*xbar16 + 
  eps20*(2.01155912712848607e-19*A4*g7 - 
     7.30080971811155416e-18*A*g9 + 
     3.56400456280639278e-16*A3*g8*x2 - 
     1.2296396496067157e-16*g10*x2 + 
     2.32934306679785846e-15*A2*g9*x4 + 
     2.9459266889986156e-15*A*g10*x6 + 
     8.83078646848089353e-16*g11*x8)*xbar16 - 
  4.98845119121947873e-19*eps14*g8*xbar18 + 
  3.29589363262920182e-19*eps17*g9*xbar18 + 
  eps16*(2.61992075966627237e-19*A*g8 + 
     2.27018895731900669e-17*g9*x2)*xbar18 + 
  eps19*(-3.0880236512109574e-19*A*g9 - 
     8.39862229741645369e-18*g10*x2)*xbar18 + 
  eps18*(-7.34772661645623638e-20*A2*g8 - 
     2.39905600259048083e-17*A*g9*x2 - 
     4.43602818448693464e-17*g10*x4)*xbar18 + 
  eps20*(1.45788093126933163e-20*A3*g8 - 
     9.09208792406558331e-20*g10 + 
     1.38400818990040416e-17*A2*g9*x2 + 
     5.99620676416795809e-17*A*g10*x4 + 
     3.8181946939882766e-17*g11*x6)*xbar18 + 
  3.62101682176476165e-21*eps16*g9*xbar20 - 
  3.5603575879202663e-21*eps19*g10*xbar20 + 
  eps18*(-2.14042456564486975e-21*A*g9 - 
     2.74739666662032349e-19*g10*x2)*xbar20 - 
  2.70441159051273525e-23*eps18*g10*xbar22;
}
#endif
